Class: Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByMatchingInfoTypes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

AdjustmentRule condition for matching infoTypes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2AdjustByMatchingInfoTypes

Returns a new instance of GooglePrivacyDlpV2AdjustByMatchingInfoTypes.



235
236
237
# File 'lib/google/apis/dlp_v2/classes.rb', line 235

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>

Sensitive Data Protection adjusts the likelihood of a finding if that finding also matches one of these infoTypes. For example, you can create a rule to adjust the likelihood of a PHONE_NUMBER finding if the string is found within a document that is classified as DOCUMENT_TYPE/HR/RESUME. To configure this, set PHONE_NUMBER in InspectionRuleSet.info_types. Add an adjustment_rule with an adjust_by_matching_info_types.info_types that contains DOCUMENT_TYPE/HR/RESUME. In this case, the likelihood of the PHONE_NUMBER finding is adjusted, but the likelihood of the DOCUMENT_TYPE/HR/ RESUME finding is not. Corresponds to the JSON property infoTypes



218
219
220
# File 'lib/google/apis/dlp_v2/classes.rb', line 218

def info_types
  @info_types
end

#matching_typeString

How the adjustment rule is applied. Only MATCHING_TYPE_PARTIAL_MATCH is supported: - Partial match: adjusts the findings of infoTypes specified in the inspection rule when they have a nonempty intersection with a finding of an infoType specified in this adjustment rule. Corresponds to the JSON property matchingType

Returns:

  • (String)


226
227
228
# File 'lib/google/apis/dlp_v2/classes.rb', line 226

def matching_type
  @matching_type
end

#min_likelihoodString

Required. Minimum likelihood of the adjust_by_matching_info_types.info_types finding. If the likelihood is lower than this value, Sensitive Data Protection doesn't adjust the likelihood of the InspectionRuleSet.info_types finding. Corresponds to the JSON property minLikelihood

Returns:

  • (String)


233
234
235
# File 'lib/google/apis/dlp_v2/classes.rb', line 233

def min_likelihood
  @min_likelihood
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



240
241
242
243
244
# File 'lib/google/apis/dlp_v2/classes.rb', line 240

def update!(**args)
  @info_types = args[:info_types] if args.key?(:info_types)
  @matching_type = args[:matching_type] if args.key?(:matching_type)
  @min_likelihood = args[:min_likelihood] if args.key?(:min_likelihood)
end