Class: Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Rule that specifies conditions when a certain infoType's finding details should be adjusted.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2AdjustmentRule

Returns a new instance of GooglePrivacyDlpV2AdjustmentRule.



270
271
272
# File 'lib/google/apis/dlp_v2/classes.rb', line 270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjust_by_image_findingsGoogle::Apis::DlpV2::GooglePrivacyDlpV2AdjustByImageFindings

AdjustmentRule condition for image findings. This rule is silently ignored if the content being inspected is not an image. Corresponds to the JSON property adjustByImageFindings



257
258
259
# File 'lib/google/apis/dlp_v2/classes.rb', line 257

def adjust_by_image_findings
  @adjust_by_image_findings
end

#adjust_by_matching_info_typesGoogle::Apis::DlpV2::GooglePrivacyDlpV2AdjustByMatchingInfoTypes

AdjustmentRule condition for matching infoTypes. Corresponds to the JSON property adjustByMatchingInfoTypes



262
263
264
# File 'lib/google/apis/dlp_v2/classes.rb', line 262

def adjust_by_matching_info_types
  @adjust_by_matching_info_types
end

#likelihood_adjustmentGoogle::Apis::DlpV2::GooglePrivacyDlpV2LikelihoodAdjustment

Message for specifying an adjustment to the likelihood of a finding as part of a detection rule. Corresponds to the JSON property likelihoodAdjustment



268
269
270
# File 'lib/google/apis/dlp_v2/classes.rb', line 268

def likelihood_adjustment
  @likelihood_adjustment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



275
276
277
278
279
# File 'lib/google/apis/dlp_v2/classes.rb', line 275

def update!(**args)
  @adjust_by_image_findings = args[:adjust_by_image_findings] if args.key?(:adjust_by_image_findings)
  @adjust_by_matching_info_types = args[:adjust_by_matching_info_types] if args.key?(:adjust_by_matching_info_types)
  @likelihood_adjustment = args[:likelihood_adjustment] if args.key?(:likelihood_adjustment)
end