Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Options defining BigQuery table and row identifiers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2BigQueryOptions

Returns a new instance of GooglePrivacyDlpV2BigQueryOptions.



778
779
780
# File 'lib/google/apis/dlp_v2/classes.rb', line 778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_fieldsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>

References to fields excluded from scanning. This allows you to skip inspection of entire columns which you know have no findings. When inspecting a table, we recommend that you inspect all columns. Otherwise, findings might be affected because hints from excluded columns will not be used. Corresponds to the JSON property excludedFields



728
729
730
# File 'lib/google/apis/dlp_v2/classes.rb', line 728

def excluded_fields
  @excluded_fields
end

#identifying_fieldsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>

Table fields that may uniquely identify a row within the table. When actions. saveFindings.outputConfig.table is specified, the values of columns specified here are available in the output table under location.content_locations. record_location.record_key.id_values. Nested fields such as person.birthdate. year are allowed. Corresponds to the JSON property identifyingFields



737
738
739
# File 'lib/google/apis/dlp_v2/classes.rb', line 737

def identifying_fields
  @identifying_fields
end

#included_fieldsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>

Limit scanning only to these fields. When inspecting a table, we recommend that you inspect all columns. Otherwise, findings might be affected because hints from excluded columns will not be used. Corresponds to the JSON property includedFields



744
745
746
# File 'lib/google/apis/dlp_v2/classes.rb', line 744

def included_fields
  @included_fields
end

#rows_limitFixnum

Max number of rows to scan. If the table has more rows than this value, the rest of the rows are omitted. If not set, or if set to 0, all rows will be scanned. Only one of rows_limit and rows_limit_percent can be specified. Cannot be used in conjunction with TimespanConfig. Corresponds to the JSON property rowsLimit

Returns:

  • (Fixnum)


752
753
754
# File 'lib/google/apis/dlp_v2/classes.rb', line 752

def rows_limit
  @rows_limit
end

#rows_limit_percentFixnum

Max percentage of rows to scan. The rest are omitted. The number of rows scanned is rounded down. Must be between 0 and 100, inclusively. Both 0 and 100 means no limit. Defaults to 0. Only one of rows_limit and rows_limit_percent can be specified. Cannot be used in conjunction with TimespanConfig. Caution: A known issue is causing the rowsLimitPercent field to behave unexpectedly. We recommend using rowsLimit instead. Corresponds to the JSON property rowsLimitPercent

Returns:

  • (Fixnum)


764
765
766
# File 'lib/google/apis/dlp_v2/classes.rb', line 764

def rows_limit_percent
  @rows_limit_percent
end

#sample_methodString

How to sample the data. Corresponds to the JSON property sampleMethod

Returns:

  • (String)


769
770
771
# File 'lib/google/apis/dlp_v2/classes.rb', line 769

def sample_method
  @sample_method
end

#table_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property tableReference



776
777
778
# File 'lib/google/apis/dlp_v2/classes.rb', line 776

def table_reference
  @table_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



783
784
785
786
787
788
789
790
791
# File 'lib/google/apis/dlp_v2/classes.rb', line 783

def update!(**args)
  @excluded_fields = args[:excluded_fields] if args.key?(:excluded_fields)
  @identifying_fields = args[:identifying_fields] if args.key?(:identifying_fields)
  @included_fields = args[:included_fields] if args.key?(:included_fields)
  @rows_limit = args[:rows_limit] if args.key?(:rows_limit)
  @rows_limit_percent = args[:rows_limit_percent] if args.key?(:rows_limit_percent)
  @sample_method = args[:sample_method] if args.key?(:sample_method)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
end