Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryRegex

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A pattern to match against one or more tables, datasets, or projects that contain BigQuery tables. At least one pattern must be specified. Regular expressions use RE2 syntax; a guide can be found under the google/re2 repository on GitHub.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2BigQueryRegex

Returns a new instance of GooglePrivacyDlpV2BigQueryRegex.



856
857
858
# File 'lib/google/apis/dlp_v2/classes.rb', line 856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataset_id_regexString

If unset, this property matches all datasets. Corresponds to the JSON property datasetIdRegex

Returns:

  • (String)


843
844
845
# File 'lib/google/apis/dlp_v2/classes.rb', line 843

def dataset_id_regex
  @dataset_id_regex
end

#project_id_regexString

For organizations, if unset, will match all projects. Has no effect for data profile configurations created within a project. Corresponds to the JSON property projectIdRegex

Returns:

  • (String)


849
850
851
# File 'lib/google/apis/dlp_v2/classes.rb', line 849

def project_id_regex
  @project_id_regex
end

#table_id_regexString

If unset, this property matches all tables. Corresponds to the JSON property tableIdRegex

Returns:

  • (String)


854
855
856
# File 'lib/google/apis/dlp_v2/classes.rb', line 854

def table_id_regex
  @table_id_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



861
862
863
864
865
# File 'lib/google/apis/dlp_v2/classes.rb', line 861

def update!(**args)
  @dataset_id_regex = args[:dataset_id_regex] if args.key?(:dataset_id_regex)
  @project_id_regex = args[:project_id_regex] if args.key?(:project_id_regex)
  @table_id_regex = args[:table_id_regex] if args.key?(:table_id_regex)
end