Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Bucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Bucket is represented as a range, along with replacement values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Bucket

Returns a new instance of GooglePrivacyDlpV2Bucket.



1027
1028
1029
# File 'lib/google/apis/dlp_v2/classes.rb', line 1027

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maxGoogle::Apis::DlpV2::GooglePrivacyDlpV2Value

Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data. Corresponds to the JSON property max



1007
1008
1009
# File 'lib/google/apis/dlp_v2/classes.rb', line 1007

def max
  @max
end

#minGoogle::Apis::DlpV2::GooglePrivacyDlpV2Value

Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data. Corresponds to the JSON property min



1016
1017
1018
# File 'lib/google/apis/dlp_v2/classes.rb', line 1016

def min
  @min
end

#replacement_valueGoogle::Apis::DlpV2::GooglePrivacyDlpV2Value

Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data. Corresponds to the JSON property replacementValue



1025
1026
1027
# File 'lib/google/apis/dlp_v2/classes.rb', line 1025

def replacement_value
  @replacement_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1032
1033
1034
1035
1036
# File 'lib/google/apis/dlp_v2/classes.rb', line 1032

def update!(**args)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @replacement_value = args[:replacement_value] if args.key?(:replacement_value)
end