Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BucketingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Generalization function that buckets values based on ranges. The ranges and replacement values are dynamically provided by the user for custom behavior, such as 1-30 -> LOW, 31-65 -> MEDIUM, 66-100 -> HIGH. This can be used on data of type: number, long, string, timestamp. If the bound Value type differs from the type of data being transformed, we will first attempt converting the type of the data to be transformed to match the type of the bound before comparing. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-bucketing to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2BucketingConfig

Returns a new instance of GooglePrivacyDlpV2BucketingConfig.



1017
1018
1019
# File 'lib/google/apis/dlp_v2/classes.rb', line 1017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Bucket>

Set of buckets. Ranges must be non-overlapping. Corresponds to the JSON property buckets



1015
1016
1017
# File 'lib/google/apis/dlp_v2/classes.rb', line 1015

def buckets
  @buckets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1022
1023
1024
# File 'lib/google/apis/dlp_v2/classes.rb', line 1022

def update!(**args)
  @buckets = args[:buckets] if args.key?(:buckets)
end