Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Compute numerical stats over an individual column, including number of distinct values and value count distribution.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CategoricalStatsConfig
constructor
A new instance of GooglePrivacyDlpV2CategoricalStatsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CategoricalStatsConfig
Returns a new instance of GooglePrivacyDlpV2CategoricalStatsConfig.
1114 1115 1116 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
1112 1113 1114 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1112 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1119 1120 1121 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1119 def update!(**args) @field = args[:field] if args.key?(:field) end |