Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsHistogramBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Histogram of value frequencies in the column.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CategoricalStatsHistogramBucket

Returns a new instance of GooglePrivacyDlpV2CategoricalStatsHistogramBucket.



1103
1104
1105
# File 'lib/google/apis/dlp_v2/classes.rb', line 1103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_sizeFixnum

Total number of values in this bucket. Corresponds to the JSON property bucketSize

Returns:

  • (Fixnum)


1080
1081
1082
# File 'lib/google/apis/dlp_v2/classes.rb', line 1080

def bucket_size
  @bucket_size
end

#bucket_value_countFixnum

Total number of distinct values in this bucket. Corresponds to the JSON property bucketValueCount

Returns:

  • (Fixnum)


1085
1086
1087
# File 'lib/google/apis/dlp_v2/classes.rb', line 1085

def bucket_value_count
  @bucket_value_count
end

#bucket_valuesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ValueFrequency>

Sample of value frequencies in this bucket. The total number of values returned per bucket is capped at 20. Corresponds to the JSON property bucketValues



1091
1092
1093
# File 'lib/google/apis/dlp_v2/classes.rb', line 1091

def bucket_values
  @bucket_values
end

#value_frequency_lower_boundFixnum

Lower bound on the value frequency of the values in this bucket. Corresponds to the JSON property valueFrequencyLowerBound

Returns:

  • (Fixnum)


1096
1097
1098
# File 'lib/google/apis/dlp_v2/classes.rb', line 1096

def value_frequency_lower_bound
  @value_frequency_lower_bound
end

#value_frequency_upper_boundFixnum

Upper bound on the value frequency of the values in this bucket. Corresponds to the JSON property valueFrequencyUpperBound

Returns:

  • (Fixnum)


1101
1102
1103
# File 'lib/google/apis/dlp_v2/classes.rb', line 1101

def value_frequency_upper_bound
  @value_frequency_upper_bound
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1108
1109
1110
1111
1112
1113
1114
# File 'lib/google/apis/dlp_v2/classes.rb', line 1108

def update!(**args)
  @bucket_size = args[:bucket_size] if args.key?(:bucket_size)
  @bucket_value_count = args[:bucket_value_count] if args.key?(:bucket_value_count)
  @bucket_values = args[:bucket_values] if args.key?(:bucket_values)
  @value_frequency_lower_bound = args[:value_frequency_lower_bound] if args.key?(:value_frequency_lower_bound)
  @value_frequency_upper_bound = args[:value_frequency_upper_bound] if args.key?(:value_frequency_upper_bound)
end