Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Cloud SQL tables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2CloudSqlDiscoveryTarget.



1303
1304
1305
# File 'lib/google/apis/dlp_v2/classes.rb', line 1303

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlConditions

Requirements that must be true before a table is profiled for the first time. Corresponds to the JSON property conditions



1283
1284
1285
# File 'lib/google/apis/dlp_v2/classes.rb', line 1283

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



1288
1289
1290
# File 'lib/google/apis/dlp_v2/classes.rb', line 1288

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name. Corresponds to the JSON property filter



1295
1296
1297
# File 'lib/google/apis/dlp_v2/classes.rb', line 1295

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence

How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



1301
1302
1303
# File 'lib/google/apis/dlp_v2/classes.rb', line 1301

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1308
1309
1310
1311
1312
1313
# File 'lib/google/apis/dlp_v2/classes.rb', line 1308

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end