Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Color

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Represents a color in the RGB color space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Color

Returns a new instance of GooglePrivacyDlpV2Color.



1618
1619
1620
# File 'lib/google/apis/dlp_v2/classes.rb', line 1618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blueFloat

The amount of blue in the color as a value in the interval [0, 1]. Corresponds to the JSON property blue

Returns:

  • (Float)


1606
1607
1608
# File 'lib/google/apis/dlp_v2/classes.rb', line 1606

def blue
  @blue
end

#greenFloat

The amount of green in the color as a value in the interval [0, 1]. Corresponds to the JSON property green

Returns:

  • (Float)


1611
1612
1613
# File 'lib/google/apis/dlp_v2/classes.rb', line 1611

def green
  @green
end

#redFloat

The amount of red in the color as a value in the interval [0, 1]. Corresponds to the JSON property red

Returns:

  • (Float)


1616
1617
1618
# File 'lib/google/apis/dlp_v2/classes.rb', line 1616

def red
  @red
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1623
1624
1625
1626
1627
# File 'lib/google/apis/dlp_v2/classes.rb', line 1623

def update!(**args)
  @blue = args[:blue] if args.key?(:blue)
  @green = args[:green] if args.key?(:green)
  @red = args[:red] if args.key?(:red)
end