Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Container

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Represents a container that may contain DLP findings. Examples of a container include a file, table, or database record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Container

Returns a new instance of GooglePrivacyDlpV2Container.



1975
1976
1977
# File 'lib/google/apis/dlp_v2/classes.rb', line 1975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#full_pathString

A string representation of the full container name. Examples: - BigQuery: ' Project:DataSetId.TableId' - Cloud Storage: 'gs://Bucket/folders/filename.txt' Corresponds to the JSON property fullPath

Returns:

  • (String)


1934
1935
1936
# File 'lib/google/apis/dlp_v2/classes.rb', line 1934

def full_path
  @full_path
end

#project_idString

Project where the finding was found. Can be different from the project that owns the finding. Corresponds to the JSON property projectId

Returns:

  • (String)


1940
1941
1942
# File 'lib/google/apis/dlp_v2/classes.rb', line 1940

def project_id
  @project_id
end

#relative_pathString

The rest of the path after the root. Examples: - For BigQuery table project_id:dataset_id.table_id, the relative path is table_id - For Cloud Storage file gs://bucket/folder/filename.txt, the relative path is folder/ filename.txt Corresponds to the JSON property relativePath

Returns:

  • (String)


1948
1949
1950
# File 'lib/google/apis/dlp_v2/classes.rb', line 1948

def relative_path
  @relative_path
end

#root_pathString

The root of the container. Examples: - For BigQuery table project_id: dataset_id.table_id, the root is dataset_id - For Cloud Storage file gs:// bucket/folder/filename.txt, the root is gs://bucket Corresponds to the JSON property rootPath

Returns:

  • (String)


1955
1956
1957
# File 'lib/google/apis/dlp_v2/classes.rb', line 1955

def root_path
  @root_path
end

#typeString

Container type, for example BigQuery or Cloud Storage. Corresponds to the JSON property type

Returns:

  • (String)


1960
1961
1962
# File 'lib/google/apis/dlp_v2/classes.rb', line 1960

def type
  @type
end

#update_timeString

Findings container modification timestamp, if applicable. For Cloud Storage, this field contains the last file modification timestamp. For a BigQuery table, this field contains the last_modified_time property. For Datastore, this field isn't populated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/dlp_v2/classes.rb', line 1968

def update_time
  @update_time
end

#versionString

Findings container version, if available ("generation" for Cloud Storage). Corresponds to the JSON property version

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/dlp_v2/classes.rb', line 1973

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1980
1981
1982
1983
1984
1985
1986
1987
1988
# File 'lib/google/apis/dlp_v2/classes.rb', line 1980

def update!(**args)
  @full_path = args[:full_path] if args.key?(:full_path)
  @project_id = args[:project_id] if args.key?(:project_id)
  @relative_path = args[:relative_path] if args.key?(:relative_path)
  @root_path = args[:root_path] if args.key?(:root_path)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end