Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Conversation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Complete conversation or slice of a conversation. It is assumed that all included messages are contiguous and ordered in chronological order.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Conversation

Returns a new instance of GooglePrivacyDlpV2Conversation.



2255
2256
2257
# File 'lib/google/apis/dlp_v2/classes.rb', line 2255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#messagesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationMessage>

Messages exchanged within this conversation. The maximum number of messages allowed is 50k. The order of the messages is assumed to be chronological and will be used to index findings in the response. Corresponds to the JSON property messages



2253
2254
2255
# File 'lib/google/apis/dlp_v2/classes.rb', line 2253

def messages
  @messages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2260
2261
2262
# File 'lib/google/apis/dlp_v2/classes.rb', line 2260

def update!(**args)
  @messages = args[:messages] if args.key?(:messages)
end