Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Location within a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ConversationLocation

Returns a new instance of GooglePrivacyDlpV2ConversationLocation.



2173
2174
2175
# File 'lib/google/apis/dlp_v2/classes.rb', line 2173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_messagesGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllMessages

If set, indicates that the finding applies to all messages in the conversation. Corresponds to the JSON property allMessages



2166
2167
2168
# File 'lib/google/apis/dlp_v2/classes.rb', line 2166

def all_messages
  @all_messages
end

#message_indexFixnum

Matches an index of a message in the conversation provided in the request. Corresponds to the JSON property messageIndex

Returns:

  • (Fixnum)


2171
2172
2173
# File 'lib/google/apis/dlp_v2/classes.rb', line 2171

def message_index
  @message_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2178
2179
2180
2181
# File 'lib/google/apis/dlp_v2/classes.rb', line 2178

def update!(**args)
  @all_messages = args[:all_messages] if args.key?(:all_messages)
  @message_index = args[:message_index] if args.key?(:message_index)
end