Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateContentPolicyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateContentPolicy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateContentPolicyRequest

Returns a new instance of GooglePrivacyDlpV2CreateContentPolicyRequest.



2359
2360
2361
# File 'lib/google/apis/dlp_v2/classes.rb', line 2359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_policyGoogle::Apis::DlpV2::GooglePrivacyDlpV2ContentPolicy

A policy to apply to content based on its inspection findings. Corresponds to the JSON property contentPolicy



2349
2350
2351
# File 'lib/google/apis/dlp_v2/classes.rb', line 2349

def content_policy
  @content_policy
end

#content_policy_idString

Optional. The content policy ID can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\ d-_]+. The maximum length is 100 characters. If empty, the system will generate a random id. Corresponds to the JSON property contentPolicyId

Returns:

  • (String)


2357
2358
2359
# File 'lib/google/apis/dlp_v2/classes.rb', line 2357

def content_policy_id
  @content_policy_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2364
2365
2366
2367
# File 'lib/google/apis/dlp_v2/classes.rb', line 2364

def update!(**args)
  @content_policy = args[:content_policy] if args.key?(:content_policy)
  @content_policy_id = args[:content_policy_id] if args.key?(:content_policy_id)
end