Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateDeidentifyTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateDeidentifyTemplate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateDeidentifyTemplateRequest

Returns a new instance of GooglePrivacyDlpV2CreateDeidentifyTemplateRequest.



2080
2081
2082
# File 'lib/google/apis/dlp_v2/classes.rb', line 2080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deidentify_templateGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyTemplate

DeidentifyTemplates contains instructions on how to de-identify content. See https://cloud.google.com/sensitive-data-protection/docs/concepts-templates to learn more. Corresponds to the JSON property deidentifyTemplate



2065
2066
2067
# File 'lib/google/apis/dlp_v2/classes.rb', line 2065

def deidentify_template
  @deidentify_template
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


2070
2071
2072
# File 'lib/google/apis/dlp_v2/classes.rb', line 2070

def location_id
  @location_id
end

#template_idString

The template id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property templateId

Returns:

  • (String)


2078
2079
2080
# File 'lib/google/apis/dlp_v2/classes.rb', line 2078

def template_id
  @template_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2085
2086
2087
2088
2089
# File 'lib/google/apis/dlp_v2/classes.rb', line 2085

def update!(**args)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @location_id = args[:location_id] if args.key?(:location_id)
  @template_id = args[:template_id] if args.key?(:template_id)
end