Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateJobTriggerRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateJobTrigger.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateJobTriggerRequest

Returns a new instance of GooglePrivacyDlpV2CreateJobTriggerRequest.



2540
2541
2542
# File 'lib/google/apis/dlp_v2/classes.rb', line 2540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_triggerGoogle::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger

Contains a configuration to make API calls on a repeating basis. See https:// cloud.google.com/sensitive-data-protection/docs/concepts-job-triggers to learn more. Corresponds to the JSON property jobTrigger



2525
2526
2527
# File 'lib/google/apis/dlp_v2/classes.rb', line 2525

def job_trigger
  @job_trigger
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


2530
2531
2532
# File 'lib/google/apis/dlp_v2/classes.rb', line 2530

def location_id
  @location_id
end

#trigger_idString

The trigger id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property triggerId

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/dlp_v2/classes.rb', line 2538

def trigger_id
  @trigger_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2545
2546
2547
2548
2549
# File 'lib/google/apis/dlp_v2/classes.rb', line 2545

def update!(**args)
  @job_trigger = args[:job_trigger] if args.key?(:job_trigger)
  @location_id = args[:location_id] if args.key?(:location_id)
  @trigger_id = args[:trigger_id] if args.key?(:trigger_id)
end