Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Location of a data profile finding within a resource.
Instance Attribute Summary collapse
-
#container_name ⇒ String
Name of the container where the finding is located.
-
#data_profile_finding_record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
Location of a finding within a resource that produces a table data profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingLocation
constructor
A new instance of GooglePrivacyDlpV2DataProfileFindingLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingLocation
Returns a new instance of GooglePrivacyDlpV2DataProfileFindingLocation.
3112 3113 3114 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_name ⇒ String
Name of the container where the finding is located. The top-level name is the
source file name or table name. Names of some common storage containers are
formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id
- Cloud Storage files:
gs://bucket/path`Corresponds to the JSON propertycontainerName`
3105 3106 3107 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3105 def container_name @container_name end |
#data_profile_finding_record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
Location of a finding within a resource that produces a table data profile.
Corresponds to the JSON property dataProfileFindingRecordLocation
3110 3111 3112 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3110 def data_profile_finding_record_location @data_profile_finding_record_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3117 3118 3119 3120 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3117 def update!(**args) @container_name = args[:container_name] if args.key?(:container_name) @data_profile_finding_record_location = args[:data_profile_finding_record_location] if args.key?(:data_profile_finding_record_location) end |