Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Location of a finding within a resource that produces a table data profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingRecordLocation

Returns a new instance of GooglePrivacyDlpV2DataProfileFindingRecordLocation.



2994
2995
2996
# File 'lib/google/apis/dlp_v2/classes.rb', line 2994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



2992
2993
2994
# File 'lib/google/apis/dlp_v2/classes.rb', line 2992

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2999
3000
3001
# File 'lib/google/apis/dlp_v2/classes.rb', line 2999

def update!(**args)
  @field = args[:field] if args.key?(:field)
end