Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfilePubSubMessage
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfilePubSubMessage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Pub/Sub topic message for a DataProfileAction.PubSubNotification event. To receive a message of protocol buffer schema type, convert the message data to an object of this proto class.
Instance Attribute Summary collapse
-
#event ⇒ String
The event that caused the Pub/Sub message to be sent.
-
#file_store_profile ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
The profile for a file store.
-
#profile ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
The profile for a scanned table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfilePubSubMessage
constructor
A new instance of GooglePrivacyDlpV2DataProfilePubSubMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfilePubSubMessage
Returns a new instance of GooglePrivacyDlpV2DataProfilePubSubMessage.
3266 3267 3268 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#event ⇒ String
The event that caused the Pub/Sub message to be sent.
Corresponds to the JSON property event
3253 3254 3255 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3253 def event @event end |
#file_store_profile ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
The profile for a file store. * Cloud Storage: maps 1:1 with a bucket. *
Amazon S3: maps 1:1 with a bucket.
Corresponds to the JSON property fileStoreProfile
3259 3260 3261 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3259 def file_store_profile @file_store_profile end |
#profile ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
The profile for a scanned table.
Corresponds to the JSON property profile
3264 3265 3266 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3264 def profile @profile end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3271 3272 3273 3274 3275 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3271 def update!(**args) @event = args[:event] if args.key?(:event) @file_store_profile = args[:file_store_profile] if args.key?(:file_store_profile) @profile = args[:profile] if args.key?(:profile) end |