Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Message used to identify the type of resource being profiled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataSourceType

Returns a new instance of GooglePrivacyDlpV2DataSourceType.



3013
3014
3015
# File 'lib/google/apis/dlp_v2/classes.rb', line 3013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_sourceString

A string that identifies the type of resource being profiled. Current values: * google/bigquery/table * google/project * google/sql/table * google/gcs/bucket Corresponds to the JSON property dataSource

Returns:

  • (String)


3011
3012
3013
# File 'lib/google/apis/dlp_v2/classes.rb', line 3011

def data_source
  @data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3018
3019
3020
# File 'lib/google/apis/dlp_v2/classes.rb', line 3018

def update!(**args)
  @data_source = args[:data_source] if args.key?(:data_source)
end