Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Match database resources using regex filters. Examples of database resources are tables, views, and stored procedures.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DatabaseResourceCollection

Returns a new instance of GooglePrivacyDlpV2DatabaseResourceCollection.



3002
3003
3004
# File 'lib/google/apis/dlp_v2/classes.rb', line 3002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_regexesGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceRegexes

A collection of regular expressions to determine what database resources to match against. Corresponds to the JSON property includeRegexes



3000
3001
3002
# File 'lib/google/apis/dlp_v2/classes.rb', line 3000

def include_regexes
  @include_regexes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3007
3008
3009
# File 'lib/google/apis/dlp_v2/classes.rb', line 3007

def update!(**args)
  @include_regexes = args[:include_regexes] if args.key?(:include_regexes)
end