Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceRegexes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A collection of regular expressions to determine what database resources to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DatabaseResourceRegexes

Returns a new instance of GooglePrivacyDlpV2DatabaseResourceRegexes.



3436
3437
3438
# File 'lib/google/apis/dlp_v2/classes.rb', line 3436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patternsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceRegex>

A group of regular expression patterns to match against one or more database resources. Maximum of 100 entries. The sum of all regular expression's length can't exceed 10 KiB. Corresponds to the JSON property patterns



3434
3435
3436
# File 'lib/google/apis/dlp_v2/classes.rb', line 3434

def patterns
  @patterns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3441
3442
3443
# File 'lib/google/apis/dlp_v2/classes.rb', line 3441

def update!(**args)
  @patterns = args[:patterns] if args.key?(:patterns)
end