Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DatastoreOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Options defining a data set within Google Cloud Datastore.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DatastoreOptions

Returns a new instance of GooglePrivacyDlpV2DatastoreOptions.



3484
3485
3486
# File 'lib/google/apis/dlp_v2/classes.rb', line 3484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindGoogle::Apis::DlpV2::GooglePrivacyDlpV2KindExpression

A representation of a Datastore kind. Corresponds to the JSON property kind



3475
3476
3477
# File 'lib/google/apis/dlp_v2/classes.rb', line 3475

def kind
  @kind
end

#partition_idGoogle::Apis::DlpV2::GooglePrivacyDlpV2PartitionId

Datastore partition ID. A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID. Corresponds to the JSON property partitionId



3482
3483
3484
# File 'lib/google/apis/dlp_v2/classes.rb', line 3482

def partition_id
  @partition_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3489
3490
3491
3492
# File 'lib/google/apis/dlp_v2/classes.rb', line 3489

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @partition_id = args[:partition_id] if args.key?(:partition_id)
end