Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DateTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Message for a date time object. e.g. 2018-01-01, 5th August.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DateTime

Returns a new instance of GooglePrivacyDlpV2DateTime.



3573
3574
3575
# File 'lib/google/apis/dlp_v2/classes.rb', line 3573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dateGoogle::Apis::DlpV2::GoogleTypeDate

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following: * A full date, with non-zero year, month, and day values. * A month and day, with a zero year (for example, an anniversary). * A year on its own, with a zero month and a zero day. * A year and month, with a zero day (for example, a credit card expiration date). Related types: * google.type. TimeOfDay * google.type.DateTime * google.protobuf.Timestamp Corresponds to the JSON property date



3554
3555
3556
# File 'lib/google/apis/dlp_v2/classes.rb', line 3554

def date
  @date
end

#day_of_weekString

Day of week Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


3559
3560
3561
# File 'lib/google/apis/dlp_v2/classes.rb', line 3559

def day_of_week
  @day_of_week
end

#timeGoogle::Apis::DlpV2::GoogleTypeTimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property time



3566
3567
3568
# File 'lib/google/apis/dlp_v2/classes.rb', line 3566

def time
  @time
end

#time_zoneGoogle::Apis::DlpV2::GooglePrivacyDlpV2TimeZone

Time zone of the date time object. Corresponds to the JSON property timeZone



3571
3572
3573
# File 'lib/google/apis/dlp_v2/classes.rb', line 3571

def time_zone
  @time_zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3578
3579
3580
3581
3582
3583
# File 'lib/google/apis/dlp_v2/classes.rb', line 3578

def update!(**args)
  @date = args[:date] if args.key?(:date)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @time = args[:time] if args.key?(:time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
end