Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyDataSourceStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Summary of what was modified during a transformation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyDataSourceStats

Returns a new instance of GooglePrivacyDlpV2DeidentifyDataSourceStats.



3666
3667
3668
# File 'lib/google/apis/dlp_v2/classes.rb', line 3666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#transformation_countFixnum

Number of successfully applied transformations. Corresponds to the JSON property transformationCount

Returns:

  • (Fixnum)


3654
3655
3656
# File 'lib/google/apis/dlp_v2/classes.rb', line 3654

def transformation_count
  @transformation_count
end

#transformation_error_countFixnum

Number of errors encountered while trying to apply transformations. Corresponds to the JSON property transformationErrorCount

Returns:

  • (Fixnum)


3659
3660
3661
# File 'lib/google/apis/dlp_v2/classes.rb', line 3659

def transformation_error_count
  @transformation_error_count
end

#transformed_bytesFixnum

Total size in bytes that were transformed in some way. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


3664
3665
3666
# File 'lib/google/apis/dlp_v2/classes.rb', line 3664

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3671
3672
3673
3674
3675
# File 'lib/google/apis/dlp_v2/classes.rb', line 3671

def update!(**args)
  @transformation_count = args[:transformation_count] if args.key?(:transformation_count)
  @transformation_error_count = args[:transformation_error_count] if args.key?(:transformation_error_count)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end