Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryConditions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryConditions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Requirements that must be true before a table is scanned in discovery for the first time. There is an AND relationship between the top-level attributes. Additionally, minimum conditions with an OR relationship that must be met before Cloud DLP scans a table can be set (like a minimum row count or a minimum table age).
Instance Attribute Summary collapse
-
#created_after ⇒ String
BigQuery table must have been created after this date.
-
#or_conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrConditions
There is an OR relationship between these attributes.
-
#type_collection ⇒ String
Restrict discovery to categories of table types.
-
#types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTableTypes
The types of BigQuery tables supported by Cloud DLP.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryBigQueryConditions
constructor
A new instance of GooglePrivacyDlpV2DiscoveryBigQueryConditions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryBigQueryConditions
Returns a new instance of GooglePrivacyDlpV2DiscoveryBigQueryConditions.
3983 3984 3985 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3983 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_after ⇒ String
BigQuery table must have been created after this date. Used to avoid
backfilling.
Corresponds to the JSON property createdAfter
3965 3966 3967 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3965 def created_after @created_after end |
#or_conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrConditions
There is an OR relationship between these attributes. They are used to
determine if a table should be scanned or not in Discovery.
Corresponds to the JSON property orConditions
3971 3972 3973 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3971 def or_conditions @or_conditions end |
#type_collection ⇒ String
Restrict discovery to categories of table types.
Corresponds to the JSON property typeCollection
3976 3977 3978 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3976 def type_collection @type_collection end |
#types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTableTypes
The types of BigQuery tables supported by Cloud DLP.
Corresponds to the JSON property types
3981 3982 3983 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3981 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3988 3989 3990 3991 3992 3993 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3988 def update!(**args) @created_after = args[:created_after] if args.key?(:created_after) @or_conditions = args[:or_conditions] if args.key?(:or_conditions) @type_collection = args[:type_collection] if args.key?(:type_collection) @types = args[:types] if args.key?(:types) end |