Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.



4224
4225
4226
# File 'lib/google/apis/dlp_v2/classes.rb', line 4224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection

Match database resources using regex filters. Examples of database resources are tables, views, and stored procedures. Corresponds to the JSON property collection



4212
4213
4214
# File 'lib/google/apis/dlp_v2/classes.rb', line 4212

def collection
  @collection
end

#database_resource_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference

Identifies a single database resource, like a table within a database. Corresponds to the JSON property databaseResourceReference



4217
4218
4219
# File 'lib/google/apis/dlp_v2/classes.rb', line 4217

def database_resource_reference
  @database_resource_reference
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources

Match database resources not covered by any other filter. Corresponds to the JSON property others



4222
4223
4224
# File 'lib/google/apis/dlp_v2/classes.rb', line 4222

def others
  @others
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4229
4230
4231
4232
4233
# File 'lib/google/apis/dlp_v2/classes.rb', line 4229

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @database_resource_reference = args[:database_resource_reference] if args.key?(:database_resource_reference)
  @others = args[:others] if args.key?(:others)
end