Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig

Returns a new instance of GooglePrivacyDlpV2DiscoveryConfig.



4453
4454
4455
# File 'lib/google/apis/dlp_v2/classes.rb', line 4453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>

Actions to execute at the completion of scanning. Corresponds to the JSON property actions



4375
4376
4377
# File 'lib/google/apis/dlp_v2/classes.rb', line 4375

def actions
  @actions
end

#create_timeString

Output only. The creation timestamp of a DiscoveryConfig. Corresponds to the JSON property createTime

Returns:

  • (String)


4380
4381
4382
# File 'lib/google/apis/dlp_v2/classes.rb', line 4380

def create_time
  @create_time
end

#display_nameString

Display name (max 100 chars) Corresponds to the JSON property displayName

Returns:

  • (String)


4385
4386
4387
# File 'lib/google/apis/dlp_v2/classes.rb', line 4385

def display_name
  @display_name
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

Output only. A stream of errors encountered when the config was activated. Repeated errors may result in the config automatically being paused. Output only field. Will return the last 100 errors. Whenever the config is modified this list will be cleared. Corresponds to the JSON property errors



4393
4394
4395
# File 'lib/google/apis/dlp_v2/classes.rb', line 4393

def errors
  @errors
end

#inspect_templatesArray<String>

Detection logic for profile generation. Not all template features are used by Discovery. FindingLimits, include_quote and exclude_info_types have no impact on Discovery. Multiple templates may be provided if there is data in multiple regions. At most one template must be specified per-region (including "global") . Each region is scanned using the applicable template. If no region-specific template is specified, but a "global" template is specified, it will be copied to that region and used instead. If no global or region-specific template is provided for a region with data, that region's data will not be scanned. For more information, see https://docs.cloud.google.com/sensitive-data-protection/ docs/data-profiles#data-residency. Corresponds to the JSON property inspectTemplates

Returns:

  • (Array<String>)


4407
4408
4409
# File 'lib/google/apis/dlp_v2/classes.rb', line 4407

def inspect_templates
  @inspect_templates
end

#last_run_timeString

Output only. The timestamp of the last time this config was executed. Corresponds to the JSON property lastRunTime

Returns:

  • (String)


4412
4413
4414
# File 'lib/google/apis/dlp_v2/classes.rb', line 4412

def last_run_time
  @last_run_time
end

#nameString

Output only. Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example projects/dlp-test- project/locations/global/discoveryConfigs/53234423. Corresponds to the JSON property name

Returns:

  • (String)


4419
4420
4421
# File 'lib/google/apis/dlp_v2/classes.rb', line 4419

def name
  @name
end

#org_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig

Project and scan location information. Only set when the parent is an org. Corresponds to the JSON property orgConfig



4424
4425
4426
# File 'lib/google/apis/dlp_v2/classes.rb', line 4424

def org_config
  @org_config
end

#other_cloud_starting_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation

The other cloud starting location for discovery. Corresponds to the JSON property otherCloudStartingLocation



4429
4430
4431
# File 'lib/google/apis/dlp_v2/classes.rb', line 4429

def other_cloud_starting_location
  @other_cloud_starting_location
end

#processing_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation

Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided. Corresponds to the JSON property processingLocation



4436
4437
4438
# File 'lib/google/apis/dlp_v2/classes.rb', line 4436

def processing_location
  @processing_location
end

#statusString

Required. A status for this configuration. Corresponds to the JSON property status

Returns:

  • (String)


4441
4442
4443
# File 'lib/google/apis/dlp_v2/classes.rb', line 4441

def status
  @status
end

#targetsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>

Target to match against for determining what to scan and how frequently. Corresponds to the JSON property targets



4446
4447
4448
# File 'lib/google/apis/dlp_v2/classes.rb', line 4446

def targets
  @targets
end

#update_timeString

Output only. The last update timestamp of a DiscoveryConfig. Corresponds to the JSON property updateTime

Returns:

  • (String)


4451
4452
4453
# File 'lib/google/apis/dlp_v2/classes.rb', line 4451

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4458
4459
4460
4461
4462
4463
4464
4465
4466
4467
4468
4469
4470
4471
4472
# File 'lib/google/apis/dlp_v2/classes.rb', line 4458

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates)
  @last_run_time = args[:last_run_time] if args.key?(:last_run_time)
  @name = args[:name] if args.key?(:name)
  @org_config = args[:org_config] if args.key?(:org_config)
  @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location)
  @processing_location = args[:processing_location] if args.key?(:processing_location)
  @status = args[:status] if args.key?(:status)
  @targets = args[:targets] if args.key?(:targets)
  @update_time = args[:update_time] if args.key?(:update_time)
end