Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence.



4232
4233
4234
# File 'lib/google/apis/dlp_v2/classes.rb', line 4232

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequencyString

How frequently data profiles can be updated when the template is modified. Defaults to never. Corresponds to the JSON property frequency

Returns:

  • (String)


4230
4231
4232
# File 'lib/google/apis/dlp_v2/classes.rb', line 4230

def frequency
  @frequency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4237
4238
4239
# File 'lib/google/apis/dlp_v2/classes.rb', line 4237

def update!(**args)
  @frequency = args[:frequency] if args.key?(:frequency)
end