Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Requirements that must be true before a resource is profiled for the first time.
Instance Attribute Summary collapse
-
#amazon_s3_bucket_conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AmazonS3BucketConditions
Amazon S3 bucket conditions.
-
#min_age ⇒ String
Minimum age a resource must be before Cloud DLP can profile it.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudConditions
constructor
A new instance of GooglePrivacyDlpV2DiscoveryOtherCloudConditions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudConditions
Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudConditions.
4397 4398 4399 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4397 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amazon_s3_bucket_conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AmazonS3BucketConditions
Amazon S3 bucket conditions.
Corresponds to the JSON property amazonS3BucketConditions
4389 4390 4391 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4389 def amazon_s3_bucket_conditions @amazon_s3_bucket_conditions end |
#min_age ⇒ String
Minimum age a resource must be before Cloud DLP can profile it. Value must be
1 hour or greater.
Corresponds to the JSON property minAge
4395 4396 4397 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4395 def min_age @min_age end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4402 4403 4404 4405 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4402 def update!(**args) @amazon_s3_bucket_conditions = args[:amazon_s3_bucket_conditions] if args.key?(:amazon_s3_bucket_conditions) @min_age = args[:min_age] if args.key?(:min_age) end |