Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines which resources from the other cloud will have profiles generated. Includes the ability to filter by resource names.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudFilter.



4428
4429
4430
# File 'lib/google/apis/dlp_v2/classes.rb', line 4428

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceCollection

Match resources using regex filters. Corresponds to the JSON property collection



4416
4417
4418
# File 'lib/google/apis/dlp_v2/classes.rb', line 4416

def collection
  @collection
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources

Match discovery resources not covered by any other filter. Corresponds to the JSON property others



4421
4422
4423
# File 'lib/google/apis/dlp_v2/classes.rb', line 4421

def others
  @others
end

#single_resourceGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudSingleResourceReference

Identifies a single resource, like a single Amazon S3 bucket. Corresponds to the JSON property singleResource



4426
4427
4428
# File 'lib/google/apis/dlp_v2/classes.rb', line 4426

def single_resource
  @single_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4433
4434
4435
4436
4437
# File 'lib/google/apis/dlp_v2/classes.rb', line 4433

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @others = args[:others] if args.key?(:others)
  @single_resource = args[:single_resource] if args.key?(:single_resource)
end