Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTableModifiedCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The cadence at which to update data profiles when a table is modified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryTableModifiedCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryTableModifiedCadence.



4430
4431
4432
# File 'lib/google/apis/dlp_v2/classes.rb', line 4430

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequencyString

How frequently data profiles can be updated when tables are modified. Defaults to never. Corresponds to the JSON property frequency

Returns:

  • (String)


4422
4423
4424
# File 'lib/google/apis/dlp_v2/classes.rb', line 4422

def frequency
  @frequency
end

#typesArray<String>

The type of events to consider when deciding if the table has been modified and should have the profile updated. Defaults to MODIFIED_TIMESTAMP. Corresponds to the JSON property types

Returns:

  • (Array<String>)


4428
4429
4430
# File 'lib/google/apis/dlp_v2/classes.rb', line 4428

def types
  @types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4435
4436
4437
4438
# File 'lib/google/apis/dlp_v2/classes.rb', line 4435

def update!(**args)
  @frequency = args[:frequency] if args.key?(:frequency)
  @types = args[:types] if args.key?(:types)
end