Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetConditions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Requirements that must be true before a dataset is profiled for the first time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetConditions

Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetConditions.



4484
4485
4486
# File 'lib/google/apis/dlp_v2/classes.rb', line 4484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_afterString

Vertex AI dataset must have been created after this date. Used to avoid backfilling. Corresponds to the JSON property createdAfter

Returns:

  • (String)


4476
4477
4478
# File 'lib/google/apis/dlp_v2/classes.rb', line 4476

def created_after
  @created_after
end

#min_ageString

Minimum age a Vertex AI dataset must have. If set, the value must be 1 hour or greater. Corresponds to the JSON property minAge

Returns:

  • (String)


4482
4483
4484
# File 'lib/google/apis/dlp_v2/classes.rb', line 4482

def min_age
  @min_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4489
4490
4491
4492
# File 'lib/google/apis/dlp_v2/classes.rb', line 4489

def update!(**args)
  @created_after = args[:created_after] if args.key?(:created_after)
  @min_age = args[:min_age] if args.key?(:min_age)
end