Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines what datasets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID or dataset regex.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.



4847
4848
4849
# File 'lib/google/apis/dlp_v2/classes.rb', line 4847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection

Match dataset resources using regex filters. Corresponds to the JSON property collection



4835
4836
4837
# File 'lib/google/apis/dlp_v2/classes.rb', line 4835

def collection
  @collection
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources

Match discovery resources not covered by any other filter. Corresponds to the JSON property others



4840
4841
4842
# File 'lib/google/apis/dlp_v2/classes.rb', line 4840

def others
  @others
end

#vertex_dataset_resource_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference

Identifies a single Vertex AI resource. Only datasets are supported. Corresponds to the JSON property vertexDatasetResourceReference



4845
4846
4847
# File 'lib/google/apis/dlp_v2/classes.rb', line 4845

def vertex_dataset_resource_reference
  @vertex_dataset_resource_reference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4852
4853
4854
4855
4856
# File 'lib/google/apis/dlp_v2/classes.rb', line 4852

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @others = args[:others] if args.key?(:others)
  @vertex_dataset_resource_reference = args[:vertex_dataset_resource_reference] if args.key?(:vertex_dataset_resource_reference)
end