Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DlpJob
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DlpJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Combines all of the information about a DLP job.
Instance Attribute Summary collapse
-
#action_details ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2ActionDetails>
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only.
-
#inspect_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectDataSourceDetails
The results of an inspect DataSource job.
-
#job_trigger_name ⇒ String
Output only.
-
#last_modified ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#risk_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AnalyzeDataSourceRiskDetails
Result of a risk analysis operation request.
-
#start_time ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#type ⇒ String
The type of job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DlpJob
constructor
A new instance of GooglePrivacyDlpV2DlpJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DlpJob
Returns a new instance of GooglePrivacyDlpV2DlpJob.
4952 4953 4954 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4952 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_details ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2ActionDetails>
Output only. Events that should occur after the job has completed.
Corresponds to the JSON property actionDetails
4894 4895 4896 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4894 def action_details @action_details end |
#create_time ⇒ String
Output only. Time when the job was created.
Corresponds to the JSON property createTime
4899 4900 4901 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4899 def create_time @create_time end |
#end_time ⇒ String
Output only. Time when the job finished.
Corresponds to the JSON property endTime
4904 4905 4906 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4904 def end_time @end_time end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only. A stream of errors encountered running the job.
Corresponds to the JSON property errors
4909 4910 4911 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4909 def errors @errors end |
#inspect_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectDataSourceDetails
The results of an inspect DataSource job.
Corresponds to the JSON property inspectDetails
4914 4915 4916 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4914 def inspect_details @inspect_details end |
#job_trigger_name ⇒ String
Output only. If created by a job trigger, the resource name of the trigger
that instantiated the job.
Corresponds to the JSON property jobTriggerName
4920 4921 4922 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4920 def job_trigger_name @job_trigger_name end |
#last_modified ⇒ String
Output only. Time when the job was last modified by the system.
Corresponds to the JSON property lastModified
4925 4926 4927 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4925 def last_modified @last_modified end |
#name ⇒ String
Output only. The server-assigned name.
Corresponds to the JSON property name
4930 4931 4932 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4930 def name @name end |
#risk_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AnalyzeDataSourceRiskDetails
Result of a risk analysis operation request.
Corresponds to the JSON property riskDetails
4935 4936 4937 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4935 def risk_details @risk_details end |
#start_time ⇒ String
Output only. Time when the job started.
Corresponds to the JSON property startTime
4940 4941 4942 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4940 def start_time @start_time end |
#state ⇒ String
Output only. State of a job.
Corresponds to the JSON property state
4945 4946 4947 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4945 def state @state end |
#type ⇒ String
The type of job.
Corresponds to the JSON property type
4950 4951 4952 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4950 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4957 4958 4959 4960 4961 4962 4963 4964 4965 4966 4967 4968 4969 4970 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4957 def update!(**args) @action_details = args[:action_details] if args.key?(:action_details) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @errors = args[:errors] if args.key?(:errors) @inspect_details = args[:inspect_details] if args.key?(:inspect_details) @job_trigger_name = args[:job_trigger_name] if args.key?(:job_trigger_name) @last_modified = args[:last_modified] if args.key?(:last_modified) @name = args[:name] if args.key?(:name) @risk_details = args[:risk_details] if args.key?(:risk_details) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |