Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentFallbackLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentFallbackLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configure document processing to fall back to any of the following processing options if document processing is unavailable in the original request location.
Instance Attribute Summary collapse
-
#global_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2GlobalProcessing
Processing occurs in the global region.
-
#multi_region_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MultiRegionProcessing
Processing occurs in a multi-region that contains the current region if available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DocumentFallbackLocation
constructor
A new instance of GooglePrivacyDlpV2DocumentFallbackLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DocumentFallbackLocation
Returns a new instance of GooglePrivacyDlpV2DocumentFallbackLocation.
4533 4534 4535 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4533 def initialize(**args) update!(**args) end |
Instance Attribute Details
#global_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2GlobalProcessing
Processing occurs in the global region.
Corresponds to the JSON property globalProcessing
4525 4526 4527 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4525 def global_processing @global_processing end |
#multi_region_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MultiRegionProcessing
Processing occurs in a multi-region that contains the current region if
available.
Corresponds to the JSON property multiRegionProcessing
4531 4532 4533 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4531 def multi_region_processing @multi_region_processing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4538 4539 4540 4541 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4538 def update!(**args) @global_processing = args[:global_processing] if args.key?(:global_processing) @multi_region_processing = args[:multi_region_processing] if args.key?(:multi_region_processing) end |