Class: Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

An entity in a dataset is a field or set of fields that correspond to a single person. For example, in medical records the EntityId might be a patient identifier, or for financial records it might be an account identifier. This message is used when generalizations or analysis must take into account that multiple rows correspond to the same entity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2EntityId

Returns a new instance of GooglePrivacyDlpV2EntityId.



5071
5072
5073
# File 'lib/google/apis/dlp_v2/classes.rb', line 5071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



5069
5070
5071
# File 'lib/google/apis/dlp_v2/classes.rb', line 5069

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5076
5077
5078
# File 'lib/google/apis/dlp_v2/classes.rb', line 5076

def update!(**args)
  @field = args[:field] if args.key?(:field)
end