Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Export

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

If set, the detailed data profiles will be persisted to the location of your choice whenever updated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Export

Returns a new instance of GooglePrivacyDlpV2Export.



5000
5001
5002
# File 'lib/google/apis/dlp_v2/classes.rb', line 5000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#profile_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property profileTable



4991
4992
4993
# File 'lib/google/apis/dlp_v2/classes.rb', line 4991

def profile_table
  @profile_table
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



4998
4999
5000
# File 'lib/google/apis/dlp_v2/classes.rb', line 4998

def sample_findings_table
  @sample_findings_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5005
5006
5007
5008
# File 'lib/google/apis/dlp_v2/classes.rb', line 5005

def update!(**args)
  @profile_table = args[:profile_table] if args.key?(:profile_table)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
end