Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreCollection
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreCollection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Match file stores (e.g. buckets) using filters.
Instance Attribute Summary collapse
-
#include_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegexes
A collection of regular expressions to determine what file store to match against.
-
#include_tags ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TagFilters
Tags to match against for filtering.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreCollection
constructor
A new instance of GooglePrivacyDlpV2FileStoreCollection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreCollection
Returns a new instance of GooglePrivacyDlpV2FileStoreCollection.
5238 5239 5240 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5238 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegexes
A collection of regular expressions to determine what file store to match
against.
Corresponds to the JSON property includeRegexes
5231 5232 5233 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5231 def include_regexes @include_regexes end |
#include_tags ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TagFilters
Tags to match against for filtering.
Corresponds to the JSON property includeTags
5236 5237 5238 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5236 def @include_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5243 5244 5245 5246 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5243 def update!(**args) @include_regexes = args[:include_regexes] if args.key?(:include_regexes) @include_tags = args[:include_tags] if args.key?(:include_tags) end |