Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration to control the number of findings returned for inspection. This is not used for de-identification or data profiling. When redacting sensitive data from images, finding limits don't apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don't include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error.
Instance Attribute Summary collapse
-
#max_findings_per_info_type ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLimit>
Configuration of findings limit given for specified infoTypes.
-
#max_findings_per_item ⇒ Fixnum
Max number of findings that are returned for each item scanned.
-
#max_findings_per_request ⇒ Fixnum
Max number of findings that are returned per request or job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FindingLimits
constructor
A new instance of GooglePrivacyDlpV2FindingLimits.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FindingLimits
Returns a new instance of GooglePrivacyDlpV2FindingLimits.
6021 6022 6023 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_findings_per_info_type ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLimit>
Configuration of findings limit given for specified infoTypes.
Corresponds to the JSON property maxFindingsPerInfoType
5999 6000 6001 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5999 def max_findings_per_info_type @max_findings_per_info_type end |
#max_findings_per_item ⇒ Fixnum
Max number of findings that are returned for each item scanned. When set
within an InspectContentRequest, this field is ignored. This value isn't a
hard limit. If the number of findings for an item reaches this limit, the
inspection of that item ends gradually, not abruptly. Therefore, the actual
number of findings that Cloud DLP returns for the item can be multiple times
higher than this value.
Corresponds to the JSON property maxFindingsPerItem
6009 6010 6011 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6009 def max_findings_per_item @max_findings_per_item end |
#max_findings_per_request ⇒ Fixnum
Max number of findings that are returned per request or job. If you set this
field in an InspectContentRequest, the resulting maximum value is the value
that you set or 3,000, whichever is lower. This value isn't a hard limit. If
an inspection reaches this limit, the inspection ends gradually, not abruptly.
Therefore, the actual number of findings that Cloud DLP returns can be
multiple times higher than this value.
Corresponds to the JSON property maxFindingsPerRequest
6019 6020 6021 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6019 def max_findings_per_request @max_findings_per_request end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6026 6027 6028 6029 6030 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6026 def update!(**args) @max_findings_per_info_type = args[:max_findings_per_info_type] if args.key?(:max_findings_per_info_type) @max_findings_per_item = args[:max_findings_per_item] if args.key?(:max_findings_per_item) @max_findings_per_request = args[:max_findings_per_request] if args.key?(:max_findings_per_request) end |