Class: Google::Apis::DlpV2::GooglePrivacyDlpV2GoogleDriveLabel
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2GoogleDriveLabel
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Google Drive labels published by Google.
Instance Attribute Summary collapse
-
#label_fields_to_match ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2LabelField>
The field values of the Google Drive label to match.
-
#label_id ⇒ String
The label ID of the Google Drive label.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2GoogleDriveLabel
constructor
A new instance of GooglePrivacyDlpV2GoogleDriveLabel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2GoogleDriveLabel
Returns a new instance of GooglePrivacyDlpV2GoogleDriveLabel.
6139 6140 6141 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#label_fields_to_match ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2LabelField>
The field values of the Google Drive label to match.
Corresponds to the JSON property labelFieldsToMatch
6131 6132 6133 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6131 def label_fields_to_match @label_fields_to_match end |
#label_id ⇒ String
The label ID of the Google Drive label.
Corresponds to the JSON property labelId
6137 6138 6139 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6137 def label_id @label_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6144 6145 6146 6147 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6144 def update!(**args) @label_fields_to_match = args[:label_fields_to_match] if args.key?(:label_fields_to_match) @label_id = args[:label_id] if args.key?(:label_id) end |