Class: Google::Apis::DlpV2::GooglePrivacyDlpV2HotwordRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The rule that adjusts the likelihood of findings within a certain proximity of hotwords.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2HotwordRule

Returns a new instance of GooglePrivacyDlpV2HotwordRule.



5800
5801
5802
# File 'lib/google/apis/dlp_v2/classes.rb', line 5800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hotword_regexGoogle::Apis::DlpV2::GooglePrivacyDlpV2Regex

Message defining a custom regular expression. Corresponds to the JSON property hotwordRegex



5787
5788
5789
# File 'lib/google/apis/dlp_v2/classes.rb', line 5787

def hotword_regex
  @hotword_regex
end

#likelihood_adjustmentGoogle::Apis::DlpV2::GooglePrivacyDlpV2LikelihoodAdjustment

Message for specifying an adjustment to the likelihood of a finding as part of a detection rule. Corresponds to the JSON property likelihoodAdjustment



5793
5794
5795
# File 'lib/google/apis/dlp_v2/classes.rb', line 5793

def likelihood_adjustment
  @likelihood_adjustment
end

#proximityGoogle::Apis::DlpV2::GooglePrivacyDlpV2Proximity

Message for specifying a window around a finding to apply a detection rule. Corresponds to the JSON property proximity



5798
5799
5800
# File 'lib/google/apis/dlp_v2/classes.rb', line 5798

def proximity
  @proximity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5805
5806
5807
5808
5809
# File 'lib/google/apis/dlp_v2/classes.rb', line 5805

def update!(**args)
  @hotword_regex = args[:hotword_regex] if args.key?(:hotword_regex)
  @likelihood_adjustment = args[:likelihood_adjustment] if args.key?(:likelihood_adjustment)
  @proximity = args[:proximity] if args.key?(:proximity)
end