Class: Google::Apis::DlpV2::GooglePrivacyDlpV2HybridInspectStatistics
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2HybridInspectStatistics
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Statistics related to processing hybrid inspect requests.
Instance Attribute Summary collapse
-
#aborted_count ⇒ Fixnum
The number of hybrid inspection requests aborted because the job ran out of quota or was ended before they could be processed.
-
#pending_count ⇒ Fixnum
The number of hybrid requests currently being processed.
-
#processed_count ⇒ Fixnum
The number of hybrid inspection requests processed within this job.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridInspectStatistics
constructor
A new instance of GooglePrivacyDlpV2HybridInspectStatistics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridInspectStatistics
Returns a new instance of GooglePrivacyDlpV2HybridInspectStatistics.
6126 6127 6128 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aborted_count ⇒ Fixnum
The number of hybrid inspection requests aborted because the job ran out of
quota or was ended before they could be processed.
Corresponds to the JSON property abortedCount
6111 6112 6113 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6111 def aborted_count @aborted_count end |
#pending_count ⇒ Fixnum
The number of hybrid requests currently being processed. Only populated when
called via method getDlpJob. A burst of traffic may cause hybrid inspect
requests to be enqueued. Processing will take place as quickly as possible,
but resource limitations may impact how long a request is enqueued for.
Corresponds to the JSON property pendingCount
6119 6120 6121 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6119 def pending_count @pending_count end |
#processed_count ⇒ Fixnum
The number of hybrid inspection requests processed within this job.
Corresponds to the JSON property processedCount
6124 6125 6126 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6124 def processed_count @processed_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6131 6132 6133 6134 6135 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6131 def update!(**args) @aborted_count = args[:aborted_count] if args.key?(:aborted_count) @pending_count = args[:pending_count] if args.key?(:pending_count) @processed_count = args[:processed_count] if args.key?(:processed_count) end |