Class: Google::Apis::DlpV2::GooglePrivacyDlpV2HybridOptions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2HybridOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration to control jobs where the content being inspected is outside of Google Cloud Platform.
Instance Attribute Summary collapse
-
#description ⇒ String
A short description of where the data is coming from.
-
#labels ⇒ Hash<String,String>
To organize findings, these labels will be added to each finding.
-
#required_finding_label_keys ⇒ Array<String>
These are labels that each inspection request must include within their ' finding_labels' map.
-
#table_options ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableOptions
Instructions regarding the table content being inspected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridOptions
constructor
A new instance of GooglePrivacyDlpV2HybridOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridOptions
Returns a new instance of GooglePrivacyDlpV2HybridOptions.
5984 5985 5986 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
A short description of where the data is coming from. Will be stored once in
the job. 256 max length.
Corresponds to the JSON property description
5958 5959 5960 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5958 def description @description end |
#labels ⇒ Hash<String,String>
To organize findings, these labels will be added to each finding. Label keys
must be between 1 and 63 characters long and must conform to the following
regular expression: [a-z]([-a-z0-9]*[a-z0-9])?. Label values must be between
0 and 63 characters long and must conform to the regular expression ([a-z]([-
a-z0-9]*[a-z0-9])?)?. No more than 10 labels can be associated with a given
finding. Examples: * "environment" : "production" * "pipeline" : "etl"
Corresponds to the JSON property labels
5968 5969 5970 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5968 def labels @labels end |
#required_finding_label_keys ⇒ Array<String>
These are labels that each inspection request must include within their '
finding_labels' map. Request may contain others, but any missing one of these
will be rejected. Label keys must be between 1 and 63 characters long and must
conform to the following regular expression: [a-z]([-a-z0-9]*[a-z0-9])?. No
more than 10 keys can be required.
Corresponds to the JSON property requiredFindingLabelKeys
5977 5978 5979 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5977 def required_finding_label_keys @required_finding_label_keys end |
#table_options ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableOptions
Instructions regarding the table content being inspected.
Corresponds to the JSON property tableOptions
5982 5983 5984 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5982 def @table_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5989 5990 5991 5992 5993 5994 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5989 def update!(**args) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @required_finding_label_keys = args[:required_finding_label_keys] if args.key?(:required_finding_label_keys) @table_options = args[:table_options] if args.key?(:table_options) end |