Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ImageFallbackLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ImageFallbackLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configure image processing to fall back to any of the following processing options if image processing is unavailable in the original request location.
Instance Attribute Summary collapse
-
#global_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2GlobalProcessing
Processing occurs in the global region.
-
#multi_region_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MultiRegionProcessing
Processing occurs in a multi-region that contains the current region if available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ImageFallbackLocation
constructor
A new instance of GooglePrivacyDlpV2ImageFallbackLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ImageFallbackLocation
Returns a new instance of GooglePrivacyDlpV2ImageFallbackLocation.
5816 5817 5818 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5816 def initialize(**args) update!(**args) end |
Instance Attribute Details
#global_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2GlobalProcessing
Processing occurs in the global region.
Corresponds to the JSON property globalProcessing
5808 5809 5810 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5808 def global_processing @global_processing end |
#multi_region_processing ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MultiRegionProcessing
Processing occurs in a multi-region that contains the current region if
available.
Corresponds to the JSON property multiRegionProcessing
5814 5815 5816 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5814 def multi_region_processing @multi_region_processing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5821 5822 5823 5824 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5821 def update!(**args) @global_processing = args[:global_processing] if args.key?(:global_processing) @multi_region_processing = args[:multi_region_processing] if args.key?(:multi_region_processing) end |