Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Type of information detected by the API.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoType

Returns a new instance of GooglePrivacyDlpV2InfoType.



6187
6188
6189
# File 'lib/google/apis/dlp_v2/classes.rb', line 6187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the information type. Either a name of your choosing when creating a CustomInfoType, or one of the names listed at https://cloud.google.com/ sensitive-data-protection/docs/infotypes-reference when specifying a built-in type. When sending Cloud DLP results to Data Catalog, infoType names should conform to the pattern [A-Za-z0-9$_-]1,64`. Corresponds to the JSON propertyname`

Returns:

  • (String)


6174
6175
6176
# File 'lib/google/apis/dlp_v2/classes.rb', line 6174

def name
  @name
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



6180
6181
6182
# File 'lib/google/apis/dlp_v2/classes.rb', line 6180

def sensitivity_score
  @sensitivity_score
end

#versionString

Optional version name for this InfoType. Corresponds to the JSON property version

Returns:

  • (String)


6185
6186
6187
# File 'lib/google/apis/dlp_v2/classes.rb', line 6185

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6192
6193
6194
6195
6196
# File 'lib/google/apis/dlp_v2/classes.rb', line 6192

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @version = args[:version] if args.key?(:version)
end