Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A info type based condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeCondition

Returns a new instance of GooglePrivacyDlpV2InfoTypeCondition.



6688
6689
6690
# File 'lib/google/apis/dlp_v2/classes.rb', line 6688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#any_info_typeGoogle::Apis::DlpV2::GoogleProtobufEmpty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property anyInfoType



6675
6676
6677
# File 'lib/google/apis/dlp_v2/classes.rb', line 6675

def any_info_type
  @any_info_type
end

#info_typesGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoTypes

Info types to match. Corresponds to the JSON property infoTypes



6680
6681
6682
# File 'lib/google/apis/dlp_v2/classes.rb', line 6680

def info_types
  @info_types
end

#min_countFixnum

Optional. The minimum total number of findings of all matching info types required for this condition to evaluate to true. Defaults to 1 if unset. Corresponds to the JSON property minCount

Returns:

  • (Fixnum)


6686
6687
6688
# File 'lib/google/apis/dlp_v2/classes.rb', line 6686

def min_count
  @min_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6693
6694
6695
6696
6697
# File 'lib/google/apis/dlp_v2/classes.rb', line 6693

def update!(**args)
  @any_info_type = args[:any_info_type] if args.key?(:any_info_type)
  @info_types = args[:info_types] if args.key?(:info_types)
  @min_count = args[:min_count] if args.key?(:min_count)
end