Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

InfoType description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription

Returns a new instance of GooglePrivacyDlpV2InfoTypeDescription.



6765
6766
6767
# File 'lib/google/apis/dlp_v2/classes.rb', line 6765

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>

The category of the infoType. Corresponds to the JSON property categories



6707
6708
6709
# File 'lib/google/apis/dlp_v2/classes.rb', line 6707

def categories
  @categories
end

#descriptionString

Description of the infotype. Translated when language is provided in the request. Corresponds to the JSON property description

Returns:

  • (String)


6713
6714
6715
# File 'lib/google/apis/dlp_v2/classes.rb', line 6713

def description
  @description
end

#display_nameString

Human readable form of the infoType name. Corresponds to the JSON property displayName

Returns:

  • (String)


6718
6719
6720
# File 'lib/google/apis/dlp_v2/classes.rb', line 6718

def display_name
  @display_name
end

#exampleString

A sample that is a true positive for this infoType. Corresponds to the JSON property example

Returns:

  • (String)


6723
6724
6725
# File 'lib/google/apis/dlp_v2/classes.rb', line 6723

def example
  @example
end

#launch_statusString

The launch status of the infoType. Corresponds to the JSON property launchStatus

Returns:

  • (String)


6728
6729
6730
# File 'lib/google/apis/dlp_v2/classes.rb', line 6728

def launch_status
  @launch_status
end

#location_supportGoogle::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport

Locations at which a feature can be used. Corresponds to the JSON property locationSupport



6733
6734
6735
# File 'lib/google/apis/dlp_v2/classes.rb', line 6733

def location_support
  @location_support
end

#nameString

Internal name of the infoType. Corresponds to the JSON property name

Returns:

  • (String)


6738
6739
6740
# File 'lib/google/apis/dlp_v2/classes.rb', line 6738

def name
  @name
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



6744
6745
6746
# File 'lib/google/apis/dlp_v2/classes.rb', line 6744

def sensitivity_score
  @sensitivity_score
end

#specific_info_typesArray<String>

If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it. General infoTypes are infoTypes that encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA" general infoType would have set for this field "LOCATION", " LOCATION_COORDINATES", and "STREET_ADDRESS". Corresponds to the JSON property specificInfoTypes

Returns:

  • (Array<String>)


6753
6754
6755
# File 'lib/google/apis/dlp_v2/classes.rb', line 6753

def specific_info_types
  @specific_info_types
end

#supported_byArray<String>

Which parts of the API supports this InfoType. Corresponds to the JSON property supportedBy

Returns:

  • (Array<String>)


6758
6759
6760
# File 'lib/google/apis/dlp_v2/classes.rb', line 6758

def supported_by
  @supported_by
end

#versionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>

A list of available versions for the infotype. Corresponds to the JSON property versions



6763
6764
6765
# File 'lib/google/apis/dlp_v2/classes.rb', line 6763

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6770
6771
6772
6773
6774
6775
6776
6777
6778
6779
6780
6781
6782
# File 'lib/google/apis/dlp_v2/classes.rb', line 6770

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example = args[:example] if args.key?(:example)
  @launch_status = args[:launch_status] if args.key?(:launch_status)
  @location_support = args[:location_support] if args.key?(:location_support)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @specific_info_types = args[:specific_info_types] if args.key?(:specific_info_types)
  @supported_by = args[:supported_by] if args.key?(:supported_by)
  @versions = args[:versions] if args.key?(:versions)
end