Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Request to search for potentially sensitive info in a ContentItem.
Instance Attribute Summary collapse
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#inspect_template_name ⇒ String
Template to use.
-
#item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
Type of content to inspect.
-
#location_id ⇒ String
Deprecated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectContentRequest
constructor
A new instance of GooglePrivacyDlpV2InspectContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectContentRequest
Returns a new instance of GooglePrivacyDlpV2InspectContentRequest.
6626 6627 6628 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
6606 6607 6608 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6606 def inspect_config @inspect_config end |
#inspect_template_name ⇒ String
Template to use. Any configuration directly specified in inspect_config will
override those set in the template. Singular fields that are set in this
request will replace their corresponding fields in the template. Repeated
fields are appended. Singular sub-messages and groups are recursively merged.
Corresponds to the JSON property inspectTemplateName
6614 6615 6616 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6614 def inspect_template_name @inspect_template_name end |
#item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
Type of content to inspect.
Corresponds to the JSON property item
6619 6620 6621 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6619 def item @item end |
#location_id ⇒ String
Deprecated. This field has no effect.
Corresponds to the JSON property locationId
6624 6625 6626 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6624 def location_id @location_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6631 6632 6633 6634 6635 6636 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6631 def update!(**args) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name) @item = args[:item] if args.key?(:item) @location_id = args[:location_id] if args.key?(:location_id) end |