Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Controls what and how to inspect for findings.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Action>
Actions to execute at the completion of the job.
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#inspect_template_name ⇒ String
If provided, will be used as the default for all values in InspectConfig.
-
#storage_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageConfig
Shared message indicating Cloud storage type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectJobConfig
constructor
A new instance of GooglePrivacyDlpV2InspectJobConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectJobConfig
Returns a new instance of GooglePrivacyDlpV2InspectJobConfig.
6710 6711 6712 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Action>
Actions to execute at the completion of the job.
Corresponds to the JSON property actions
6690 6691 6692 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6690 def actions @actions end |
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
6696 6697 6698 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6696 def inspect_config @inspect_config end |
#inspect_template_name ⇒ String
If provided, will be used as the default for all values in InspectConfig.
inspect_config will be merged into the values persisted as part of the
template.
Corresponds to the JSON property inspectTemplateName
6703 6704 6705 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6703 def inspect_template_name @inspect_template_name end |
#storage_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageConfig
Shared message indicating Cloud storage type.
Corresponds to the JSON property storageConfig
6708 6709 6710 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6708 def storage_config @storage_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6715 6716 6717 6718 6719 6720 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6715 def update!(**args) @actions = args[:actions] if args.key?(:actions) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name) @storage_config = args[:storage_config] if args.key?(:storage_config) end |