Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A single inspection rule to be applied to infoTypes, specified in InspectionRuleSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectionRule

Returns a new instance of GooglePrivacyDlpV2InspectionRule.



7297
7298
7299
# File 'lib/google/apis/dlp_v2/classes.rb', line 7297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule

Rule that specifies conditions when a certain infoType's finding details should be adjusted. Corresponds to the JSON property adjustmentRule



7283
7284
7285
# File 'lib/google/apis/dlp_v2/classes.rb', line 7283

def adjustment_rule
  @adjustment_rule
end

#exclusion_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule

The rule that specifies conditions when findings of infoTypes specified in InspectionRuleSet are removed from results. Corresponds to the JSON property exclusionRule



7289
7290
7291
# File 'lib/google/apis/dlp_v2/classes.rb', line 7289

def exclusion_rule
  @exclusion_rule
end

#hotword_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2HotwordRule

The rule that adjusts the likelihood of findings within a certain proximity of hotwords. Corresponds to the JSON property hotwordRule



7295
7296
7297
# File 'lib/google/apis/dlp_v2/classes.rb', line 7295

def hotword_rule
  @hotword_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7302
7303
7304
7305
7306
# File 'lib/google/apis/dlp_v2/classes.rb', line 7302

def update!(**args)
  @adjustment_rule = args[:adjustment_rule] if args.key?(:adjustment_rule)
  @exclusion_rule = args[:exclusion_rule] if args.key?(:exclusion_rule)
  @hotword_rule = args[:hotword_rule] if args.key?(:hotword_rule)
end