Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

k-anonymity metric, used for analysis of reidentification risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2KAnonymityConfig

Returns a new instance of GooglePrivacyDlpV2KAnonymityConfig.



7453
7454
7455
# File 'lib/google/apis/dlp_v2/classes.rb', line 7453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#entity_idGoogle::Apis::DlpV2::GooglePrivacyDlpV2EntityId

An entity in a dataset is a field or set of fields that correspond to a single person. For example, in medical records the EntityId might be a patient identifier, or for financial records it might be an account identifier. This message is used when generalizations or analysis must take into account that multiple rows correspond to the same entity. Corresponds to the JSON property entityId



7443
7444
7445
# File 'lib/google/apis/dlp_v2/classes.rb', line 7443

def entity_id
  @entity_id
end

#quasi_idsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>

Set of fields to compute k-anonymity over. When multiple fields are specified, they are considered a single composite key. Structs and repeated data types are not supported; however, nested fields are supported so long as they are not structs themselves or nested within a repeated field. Corresponds to the JSON property quasiIds



7451
7452
7453
# File 'lib/google/apis/dlp_v2/classes.rb', line 7451

def quasi_ids
  @quasi_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7458
7459
7460
7461
# File 'lib/google/apis/dlp_v2/classes.rb', line 7458

def update!(**args)
  @entity_id = args[:entity_id] if args.key?(:entity_id)
  @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids)
end