Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListDlpJobsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ListDlpJobsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The response message for listing DLP jobs.
Instance Attribute Summary collapse
-
#jobs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DlpJob>
A list of DlpJobs that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ListDlpJobsResponse
constructor
A new instance of GooglePrivacyDlpV2ListDlpJobsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ListDlpJobsResponse
Returns a new instance of GooglePrivacyDlpV2ListDlpJobsResponse.
7879 7880 7881 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7879 def initialize(**args) update!(**args) end |
Instance Attribute Details
#jobs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DlpJob>
A list of DlpJobs that matches the specified filter in the request.
Corresponds to the JSON property jobs
7872 7873 7874 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7872 def jobs @jobs end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
7877 7878 7879 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7877 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7884 7885 7886 7887 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7884 def update!(**args) @jobs = args[:jobs] if args.key?(:jobs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |