Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListInspectTemplatesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Response message for ListInspectTemplates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ListInspectTemplatesResponse

Returns a new instance of GooglePrivacyDlpV2ListInspectTemplatesResponse.



8323
8324
8325
# File 'lib/google/apis/dlp_v2/classes.rb', line 8323

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_templatesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate>

List of inspectTemplates, up to page_size in ListInspectTemplatesRequest. Corresponds to the JSON property inspectTemplates



8315
8316
8317
# File 'lib/google/apis/dlp_v2/classes.rb', line 8315

def inspect_templates
  @inspect_templates
end

#next_page_tokenString

If the next page is available then the next page token to be used in the following ListInspectTemplates request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8321
8322
8323
# File 'lib/google/apis/dlp_v2/classes.rb', line 8321

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8328
8329
8330
8331
# File 'lib/google/apis/dlp_v2/classes.rb', line 8328

def update!(**args)
  @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end