Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the location of the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Location

Returns a new instance of GooglePrivacyDlpV2Location.



8038
8039
8040
# File 'lib/google/apis/dlp_v2/classes.rb', line 8038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property byteRange



8019
8020
8021
# File 'lib/google/apis/dlp_v2/classes.rb', line 8019

def byte_range
  @byte_range
end

#codepoint_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property codepointRange



8024
8025
8026
# File 'lib/google/apis/dlp_v2/classes.rb', line 8024

def codepoint_range
  @codepoint_range
end

#containerGoogle::Apis::DlpV2::GooglePrivacyDlpV2Container

Represents a container that may contain DLP findings. Examples of a container include a file, table, or database record. Corresponds to the JSON property container



8030
8031
8032
# File 'lib/google/apis/dlp_v2/classes.rb', line 8030

def container
  @container
end

#content_locationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation>

List of nested objects pointing to the precise location of the finding within the file or record. Corresponds to the JSON property contentLocations



8036
8037
8038
# File 'lib/google/apis/dlp_v2/classes.rb', line 8036

def content_locations
  @content_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8043
8044
8045
8046
8047
8048
# File 'lib/google/apis/dlp_v2/classes.rb', line 8043

def update!(**args)
  @byte_range = args[:byte_range] if args.key?(:byte_range)
  @codepoint_range = args[:codepoint_range] if args.key?(:codepoint_range)
  @container = args[:container] if args.key?(:container)
  @content_locations = args[:content_locations] if args.key?(:content_locations)
end