Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PartitionId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Datastore partition ID. A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PartitionId

Returns a new instance of GooglePrivacyDlpV2PartitionId.



9008
9009
9010
# File 'lib/google/apis/dlp_v2/classes.rb', line 9008

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_idString

If not empty, the ID of the namespace to which the entities belong. Corresponds to the JSON property namespaceId

Returns:

  • (String)


9001
9002
9003
# File 'lib/google/apis/dlp_v2/classes.rb', line 9001

def namespace_id
  @namespace_id
end

#project_idString

The ID of the project to which the entities belong. Corresponds to the JSON property projectId

Returns:

  • (String)


9006
9007
9008
# File 'lib/google/apis/dlp_v2/classes.rb', line 9006

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9013
9014
9015
9016
# File 'lib/google/apis/dlp_v2/classes.rb', line 9013

def update!(**args)
  @namespace_id = args[:namespace_id] if args.key?(:namespace_id)
  @project_id = args[:project_id] if args.key?(:project_id)
end