Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A single policy rule. The first rule to match from the list above controls the result.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PolicyRule

Returns a new instance of GooglePrivacyDlpV2PolicyRule.



9104
9105
9106
# File 'lib/google/apis/dlp_v2/classes.rb', line 9104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction

A possible action to take when applying a content policy. Corresponds to the JSON property action



9090
9091
9092
# File 'lib/google/apis/dlp_v2/classes.rb', line 9090

def action
  @action
end

#conditionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyCondition>

Optional. Conditions that must match for this rule to apply. All conditions must match (AND). For OR conditions, use multiple rules. Corresponds to the JSON property conditions



9096
9097
9098
# File 'lib/google/apis/dlp_v2/classes.rb', line 9096

def conditions
  @conditions
end

#return_verdictString

If set, the verdict will be returned to the user. Deprecated: Use action instead. Corresponds to the JSON property returnVerdict

Returns:

  • (String)


9102
9103
9104
# File 'lib/google/apis/dlp_v2/classes.rb', line 9102

def return_verdict
  @return_verdict
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9109
9110
9111
9112
9113
# File 'lib/google/apis/dlp_v2/classes.rb', line 9109

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @conditions = args[:conditions] if args.key?(:conditions)
  @return_verdict = args[:return_verdict] if args.key?(:return_verdict)
end