Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProjectDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

An aggregated profile for this project, based on the resources profiled within it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ProjectDataProfile

Returns a new instance of GooglePrivacyDlpV2ProjectDataProfile.



9417
9418
9419
# File 'lib/google/apis/dlp_v2/classes.rb', line 9417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



9379
9380
9381
# File 'lib/google/apis/dlp_v2/classes.rb', line 9379

def data_risk_level
  @data_risk_level
end

#file_store_data_profile_countFixnum

The number of file store data profiles generated for this project. Corresponds to the JSON property fileStoreDataProfileCount

Returns:

  • (Fixnum)


9384
9385
9386
# File 'lib/google/apis/dlp_v2/classes.rb', line 9384

def file_store_data_profile_count
  @file_store_data_profile_count
end

#nameString

The resource name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


9389
9390
9391
# File 'lib/google/apis/dlp_v2/classes.rb', line 9389

def name
  @name
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


9394
9395
9396
# File 'lib/google/apis/dlp_v2/classes.rb', line 9394

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



9399
9400
9401
# File 'lib/google/apis/dlp_v2/classes.rb', line 9399

def profile_status
  @profile_status
end

#project_idString

Project ID or account that was profiled. Corresponds to the JSON property projectId

Returns:

  • (String)


9404
9405
9406
# File 'lib/google/apis/dlp_v2/classes.rb', line 9404

def project_id
  @project_id
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



9410
9411
9412
# File 'lib/google/apis/dlp_v2/classes.rb', line 9410

def sensitivity_score
  @sensitivity_score
end

#table_data_profile_countFixnum

The number of table data profiles generated for this project. Corresponds to the JSON property tableDataProfileCount

Returns:

  • (Fixnum)


9415
9416
9417
# File 'lib/google/apis/dlp_v2/classes.rb', line 9415

def table_data_profile_count
  @table_data_profile_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
# File 'lib/google/apis/dlp_v2/classes.rb', line 9422

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @file_store_data_profile_count = args[:file_store_data_profile_count] if args.key?(:file_store_data_profile_count)
  @name = args[:name] if args.key?(:name)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_id = args[:project_id] if args.key?(:project_id)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @table_data_profile_count = args[:table_data_profile_count] if args.key?(:table_data_profile_count)
end