Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubExpressions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubExpressions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
An expression, consisting of an operator and conditions.
Instance Attribute Summary collapse
-
#conditions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubCondition>
Conditions to apply to the expression.
-
#logical_operator ⇒ String
The operator to apply to the collection of conditions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2PubSubExpressions
constructor
A new instance of GooglePrivacyDlpV2PubSubExpressions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2PubSubExpressions
Returns a new instance of GooglePrivacyDlpV2PubSubExpressions.
9495 9496 9497 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9495 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubCondition>
Conditions to apply to the expression.
Corresponds to the JSON property conditions
9488 9489 9490 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9488 def conditions @conditions end |
#logical_operator ⇒ String
The operator to apply to the collection of conditions.
Corresponds to the JSON property logicalOperator
9493 9494 9495 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9493 def logical_operator @logical_operator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9500 9501 9502 9503 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9500 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @logical_operator = args[:logical_operator] if args.key?(:logical_operator) end |