Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PublishFindingsToDataplexCatalog

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Publish findings of a DlpJob to Dataplex Universal Catalog as a sensitive- data-protection-job-result aspect. For more information, see Send inspection results to Dataplex Universal Catalog as aspects. Aspects are stored in Dataplex Universal Catalog storage and are governed by service-specific policies for Dataplex Universal Catalog. For more information, see Service Specific Terms. Only a single instance of this action can be specified. This action is allowed only if all resources being scanned are BigQuery tables. Compatible with: Inspect

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PublishFindingsToDataplexCatalog

Returns a new instance of GooglePrivacyDlpV2PublishFindingsToDataplexCatalog.



8570
8571
8572
# File 'lib/google/apis/dlp_v2/classes.rb', line 8570

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8575
8576
# File 'lib/google/apis/dlp_v2/classes.rb', line 8575

def update!(**args)
end