Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PublishSummaryToCscc
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2PublishSummaryToCscc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Publish the result summary of a DlpJob to Security Command Center. This action is available for only projects that belong to an organization. This action publishes the count of finding instances and their infoTypes. The summary of findings are persisted in Security Command Center and are governed by service-specific policies for Security Command Center. Only a single instance of this action can be specified. Compatible with: Inspect
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2PublishSummaryToCscc
constructor
A new instance of GooglePrivacyDlpV2PublishSummaryToCscc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2PublishSummaryToCscc
Returns a new instance of GooglePrivacyDlpV2PublishSummaryToCscc.
8837 8838 8839 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8837 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8842 8843 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8842 def update!(**args) end |