Class: Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A quasi-identifier column has a custom_tag, used to know which column in the data corresponds to which column in the statistical model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdField

Returns a new instance of GooglePrivacyDlpV2QuasiIdField.



8997
8998
8999
# File 'lib/google/apis/dlp_v2/classes.rb', line 8997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_tagString

A auxiliary field. Corresponds to the JSON property customTag

Returns:

  • (String)


8990
8991
8992
# File 'lib/google/apis/dlp_v2/classes.rb', line 8990

def custom_tag
  @custom_tag
end

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



8995
8996
8997
# File 'lib/google/apis/dlp_v2/classes.rb', line 8995

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9002
9003
9004
9005
# File 'lib/google/apis/dlp_v2/classes.rb', line 9002

def update!(**args)
  @custom_tag = args[:custom_tag] if args.key?(:custom_tag)
  @field = args[:field] if args.key?(:field)
end