Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The field in a record to transform.
Instance Attribute Summary collapse
-
#container_timestamp ⇒ String
Findings container modification timestamp, if applicable.
-
#container_version ⇒ String
Container version, if available ("generation" for Cloud Storage).
-
#field_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2RecordTransformation
constructor
A new instance of GooglePrivacyDlpV2RecordTransformation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2RecordTransformation
Returns a new instance of GooglePrivacyDlpV2RecordTransformation.
8955 8956 8957 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8955 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_timestamp ⇒ String
Findings container modification timestamp, if applicable.
Corresponds to the JSON property containerTimestamp
8943 8944 8945 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8943 def @container_timestamp end |
#container_version ⇒ String
Container version, if available ("generation" for Cloud Storage).
Corresponds to the JSON property containerVersion
8948 8949 8950 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8948 def container_version @container_version end |
#field_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property fieldId
8953 8954 8955 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8953 def field_id @field_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8960 8961 8962 8963 8964 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8960 def update!(**args) @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp) @container_version = args[:container_version] if args.key?(:container_version) @field_id = args[:field_id] if args.key?(:field_id) end |