Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RedactImageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to search for potentially sensitive info in an image and redact it by covering it with a colored rectangle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RedactImageRequest

Returns a new instance of GooglePrivacyDlpV2RedactImageRequest.



10074
10075
10076
# File 'lib/google/apis/dlp_v2/classes.rb', line 10074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ByteContentItem

Container for bytes to inspect or redact. Corresponds to the JSON property byteItem



10032
10033
10034
# File 'lib/google/apis/dlp_v2/classes.rb', line 10032

def byte_item
  @byte_item
end

#deidentify_templateString

The full resource name of the de-identification template to use. Settings in the main image_redaction_configs field override the corresponding settings in this de-identification template. The request fails if the type of the template's deidentify_config is not image_transformations. Corresponds to the JSON property deidentifyTemplate

Returns:

  • (String)


10040
10041
10042
# File 'lib/google/apis/dlp_v2/classes.rb', line 10040

def deidentify_template
  @deidentify_template
end

#image_redaction_configsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ImageRedactionConfig>

The configuration for specifying what content to redact from images. Corresponds to the JSON property imageRedactionConfigs



10045
10046
10047
# File 'lib/google/apis/dlp_v2/classes.rb', line 10045

def image_redaction_configs
  @image_redaction_configs
end

#include_findingsBoolean Also known as: include_findings?

Whether the response should include findings along with the redacted image. Corresponds to the JSON property includeFindings

Returns:

  • (Boolean)


10050
10051
10052
# File 'lib/google/apis/dlp_v2/classes.rb', line 10050

def include_findings
  @include_findings
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



10057
10058
10059
# File 'lib/google/apis/dlp_v2/classes.rb', line 10057

def inspect_config
  @inspect_config
end

#inspect_templateString

The full resource name of the inspection template to use. Settings in the main inspect_config field override the corresponding settings in this inspection template. The merge behavior is as follows: - Singular field: The main field's value replaces the value of the corresponding field in the template. - Repeated fields: The field values are appended to the list defined in the template. - Sub-messages and groups: The fields are recursively merged. Corresponds to the JSON property inspectTemplate

Returns:

  • (String)


10067
10068
10069
# File 'lib/google/apis/dlp_v2/classes.rb', line 10067

def inspect_template
  @inspect_template
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


10072
10073
10074
# File 'lib/google/apis/dlp_v2/classes.rb', line 10072

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10079
10080
10081
10082
10083
10084
10085
10086
10087
# File 'lib/google/apis/dlp_v2/classes.rb', line 10079

def update!(**args)
  @byte_item = args[:byte_item] if args.key?(:byte_item)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @image_redaction_configs = args[:image_redaction_configs] if args.key?(:image_redaction_configs)
  @include_findings = args[:include_findings] if args.key?(:include_findings)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
  @location_id = args[:location_id] if args.key?(:location_id)
end