Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ReplaceValueConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Replace each input value with a given Value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ReplaceValueConfig

Returns a new instance of GooglePrivacyDlpV2ReplaceValueConfig.



9747
9748
9749
# File 'lib/google/apis/dlp_v2/classes.rb', line 9747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#new_valueGoogle::Apis::DlpV2::GooglePrivacyDlpV2Value

Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data. Corresponds to the JSON property newValue



9745
9746
9747
# File 'lib/google/apis/dlp_v2/classes.rb', line 9745

def new_value
  @new_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9752
9753
9754
# File 'lib/google/apis/dlp_v2/classes.rb', line 9752

def update!(**args)
  @new_value = args[:new_value] if args.key?(:new_value)
end