Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RequestedOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Snapshot of the inspection configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RequestedOptions

Returns a new instance of GooglePrivacyDlpV2RequestedOptions.



10363
10364
10365
# File 'lib/google/apis/dlp_v2/classes.rb', line 10363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig

Controls what and how to inspect for findings. Corresponds to the JSON property jobConfig



10353
10354
10355
# File 'lib/google/apis/dlp_v2/classes.rb', line 10353

def job_config
  @job_config
end

#snapshot_inspect_templateGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate

The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more. Corresponds to the JSON property snapshotInspectTemplate



10361
10362
10363
# File 'lib/google/apis/dlp_v2/classes.rb', line 10361

def snapshot_inspect_template
  @snapshot_inspect_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10368
10369
10370
10371
# File 'lib/google/apis/dlp_v2/classes.rb', line 10368

def update!(**args)
  @job_config = args[:job_config] if args.key?(:job_config)
  @snapshot_inspect_template = args[:snapshot_inspect_template] if args.key?(:snapshot_inspect_template)
end