Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RiskAnalysisJobConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for a risk analysis job. See https://cloud.google.com/sensitive- data-protection/docs/concepts-risk-analysis to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RiskAnalysisJobConfig

Returns a new instance of GooglePrivacyDlpV2RiskAnalysisJobConfig.



9923
9924
9925
# File 'lib/google/apis/dlp_v2/classes.rb', line 9923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Action>

Actions to execute at the completion of the job. Are executed in the order provided. Corresponds to the JSON property actions



9909
9910
9911
# File 'lib/google/apis/dlp_v2/classes.rb', line 9909

def actions
  @actions
end

#privacy_metricGoogle::Apis::DlpV2::GooglePrivacyDlpV2PrivacyMetric

Privacy metric to compute for reidentification risk analysis. Corresponds to the JSON property privacyMetric



9914
9915
9916
# File 'lib/google/apis/dlp_v2/classes.rb', line 9914

def privacy_metric
  @privacy_metric
end

#source_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sourceTable



9921
9922
9923
# File 'lib/google/apis/dlp_v2/classes.rb', line 9921

def source_table
  @source_table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9928
9929
9930
9931
9932
# File 'lib/google/apis/dlp_v2/classes.rb', line 9928

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @privacy_metric = args[:privacy_metric] if args.key?(:privacy_metric)
  @source_table = args[:source_table] if args.key?(:source_table)
end