Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SaveFindings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

If set, the detailed findings will be persisted to the specified OutputStorageConfig. Only a single instance of this action can be specified. Compatible with: Inspect, Risk

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SaveFindings

Returns a new instance of GooglePrivacyDlpV2SaveFindings.



9847
9848
9849
# File 'lib/google/apis/dlp_v2/classes.rb', line 9847

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2OutputStorageConfig

Cloud repository for storing output. Corresponds to the JSON property outputConfig



9845
9846
9847
# File 'lib/google/apis/dlp_v2/classes.rb', line 9845

def output_config
  @output_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9852
9853
9854
# File 'lib/google/apis/dlp_v2/classes.rb', line 9852

def update!(**args)
  @output_config = args[:output_config] if args.key?(:output_config)
end