Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SchemaModifiedCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How frequently to modify the profile when the table's schema is modified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SchemaModifiedCadence

Returns a new instance of GooglePrivacyDlpV2SchemaModifiedCadence.



9805
9806
9807
# File 'lib/google/apis/dlp_v2/classes.rb', line 9805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequencyString

Frequency to regenerate data profiles when the schema is modified. Defaults to monthly. Corresponds to the JSON property frequency

Returns:

  • (String)


9798
9799
9800
# File 'lib/google/apis/dlp_v2/classes.rb', line 9798

def frequency
  @frequency
end

#typesArray<String>

The types of schema modifications to consider. Defaults to NEW_COLUMNS. Corresponds to the JSON property types

Returns:

  • (Array<String>)


9803
9804
9805
# File 'lib/google/apis/dlp_v2/classes.rb', line 9803

def types
  @types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9810
9811
9812
9813
# File 'lib/google/apis/dlp_v2/classes.rb', line 9810

def update!(**args)
  @frequency = args[:frequency] if args.key?(:frequency)
  @types = args[:types] if args.key?(:types)
end