Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SensitivityScore

Returns a new instance of GooglePrivacyDlpV2SensitivityScore.



10033
10034
10035
# File 'lib/google/apis/dlp_v2/classes.rb', line 10033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scoreString

The sensitivity score applied to the resource. Corresponds to the JSON property score

Returns:

  • (String)


10031
10032
10033
# File 'lib/google/apis/dlp_v2/classes.rb', line 10031

def score
  @score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10038
10039
10040
# File 'lib/google/apis/dlp_v2/classes.rb', line 10038

def update!(**args)
  @score = args[:score] if args.key?(:score)
end