Class: Google::Apis::DlpV2::GooglePrivacyDlpV2StorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Shared message indicating Cloud storage type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2StorageConfig

Returns a new instance of GooglePrivacyDlpV2StorageConfig.



10807
10808
10809
# File 'lib/google/apis/dlp_v2/classes.rb', line 10807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryOptions

Options defining BigQuery table and row identifiers. Corresponds to the JSON property bigQueryOptions



10783
10784
10785
# File 'lib/google/apis/dlp_v2/classes.rb', line 10783

def big_query_options
  @big_query_options
end

#cloud_storage_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageOptions

Options defining a file or a set of files within a Cloud Storage bucket. Corresponds to the JSON property cloudStorageOptions



10788
10789
10790
# File 'lib/google/apis/dlp_v2/classes.rb', line 10788

def cloud_storage_options
  @cloud_storage_options
end

#datastore_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatastoreOptions

Options defining a data set within Google Cloud Datastore. Corresponds to the JSON property datastoreOptions



10793
10794
10795
# File 'lib/google/apis/dlp_v2/classes.rb', line 10793

def datastore_options
  @datastore_options
end

#hybrid_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2HybridOptions

Configuration to control jobs where the content being inspected is outside of Google Cloud Platform. Corresponds to the JSON property hybridOptions



10799
10800
10801
# File 'lib/google/apis/dlp_v2/classes.rb', line 10799

def hybrid_options
  @hybrid_options
end

#timespan_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2TimespanConfig

Configuration of the timespan of the items to include in scanning. Currently only supported when inspecting Cloud Storage and BigQuery. Corresponds to the JSON property timespanConfig



10805
10806
10807
# File 'lib/google/apis/dlp_v2/classes.rb', line 10805

def timespan_config
  @timespan_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10812
10813
10814
10815
10816
10817
10818
# File 'lib/google/apis/dlp_v2/classes.rb', line 10812

def update!(**args)
  @big_query_options = args[:big_query_options] if args.key?(:big_query_options)
  @cloud_storage_options = args[:cloud_storage_options] if args.key?(:cloud_storage_options)
  @datastore_options = args[:datastore_options] if args.key?(:datastore_options)
  @hybrid_options = args[:hybrid_options] if args.key?(:hybrid_options)
  @timespan_config = args[:timespan_config] if args.key?(:timespan_config)
end