Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SummaryResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A collection that informs the user the number of times a particular TransformationResultCode and error details occurred.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SummaryResult

Returns a new instance of GooglePrivacyDlpV2SummaryResult.



10488
10489
10490
# File 'lib/google/apis/dlp_v2/classes.rb', line 10488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Outcome of the transformation. Corresponds to the JSON property code

Returns:

  • (String)


10475
10476
10477
# File 'lib/google/apis/dlp_v2/classes.rb', line 10475

def code
  @code
end

#countFixnum

Number of transformations counted by this result. Corresponds to the JSON property count

Returns:

  • (Fixnum)


10480
10481
10482
# File 'lib/google/apis/dlp_v2/classes.rb', line 10480

def count
  @count
end

#detailsString

A place for warnings or errors to show up if a transformation didn't work as expected. Corresponds to the JSON property details

Returns:

  • (String)


10486
10487
10488
# File 'lib/google/apis/dlp_v2/classes.rb', line 10486

def details
  @details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10493
10494
10495
10496
10497
# File 'lib/google/apis/dlp_v2/classes.rb', line 10493

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @count = args[:count] if args.key?(:count)
  @details = args[:details] if args.key?(:details)
end