Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile

Returns a new instance of GooglePrivacyDlpV2TableDataProfile.



11322
11323
11324
# File 'lib/google/apis/dlp_v2/classes.rb', line 11322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_snapshotGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Snapshot of the configurations used to generate the profile. Corresponds to the JSON property configSnapshot



11164
11165
11166
# File 'lib/google/apis/dlp_v2/classes.rb', line 11164

def config_snapshot
  @config_snapshot
end

#create_timeString

The time at which the table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11169
11170
11171
# File 'lib/google/apis/dlp_v2/classes.rb', line 11169

def create_time
  @create_time
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



11175
11176
11177
# File 'lib/google/apis/dlp_v2/classes.rb', line 11175

def data_risk_level
  @data_risk_level
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



11180
11181
11182
# File 'lib/google/apis/dlp_v2/classes.rb', line 11180

def data_source_type
  @data_source_type
end

#dataset_idString

If the resource is BigQuery, the dataset ID. Corresponds to the JSON property datasetId

Returns:

  • (String)


11185
11186
11187
# File 'lib/google/apis/dlp_v2/classes.rb', line 11185

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// docs.cloud.google.com/bigquery/docs/locations for supported locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


11191
11192
11193
# File 'lib/google/apis/dlp_v2/classes.rb', line 11191

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


11196
11197
11198
# File 'lib/google/apis/dlp_v2/classes.rb', line 11196

def dataset_project_id
  @dataset_project_id
end

#domainsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>

Domains associated with the profile. Corresponds to the JSON property domains



11201
11202
11203
# File 'lib/google/apis/dlp_v2/classes.rb', line 11201

def domains
  @domains
end

#encryption_statusString

How the table is encrypted. Corresponds to the JSON property encryptionStatus

Returns:

  • (String)


11206
11207
11208
# File 'lib/google/apis/dlp_v2/classes.rb', line 11206

def encryption_status
  @encryption_status
end

#expiration_timeString

Optional. The time when this table expires. Corresponds to the JSON property expirationTime

Returns:

  • (String)


11211
11212
11213
# File 'lib/google/apis/dlp_v2/classes.rb', line 11211

def expiration_time
  @expiration_time
end

#failed_column_countFixnum

The number of columns skipped in the table because of an error. Corresponds to the JSON property failedColumnCount

Returns:

  • (Fixnum)


11216
11217
11218
# File 'lib/google/apis/dlp_v2/classes.rb', line 11216

def failed_column_count
  @failed_column_count
end

#full_resourceString

The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile. https://cloud.google.com/apis/design/resource_names# full_resource_name Corresponds to the JSON property fullResource

Returns:

  • (String)


11223
11224
11225
# File 'lib/google/apis/dlp_v2/classes.rb', line 11223

def full_resource
  @full_resource
end

#last_modified_timeString

The time when this table was last modified Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


11228
11229
11230
# File 'lib/google/apis/dlp_v2/classes.rb', line 11228

def last_modified_time
  @last_modified_time
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


11233
11234
11235
# File 'lib/google/apis/dlp_v2/classes.rb', line 11233

def name
  @name
end

#other_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other infoTypes found in this table's data. Corresponds to the JSON property otherInfoTypes



11238
11239
11240
# File 'lib/google/apis/dlp_v2/classes.rb', line 11238

def other_info_types
  @other_info_types
end

#predicted_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>

The infoTypes predicted from this table's data. Corresponds to the JSON property predictedInfoTypes



11243
11244
11245
# File 'lib/google/apis/dlp_v2/classes.rb', line 11243

def predicted_info_types
  @predicted_info_types
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


11248
11249
11250
# File 'lib/google/apis/dlp_v2/classes.rb', line 11248

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



11253
11254
11255
# File 'lib/google/apis/dlp_v2/classes.rb', line 11253

def profile_status
  @profile_status
end

#project_data_profileString

The resource name of the project data profile for this table. Corresponds to the JSON property projectDataProfile

Returns:

  • (String)


11258
11259
11260
# File 'lib/google/apis/dlp_v2/classes.rb', line 11258

def project_data_profile
  @project_data_profile
end

Resources related to this profile. Corresponds to the JSON property relatedResources



11263
11264
11265
# File 'lib/google/apis/dlp_v2/classes.rb', line 11263

def related_resources
  @related_resources
end

#resource_labelsHash<String,String>

The labels applied to the resource at the time the profile was generated. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


11268
11269
11270
# File 'lib/google/apis/dlp_v2/classes.rb', line 11268

def resource_labels
  @resource_labels
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


11273
11274
11275
# File 'lib/google/apis/dlp_v2/classes.rb', line 11273

def resource_visibility
  @resource_visibility
end

#row_countFixnum

Number of rows in the table when the profile was generated. This will not be populated for BigLake tables. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


11279
11280
11281
# File 'lib/google/apis/dlp_v2/classes.rb', line 11279

def row_count
  @row_count
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



11286
11287
11288
# File 'lib/google/apis/dlp_v2/classes.rb', line 11286

def sample_findings_table
  @sample_findings_table
end

#scanned_column_countFixnum

The number of columns profiled in the table. Corresponds to the JSON property scannedColumnCount

Returns:

  • (Fixnum)


11291
11292
11293
# File 'lib/google/apis/dlp_v2/classes.rb', line 11291

def scanned_column_count
  @scanned_column_count
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



11297
11298
11299
# File 'lib/google/apis/dlp_v2/classes.rb', line 11297

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. This will always be set to DONE when the table data profile is written to another service like BigQuery or Pub/Sub. Corresponds to the JSON property state

Returns:

  • (String)


11303
11304
11305
# File 'lib/google/apis/dlp_v2/classes.rb', line 11303

def state
  @state
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


11308
11309
11310
# File 'lib/google/apis/dlp_v2/classes.rb', line 11308

def table_id
  @table_id
end

#table_size_bytesFixnum

The size of the table when the profile was generated. Corresponds to the JSON property tableSizeBytes

Returns:

  • (Fixnum)


11313
11314
11315
# File 'lib/google/apis/dlp_v2/classes.rb', line 11313

def table_size_bytes
  @table_size_bytes
end

#tagsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>

The tags attached to the table, including any tags attached during profiling. Because tags are attached to Cloud SQL instances rather than Cloud SQL tables, this field is empty for Cloud SQL table profiles. Corresponds to the JSON property tags



11320
11321
11322
# File 'lib/google/apis/dlp_v2/classes.rb', line 11320

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11327
11328
11329
11330
11331
11332
11333
11334
11335
11336
11337
11338
11339
11340
11341
11342
11343
11344
11345
11346
11347
11348
11349
11350
11351
11352
11353
11354
11355
11356
11357
11358
# File 'lib/google/apis/dlp_v2/classes.rb', line 11327

def update!(**args)
  @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @domains = args[:domains] if args.key?(:domains)
  @encryption_status = args[:encryption_status] if args.key?(:encryption_status)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count)
  @full_resource = args[:full_resource] if args.key?(:full_resource)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @other_info_types = args[:other_info_types] if args.key?(:other_info_types)
  @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @row_count = args[:row_count] if args.key?(:row_count)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
  @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_id = args[:table_id] if args.key?(:table_id)
  @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes)
  @tags = args[:tags] if args.key?(:tags)
end