Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Location of a finding within a table.
Instance Attribute Summary collapse
-
#row_index ⇒ Fixnum
The zero-based index of the row where the finding is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableLocation
constructor
A new instance of GooglePrivacyDlpV2TableLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableLocation
Returns a new instance of GooglePrivacyDlpV2TableLocation.
11373 11374 11375 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#row_index ⇒ Fixnum
The zero-based index of the row where the finding is located. Only populated
for resources that have a natural ordering, not BigQuery. In BigQuery, to
identify the row a finding came from, populate BigQueryOptions.
identifying_fields with your primary key column names and when you store the
findings the value of those columns will be stored inside of Finding.
Corresponds to the JSON property rowIndex
11371 11372 11373 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11371 def row_index @row_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11378 11379 11380 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11378 def update!(**args) @row_index = args[:row_index] if args.key?(:row_index) end |