Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Tag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A tag associated with a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Tag

Returns a new instance of GooglePrivacyDlpV2Tag.



10924
10925
10926
# File 'lib/google/apis/dlp_v2/classes.rb', line 10924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

The key of a tag key-value pair. For Google Cloud resources, this is the resource name of the key, for example, "tagKeys/123456". Corresponds to the JSON property key

Returns:

  • (String)


10907
10908
10909
# File 'lib/google/apis/dlp_v2/classes.rb', line 10907

def key
  @key
end

#namespaced_tag_valueString

The namespaced name for the tag value to attach to Google Cloud resources. Must be in the format parent_id`/`tag_key_short_name`/`short_name, for example, "123456/environment/prod" for an organization parent, or "my-project/ environment/prod" for a project parent. This is only set for Google Cloud resources. Corresponds to the JSON property namespacedTagValue

Returns:

  • (String)


10916
10917
10918
# File 'lib/google/apis/dlp_v2/classes.rb', line 10916

def namespaced_tag_value
  @namespaced_tag_value
end

#valueString

The value of a tag key-value pair. For Google Cloud resources, this is the resource name of the value, for example, "tagValues/123456". Corresponds to the JSON property value

Returns:

  • (String)


10922
10923
10924
# File 'lib/google/apis/dlp_v2/classes.rb', line 10922

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10929
10930
10931
10932
10933
# File 'lib/google/apis/dlp_v2/classes.rb', line 10929

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @namespaced_tag_value = args[:namespaced_tag_value] if args.key?(:namespaced_tag_value)
  @value = args[:value] if args.key?(:value)
end