Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TagCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The tag to attach to profiles matching the condition. At most one TagCondition can be specified per sensitivity level.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TagCondition

Returns a new instance of GooglePrivacyDlpV2TagCondition.



11479
11480
11481
# File 'lib/google/apis/dlp_v2/classes.rb', line 11479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



11472
11473
11474
# File 'lib/google/apis/dlp_v2/classes.rb', line 11472

def sensitivity_score
  @sensitivity_score
end

#tagGoogle::Apis::DlpV2::GooglePrivacyDlpV2TagValue

A value of a tag. Corresponds to the JSON property tag



11477
11478
11479
# File 'lib/google/apis/dlp_v2/classes.rb', line 11477

def tag
  @tag
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11484
11485
11486
11487
# File 'lib/google/apis/dlp_v2/classes.rb', line 11484

def update!(**args)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @tag = args[:tag] if args.key?(:tag)
end