Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TimespanConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TimespanConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration of the timespan of the items to include in scanning. Currently only supported when inspecting Cloud Storage and BigQuery.
Instance Attribute Summary collapse
-
#enable_auto_population_of_timespan_config ⇒ Boolean
(also: #enable_auto_population_of_timespan_config?)
When the job is started by a JobTrigger we will automatically figure out a valid start_time to avoid scanning files that have not been modified since the last time the JobTrigger executed.
-
#end_time ⇒ String
Exclude files, tables, or rows newer than this value.
-
#start_time ⇒ String
Exclude files, tables, or rows older than this value.
-
#timestamp_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TimespanConfig
constructor
A new instance of GooglePrivacyDlpV2TimespanConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TimespanConfig
Returns a new instance of GooglePrivacyDlpV2TimespanConfig.
11747 11748 11749 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_auto_population_of_timespan_config ⇒ Boolean Also known as: enable_auto_population_of_timespan_config?
When the job is started by a JobTrigger we will automatically figure out a
valid start_time to avoid scanning files that have not been modified since the
last time the JobTrigger executed. This will be based on the time of the
execution of the last run of the JobTrigger or the timespan end_time used in
the last run of the JobTrigger. For BigQuery Inspect jobs triggered by
automatic population will scan data that is at least three hours old when the
job starts. This is because streaming buffer rows are not read during
inspection and reading up to the current timestamp will result in skipped rows.
See the known issue related to this operation.
Corresponds to the JSON property enableAutoPopulationOfTimespanConfig
11727 11728 11729 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11727 def enable_auto_population_of_timespan_config @enable_auto_population_of_timespan_config end |
#end_time ⇒ String
Exclude files, tables, or rows newer than this value. If not set, no upper
time limit is applied.
Corresponds to the JSON property endTime
11734 11735 11736 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11734 def end_time @end_time end |
#start_time ⇒ String
Exclude files, tables, or rows older than this value. If not set, no lower
time limit is applied.
Corresponds to the JSON property startTime
11740 11741 11742 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11740 def start_time @start_time end |
#timestamp_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property timestampField
11745 11746 11747 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11745 def @timestamp_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11752 11753 11754 11755 11756 11757 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11752 def update!(**args) @enable_auto_population_of_timespan_config = args[:enable_auto_population_of_timespan_config] if args.key?(:enable_auto_population_of_timespan_config) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) @timestamp_field = args[:timestamp_field] if args.key?(:timestamp_field) end |