Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationErrorHandling

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How to handle transformation errors during de-identification. A transformation error occurs when the requested transformation is incompatible with the data. For example, trying to de-identify an IP address using a DateShift transformation would result in a transformation error, since date info cannot be extracted from an IP address. Information about any incompatible transformations, and how they were handled, is returned in the response as part of the TransformationOverviews.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationErrorHandling

Returns a new instance of GooglePrivacyDlpV2TransformationErrorHandling.



11957
11958
11959
# File 'lib/google/apis/dlp_v2/classes.rb', line 11957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#leave_untransformedGoogle::Apis::DlpV2::GooglePrivacyDlpV2LeaveUntransformed

Skips the data without modifying it if the requested transformation would cause an error. For example, if a DateShift transformation were applied an an IP address, this mode would leave the IP address unchanged in the response. Corresponds to the JSON property leaveUntransformed



11950
11951
11952
# File 'lib/google/apis/dlp_v2/classes.rb', line 11950

def leave_untransformed
  @leave_untransformed
end

#throw_errorGoogle::Apis::DlpV2::GooglePrivacyDlpV2ThrowError

Throw an error and fail the request when a transformation error occurs. Corresponds to the JSON property throwError



11955
11956
11957
# File 'lib/google/apis/dlp_v2/classes.rb', line 11955

def throw_error
  @throw_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11962
11963
11964
11965
# File 'lib/google/apis/dlp_v2/classes.rb', line 11962

def update!(**args)
  @leave_untransformed = args[:leave_untransformed] if args.key?(:leave_untransformed)
  @throw_error = args[:throw_error] if args.key?(:throw_error)
end