Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationOverview
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationOverview
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Overview of the modifications that occurred.
Instance Attribute Summary collapse
-
#transformation_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationSummary>
Transformations applied to the dataset.
-
#transformed_bytes ⇒ Fixnum
Total size in bytes that were transformed in some way.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationOverview
constructor
A new instance of GooglePrivacyDlpV2TransformationOverview.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationOverview
Returns a new instance of GooglePrivacyDlpV2TransformationOverview.
11477 11478 11479 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#transformation_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationSummary>
Transformations applied to the dataset.
Corresponds to the JSON property transformationSummaries
11470 11471 11472 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11470 def transformation_summaries @transformation_summaries end |
#transformed_bytes ⇒ Fixnum
Total size in bytes that were transformed in some way.
Corresponds to the JSON property transformedBytes
11475 11476 11477 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11475 def transformed_bytes @transformed_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11482 11483 11484 11485 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11482 def update!(**args) @transformation_summaries = args[:transformation_summaries] if args.key?(:transformation_summaries) @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes) end |