Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The outcome of a transformation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationResultStatus

Returns a new instance of GooglePrivacyDlpV2TransformationResultStatus.



12035
12036
12037
# File 'lib/google/apis/dlp_v2/classes.rb', line 12035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsGoogle::Apis::DlpV2::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property details



12027
12028
12029
# File 'lib/google/apis/dlp_v2/classes.rb', line 12027

def details
  @details
end

#result_status_typeString

Transformation result status type, this will be either SUCCESS, or it will be the reason for why the transformation was not completely successful. Corresponds to the JSON property resultStatusType

Returns:

  • (String)


12033
12034
12035
# File 'lib/google/apis/dlp_v2/classes.rb', line 12033

def result_status_type
  @result_status_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12040
12041
12042
12043
# File 'lib/google/apis/dlp_v2/classes.rb', line 12040

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @result_status_type = args[:result_status_type] if args.key?(:result_status_type)
end