Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Summary of a single transformation. Only one of 'transformation', ' field_transformation', or 'record_suppress' will be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationSummary

Returns a new instance of GooglePrivacyDlpV2TransformationSummary.



12096
12097
12098
# File 'lib/google/apis/dlp_v2/classes.rb', line 12096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



12061
12062
12063
# File 'lib/google/apis/dlp_v2/classes.rb', line 12061

def field
  @field
end

#field_transformationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldTransformation>

The field transformation that was applied. If multiple field transformations are requested for a single field, this list will contain all of them; otherwise, only one is supplied. Corresponds to the JSON property fieldTransformations



12068
12069
12070
# File 'lib/google/apis/dlp_v2/classes.rb', line 12068

def field_transformations
  @field_transformations
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



12073
12074
12075
# File 'lib/google/apis/dlp_v2/classes.rb', line 12073

def info_type
  @info_type
end

#record_suppressGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordSuppression

Configuration to suppress records whose suppression conditions evaluate to true. Corresponds to the JSON property recordSuppress



12079
12080
12081
# File 'lib/google/apis/dlp_v2/classes.rb', line 12079

def record_suppress
  @record_suppress
end

#resultsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2SummaryResult>

Collection of all transformations that took place or had an error. Corresponds to the JSON property results



12084
12085
12086
# File 'lib/google/apis/dlp_v2/classes.rb', line 12084

def results
  @results
end

#transformationGoogle::Apis::DlpV2::GooglePrivacyDlpV2PrimitiveTransformation

A rule for transforming a value. Corresponds to the JSON property transformation



12089
12090
12091
# File 'lib/google/apis/dlp_v2/classes.rb', line 12089

def transformation
  @transformation
end

#transformed_bytesFixnum

Total size in bytes that were transformed in some way. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


12094
12095
12096
# File 'lib/google/apis/dlp_v2/classes.rb', line 12094

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12101
12102
12103
12104
12105
12106
12107
12108
12109
# File 'lib/google/apis/dlp_v2/classes.rb', line 12101

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @field_transformations = args[:field_transformations] if args.key?(:field_transformations)
  @info_type = args[:info_type] if args.key?(:info_type)
  @record_suppress = args[:record_suppress] if args.key?(:record_suppress)
  @results = args[:results] if args.key?(:results)
  @transformation = args[:transformation] if args.key?(:transformation)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end