Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateContentPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateContentPolicyRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Request message for UpdateContentPolicy.
Instance Attribute Summary collapse
-
#content_policy ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentPolicy
A policy to apply to content based on its inspection findings.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateContentPolicyRequest
constructor
A new instance of GooglePrivacyDlpV2UpdateContentPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateContentPolicyRequest
Returns a new instance of GooglePrivacyDlpV2UpdateContentPolicyRequest.
12215 12216 12217 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_policy ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentPolicy
A policy to apply to content based on its inspection findings.
Corresponds to the JSON property contentPolicy
12208 12209 12210 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12208 def content_policy @content_policy end |
#update_mask ⇒ String
Optional. Mask to control which fields get updated.
Corresponds to the JSON property updateMask
12213 12214 12215 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12213 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12220 12221 12222 12223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12220 def update!(**args) @content_policy = args[:content_policy] if args.key?(:content_policy) @update_mask = args[:update_mask] if args.key?(:update_mask) end |