Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for UpdateDiscoveryConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Returns a new instance of GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.



12285
12286
12287
# File 'lib/google/apis/dlp_v2/classes.rb', line 12285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



12278
12279
12280
# File 'lib/google/apis/dlp_v2/classes.rb', line 12278

def discovery_config
  @discovery_config
end

#update_maskString

Mask to control which fields get updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


12283
12284
12285
# File 'lib/google/apis/dlp_v2/classes.rb', line 12283

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12290
12291
12292
12293
# File 'lib/google/apis/dlp_v2/classes.rb', line 12290

def update!(**args)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end