Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Match dataset resources using regex filters.
Instance Attribute Summary collapse
-
#vertex_dataset_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
A collection of regular expressions to determine what datasets to match against.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetCollection
constructor
A new instance of GooglePrivacyDlpV2VertexDatasetCollection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetCollection
Returns a new instance of GooglePrivacyDlpV2VertexDatasetCollection.
12503 12504 12505 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12503 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vertex_dataset_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
A collection of regular expressions to determine what datasets to match
against.
Corresponds to the JSON property vertexDatasetRegexes
12501 12502 12503 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12501 def vertex_dataset_regexes @vertex_dataset_regexes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12508 12509 12510 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12508 def update!(**args) @vertex_dataset_regexes = args[:vertex_dataset_regexes] if args.key?(:vertex_dataset_regexes) end |