Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Vertex AI datasets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2VertexDatasetDiscoveryTarget.



12554
12555
12556
# File 'lib/google/apis/dlp_v2/classes.rb', line 12554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetConditions

Requirements that must be true before a dataset is profiled for the first time. Corresponds to the JSON property conditions



12534
12535
12536
# File 'lib/google/apis/dlp_v2/classes.rb', line 12534

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



12539
12540
12541
# File 'lib/google/apis/dlp_v2/classes.rb', line 12539

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter

Determines what datasets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID or dataset regex. Corresponds to the JSON property filter



12546
12547
12548
# File 'lib/google/apis/dlp_v2/classes.rb', line 12546

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence

How often existing datasets should have their profiles refreshed. New datasets are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



12552
12553
12554
# File 'lib/google/apis/dlp_v2/classes.rb', line 12552

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12559
12560
12561
12562
12563
12564
# File 'lib/google/apis/dlp_v2/classes.rb', line 12559

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end