Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegex

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A pattern to match against one or more dataset resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetRegex

Returns a new instance of GooglePrivacyDlpV2VertexDatasetRegex.



11713
11714
11715
# File 'lib/google/apis/dlp_v2/classes.rb', line 11713

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#project_id_regexString

For organizations, if unset, will match all projects. Has no effect for configurations created within a project. Corresponds to the JSON property projectIdRegex

Returns:

  • (String)


11711
11712
11713
# File 'lib/google/apis/dlp_v2/classes.rb', line 11711

def project_id_regex
  @project_id_regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11718
11719
11720
# File 'lib/google/apis/dlp_v2/classes.rb', line 11718

def update!(**args)
  @project_id_regex = args[:project_id_regex] if args.key?(:project_id_regex)
end