Class: Google::Apis::DlpV2::UtilStatusProto
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::UtilStatusProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Wire-format for a Status object
Instance Attribute Summary collapse
-
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property
canonicalCode. -
#code ⇒ Fixnum
Numeric code drawn from the space specified below.
-
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property
message. -
#message_set ⇒ Google::Apis::DlpV2::Proto2BridgeMessageSet
This is proto2's version of MessageSet.
-
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property
space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UtilStatusProto
constructor
A new instance of UtilStatusProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UtilStatusProto
Returns a new instance of UtilStatusProto.
12843 12844 12845 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#canonical_code ⇒ Fixnum
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 canonical_code = 6;
Corresponds to the JSON property canonicalCode
12807 12808 12809 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12807 def canonical_code @canonical_code end |
#code ⇒ Fixnum
Numeric code drawn from the space specified below. Often, this is the
canonical error space, and code is drawn from google3/util/task/codes.proto
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional
int32 code = 1;
Corresponds to the JSON property code
12815 12816 12817 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12815 def code @code end |
#message ⇒ String
Detail message copybara:strip_begin(b/383363683) copybara:
strip_end_and_replace optional string message = 3;
Corresponds to the JSON property message
12821 12822 12823 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12821 def @message end |
#message_set ⇒ Google::Apis::DlpV2::Proto2BridgeMessageSet
This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS.
If you are using editions or proto2, please make your own extendable messages
for your use case. If you are using proto3, please use Any instead.
MessageSet was the implementation of extensions for proto1. When proto2 was
introduced, extensions were implemented as a first-class feature. This schema
for MessageSet was meant to be a "bridge" solution to migrate MessageSet-
bearing messages from proto1 to proto2. This schema has been open-sourced only
to facilitate the migration of Google products with MessageSet-bearing
messages to open-source environments.
Corresponds to the JSON property messageSet
12834 12835 12836 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12834 def @message_set end |
#space ⇒ String
copybara:strip_begin(b/383363683) Space to which this status belongs copybara:
strip_end_and_replace optional string space = 2; // Space to which this status
belongs
Corresponds to the JSON property space
12841 12842 12843 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12841 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12848 12849 12850 12851 12852 12853 12854 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12848 def update!(**args) @canonical_code = args[:canonical_code] if args.key?(:canonical_code) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @message_set = args[:message_set] if args.key?(:message_set) @space = args[:space] if args.key?(:space) end |