Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Action
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Action
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A task to execute on the completion of a job. See https://cloud.google.com/ sensitive-data-protection/docs/concepts-actions to learn more.
Instance Attribute Summary collapse
-
#deidentify ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Deidentify
Create a de-identified copy of a storage bucket.
-
#job_notification_emails ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2JobNotificationEmails
Sends an email when the job completes.
-
#pub_sub ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToPubSub
Publish a message into a given Pub/Sub topic when DlpJob has completed.
-
#publish_findings_to_cloud_data_catalog ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog
Publish findings of a DlpJob to Data Catalog.
-
#publish_findings_to_dataplex_catalog ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishFindingsToDataplexCatalog
Publish findings of a DlpJob to Dataplex Universal Catalog as a
sensitive- data-protection-job-resultaspect. -
#publish_summary_to_cscc ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishSummaryToCscc
Publish the result summary of a DlpJob to Security Command Center.
-
#publish_to_stackdriver ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToStackdriver
Enable Stackdriver metric dlp.googleapis.com/finding_count.
-
#save_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SaveFindings
If set, the detailed findings will be persisted to the specified OutputStorageConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Action
constructor
A new instance of GooglePrivacyDlpV2Action.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Action
Returns a new instance of GooglePrivacyDlpV2Action.
108 109 110 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deidentify ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Deidentify
Create a de-identified copy of a storage bucket. Only compatible with Cloud
Storage buckets. A TransformationDetail will be created for each
transformation. Compatible with: Inspection of Cloud Storage
Corresponds to the JSON property deidentify
35 36 37 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 35 def deidentify @deidentify end |
#job_notification_emails ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2JobNotificationEmails
Sends an email when the job completes. The email goes to IAM project owners
and technical Essential Contacts.
Corresponds to the JSON property jobNotificationEmails
42 43 44 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 42 def job_notification_emails @job_notification_emails end |
#pub_sub ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToPubSub
Publish a message into a given Pub/Sub topic when DlpJob has completed. The
message contains a single field, DlpJobName, which is equal to the finished
job's DlpJob.name. Compatible with: Inspect, Risk
Corresponds to the JSON property pubSub
50 51 52 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 50 def pub_sub @pub_sub end |
#publish_findings_to_cloud_data_catalog ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishFindingsToCloudDataCatalog
Publish findings of a DlpJob to Data Catalog. In Data Catalog, tag templates
are applied to the resource that Cloud DLP scanned. Data Catalog tag templates
are stored in the same project and region where the BigQuery table exists. For
Cloud DLP to create and apply the tag template, the Cloud DLP service agent
must have the roles/datacatalog.tagTemplateOwner permission on the project.
The tag template contains fields summarizing the results of the DlpJob. Any
field values previously written by another DlpJob are deleted. InfoType naming
patterns are strictly enforced when using this feature. Findings are persisted
in Data Catalog storage and are governed by service-specific policies for Data
Catalog. For more information, see Service Specific Terms. Only a single instance of this action can be
specified. This action is allowed only if all resources being scanned are
BigQuery tables. Compatible with: Inspect
Corresponds to the JSON property publishFindingsToCloudDataCatalog
67 68 69 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 67 def publish_findings_to_cloud_data_catalog @publish_findings_to_cloud_data_catalog end |
#publish_findings_to_dataplex_catalog ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishFindingsToDataplexCatalog
Publish findings of a DlpJob to Dataplex Universal Catalog as a sensitive-
data-protection-job-result aspect. For more information, see Send inspection
results to Dataplex Universal Catalog as aspects. Aspects are stored
in Dataplex Universal Catalog storage and are governed by service-specific
policies for Dataplex Universal Catalog. For more information, see Service
Specific Terms. Only a single
instance of this action can be specified. This action is allowed only if all
resources being scanned are BigQuery tables. Compatible with: Inspect
Corresponds to the JSON property publishFindingsToDataplexCatalog
80 81 82 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 80 def publish_findings_to_dataplex_catalog @publish_findings_to_dataplex_catalog end |
#publish_summary_to_cscc ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishSummaryToCscc
Publish the result summary of a DlpJob to Security Command Center. This action is available for only
projects that belong to an organization. This action publishes the count of
finding instances and their infoTypes. The summary of findings are persisted
in Security Command Center and are governed by service-specific policies for
Security Command Center. Only a
single instance of this action can be specified. Compatible with: Inspect
Corresponds to the JSON property publishSummaryToCscc
91 92 93 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 91 def publish_summary_to_cscc @publish_summary_to_cscc end |
#publish_to_stackdriver ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToStackdriver
Enable Stackdriver metric dlp.googleapis.com/finding_count. This will publish
a metric to stack driver on each infotype requested and how many findings were
found for it. CustomDetectors will be bucketed as 'Custom' under the
Stackdriver label 'info_type'.
Corresponds to the JSON property publishToStackdriver
99 100 101 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 99 def publish_to_stackdriver @publish_to_stackdriver end |
#save_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SaveFindings
If set, the detailed findings will be persisted to the specified
OutputStorageConfig. Only a single instance of this action can be specified.
Compatible with: Inspect, Risk
Corresponds to the JSON property saveFindings
106 107 108 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 106 def save_findings @save_findings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
113 114 115 116 117 118 119 120 121 122 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 113 def update!(**args) @deidentify = args[:deidentify] if args.key?(:deidentify) @job_notification_emails = args[:job_notification_emails] if args.key?(:job_notification_emails) @pub_sub = args[:pub_sub] if args.key?(:pub_sub) @publish_findings_to_cloud_data_catalog = args[:publish_findings_to_cloud_data_catalog] if args.key?(:publish_findings_to_cloud_data_catalog) @publish_findings_to_dataplex_catalog = args[:publish_findings_to_dataplex_catalog] if args.key?(:publish_findings_to_dataplex_catalog) @publish_summary_to_cscc = args[:publish_summary_to_cscc] if args.key?(:publish_summary_to_cscc) @publish_to_stackdriver = args[:publish_to_stackdriver] if args.key?(:publish_to_stackdriver) @save_findings = args[:save_findings] if args.key?(:save_findings) end |