Class: Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByImageFindings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

AdjustmentRule condition for image findings. This rule is silently ignored if the content being inspected is not an image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2AdjustByImageFindings

Returns a new instance of GooglePrivacyDlpV2AdjustByImageFindings.



191
192
193
# File 'lib/google/apis/dlp_v2/classes.rb', line 191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#image_containment_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType

Specifies the relationship between bounding boxes for image findings. Corresponds to the JSON property imageContainmentType



165
166
167
# File 'lib/google/apis/dlp_v2/classes.rb', line 165

def image_containment_type
  @image_containment_type
end

#info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>

A list of image-supported infoTypes—excluding document infoTypes— to be used as context for the adjustment rule. Sensitive Data Protection adjusts the likelihood of an image finding if its bounding box has the specified spatial relationship (defined by image_containment_type) with a finding of an infoType in this list. For example, you can create a rule to adjust the likelihood of a US_PASSPORT finding if it is enclosed by a finding of OBJECT_TYPE/PERSON/PASSPORT. To configure this, set US_PASSPORT in InspectionRuleSet.info_types. Add an adjustment_rule with an adjust_by_image_findings.info_types that contains OBJECT_TYPE/PERSON/ PASSPORT and image_containment_type set to encloses. In this case, the likelihood of the US_PASSPORT finding is adjusted, but the likelihood of the OBJECT_TYPE/PERSON/PASSPORT finding is not. Corresponds to the JSON property infoTypes



182
183
184
# File 'lib/google/apis/dlp_v2/classes.rb', line 182

def info_types
  @info_types
end

#min_likelihoodString

Required. Minimum likelihood of the adjust_by_image_findings.info_types finding. If the likelihood is lower than this value, Sensitive Data Protection doesn't adjust the likelihood of the InspectionRuleSet.info_types finding. Corresponds to the JSON property minLikelihood

Returns:

  • (String)


189
190
191
# File 'lib/google/apis/dlp_v2/classes.rb', line 189

def min_likelihood
  @min_likelihood
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



196
197
198
199
200
# File 'lib/google/apis/dlp_v2/classes.rb', line 196

def update!(**args)
  @image_containment_type = args[:image_containment_type] if args.key?(:image_containment_type)
  @info_types = args[:info_types] if args.key?(:info_types)
  @min_likelihood = args[:min_likelihood] if args.key?(:min_likelihood)
end