Class: Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Rule that specifies conditions when a certain infoType's finding details should be adjusted.
Instance Attribute Summary collapse
-
#adjust_by_image_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByImageFindings
AdjustmentRule condition for image findings.
-
#adjust_by_matching_info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByMatchingInfoTypes
AdjustmentRule condition for matching infoTypes.
-
#likelihood_adjustment ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LikelihoodAdjustment
Message for specifying an adjustment to the likelihood of a finding as part of a detection rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2AdjustmentRule
constructor
A new instance of GooglePrivacyDlpV2AdjustmentRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2AdjustmentRule
Returns a new instance of GooglePrivacyDlpV2AdjustmentRule.
269 270 271 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 269 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adjust_by_image_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByImageFindings
AdjustmentRule condition for image findings. This rule is silently ignored if
the content being inspected is not an image.
Corresponds to the JSON property adjustByImageFindings
256 257 258 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 256 def adjust_by_image_findings @adjust_by_image_findings end |
#adjust_by_matching_info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AdjustByMatchingInfoTypes
AdjustmentRule condition for matching infoTypes.
Corresponds to the JSON property adjustByMatchingInfoTypes
261 262 263 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 261 def adjust_by_matching_info_types @adjust_by_matching_info_types end |
#likelihood_adjustment ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LikelihoodAdjustment
Message for specifying an adjustment to the likelihood of a finding as part of
a detection rule.
Corresponds to the JSON property likelihoodAdjustment
267 268 269 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 267 def likelihood_adjustment @likelihood_adjustment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
274 275 276 277 278 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 274 def update!(**args) @adjust_by_image_findings = args[:adjust_by_image_findings] if args.key?(:adjust_by_image_findings) @adjust_by_matching_info_types = args[:adjust_by_matching_info_types] if args.key?(:adjust_by_matching_info_types) @likelihood_adjustment = args[:likelihood_adjustment] if args.key?(:likelihood_adjustment) end |