Class: Google::Apis::DlpV2::GooglePrivacyDlpV2AuxiliaryTable

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

An auxiliary table contains statistical information on the relative frequency of different quasi-identifiers values. It has one or several quasi-identifiers columns, and one column that indicates the relative frequency of each quasi- identifier tuple. If a tuple is present in the data but not in the auxiliary table, the corresponding relative frequency is assumed to be zero (and thus, the tuple is highly reidentifiable).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2AuxiliaryTable

Returns a new instance of GooglePrivacyDlpV2AuxiliaryTable.



522
523
524
# File 'lib/google/apis/dlp_v2/classes.rb', line 522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#quasi_idsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdField>

Required. Quasi-identifier columns. Corresponds to the JSON property quasiIds



508
509
510
# File 'lib/google/apis/dlp_v2/classes.rb', line 508

def quasi_ids
  @quasi_ids
end

#relative_frequencyGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property relativeFrequency



513
514
515
# File 'lib/google/apis/dlp_v2/classes.rb', line 513

def relative_frequency
  @relative_frequency
end

#tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property table



520
521
522
# File 'lib/google/apis/dlp_v2/classes.rb', line 520

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



527
528
529
530
531
# File 'lib/google/apis/dlp_v2/classes.rb', line 527

def update!(**args)
  @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids)
  @relative_frequency = args[:relative_frequency] if args.key?(:relative_frequency)
  @table = args[:table] if args.key?(:table)
end