Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentItem
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Represents a batch of content to inspect or redact.
Instance Attribute Summary collapse
-
#string_value_batch ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StringValueBatch
Represents a batch of string values to inspect or redact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2BatchContentItem
constructor
A new instance of GooglePrivacyDlpV2BatchContentItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2BatchContentItem
Returns a new instance of GooglePrivacyDlpV2BatchContentItem.
625 626 627 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 625 def initialize(**args) update!(**args) end |
Instance Attribute Details
#string_value_batch ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StringValueBatch
Represents a batch of string values to inspect or redact.
Corresponds to the JSON property stringValueBatch
623 624 625 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 623 def string_value_batch @string_value_batch end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
630 631 632 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 630 def update!(**args) @string_value_batch = args[:string_value_batch] if args.key?(:string_value_batch) end |