Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with BigQuery tables

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2BigQueryDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2BigQueryDiscoveryTarget.



648
649
650
# File 'lib/google/apis/dlp_v2/classes.rb', line 648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence

What must take place for a profile to be updated and how frequently it should occur. New tables are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property cadence



625
626
627
# File 'lib/google/apis/dlp_v2/classes.rb', line 625

def cadence
  @cadence
end

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryConditions

Requirements that must be true before a table is scanned in discovery for the first time. There is an AND relationship between the top-level attributes. Additionally, minimum conditions with an OR relationship that must be met before Cloud DLP scans a table can be set (like a minimum row count or a minimum table age). Corresponds to the JSON property conditions



634
635
636
# File 'lib/google/apis/dlp_v2/classes.rb', line 634

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



639
640
641
# File 'lib/google/apis/dlp_v2/classes.rb', line 639

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, dataset ID, and table ID. Corresponds to the JSON property filter



646
647
648
# File 'lib/google/apis/dlp_v2/classes.rb', line 646

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



653
654
655
656
657
658
# File 'lib/google/apis/dlp_v2/classes.rb', line 653

def update!(**args)
  @cadence = args[:cadence] if args.key?(:cadence)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
end