Class: Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery with BigQuery tables
Instance Attribute Summary collapse
-
#cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence
What must take place for a profile to be updated and how frequently it should occur.
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryConditions
Requirements that must be true before a table is scanned in discovery for the first time.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter
Determines what tables will have profiles generated within an organization or project.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2BigQueryDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2BigQueryDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2BigQueryDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2BigQueryDiscoveryTarget.
511 512 513 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 511 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence
What must take place for a profile to be updated and how frequently it should
occur. New tables are scanned as quickly as possible depending on system
capacity.
Corresponds to the JSON property cadence
488 489 490 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 488 def cadence @cadence end |
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryConditions
Requirements that must be true before a table is scanned in discovery for the
first time. There is an AND relationship between the top-level attributes.
Additionally, minimum conditions with an OR relationship that must be met
before Cloud DLP scans a table can be set (like a minimum row count or a
minimum table age).
Corresponds to the JSON property conditions
497 498 499 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 497 def conditions @conditions end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
502 503 504 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 502 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter
Determines what tables will have profiles generated within an organization or
project. Includes the ability to filter by regular expression patterns on
project ID, dataset ID, and table ID.
Corresponds to the JSON property filter
509 510 511 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 509 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
516 517 518 519 520 521 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 516 def update!(**args) @cadence = args[:cadence] if args.key?(:cadence) @conditions = args[:conditions] if args.key?(:conditions) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) end |