Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Compute numerical stats over an individual column, including number of distinct values and value count distribution.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CategoricalStatsConfig

Returns a new instance of GooglePrivacyDlpV2CategoricalStatsConfig.



1063
1064
1065
# File 'lib/google/apis/dlp_v2/classes.rb', line 1063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



1061
1062
1063
# File 'lib/google/apis/dlp_v2/classes.rb', line 1061

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1068
1069
1070
# File 'lib/google/apis/dlp_v2/classes.rb', line 1068

def update!(**args)
  @field = args[:field] if args.key?(:field)
end