Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Cloud SQL tables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2CloudSqlDiscoveryTarget.



1301
1302
1303
# File 'lib/google/apis/dlp_v2/classes.rb', line 1301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlConditions

Requirements that must be true before a table is profiled for the first time. Corresponds to the JSON property conditions



1281
1282
1283
# File 'lib/google/apis/dlp_v2/classes.rb', line 1281

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



1286
1287
1288
# File 'lib/google/apis/dlp_v2/classes.rb', line 1286

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name. Corresponds to the JSON property filter



1293
1294
1295
# File 'lib/google/apis/dlp_v2/classes.rb', line 1293

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence

How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



1299
1300
1301
# File 'lib/google/apis/dlp_v2/classes.rb', line 1299

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1306
1307
1308
1309
1310
1311
# File 'lib/google/apis/dlp_v2/classes.rb', line 1306

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end