Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Cloud SQL tables.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2CloudSqlDiscoveryTarget.



1263
1264
1265
# File 'lib/google/apis/dlp_v2/classes.rb', line 1263

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlConditions

Requirements that must be true before a table is profiled for the first time. Corresponds to the JSON property conditions



1243
1244
1245
# File 'lib/google/apis/dlp_v2/classes.rb', line 1243

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



1248
1249
1250
# File 'lib/google/apis/dlp_v2/classes.rb', line 1248

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name. Corresponds to the JSON property filter



1255
1256
1257
# File 'lib/google/apis/dlp_v2/classes.rb', line 1255

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence

How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



1261
1262
1263
# File 'lib/google/apis/dlp_v2/classes.rb', line 1261

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1268
1269
1270
1271
1272
1273
# File 'lib/google/apis/dlp_v2/classes.rb', line 1268

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end