Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery with Cloud SQL tables.
Instance Attribute Summary collapse
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlConditions
Requirements that must be true before a table is profiled for the first time.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
Determines what tables will have profiles generated within an organization or project.
-
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
How often existing tables should have their profiles refreshed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2CloudSqlDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2CloudSqlDiscoveryTarget.
1126 1127 1128 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1126 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlConditions
Requirements that must be true before a table is profiled for the first time.
Corresponds to the JSON property conditions
1106 1107 1108 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1106 def conditions @conditions end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
1111 1112 1113 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1111 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
Determines what tables will have profiles generated within an organization or
project. Includes the ability to filter by regular expression patterns on
project ID, location, instance, database, and database resource name.
Corresponds to the JSON property filter
1118 1119 1120 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1118 def filter @filter end |
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
How often existing tables should have their profiles refreshed. New tables are
scanned as quickly as possible depending on system capacity.
Corresponds to the JSON property generationCadence
1124 1125 1126 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1124 def generation_cadence @generation_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1131 1132 1133 1134 1135 1136 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1131 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence) end |