Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlProperties
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Cloud SQL connection properties.
Instance Attribute Summary collapse
-
#cloud_sql_iam ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlIamCredential
Use IAM authentication to connect.
-
#connection_name ⇒ String
Optional.
-
#database_engine ⇒ String
Required.
-
#max_connections ⇒ Fixnum
Required.
-
#username_password ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretManagerCredential
A credential consisting of a username and password, where the password is stored in a Secret Manager resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlProperties
constructor
A new instance of GooglePrivacyDlpV2CloudSqlProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlProperties
Returns a new instance of GooglePrivacyDlpV2CloudSqlProperties.
1372 1373 1374 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_iam ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlIamCredential
Use IAM authentication to connect. This requires the Cloud SQL IAM feature to
be enabled on the instance, which is not the default for Cloud SQL. See https:/
/cloud.google.com/sql/docs/postgres/authentication and https://cloud.google.
com/sql/docs/mysql/authentication.
Corresponds to the JSON property cloudSqlIam
1340 1341 1342 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1340 def cloud_sql_iam @cloud_sql_iam end |
#connection_name ⇒ String
Optional. Immutable. The Cloud SQL instance for which the connection is
defined. Only one connection per instance is allowed. This can only be set at
creation time, and cannot be updated. It is an error to use a connection_name
from different project or region than the one that holds the connection. For
example, a Connection resource for Cloud SQL connection_name project-id:us-
central1:sql-instance must be created under the parent projects/project-id/
locations/us-central1
Corresponds to the JSON property connectionName
1351 1352 1353 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1351 def connection_name @connection_name end |
#database_engine ⇒ String
Required. The database engine used by the Cloud SQL instance that this
connection configures.
Corresponds to the JSON property databaseEngine
1357 1358 1359 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1357 def database_engine @database_engine end |
#max_connections ⇒ Fixnum
Required. The DLP API will limit its connections to max_connections. Must be 2
or greater.
Corresponds to the JSON property maxConnections
1363 1364 1365 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1363 def max_connections @max_connections end |
#username_password ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretManagerCredential
A credential consisting of a username and password, where the password is
stored in a Secret Manager resource. Note: Secret Manager charges apply.
Corresponds to the JSON property usernamePassword
1370 1371 1372 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1370 def username_password @username_password end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1377 1378 1379 1380 1381 1382 1383 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1377 def update!(**args) @cloud_sql_iam = args[:cloud_sql_iam] if args.key?(:cloud_sql_iam) @connection_name = args[:connection_name] if args.key?(:connection_name) @database_engine = args[:database_engine] if args.key?(:database_engine) @max_connections = args[:max_connections] if args.key?(:max_connections) @username_password = args[:username_password] if args.key?(:username_password) end |