Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlProperties
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlProperties
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Cloud SQL connection properties.
Instance Attribute Summary collapse
-
#cloud_sql_iam ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlIamCredential
Use IAM authentication to connect.
-
#connection_name ⇒ String
Optional.
-
#database_engine ⇒ String
Required.
-
#max_connections ⇒ Fixnum
Required.
-
#username_password ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretManagerCredential
A credential consisting of a username and password, where the password is stored in a Secret Manager resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlProperties
constructor
A new instance of GooglePrivacyDlpV2CloudSqlProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudSqlProperties
Returns a new instance of GooglePrivacyDlpV2CloudSqlProperties.
1321 1322 1323 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_sql_iam ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlIamCredential
Use IAM authentication to connect. This requires the Cloud SQL IAM feature to
be enabled on the instance, which is not the default for Cloud SQL. See https:/
/cloud.google.com/sql/docs/postgres/authentication and https://cloud.google.
com/sql/docs/mysql/authentication.
Corresponds to the JSON property cloudSqlIam
1289 1290 1291 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1289 def cloud_sql_iam @cloud_sql_iam end |
#connection_name ⇒ String
Optional. Immutable. The Cloud SQL instance for which the connection is
defined. Only one connection per instance is allowed. This can only be set at
creation time, and cannot be updated. It is an error to use a connection_name
from different project or region than the one that holds the connection. For
example, a Connection resource for Cloud SQL connection_name project-id:us-
central1:sql-instance must be created under the parent projects/project-id/
locations/us-central1
Corresponds to the JSON property connectionName
1300 1301 1302 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1300 def connection_name @connection_name end |
#database_engine ⇒ String
Required. The database engine used by the Cloud SQL instance that this
connection configures.
Corresponds to the JSON property databaseEngine
1306 1307 1308 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1306 def database_engine @database_engine end |
#max_connections ⇒ Fixnum
Required. The DLP API will limit its connections to max_connections. Must be 2
or greater.
Corresponds to the JSON property maxConnections
1312 1313 1314 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1312 def max_connections @max_connections end |
#username_password ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretManagerCredential
A credential consisting of a username and password, where the password is
stored in a Secret Manager resource. Note: Secret Manager charges apply.
Corresponds to the JSON property usernamePassword
1319 1320 1321 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1319 def username_password @username_password end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1326 1327 1328 1329 1330 1331 1332 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1326 def update!(**args) @cloud_sql_iam = args[:cloud_sql_iam] if args.key?(:cloud_sql_iam) @connection_name = args[:connection_name] if args.key?(:connection_name) @database_engine = args[:database_engine] if args.key?(:database_engine) @max_connections = args[:max_connections] if args.key?(:max_connections) @username_password = args[:username_password] if args.key?(:username_password) end |