Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery with Cloud Storage buckets.
Instance Attribute Summary collapse
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryFileStoreConditions
Requirements that must be true before a file store is scanned in discovery for the first time.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageFilter
Determines which buckets will have profiles generated within an organization or project.
-
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence
How often existing buckets should have their profiles refreshed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2CloudStorageDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2CloudStorageDiscoveryTarget.
1415 1416 1417 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryFileStoreConditions
Requirements that must be true before a file store is scanned in discovery for
the first time. There is an AND relationship between the top-level attributes.
Corresponds to the JSON property conditions
1395 1396 1397 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1395 def conditions @conditions end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
1400 1401 1402 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1400 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageFilter
Determines which buckets will have profiles generated within an organization
or project. Includes the ability to filter by regular expression patterns on
project ID and bucket name.
Corresponds to the JSON property filter
1407 1408 1409 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1407 def filter @filter end |
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence
How often existing buckets should have their profiles refreshed. New buckets
are scanned as quickly as possible depending on system capacity.
Corresponds to the JSON property generationCadence
1413 1414 1415 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1413 def generation_cadence @generation_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1420 1421 1422 1423 1424 1425 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1420 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence) end |