Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Cloud Storage buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2CloudStorageDiscoveryTarget.



1414
1415
1416
# File 'lib/google/apis/dlp_v2/classes.rb', line 1414

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryFileStoreConditions

Requirements that must be true before a file store is scanned in discovery for the first time. There is an AND relationship between the top-level attributes. Corresponds to the JSON property conditions



1394
1395
1396
# File 'lib/google/apis/dlp_v2/classes.rb', line 1394

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



1399
1400
1401
# File 'lib/google/apis/dlp_v2/classes.rb', line 1399

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageFilter

Determines which buckets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID and bucket name. Corresponds to the JSON property filter



1406
1407
1408
# File 'lib/google/apis/dlp_v2/classes.rb', line 1406

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence

How often existing buckets should have their profiles refreshed. New buckets are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



1412
1413
1414
# File 'lib/google/apis/dlp_v2/classes.rb', line 1412

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1419
1420
1421
1422
1423
1424
# File 'lib/google/apis/dlp_v2/classes.rb', line 1419

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end