Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery with Cloud Storage buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2CloudStorageDiscoveryTarget.



1376
1377
1378
# File 'lib/google/apis/dlp_v2/classes.rb', line 1376

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryFileStoreConditions

Requirements that must be true before a file store is scanned in discovery for the first time. There is an AND relationship between the top-level attributes. Corresponds to the JSON property conditions



1356
1357
1358
# File 'lib/google/apis/dlp_v2/classes.rb', line 1356

def conditions
  @conditions
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



1361
1362
1363
# File 'lib/google/apis/dlp_v2/classes.rb', line 1361

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageFilter

Determines which buckets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID and bucket name. Corresponds to the JSON property filter



1368
1369
1370
# File 'lib/google/apis/dlp_v2/classes.rb', line 1368

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence

How often existing buckets should have their profiles refreshed. New buckets are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



1374
1375
1376
# File 'lib/google/apis/dlp_v2/classes.rb', line 1374

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1381
1382
1383
1384
1385
1386
# File 'lib/google/apis/dlp_v2/classes.rb', line 1381

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end