Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Options defining a file or a set of files within a Cloud Storage bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageOptions

Returns a new instance of GooglePrivacyDlpV2CloudStorageOptions.



1449
1450
1451
# File 'lib/google/apis/dlp_v2/classes.rb', line 1449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bytes_limit_per_fileFixnum

Max number of bytes to scan from a file. If a scanned file's size is bigger than this value then the rest of the bytes are omitted. Only one of bytes_limit_per_file and bytes_limit_per_file_percent can be specified. This field can't be set if de-identification is requested. For certain file types, setting this field has no effect. For more information, see Limits on bytes scanned per file. Corresponds to the JSON property bytesLimitPerFile

Returns:

  • (Fixnum)


1408
1409
1410
# File 'lib/google/apis/dlp_v2/classes.rb', line 1408

def bytes_limit_per_file
  @bytes_limit_per_file
end

#bytes_limit_per_file_percentFixnum

Max percentage of bytes to scan from a file. The rest are omitted. The number of bytes scanned is rounded down. Must be between 0 and 100, inclusively. Both 0 and 100 means no limit. Defaults to 0. Only one of bytes_limit_per_file and bytes_limit_per_file_percent can be specified. This field can't be set if de- identification is requested. For certain file types, setting this field has no effect. For more information, see Limits on bytes scanned per file. Corresponds to the JSON property bytesLimitPerFilePercent

Returns:

  • (Fixnum)


1420
1421
1422
# File 'lib/google/apis/dlp_v2/classes.rb', line 1420

def bytes_limit_per_file_percent
  @bytes_limit_per_file_percent
end

#file_setGoogle::Apis::DlpV2::GooglePrivacyDlpV2FileSet

Set of files to scan. Corresponds to the JSON property fileSet



1425
1426
1427
# File 'lib/google/apis/dlp_v2/classes.rb', line 1425

def file_set
  @file_set
end

#file_typesArray<String>

List of file type groups to include in the scan. If empty, all files are scanned and available data format processors are applied. In addition, the binary content of the selected files is always scanned as well. Images are scanned only as binary if the specified region does not support image inspection and no file_types were specified. Image inspection is restricted to 'global', 'us', 'asia', and 'europe'. Corresponds to the JSON property fileTypes

Returns:

  • (Array<String>)


1435
1436
1437
# File 'lib/google/apis/dlp_v2/classes.rb', line 1435

def file_types
  @file_types
end

#files_limit_percentFixnum

Limits the number of files to scan to this percentage of the input FileSet. Number of files scanned is rounded down. Must be between 0 and 100, inclusively. Both 0 and 100 means no limit. Defaults to 0. Corresponds to the JSON property filesLimitPercent

Returns:

  • (Fixnum)


1442
1443
1444
# File 'lib/google/apis/dlp_v2/classes.rb', line 1442

def files_limit_percent
  @files_limit_percent
end

#sample_methodString

How to sample the data. Corresponds to the JSON property sampleMethod

Returns:

  • (String)


1447
1448
1449
# File 'lib/google/apis/dlp_v2/classes.rb', line 1447

def sample_method
  @sample_method
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1454
1455
1456
1457
1458
1459
1460
1461
# File 'lib/google/apis/dlp_v2/classes.rb', line 1454

def update!(**args)
  @bytes_limit_per_file = args[:bytes_limit_per_file] if args.key?(:bytes_limit_per_file)
  @bytes_limit_per_file_percent = args[:bytes_limit_per_file_percent] if args.key?(:bytes_limit_per_file_percent)
  @file_set = args[:file_set] if args.key?(:file_set)
  @file_types = args[:file_types] if args.key?(:file_types)
  @files_limit_percent = args[:files_limit_percent] if args.key?(:files_limit_percent)
  @sample_method = args[:sample_method] if args.key?(:sample_method)
end