Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageOptions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Options defining a file or a set of files within a Cloud Storage bucket.
Instance Attribute Summary collapse
-
#bytes_limit_per_file ⇒ Fixnum
Max number of bytes to scan from a file.
-
#bytes_limit_per_file_percent ⇒ Fixnum
Max percentage of bytes to scan from a file.
-
#file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileSet
Set of files to scan.
-
#file_types ⇒ Array<String>
List of file type groups to include in the scan.
-
#files_limit_percent ⇒ Fixnum
Limits the number of files to scan to this percentage of the input FileSet.
-
#sample_method ⇒ String
How to sample the data.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageOptions
constructor
A new instance of GooglePrivacyDlpV2CloudStorageOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CloudStorageOptions
Returns a new instance of GooglePrivacyDlpV2CloudStorageOptions.
1325 1326 1327 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bytes_limit_per_file ⇒ Fixnum
Max number of bytes to scan from a file. If a scanned file's size is bigger
than this value then the rest of the bytes are omitted. Only one of
bytes_limit_per_file and bytes_limit_per_file_percent can be specified.
This field can't be set if de-identification is requested. For certain file
types, setting this field has no effect. For more information, see Limits on
bytes scanned per file.
Corresponds to the JSON property bytesLimitPerFile
1284 1285 1286 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1284 def bytes_limit_per_file @bytes_limit_per_file end |
#bytes_limit_per_file_percent ⇒ Fixnum
Max percentage of bytes to scan from a file. The rest are omitted. The number
of bytes scanned is rounded down. Must be between 0 and 100, inclusively. Both
0 and 100 means no limit. Defaults to 0. Only one of bytes_limit_per_file and
bytes_limit_per_file_percent can be specified. This field can't be set if de-
identification is requested. For certain file types, setting this field has no
effect. For more information, see Limits on bytes scanned per file.
Corresponds to the JSON property bytesLimitPerFilePercent
1296 1297 1298 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1296 def bytes_limit_per_file_percent @bytes_limit_per_file_percent end |
#file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileSet
Set of files to scan.
Corresponds to the JSON property fileSet
1301 1302 1303 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1301 def file_set @file_set end |
#file_types ⇒ Array<String>
List of file type groups to include in the scan. If empty, all files are
scanned and available data format processors are applied. In addition, the
binary content of the selected files is always scanned as well. Images are
scanned only as binary if the specified region does not support image
inspection and no file_types were specified. Image inspection is restricted to
'global', 'us', 'asia', and 'europe'.
Corresponds to the JSON property fileTypes
1311 1312 1313 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1311 def file_types @file_types end |
#files_limit_percent ⇒ Fixnum
Limits the number of files to scan to this percentage of the input FileSet.
Number of files scanned is rounded down. Must be between 0 and 100,
inclusively. Both 0 and 100 means no limit. Defaults to 0.
Corresponds to the JSON property filesLimitPercent
1318 1319 1320 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1318 def files_limit_percent @files_limit_percent end |
#sample_method ⇒ String
How to sample the data.
Corresponds to the JSON property sampleMethod
1323 1324 1325 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1323 def sample_method @sample_method end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1330 1331 1332 1333 1334 1335 1336 1337 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1330 def update!(**args) @bytes_limit_per_file = args[:bytes_limit_per_file] if args.key?(:bytes_limit_per_file) @bytes_limit_per_file_percent = args[:bytes_limit_per_file_percent] if args.key?(:bytes_limit_per_file_percent) @file_set = args[:file_set] if args.key?(:file_set) @file_types = args[:file_types] if args.key?(:file_types) @files_limit_percent = args[:files_limit_percent] if args.key?(:files_limit_percent) @sample_method = args[:sample_method] if args.key?(:sample_method) end |