Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ColumnDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned column within a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ColumnDataProfile

Returns a new instance of GooglePrivacyDlpV2ColumnDataProfile.



1791
1792
1793
# File 'lib/google/apis/dlp_v2/classes.rb', line 1791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The name of the column. Corresponds to the JSON property column

Returns:

  • (String)


1689
1690
1691
# File 'lib/google/apis/dlp_v2/classes.rb', line 1689

def column
  @column
end

#column_info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary

The infoType details for this column. Corresponds to the JSON property columnInfoType



1694
1695
1696
# File 'lib/google/apis/dlp_v2/classes.rb', line 1694

def column_info_type
  @column_info_type
end

#column_typeString

The data type of a given column. Corresponds to the JSON property columnType

Returns:

  • (String)


1699
1700
1701
# File 'lib/google/apis/dlp_v2/classes.rb', line 1699

def column_type
  @column_type
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



1705
1706
1707
# File 'lib/google/apis/dlp_v2/classes.rb', line 1705

def data_risk_level
  @data_risk_level
end

#dataset_idString

The BigQuery dataset ID, if the resource profiled is a BigQuery table. Corresponds to the JSON property datasetId

Returns:

  • (String)


1710
1711
1712
# File 'lib/google/apis/dlp_v2/classes.rb', line 1710

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// docs.cloud.google.com/bigquery/docs/locations for supported BigQuery locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/dlp_v2/classes.rb', line 1716

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the profiled resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


1721
1722
1723
# File 'lib/google/apis/dlp_v2/classes.rb', line 1721

def dataset_project_id
  @dataset_project_id
end

#estimated_null_percentageString

Approximate percentage of entries being null in the column. Corresponds to the JSON property estimatedNullPercentage

Returns:

  • (String)


1726
1727
1728
# File 'lib/google/apis/dlp_v2/classes.rb', line 1726

def estimated_null_percentage
  @estimated_null_percentage
end

#estimated_uniqueness_scoreString

Approximate uniqueness of the column. Corresponds to the JSON property estimatedUniquenessScore

Returns:

  • (String)


1731
1732
1733
# File 'lib/google/apis/dlp_v2/classes.rb', line 1731

def estimated_uniqueness_score
  @estimated_uniqueness_score
end

#free_text_scoreFloat

The likelihood that this column contains free-form text. A value close to 1 may indicate the column is likely to contain free-form or natural language text. Range in 0-1. Corresponds to the JSON property freeTextScore

Returns:

  • (Float)


1738
1739
1740
# File 'lib/google/apis/dlp_v2/classes.rb', line 1738

def free_text_score
  @free_text_score
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


1743
1744
1745
# File 'lib/google/apis/dlp_v2/classes.rb', line 1743

def name
  @name
end

#other_matchesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other types found within this column. List will be unordered. Corresponds to the JSON property otherMatches



1748
1749
1750
# File 'lib/google/apis/dlp_v2/classes.rb', line 1748

def other_matches
  @other_matches
end

#policy_stateString

Indicates if a policy tag has been applied to the column. Corresponds to the JSON property policyState

Returns:

  • (String)


1753
1754
1755
# File 'lib/google/apis/dlp_v2/classes.rb', line 1753

def policy_state
  @policy_state
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


1758
1759
1760
# File 'lib/google/apis/dlp_v2/classes.rb', line 1758

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



1763
1764
1765
# File 'lib/google/apis/dlp_v2/classes.rb', line 1763

def profile_status
  @profile_status
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



1769
1770
1771
# File 'lib/google/apis/dlp_v2/classes.rb', line 1769

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. Corresponds to the JSON property state

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/dlp_v2/classes.rb', line 1774

def state
  @state
end

#table_data_profileString

The resource name of the table data profile. Corresponds to the JSON property tableDataProfile

Returns:

  • (String)


1779
1780
1781
# File 'lib/google/apis/dlp_v2/classes.rb', line 1779

def table_data_profile
  @table_data_profile
end

#table_full_resourceString

The resource name of the resource this column is within. Corresponds to the JSON property tableFullResource

Returns:

  • (String)


1784
1785
1786
# File 'lib/google/apis/dlp_v2/classes.rb', line 1784

def table_full_resource
  @table_full_resource
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


1789
1790
1791
# File 'lib/google/apis/dlp_v2/classes.rb', line 1789

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1796
1797
1798
1799
1800
1801
1802
1803
1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
# File 'lib/google/apis/dlp_v2/classes.rb', line 1796

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @column_info_type = args[:column_info_type] if args.key?(:column_info_type)
  @column_type = args[:column_type] if args.key?(:column_type)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @estimated_null_percentage = args[:estimated_null_percentage] if args.key?(:estimated_null_percentage)
  @estimated_uniqueness_score = args[:estimated_uniqueness_score] if args.key?(:estimated_uniqueness_score)
  @free_text_score = args[:free_text_score] if args.key?(:free_text_score)
  @name = args[:name] if args.key?(:name)
  @other_matches = args[:other_matches] if args.key?(:other_matches)
  @policy_state = args[:policy_state] if args.key?(:policy_state)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_data_profile = args[:table_data_profile] if args.key?(:table_data_profile)
  @table_full_resource = args[:table_full_resource] if args.key?(:table_full_resource)
  @table_id = args[:table_id] if args.key?(:table_id)
end