Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ColumnDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned column within a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ColumnDataProfile

Returns a new instance of GooglePrivacyDlpV2ColumnDataProfile.



1752
1753
1754
# File 'lib/google/apis/dlp_v2/classes.rb', line 1752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The name of the column. Corresponds to the JSON property column

Returns:

  • (String)


1650
1651
1652
# File 'lib/google/apis/dlp_v2/classes.rb', line 1650

def column
  @column
end

#column_info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary

The infoType details for this column. Corresponds to the JSON property columnInfoType



1655
1656
1657
# File 'lib/google/apis/dlp_v2/classes.rb', line 1655

def column_info_type
  @column_info_type
end

#column_typeString

The data type of a given column. Corresponds to the JSON property columnType

Returns:

  • (String)


1660
1661
1662
# File 'lib/google/apis/dlp_v2/classes.rb', line 1660

def column_type
  @column_type
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



1666
1667
1668
# File 'lib/google/apis/dlp_v2/classes.rb', line 1666

def data_risk_level
  @data_risk_level
end

#dataset_idString

The BigQuery dataset ID, if the resource profiled is a BigQuery table. Corresponds to the JSON property datasetId

Returns:

  • (String)


1671
1672
1673
# File 'lib/google/apis/dlp_v2/classes.rb', line 1671

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// cloud.google.com/bigquery/docs/locations for supported BigQuery locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


1677
1678
1679
# File 'lib/google/apis/dlp_v2/classes.rb', line 1677

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the profiled resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


1682
1683
1684
# File 'lib/google/apis/dlp_v2/classes.rb', line 1682

def dataset_project_id
  @dataset_project_id
end

#estimated_null_percentageString

Approximate percentage of entries being null in the column. Corresponds to the JSON property estimatedNullPercentage

Returns:

  • (String)


1687
1688
1689
# File 'lib/google/apis/dlp_v2/classes.rb', line 1687

def estimated_null_percentage
  @estimated_null_percentage
end

#estimated_uniqueness_scoreString

Approximate uniqueness of the column. Corresponds to the JSON property estimatedUniquenessScore

Returns:

  • (String)


1692
1693
1694
# File 'lib/google/apis/dlp_v2/classes.rb', line 1692

def estimated_uniqueness_score
  @estimated_uniqueness_score
end

#free_text_scoreFloat

The likelihood that this column contains free-form text. A value close to 1 may indicate the column is likely to contain free-form or natural language text. Range in 0-1. Corresponds to the JSON property freeTextScore

Returns:

  • (Float)


1699
1700
1701
# File 'lib/google/apis/dlp_v2/classes.rb', line 1699

def free_text_score
  @free_text_score
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


1704
1705
1706
# File 'lib/google/apis/dlp_v2/classes.rb', line 1704

def name
  @name
end

#other_matchesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other types found within this column. List will be unordered. Corresponds to the JSON property otherMatches



1709
1710
1711
# File 'lib/google/apis/dlp_v2/classes.rb', line 1709

def other_matches
  @other_matches
end

#policy_stateString

Indicates if a policy tag has been applied to the column. Corresponds to the JSON property policyState

Returns:

  • (String)


1714
1715
1716
# File 'lib/google/apis/dlp_v2/classes.rb', line 1714

def policy_state
  @policy_state
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


1719
1720
1721
# File 'lib/google/apis/dlp_v2/classes.rb', line 1719

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



1724
1725
1726
# File 'lib/google/apis/dlp_v2/classes.rb', line 1724

def profile_status
  @profile_status
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



1730
1731
1732
# File 'lib/google/apis/dlp_v2/classes.rb', line 1730

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. Corresponds to the JSON property state

Returns:

  • (String)


1735
1736
1737
# File 'lib/google/apis/dlp_v2/classes.rb', line 1735

def state
  @state
end

#table_data_profileString

The resource name of the table data profile. Corresponds to the JSON property tableDataProfile

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/dlp_v2/classes.rb', line 1740

def table_data_profile
  @table_data_profile
end

#table_full_resourceString

The resource name of the resource this column is within. Corresponds to the JSON property tableFullResource

Returns:

  • (String)


1745
1746
1747
# File 'lib/google/apis/dlp_v2/classes.rb', line 1745

def table_full_resource
  @table_full_resource
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


1750
1751
1752
# File 'lib/google/apis/dlp_v2/classes.rb', line 1750

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
# File 'lib/google/apis/dlp_v2/classes.rb', line 1757

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @column_info_type = args[:column_info_type] if args.key?(:column_info_type)
  @column_type = args[:column_type] if args.key?(:column_type)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @estimated_null_percentage = args[:estimated_null_percentage] if args.key?(:estimated_null_percentage)
  @estimated_uniqueness_score = args[:estimated_uniqueness_score] if args.key?(:estimated_uniqueness_score)
  @free_text_score = args[:free_text_score] if args.key?(:free_text_score)
  @name = args[:name] if args.key?(:name)
  @other_matches = args[:other_matches] if args.key?(:other_matches)
  @policy_state = args[:policy_state] if args.key?(:policy_state)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_data_profile = args[:table_data_profile] if args.key?(:table_data_profile)
  @table_full_resource = args[:table_full_resource] if args.key?(:table_full_resource)
  @table_id = args[:table_id] if args.key?(:table_id)
end