Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ColumnDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ColumnDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a scanned column within a table.
Instance Attribute Summary collapse
-
#column ⇒ String
The name of the column.
-
#column_info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary
The infoType details for this column.
-
#column_type ⇒ String
The data type of a given column.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#dataset_id ⇒ String
The BigQuery dataset ID, if the resource profiled is a BigQuery table.
-
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the profiled resource.
-
#estimated_null_percentage ⇒ String
Approximate percentage of entries being null in the column.
-
#estimated_uniqueness_score ⇒ String
Approximate uniqueness of the column.
-
#free_text_score ⇒ Float
The likelihood that this column contains free-form text.
-
#name ⇒ String
The name of the profile.
-
#other_matches ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other types found within this column.
-
#policy_state ⇒ String
Indicates if a policy tag has been applied to the column.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#table_data_profile ⇒ String
The resource name of the table data profile.
-
#table_full_resource ⇒ String
The resource name of the resource this column is within.
-
#table_id ⇒ String
The table ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ColumnDataProfile
constructor
A new instance of GooglePrivacyDlpV2ColumnDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ColumnDataProfile
Returns a new instance of GooglePrivacyDlpV2ColumnDataProfile.
1739 1740 1741 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#column ⇒ String
The name of the column.
Corresponds to the JSON property column
1637 1638 1639 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1637 def column @column end |
#column_info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary
The infoType details for this column.
Corresponds to the JSON property columnInfoType
1642 1643 1644 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1642 def column_info_type @column_info_type end |
#column_type ⇒ String
The data type of a given column.
Corresponds to the JSON property columnType
1647 1648 1649 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1647 def column_type @column_type end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
1653 1654 1655 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1653 def data_risk_level @data_risk_level end |
#dataset_id ⇒ String
The BigQuery dataset ID, if the resource profiled is a BigQuery table.
Corresponds to the JSON property datasetId
1658 1659 1660 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1658 def dataset_id @dataset_id end |
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored. See https://
cloud.google.com/bigquery/docs/locations for supported BigQuery locations.
Corresponds to the JSON property datasetLocation
1664 1665 1666 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1664 def dataset_location @dataset_location end |
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the profiled resource.
Corresponds to the JSON property datasetProjectId
1669 1670 1671 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1669 def dataset_project_id @dataset_project_id end |
#estimated_null_percentage ⇒ String
Approximate percentage of entries being null in the column.
Corresponds to the JSON property estimatedNullPercentage
1674 1675 1676 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1674 def estimated_null_percentage @estimated_null_percentage end |
#estimated_uniqueness_score ⇒ String
Approximate uniqueness of the column.
Corresponds to the JSON property estimatedUniquenessScore
1679 1680 1681 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1679 def estimated_uniqueness_score @estimated_uniqueness_score end |
#free_text_score ⇒ Float
The likelihood that this column contains free-form text. A value close to 1
may indicate the column is likely to contain free-form or natural language
text. Range in 0-1.
Corresponds to the JSON property freeTextScore
1686 1687 1688 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1686 def free_text_score @free_text_score end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
1691 1692 1693 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1691 def name @name end |
#other_matches ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other types found within this column. List will be unordered.
Corresponds to the JSON property otherMatches
1696 1697 1698 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1696 def other_matches @other_matches end |
#policy_state ⇒ String
Indicates if a policy tag has been applied to the column.
Corresponds to the JSON property policyState
1701 1702 1703 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1701 def policy_state @policy_state end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
1706 1707 1708 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1706 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
1711 1712 1713 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1711 def profile_status @profile_status end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
1717 1718 1719 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1717 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile.
Corresponds to the JSON property state
1722 1723 1724 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1722 def state @state end |
#table_data_profile ⇒ String
The resource name of the table data profile.
Corresponds to the JSON property tableDataProfile
1727 1728 1729 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1727 def table_data_profile @table_data_profile end |
#table_full_resource ⇒ String
The resource name of the resource this column is within.
Corresponds to the JSON property tableFullResource
1732 1733 1734 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1732 def table_full_resource @table_full_resource end |
#table_id ⇒ String
The table ID.
Corresponds to the JSON property tableId
1737 1738 1739 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1737 def table_id @table_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1744 1745 1746 1747 1748 1749 1750 1751 1752 1753 1754 1755 1756 1757 1758 1759 1760 1761 1762 1763 1764 1765 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1744 def update!(**args) @column = args[:column] if args.key?(:column) @column_info_type = args[:column_info_type] if args.key?(:column_info_type) @column_type = args[:column_type] if args.key?(:column_type) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @dataset_location = args[:dataset_location] if args.key?(:dataset_location) @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id) @estimated_null_percentage = args[:estimated_null_percentage] if args.key?(:estimated_null_percentage) @estimated_uniqueness_score = args[:estimated_uniqueness_score] if args.key?(:estimated_uniqueness_score) @free_text_score = args[:free_text_score] if args.key?(:free_text_score) @name = args[:name] if args.key?(:name) @other_matches = args[:other_matches] if args.key?(:other_matches) @policy_state = args[:policy_state] if args.key?(:policy_state) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @table_data_profile = args[:table_data_profile] if args.key?(:table_data_profile) @table_full_resource = args[:table_full_resource] if args.key?(:table_full_resource) @table_id = args[:table_id] if args.key?(:table_id) end |