Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ColumnDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned column within a table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ColumnDataProfile

Returns a new instance of GooglePrivacyDlpV2ColumnDataProfile.



1615
1616
1617
# File 'lib/google/apis/dlp_v2/classes.rb', line 1615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnString

The name of the column. Corresponds to the JSON property column

Returns:

  • (String)


1513
1514
1515
# File 'lib/google/apis/dlp_v2/classes.rb', line 1513

def column
  @column
end

#column_info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary

The infoType details for this column. Corresponds to the JSON property columnInfoType



1518
1519
1520
# File 'lib/google/apis/dlp_v2/classes.rb', line 1518

def column_info_type
  @column_info_type
end

#column_typeString

The data type of a given column. Corresponds to the JSON property columnType

Returns:

  • (String)


1523
1524
1525
# File 'lib/google/apis/dlp_v2/classes.rb', line 1523

def column_type
  @column_type
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



1529
1530
1531
# File 'lib/google/apis/dlp_v2/classes.rb', line 1529

def data_risk_level
  @data_risk_level
end

#dataset_idString

The BigQuery dataset ID, if the resource profiled is a BigQuery table. Corresponds to the JSON property datasetId

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/dlp_v2/classes.rb', line 1534

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// cloud.google.com/bigquery/docs/locations for supported BigQuery locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


1540
1541
1542
# File 'lib/google/apis/dlp_v2/classes.rb', line 1540

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the profiled resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


1545
1546
1547
# File 'lib/google/apis/dlp_v2/classes.rb', line 1545

def dataset_project_id
  @dataset_project_id
end

#estimated_null_percentageString

Approximate percentage of entries being null in the column. Corresponds to the JSON property estimatedNullPercentage

Returns:

  • (String)


1550
1551
1552
# File 'lib/google/apis/dlp_v2/classes.rb', line 1550

def estimated_null_percentage
  @estimated_null_percentage
end

#estimated_uniqueness_scoreString

Approximate uniqueness of the column. Corresponds to the JSON property estimatedUniquenessScore

Returns:

  • (String)


1555
1556
1557
# File 'lib/google/apis/dlp_v2/classes.rb', line 1555

def estimated_uniqueness_score
  @estimated_uniqueness_score
end

#free_text_scoreFloat

The likelihood that this column contains free-form text. A value close to 1 may indicate the column is likely to contain free-form or natural language text. Range in 0-1. Corresponds to the JSON property freeTextScore

Returns:

  • (Float)


1562
1563
1564
# File 'lib/google/apis/dlp_v2/classes.rb', line 1562

def free_text_score
  @free_text_score
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


1567
1568
1569
# File 'lib/google/apis/dlp_v2/classes.rb', line 1567

def name
  @name
end

#other_matchesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other types found within this column. List will be unordered. Corresponds to the JSON property otherMatches



1572
1573
1574
# File 'lib/google/apis/dlp_v2/classes.rb', line 1572

def other_matches
  @other_matches
end

#policy_stateString

Indicates if a policy tag has been applied to the column. Corresponds to the JSON property policyState

Returns:

  • (String)


1577
1578
1579
# File 'lib/google/apis/dlp_v2/classes.rb', line 1577

def policy_state
  @policy_state
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


1582
1583
1584
# File 'lib/google/apis/dlp_v2/classes.rb', line 1582

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



1587
1588
1589
# File 'lib/google/apis/dlp_v2/classes.rb', line 1587

def profile_status
  @profile_status
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



1593
1594
1595
# File 'lib/google/apis/dlp_v2/classes.rb', line 1593

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. Corresponds to the JSON property state

Returns:

  • (String)


1598
1599
1600
# File 'lib/google/apis/dlp_v2/classes.rb', line 1598

def state
  @state
end

#table_data_profileString

The resource name of the table data profile. Corresponds to the JSON property tableDataProfile

Returns:

  • (String)


1603
1604
1605
# File 'lib/google/apis/dlp_v2/classes.rb', line 1603

def table_data_profile
  @table_data_profile
end

#table_full_resourceString

The resource name of the resource this column is within. Corresponds to the JSON property tableFullResource

Returns:

  • (String)


1608
1609
1610
# File 'lib/google/apis/dlp_v2/classes.rb', line 1608

def table_full_resource
  @table_full_resource
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


1613
1614
1615
# File 'lib/google/apis/dlp_v2/classes.rb', line 1613

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
# File 'lib/google/apis/dlp_v2/classes.rb', line 1620

def update!(**args)
  @column = args[:column] if args.key?(:column)
  @column_info_type = args[:column_info_type] if args.key?(:column_info_type)
  @column_type = args[:column_type] if args.key?(:column_type)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @estimated_null_percentage = args[:estimated_null_percentage] if args.key?(:estimated_null_percentage)
  @estimated_uniqueness_score = args[:estimated_uniqueness_score] if args.key?(:estimated_uniqueness_score)
  @free_text_score = args[:free_text_score] if args.key?(:free_text_score)
  @name = args[:name] if args.key?(:name)
  @other_matches = args[:other_matches] if args.key?(:other_matches)
  @policy_state = args[:policy_state] if args.key?(:policy_state)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_data_profile = args[:table_data_profile] if args.key?(:table_data_profile)
  @table_full_resource = args[:table_full_resource] if args.key?(:table_full_resource)
  @table_id = args[:table_id] if args.key?(:table_id)
end