Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Type of content to inspect.
Instance Attribute Summary collapse
-
#batch_content_item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentItem
Represents a batch of content to inspect or redact.
-
#byte_item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ByteContentItem
Container for bytes to inspect or redact.
-
#content_metadata ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentMetadata
Metadata on content to be scanned.
-
#conversation ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Conversation
Complete conversation or slice of a conversation.
-
#table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Table
Structured content to inspect.
-
#value ⇒ String
String data to inspect or redact.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentItem
constructor
A new instance of GooglePrivacyDlpV2ContentItem.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentItem
Returns a new instance of GooglePrivacyDlpV2ContentItem.
2027 2028 2029 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2027 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_content_item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentItem
Represents a batch of content to inspect or redact.
Corresponds to the JSON property batchContentItem
1997 1998 1999 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1997 def batch_content_item @batch_content_item end |
#byte_item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ByteContentItem
Container for bytes to inspect or redact.
Corresponds to the JSON property byteItem
2002 2003 2004 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2002 def byte_item @byte_item end |
#content_metadata ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentMetadata
Metadata on content to be scanned.
Corresponds to the JSON property contentMetadata
2007 2008 2009 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2007 def @content_metadata end |
#conversation ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Conversation
Complete conversation or slice of a conversation. It is assumed that all
included messages are contiguous and ordered in chronological order.
Corresponds to the JSON property conversation
2013 2014 2015 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2013 def conversation @conversation end |
#table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Table
Structured content to inspect. Up to 50,000 Values per request allowed. See
https://cloud.google.com/sensitive-data-protection/docs/inspecting-structured-
text#inspecting_a_table to learn more.
Corresponds to the JSON property table
2020 2021 2022 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2020 def table @table end |
#value ⇒ String
String data to inspect or redact.
Corresponds to the JSON property value
2025 2026 2027 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2025 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2032 2033 2034 2035 2036 2037 2038 2039 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2032 def update!(**args) @batch_content_item = args[:batch_content_item] if args.key?(:batch_content_item) @byte_item = args[:byte_item] if args.key?(:byte_item) @content_metadata = args[:content_metadata] if args.key?(:content_metadata) @conversation = args[:conversation] if args.key?(:conversation) @table = args[:table] if args.key?(:table) @value = args[:value] if args.key?(:value) end |