Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Precise location of the finding within a document, record, image, or metadata container.
Instance Attribute Summary collapse
-
#batch_content_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentLocation
Location within a batch of content.
-
#container_name ⇒ String
Name of the container where the finding is located.
-
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable.
-
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
-
#conversation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation
Location within a conversation.
-
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
-
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
-
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location Corresponds to the JSON property
metadataLocation. -
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
constructor
A new instance of GooglePrivacyDlpV2ContentLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
Returns a new instance of GooglePrivacyDlpV2ContentLocation.
2102 2103 2104 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_content_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BatchContentLocation
Location within a batch of content.
Corresponds to the JSON property batchContentLocation
2052 2053 2054 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2052 def batch_content_location @batch_content_location end |
#container_name ⇒ String
Name of the container where the finding is located. The top level name is the
source file name or table name. Names of some common storage containers are
formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id
- Cloud Storage files:
gs://bucket/path`* Datastore namespace:namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`
2062 2063 2064 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2062 def container_name @container_name end |
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable. For Cloud Storage,
this field contains the last file modification timestamp. For a BigQuery table,
this field contains the last_modified_time property. For Datastore, this
field isn't populated.
Corresponds to the JSON property containerTimestamp
2070 2071 2072 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2070 def @container_timestamp end |
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
Corresponds to the JSON property containerVersion
2075 2076 2077 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2075 def container_version @container_version end |
#conversation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation
Location within a conversation.
Corresponds to the JSON property conversationLocation
2080 2081 2082 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2080 def conversation_location @conversation_location end |
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
Corresponds to the JSON property documentLocation
2085 2086 2087 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2085 def document_location @document_location end |
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
Corresponds to the JSON property imageLocation
2090 2091 2092 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2090 def image_location @image_location end |
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location
Corresponds to the JSON property metadataLocation
2095 2096 2097 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2095 def @metadata_location end |
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Corresponds to the JSON property recordLocation
2100 2101 2102 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2100 def record_location @record_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2107 2108 2109 2110 2111 2112 2113 2114 2115 2116 2117 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2107 def update!(**args) @batch_content_location = args[:batch_content_location] if args.key?(:batch_content_location) @container_name = args[:container_name] if args.key?(:container_name) @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp) @container_version = args[:container_version] if args.key?(:container_version) @conversation_location = args[:conversation_location] if args.key?(:conversation_location) @document_location = args[:document_location] if args.key?(:document_location) @image_location = args[:image_location] if args.key?(:image_location) @metadata_location = args[:metadata_location] if args.key?(:metadata_location) @record_location = args[:record_location] if args.key?(:record_location) end |