Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Precise location of the finding within a document, record, image, or metadata container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation

Returns a new instance of GooglePrivacyDlpV2ContentLocation.



2100
2101
2102
# File 'lib/google/apis/dlp_v2/classes.rb', line 2100

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#batch_content_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2BatchContentLocation

Location within a batch of content. Corresponds to the JSON property batchContentLocation



2050
2051
2052
# File 'lib/google/apis/dlp_v2/classes.rb', line 2050

def batch_content_location
  @batch_content_location
end

#container_nameString

Name of the container where the finding is located. The top level name is the source file name or table name. Names of some common storage containers are formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id

  • Cloud Storage files: gs://bucket/path`* Datastore namespace: namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`

Returns:

  • (String)


2060
2061
2062
# File 'lib/google/apis/dlp_v2/classes.rb', line 2060

def container_name
  @container_name
end

#container_timestampString

Finding container modification timestamp, if applicable. For Cloud Storage, this field contains the last file modification timestamp. For a BigQuery table, this field contains the last_modified_time property. For Datastore, this field isn't populated. Corresponds to the JSON property containerTimestamp

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/dlp_v2/classes.rb', line 2068

def container_timestamp
  @container_timestamp
end

#container_versionString

Finding container version, if available ("generation" for Cloud Storage). Corresponds to the JSON property containerVersion

Returns:

  • (String)


2073
2074
2075
# File 'lib/google/apis/dlp_v2/classes.rb', line 2073

def container_version
  @container_version
end

#conversation_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation

Location within a conversation. Corresponds to the JSON property conversationLocation



2078
2079
2080
# File 'lib/google/apis/dlp_v2/classes.rb', line 2078

def conversation_location
  @conversation_location
end

#document_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation

Location of a finding within a document. Corresponds to the JSON property documentLocation



2083
2084
2085
# File 'lib/google/apis/dlp_v2/classes.rb', line 2083

def document_location
  @document_location
end

#image_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation

Location of the finding within an image. Corresponds to the JSON property imageLocation



2088
2089
2090
# File 'lib/google/apis/dlp_v2/classes.rb', line 2088

def image_location
  @image_location
end

#metadata_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation

Metadata Location Corresponds to the JSON property metadataLocation



2093
2094
2095
# File 'lib/google/apis/dlp_v2/classes.rb', line 2093

def 
  @metadata_location
end

#record_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation

Location of a finding within a row or record. Corresponds to the JSON property recordLocation



2098
2099
2100
# File 'lib/google/apis/dlp_v2/classes.rb', line 2098

def record_location
  @record_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2105
2106
2107
2108
2109
2110
2111
2112
2113
2114
2115
# File 'lib/google/apis/dlp_v2/classes.rb', line 2105

def update!(**args)
  @batch_content_location = args[:batch_content_location] if args.key?(:batch_content_location)
  @container_name = args[:container_name] if args.key?(:container_name)
  @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp)
  @container_version = args[:container_version] if args.key?(:container_version)
  @conversation_location = args[:conversation_location] if args.key?(:conversation_location)
  @document_location = args[:document_location] if args.key?(:document_location)
  @image_location = args[:image_location] if args.key?(:image_location)
  @metadata_location = args[:metadata_location] if args.key?(:metadata_location)
  @record_location = args[:record_location] if args.key?(:record_location)
end