Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Precise location of the finding within a document, record, image, or metadata container.
Instance Attribute Summary collapse
-
#container_name ⇒ String
Name of the container where the finding is located.
-
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable.
-
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
-
#conversation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation
Location within a conversation.
-
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
-
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
-
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location Corresponds to the JSON property
metadataLocation. -
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
constructor
A new instance of GooglePrivacyDlpV2ContentLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
Returns a new instance of GooglePrivacyDlpV2ContentLocation.
2051 2052 2053 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_name ⇒ String
Name of the container where the finding is located. The top level name is the
source file name or table name. Names of some common storage containers are
formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id
- Cloud Storage files:
gs://bucket/path`* Datastore namespace:namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`
2011 2012 2013 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2011 def container_name @container_name end |
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable. For Cloud Storage,
this field contains the last file modification timestamp. For a BigQuery table,
this field contains the last_modified_time property. For Datastore, this
field isn't populated.
Corresponds to the JSON property containerTimestamp
2019 2020 2021 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2019 def @container_timestamp end |
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
Corresponds to the JSON property containerVersion
2024 2025 2026 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2024 def container_version @container_version end |
#conversation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation
Location within a conversation.
Corresponds to the JSON property conversationLocation
2029 2030 2031 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2029 def conversation_location @conversation_location end |
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
Corresponds to the JSON property documentLocation
2034 2035 2036 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2034 def document_location @document_location end |
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
Corresponds to the JSON property imageLocation
2039 2040 2041 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2039 def image_location @image_location end |
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location
Corresponds to the JSON property metadataLocation
2044 2045 2046 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2044 def @metadata_location end |
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Corresponds to the JSON property recordLocation
2049 2050 2051 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2049 def record_location @record_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2056 2057 2058 2059 2060 2061 2062 2063 2064 2065 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2056 def update!(**args) @container_name = args[:container_name] if args.key?(:container_name) @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp) @container_version = args[:container_version] if args.key?(:container_version) @conversation_location = args[:conversation_location] if args.key?(:conversation_location) @document_location = args[:document_location] if args.key?(:document_location) @image_location = args[:image_location] if args.key?(:image_location) @metadata_location = args[:metadata_location] if args.key?(:metadata_location) @record_location = args[:record_location] if args.key?(:record_location) end |