Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Precise location of the finding within a document, record, image, or metadata container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation

Returns a new instance of GooglePrivacyDlpV2ContentLocation.



2026
2027
2028
# File 'lib/google/apis/dlp_v2/classes.rb', line 2026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_nameString

Name of the container where the finding is located. The top level name is the source file name or table name. Names of some common storage containers are formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id

  • Cloud Storage files: gs://bucket/path`* Datastore namespace: namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`

Returns:

  • (String)


1991
1992
1993
# File 'lib/google/apis/dlp_v2/classes.rb', line 1991

def container_name
  @container_name
end

#container_timestampString

Finding container modification timestamp, if applicable. For Cloud Storage, this field contains the last file modification timestamp. For a BigQuery table, this field contains the last_modified_time property. For Datastore, this field isn't populated. Corresponds to the JSON property containerTimestamp

Returns:

  • (String)


1999
2000
2001
# File 'lib/google/apis/dlp_v2/classes.rb', line 1999

def container_timestamp
  @container_timestamp
end

#container_versionString

Finding container version, if available ("generation" for Cloud Storage). Corresponds to the JSON property containerVersion

Returns:

  • (String)


2004
2005
2006
# File 'lib/google/apis/dlp_v2/classes.rb', line 2004

def container_version
  @container_version
end

#document_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation

Location of a finding within a document. Corresponds to the JSON property documentLocation



2009
2010
2011
# File 'lib/google/apis/dlp_v2/classes.rb', line 2009

def document_location
  @document_location
end

#image_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation

Location of the finding within an image. Corresponds to the JSON property imageLocation



2014
2015
2016
# File 'lib/google/apis/dlp_v2/classes.rb', line 2014

def image_location
  @image_location
end

#metadata_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation

Metadata Location Corresponds to the JSON property metadataLocation



2019
2020
2021
# File 'lib/google/apis/dlp_v2/classes.rb', line 2019

def 
  @metadata_location
end

#record_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation

Location of a finding within a row or record. Corresponds to the JSON property recordLocation



2024
2025
2026
# File 'lib/google/apis/dlp_v2/classes.rb', line 2024

def record_location
  @record_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2031
2032
2033
2034
2035
2036
2037
2038
2039
# File 'lib/google/apis/dlp_v2/classes.rb', line 2031

def update!(**args)
  @container_name = args[:container_name] if args.key?(:container_name)
  @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp)
  @container_version = args[:container_version] if args.key?(:container_version)
  @document_location = args[:document_location] if args.key?(:document_location)
  @image_location = args[:image_location] if args.key?(:image_location)
  @metadata_location = args[:metadata_location] if args.key?(:metadata_location)
  @record_location = args[:record_location] if args.key?(:record_location)
end