Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Precise location of the finding within a document, record, image, or metadata container.
Instance Attribute Summary collapse
-
#container_name ⇒ String
Name of the container where the finding is located.
-
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable.
-
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
-
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
-
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
-
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location Corresponds to the JSON property
metadataLocation. -
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
constructor
A new instance of GooglePrivacyDlpV2ContentLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation
Returns a new instance of GooglePrivacyDlpV2ContentLocation.
2020 2021 2022 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2020 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_name ⇒ String
Name of the container where the finding is located. The top level name is the
source file name or table name. Names of some common storage containers are
formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id
- Cloud Storage files:
gs://bucket/path`* Datastore namespace:namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`
1985 1986 1987 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1985 def container_name @container_name end |
#container_timestamp ⇒ String
Finding container modification timestamp, if applicable. For Cloud Storage,
this field contains the last file modification timestamp. For a BigQuery table,
this field contains the last_modified_time property. For Datastore, this
field isn't populated.
Corresponds to the JSON property containerTimestamp
1993 1994 1995 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1993 def @container_timestamp end |
#container_version ⇒ String
Finding container version, if available ("generation" for Cloud Storage).
Corresponds to the JSON property containerVersion
1998 1999 2000 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 1998 def container_version @container_version end |
#document_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation
Location of a finding within a document.
Corresponds to the JSON property documentLocation
2003 2004 2005 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2003 def document_location @document_location end |
#image_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation
Location of the finding within an image.
Corresponds to the JSON property imageLocation
2008 2009 2010 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2008 def image_location @image_location end |
#metadata_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
Metadata Location
Corresponds to the JSON property metadataLocation
2013 2014 2015 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2013 def @metadata_location end |
#record_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation
Location of a finding within a row or record.
Corresponds to the JSON property recordLocation
2018 2019 2020 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2018 def record_location @record_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2025 2026 2027 2028 2029 2030 2031 2032 2033 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2025 def update!(**args) @container_name = args[:container_name] if args.key?(:container_name) @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp) @container_version = args[:container_version] if args.key?(:container_version) @document_location = args[:document_location] if args.key?(:document_location) @image_location = args[:image_location] if args.key?(:image_location) @metadata_location = args[:metadata_location] if args.key?(:metadata_location) @record_location = args[:record_location] if args.key?(:record_location) end |