Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Precise location of the finding within a document, record, image, or metadata container.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ContentLocation

Returns a new instance of GooglePrivacyDlpV2ContentLocation.



1896
1897
1898
# File 'lib/google/apis/dlp_v2/classes.rb', line 1896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_nameString

Name of the container where the finding is located. The top level name is the source file name or table name. Names of some common storage containers are formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id

  • Cloud Storage files: gs://bucket/path`* Datastore namespace: namespaceNested names could be absent if the embedded object has no string identifier (for example, an image contained within a document). Corresponds to the JSON propertycontainerName`

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/dlp_v2/classes.rb', line 1861

def container_name
  @container_name
end

#container_timestampString

Finding container modification timestamp, if applicable. For Cloud Storage, this field contains the last file modification timestamp. For a BigQuery table, this field contains the last_modified_time property. For Datastore, this field isn't populated. Corresponds to the JSON property containerTimestamp

Returns:

  • (String)


1869
1870
1871
# File 'lib/google/apis/dlp_v2/classes.rb', line 1869

def container_timestamp
  @container_timestamp
end

#container_versionString

Finding container version, if available ("generation" for Cloud Storage). Corresponds to the JSON property containerVersion

Returns:

  • (String)


1874
1875
1876
# File 'lib/google/apis/dlp_v2/classes.rb', line 1874

def container_version
  @container_version
end

#document_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DocumentLocation

Location of a finding within a document. Corresponds to the JSON property documentLocation



1879
1880
1881
# File 'lib/google/apis/dlp_v2/classes.rb', line 1879

def document_location
  @document_location
end

#image_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ImageLocation

Location of the finding within an image. Corresponds to the JSON property imageLocation



1884
1885
1886
# File 'lib/google/apis/dlp_v2/classes.rb', line 1884

def image_location
  @image_location
end

#metadata_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation

Metadata Location Corresponds to the JSON property metadataLocation



1889
1890
1891
# File 'lib/google/apis/dlp_v2/classes.rb', line 1889

def 
  @metadata_location
end

#record_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation

Location of a finding within a row or record. Corresponds to the JSON property recordLocation



1894
1895
1896
# File 'lib/google/apis/dlp_v2/classes.rb', line 1894

def record_location
  @record_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1901
1902
1903
1904
1905
1906
1907
1908
1909
# File 'lib/google/apis/dlp_v2/classes.rb', line 1901

def update!(**args)
  @container_name = args[:container_name] if args.key?(:container_name)
  @container_timestamp = args[:container_timestamp] if args.key?(:container_timestamp)
  @container_version = args[:container_version] if args.key?(:container_version)
  @document_location = args[:document_location] if args.key?(:document_location)
  @image_location = args[:image_location] if args.key?(:image_location)
  @metadata_location = args[:metadata_location] if args.key?(:metadata_location)
  @record_location = args[:record_location] if args.key?(:record_location)
end