Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ContentPolicy
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ContentPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A policy to apply to content based on its inspection findings.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#default_action ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
-
#display_name ⇒ String
Optional.
-
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only.
-
#failed_to_scan_supported_file_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
-
#input_too_large ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#inspect_template ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig.
-
#logging_configs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2LoggingConfig>
Optional.
-
#name ⇒ String
Output only.
-
#rules ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyRule>
Required.
-
#unsupported_file_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentPolicy
constructor
A new instance of GooglePrivacyDlpV2ContentPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ContentPolicy
Returns a new instance of GooglePrivacyDlpV2ContentPolicy.
2220 2221 2222 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of a contentPolicy; output-only field.
Corresponds to the JSON property createTime
2151 2152 2153 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2151 def create_time @create_time end |
#default_action ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
Corresponds to the JSON property defaultAction
2156 2157 2158 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2156 def default_action @default_action end |
#display_name ⇒ String
Optional. Display name (max 63 chars)
Corresponds to the JSON property displayName
2161 2162 2163 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2161 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only. A stream of errors encountered when the policy was applied.
Output only field. Will return the last 100 errors. Whenever the policy is
modified this list will be cleared.
Corresponds to the JSON property errors
2168 2169 2170 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2168 def errors @errors end |
#failed_to_scan_supported_file_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
Corresponds to the JSON property failedToScanSupportedFileType
2173 2174 2175 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2173 def failed_to_scan_supported_file_type @failed_to_scan_supported_file_type end |
#input_too_large ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
Corresponds to the JSON property inputTooLarge
2178 2179 2180 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2178 def input_too_large @input_too_large end |
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
2184 2185 2186 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2184 def inspect_config @inspect_config end |
#inspect_template ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
The inspectTemplate contains a configuration (set of types of sensitive data
to be detected) to be used anywhere you otherwise would normally specify
InspectConfig. See https://docs.cloud.google.com/sensitive-data-protection/
docs/concepts-templates to learn more.
Corresponds to the JSON property inspectTemplate
2192 2193 2194 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2192 def inspect_template @inspect_template end |
#logging_configs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2LoggingConfig>
Optional. Log the actions taken by the content policy to external systems.
Corresponds to the JSON property loggingConfigs
2197 2198 2199 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2197 def logging_configs @logging_configs end |
#name ⇒ String
Output only. Resource name of the policy.
Corresponds to the JSON property name
2202 2203 2204 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2202 def name @name end |
#rules ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyRule>
Required. Policies to apply, based on the findings returned by inspection. The
first rule to match applies.
Corresponds to the JSON property rules
2208 2209 2210 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2208 def rules @rules end |
#unsupported_file_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
A possible action to take when applying a content policy.
Corresponds to the JSON property unsupportedFileType
2213 2214 2215 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2213 def unsupported_file_type @unsupported_file_type end |
#update_time ⇒ String
Output only. The last update timestamp of a contentPolicy; output-only field.
Corresponds to the JSON property updateTime
2218 2219 2220 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2218 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 2235 2236 2237 2238 2239 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2225 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @default_action = args[:default_action] if args.key?(:default_action) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @failed_to_scan_supported_file_type = args[:failed_to_scan_supported_file_type] if args.key?(:failed_to_scan_supported_file_type) @input_too_large = args[:input_too_large] if args.key?(:input_too_large) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @inspect_template = args[:inspect_template] if args.key?(:inspect_template) @logging_configs = args[:logging_configs] if args.key?(:logging_configs) @name = args[:name] if args.key?(:name) @rules = args[:rules] if args.key?(:rules) @unsupported_file_type = args[:unsupported_file_type] if args.key?(:unsupported_file_type) @update_time = args[:update_time] if args.key?(:update_time) end |