Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Conversation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Conversation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Complete conversation or slice of a conversation. It is assumed that all included messages are contiguous and ordered in chronological order.
Instance Attribute Summary collapse
-
#messages ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationMessage>
Messages exchanged within this conversation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Conversation
constructor
A new instance of GooglePrivacyDlpV2Conversation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Conversation
Returns a new instance of GooglePrivacyDlpV2Conversation.
2149 2150 2151 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#messages ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationMessage>
Messages exchanged within this conversation. The maximum number of messages
allowed is 50k. The order of the messages is assumed to be chronological and
will be used to index findings in the response.
Corresponds to the JSON property messages
2147 2148 2149 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2147 def @messages end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2154 2155 2156 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2154 def update!(**args) @messages = args[:messages] if args.key?(:messages) end |