Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ConversationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Location within a conversation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ConversationLocation

Returns a new instance of GooglePrivacyDlpV2ConversationLocation.



2123
2124
2125
# File 'lib/google/apis/dlp_v2/classes.rb', line 2123

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_messagesGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllMessages

If set, indicates that the finding applies to all messages in the conversation. Corresponds to the JSON property allMessages



2116
2117
2118
# File 'lib/google/apis/dlp_v2/classes.rb', line 2116

def all_messages
  @all_messages
end

#message_indexFixnum

Matches an index of a message in the conversation provided in the request. Corresponds to the JSON property messageIndex

Returns:

  • (Fixnum)


2121
2122
2123
# File 'lib/google/apis/dlp_v2/classes.rb', line 2121

def message_index
  @message_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2128
2129
2130
2131
# File 'lib/google/apis/dlp_v2/classes.rb', line 2128

def update!(**args)
  @all_messages = args[:all_messages] if args.key?(:all_messages)
  @message_index = args[:message_index] if args.key?(:message_index)
end