Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateDiscoveryConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateDiscoveryConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateDiscoveryConfigRequest

Returns a new instance of GooglePrivacyDlpV2CreateDiscoveryConfigRequest.



1989
1990
1991
# File 'lib/google/apis/dlp_v2/classes.rb', line 1989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_idString

The config ID can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property configId

Returns:

  • (String)


1978
1979
1980
# File 'lib/google/apis/dlp_v2/classes.rb', line 1978

def config_id
  @config_id
end

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



1987
1988
1989
# File 'lib/google/apis/dlp_v2/classes.rb', line 1987

def discovery_config
  @discovery_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1994
1995
1996
1997
# File 'lib/google/apis/dlp_v2/classes.rb', line 1994

def update!(**args)
  @config_id = args[:config_id] if args.key?(:config_id)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
end