Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateDlpJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateDlpJobRequest. Used to initiate long running jobs such as calculating risk metrics or inspecting Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateDlpJobRequest

Returns a new instance of GooglePrivacyDlpV2CreateDlpJobRequest.



2466
2467
2468
# File 'lib/google/apis/dlp_v2/classes.rb', line 2466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig

Controls what and how to inspect for findings. Corresponds to the JSON property inspectJob



2446
2447
2448
# File 'lib/google/apis/dlp_v2/classes.rb', line 2446

def inspect_job
  @inspect_job
end

#job_idString

The job id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property jobId

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/dlp_v2/classes.rb', line 2453

def job_id
  @job_id
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/dlp_v2/classes.rb', line 2458

def location_id
  @location_id
end

#risk_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2RiskAnalysisJobConfig

Configuration for a risk analysis job. See https://cloud.google.com/sensitive- data-protection/docs/concepts-risk-analysis to learn more. Corresponds to the JSON property riskJob



2464
2465
2466
# File 'lib/google/apis/dlp_v2/classes.rb', line 2464

def risk_job
  @risk_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2471
2472
2473
2474
2475
2476
# File 'lib/google/apis/dlp_v2/classes.rb', line 2471

def update!(**args)
  @inspect_job = args[:inspect_job] if args.key?(:inspect_job)
  @job_id = args[:job_id] if args.key?(:job_id)
  @location_id = args[:location_id] if args.key?(:location_id)
  @risk_job = args[:risk_job] if args.key?(:risk_job)
end