Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateDlpJobRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateDlpJobRequest. Used to initiate long running jobs such as calculating risk metrics or inspecting Google Cloud Storage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateDlpJobRequest

Returns a new instance of GooglePrivacyDlpV2CreateDlpJobRequest.



2028
2029
2030
# File 'lib/google/apis/dlp_v2/classes.rb', line 2028

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig

Controls what and how to inspect for findings. Corresponds to the JSON property inspectJob



2008
2009
2010
# File 'lib/google/apis/dlp_v2/classes.rb', line 2008

def inspect_job
  @inspect_job
end

#job_idString

The job id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property jobId

Returns:

  • (String)


2015
2016
2017
# File 'lib/google/apis/dlp_v2/classes.rb', line 2015

def job_id
  @job_id
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/dlp_v2/classes.rb', line 2020

def location_id
  @location_id
end

#risk_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2RiskAnalysisJobConfig

Configuration for a risk analysis job. See https://cloud.google.com/sensitive- data-protection/docs/concepts-risk-analysis to learn more. Corresponds to the JSON property riskJob



2026
2027
2028
# File 'lib/google/apis/dlp_v2/classes.rb', line 2026

def risk_job
  @risk_job
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2033
2034
2035
2036
2037
2038
# File 'lib/google/apis/dlp_v2/classes.rb', line 2033

def update!(**args)
  @inspect_job = args[:inspect_job] if args.key?(:inspect_job)
  @job_id = args[:job_id] if args.key?(:job_id)
  @location_id = args[:location_id] if args.key?(:location_id)
  @risk_job = args[:risk_job] if args.key?(:risk_job)
end