Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CreateInspectTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for CreateInspectTemplate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2CreateInspectTemplateRequest

Returns a new instance of GooglePrivacyDlpV2CreateInspectTemplateRequest.



2322
2323
2324
# File 'lib/google/apis/dlp_v2/classes.rb', line 2322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_templateGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate

The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more. Corresponds to the JSON property inspectTemplate



2307
2308
2309
# File 'lib/google/apis/dlp_v2/classes.rb', line 2307

def inspect_template
  @inspect_template
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/dlp_v2/classes.rb', line 2312

def location_id
  @location_id
end

#template_idString

The template id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+. The maximum length is 100 characters. Can be empty to allow the system to generate one. Corresponds to the JSON property templateId

Returns:

  • (String)


2320
2321
2322
# File 'lib/google/apis/dlp_v2/classes.rb', line 2320

def template_id
  @template_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2327
2328
2329
2330
2331
# File 'lib/google/apis/dlp_v2/classes.rb', line 2327

def update!(**args)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
  @location_id = args[:location_id] if args.key?(:location_id)
  @template_id = args[:template_id] if args.key?(:template_id)
end