Class: Google::Apis::DlpV2::GooglePrivacyDlpV2CustomInfoType
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2CustomInfoType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Custom information type provided by the user. Used to find domain-specific sensitive information configurable to the data in question.
Instance Attribute Summary collapse
-
#detection_rules ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DetectionRule>
Set of detection rules to apply to all findings of this CustomInfoType.
-
#dictionary ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Dictionary
Custom information type based on a dictionary of words or phrases.
-
#exclusion_type ⇒ String
If set to EXCLUSION_TYPE_EXCLUDE this infoType will not cause a finding to be returned.
-
#file_label_info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileLabelInfoType
Configuration for a custom infoType that detects file labels.
-
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
-
#likelihood ⇒ String
Likelihood to return for this CustomInfoType.
-
#metadata_key_value_expression ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataKeyValueExpression
Configuration for a custom infoType that detects key-value pairs in the metadata matching the specified regular expressions.
-
#regex ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Regex
Message defining a custom regular expression.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#stored_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StoredType
A reference to a StoredInfoType to use with scanning.
-
#surrogate_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SurrogateType
Message for detecting output from deidentification transformations such as
CryptoReplaceFfxFpeConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2CustomInfoType
constructor
A new instance of GooglePrivacyDlpV2CustomInfoType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2CustomInfoType
Returns a new instance of GooglePrivacyDlpV2CustomInfoType.
2854 2855 2856 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2854 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detection_rules ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DetectionRule>
Set of detection rules to apply to all findings of this CustomInfoType. Rules
are applied in the order that they are specified. Only supported for the
dictionary, regex, and stored_type CustomInfoTypes.
Corresponds to the JSON property detectionRules
2772 2773 2774 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2772 def detection_rules @detection_rules end |
#dictionary ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Dictionary
Custom information type based on a dictionary of words or phrases. This can be
used to match sensitive information specific to the data, such as a list of
employee IDs or job titles. Dictionary words are case-insensitive and all
characters other than letters and digits in the unicode Basic Multilingual
Plane will be replaced with whitespace when scanning for
matches, so the dictionary phrase "Sam Johnson" will match all three phrases "
sam johnson", "Sam, Johnson", and "Sam (Johnson)". Additionally, the
characters surrounding any match must be of a different type than the adjacent
characters within the word, so letters must be next to non-letters and digits
next to non-digits. For example, the dictionary word "jen" will match the
first three letters of the text "jen123" but will return no matches for "
jennifer". Dictionary words containing a large number of characters that are
not letters or digits may result in unexpected findings because such
characters are treated as whitespace. The limits page contains details about the size limits
of dictionaries. For dictionaries that do not fit within these constraints,
consider using LargeCustomDictionaryConfig in the StoredInfoType API.
Corresponds to the JSON property dictionary
2794 2795 2796 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2794 def dictionary @dictionary end |
#exclusion_type ⇒ String
If set to EXCLUSION_TYPE_EXCLUDE this infoType will not cause a finding to be
returned. It still can be used for rules matching. Only supported for the
dictionary, regex, and stored_type CustomInfoTypes.
Corresponds to the JSON property exclusionType
2801 2802 2803 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2801 def exclusion_type @exclusion_type end |
#file_label_info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileLabelInfoType
Configuration for a custom infoType that detects file labels.
Corresponds to the JSON property fileLabelInfoType
2806 2807 2808 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2806 def file_label_info_type @file_label_info_type end |
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infoType
2811 2812 2813 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2811 def info_type @info_type end |
#likelihood ⇒ String
Likelihood to return for this CustomInfoType. This base value can be altered
by a detection rule if the finding meets the criteria specified by the rule.
Defaults to VERY_LIKELY if not specified.
Corresponds to the JSON property likelihood
2818 2819 2820 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2818 def likelihood @likelihood end |
#metadata_key_value_expression ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataKeyValueExpression
Configuration for a custom infoType that detects key-value pairs in the
metadata matching the specified regular expressions.
Corresponds to the JSON property metadataKeyValueExpression
2824 2825 2826 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2824 def @metadata_key_value_expression end |
#regex ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Regex
Message defining a custom regular expression.
Corresponds to the JSON property regex
2829 2830 2831 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2829 def regex @regex end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
2835 2836 2837 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2835 def sensitivity_score @sensitivity_score end |
#stored_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StoredType
A reference to a StoredInfoType to use with scanning.
Corresponds to the JSON property storedType
2840 2841 2842 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2840 def stored_type @stored_type end |
#surrogate_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SurrogateType
Message for detecting output from deidentification transformations such as
CryptoReplaceFfxFpeConfig. These types of transformations are those that
perform pseudonymization, thereby producing a "surrogate" as output. This
should be used in conjunction with a field on the transformation such as
surrogate_info_type. This CustomInfoType does not support the use of
detection_rules.
Corresponds to the JSON property surrogateType
2852 2853 2854 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2852 def surrogate_type @surrogate_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2859 2860 2861 2862 2863 2864 2865 2866 2867 2868 2869 2870 2871 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2859 def update!(**args) @detection_rules = args[:detection_rules] if args.key?(:detection_rules) @dictionary = args[:dictionary] if args.key?(:dictionary) @exclusion_type = args[:exclusion_type] if args.key?(:exclusion_type) @file_label_info_type = args[:file_label_info_type] if args.key?(:file_label_info_type) @info_type = args[:info_type] if args.key?(:info_type) @likelihood = args[:likelihood] if args.key?(:likelihood) @metadata_key_value_expression = args[:metadata_key_value_expression] if args.key?(:metadata_key_value_expression) @regex = args[:regex] if args.key?(:regex) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @stored_type = args[:stored_type] if args.key?(:stored_type) @surrogate_type = args[:surrogate_type] if args.key?(:surrogate_type) end |