Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A task to execute when a data profile has been generated.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileAction

Returns a new instance of GooglePrivacyDlpV2DataProfileAction.



2466
2467
2468
# File 'lib/google/apis/dlp_v2/classes.rb', line 2466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_dataGoogle::Apis::DlpV2::GooglePrivacyDlpV2Export

If set, the detailed data profiles will be persisted to the location of your choice whenever updated. Corresponds to the JSON property exportData



2430
2431
2432
# File 'lib/google/apis/dlp_v2/classes.rb', line 2430

def export_data
  @export_data
end

#pub_sub_notificationGoogle::Apis::DlpV2::GooglePrivacyDlpV2PubSubNotification

Send a Pub/Sub message into the given Pub/Sub topic to connect other systems to data profile generation. The message payload data will be the byte serialization of DataProfilePubSubMessage. Corresponds to the JSON property pubSubNotification



2437
2438
2439
# File 'lib/google/apis/dlp_v2/classes.rb', line 2437

def pub_sub_notification
  @pub_sub_notification
end

#publish_to_chronicleGoogle::Apis::DlpV2::GooglePrivacyDlpV2PublishToChronicle

Message expressing intention to publish to Google Security Operations. Corresponds to the JSON property publishToChronicle



2442
2443
2444
# File 'lib/google/apis/dlp_v2/classes.rb', line 2442

def publish_to_chronicle
  @publish_to_chronicle
end

#publish_to_dataplex_catalogGoogle::Apis::DlpV2::GooglePrivacyDlpV2PublishToDataplexCatalog

Create Dataplex Universal Catalog aspects for profiled resources with the aspect type Sensitive Data Protection Profile. To learn more about aspects, see https://cloud.google.com/sensitive-data-protection/docs/add-aspects. Corresponds to the JSON property publishToDataplexCatalog



2449
2450
2451
# File 'lib/google/apis/dlp_v2/classes.rb', line 2449

def publish_to_dataplex_catalog
  @publish_to_dataplex_catalog
end

#publish_to_sccGoogle::Apis::DlpV2::GooglePrivacyDlpV2PublishToSecurityCommandCenter

If set, a summary finding will be created or updated in Security Command Center for each profile. Corresponds to the JSON property publishToScc



2455
2456
2457
# File 'lib/google/apis/dlp_v2/classes.rb', line 2455

def publish_to_scc
  @publish_to_scc
end

#tag_resourcesGoogle::Apis::DlpV2::GooglePrivacyDlpV2TagResources

If set, attaches the tags provided to profiled resources. Tags support access control. You can conditionally grant or deny access to a resource based on whether the resource has a specific tag. Corresponds to the JSON property tagResources



2464
2465
2466
# File 'lib/google/apis/dlp_v2/classes.rb', line 2464

def tag_resources
  @tag_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2471
2472
2473
2474
2475
2476
2477
2478
# File 'lib/google/apis/dlp_v2/classes.rb', line 2471

def update!(**args)
  @export_data = args[:export_data] if args.key?(:export_data)
  @pub_sub_notification = args[:pub_sub_notification] if args.key?(:pub_sub_notification)
  @publish_to_chronicle = args[:publish_to_chronicle] if args.key?(:publish_to_chronicle)
  @publish_to_dataplex_catalog = args[:publish_to_dataplex_catalog] if args.key?(:publish_to_dataplex_catalog)
  @publish_to_scc = args[:publish_to_scc] if args.key?(:publish_to_scc)
  @tag_resources = args[:tag_resources] if args.key?(:tag_resources)
end