Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Snapshot of the configurations used to generate the profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileConfigSnapshot

Returns a new instance of GooglePrivacyDlpV2DataProfileConfigSnapshot.



3006
3007
3008
# File 'lib/google/apis/dlp_v2/classes.rb', line 3006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profile_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig

Configuration for setting up a job to scan resources for profile generation. Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property dataProfileJob



2979
2980
2981
# File 'lib/google/apis/dlp_v2/classes.rb', line 2979

def data_profile_job
  @data_profile_job
end

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



2988
2989
2990
# File 'lib/google/apis/dlp_v2/classes.rb', line 2988

def discovery_config
  @discovery_config
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



2994
2995
2996
# File 'lib/google/apis/dlp_v2/classes.rb', line 2994

def inspect_config
  @inspect_config
end

#inspect_template_modified_timeString

Timestamp when the template was modified Corresponds to the JSON property inspectTemplateModifiedTime

Returns:

  • (String)


2999
3000
3001
# File 'lib/google/apis/dlp_v2/classes.rb', line 2999

def inspect_template_modified_time
  @inspect_template_modified_time
end

#inspect_template_nameString

Name of the inspection template used to generate this profile Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


3004
3005
3006
# File 'lib/google/apis/dlp_v2/classes.rb', line 3004

def inspect_template_name
  @inspect_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3011
3012
3013
3014
3015
3016
3017
# File 'lib/google/apis/dlp_v2/classes.rb', line 3011

def update!(**args)
  @data_profile_job = args[:data_profile_job] if args.key?(:data_profile_job)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_modified_time = args[:inspect_template_modified_time] if args.key?(:inspect_template_modified_time)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
end