Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Snapshot of the configurations used to generate the profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileConfigSnapshot

Returns a new instance of GooglePrivacyDlpV2DataProfileConfigSnapshot.



3004
3005
3006
# File 'lib/google/apis/dlp_v2/classes.rb', line 3004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profile_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig

Configuration for setting up a job to scan resources for profile generation. Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property dataProfileJob



2977
2978
2979
# File 'lib/google/apis/dlp_v2/classes.rb', line 2977

def data_profile_job
  @data_profile_job
end

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



2986
2987
2988
# File 'lib/google/apis/dlp_v2/classes.rb', line 2986

def discovery_config
  @discovery_config
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



2992
2993
2994
# File 'lib/google/apis/dlp_v2/classes.rb', line 2992

def inspect_config
  @inspect_config
end

#inspect_template_modified_timeString

Timestamp when the template was modified Corresponds to the JSON property inspectTemplateModifiedTime

Returns:

  • (String)


2997
2998
2999
# File 'lib/google/apis/dlp_v2/classes.rb', line 2997

def inspect_template_modified_time
  @inspect_template_modified_time
end

#inspect_template_nameString

Name of the inspection template used to generate this profile Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


3002
3003
3004
# File 'lib/google/apis/dlp_v2/classes.rb', line 3002

def inspect_template_name
  @inspect_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3009
3010
3011
3012
3013
3014
3015
# File 'lib/google/apis/dlp_v2/classes.rb', line 3009

def update!(**args)
  @data_profile_job = args[:data_profile_job] if args.key?(:data_profile_job)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_modified_time = args[:inspect_template_modified_time] if args.key?(:inspect_template_modified_time)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
end