Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Snapshot of the configurations used to generate the profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileConfigSnapshot

Returns a new instance of GooglePrivacyDlpV2DataProfileConfigSnapshot.



2816
2817
2818
# File 'lib/google/apis/dlp_v2/classes.rb', line 2816

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profile_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig

Configuration for setting up a job to scan resources for profile generation. Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property dataProfileJob



2789
2790
2791
# File 'lib/google/apis/dlp_v2/classes.rb', line 2789

def data_profile_job
  @data_profile_job
end

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



2798
2799
2800
# File 'lib/google/apis/dlp_v2/classes.rb', line 2798

def discovery_config
  @discovery_config
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



2804
2805
2806
# File 'lib/google/apis/dlp_v2/classes.rb', line 2804

def inspect_config
  @inspect_config
end

#inspect_template_modified_timeString

Timestamp when the template was modified Corresponds to the JSON property inspectTemplateModifiedTime

Returns:

  • (String)


2809
2810
2811
# File 'lib/google/apis/dlp_v2/classes.rb', line 2809

def inspect_template_modified_time
  @inspect_template_modified_time
end

#inspect_template_nameString

Name of the inspection template used to generate this profile Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


2814
2815
2816
# File 'lib/google/apis/dlp_v2/classes.rb', line 2814

def inspect_template_name
  @inspect_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2821
2822
2823
2824
2825
2826
2827
# File 'lib/google/apis/dlp_v2/classes.rb', line 2821

def update!(**args)
  @data_profile_job = args[:data_profile_job] if args.key?(:data_profile_job)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_modified_time = args[:inspect_template_modified_time] if args.key?(:inspect_template_modified_time)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
end