Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Snapshot of the configurations used to generate the profile.
Instance Attribute Summary collapse
-
#data_profile_job ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
Configuration for setting up a job to scan resources for profile generation.
-
#discovery_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
Configuration for discovery to scan resources for profile generation.
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#inspect_template_modified_time ⇒ String
Timestamp when the template was modified Corresponds to the JSON property
inspectTemplateModifiedTime. -
#inspect_template_name ⇒ String
Name of the inspection template used to generate this profile Corresponds to the JSON property
inspectTemplateName.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileConfigSnapshot
constructor
A new instance of GooglePrivacyDlpV2DataProfileConfigSnapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileConfigSnapshot
Returns a new instance of GooglePrivacyDlpV2DataProfileConfigSnapshot.
2552 2553 2554 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2552 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_job ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
Configuration for setting up a job to scan resources for profile generation.
Only one data profile configuration may exist per organization, folder, or
project. The generated data profiles are retained according to the data
retention policy.
Corresponds to the JSON property dataProfileJob
2525 2526 2527 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2525 def data_profile_job @data_profile_job end |
#discovery_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
Configuration for discovery to scan resources for profile generation. Only one
discovery configuration may exist per organization, folder, or project. The
generated data profiles are retained according to the data retention policy.
Corresponds to the JSON property discoveryConfig
2534 2535 2536 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2534 def discovery_config @discovery_config end |
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
2540 2541 2542 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2540 def inspect_config @inspect_config end |
#inspect_template_modified_time ⇒ String
Timestamp when the template was modified
Corresponds to the JSON property inspectTemplateModifiedTime
2545 2546 2547 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2545 def inspect_template_modified_time @inspect_template_modified_time end |
#inspect_template_name ⇒ String
Name of the inspection template used to generate this profile
Corresponds to the JSON property inspectTemplateName
2550 2551 2552 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2550 def inspect_template_name @inspect_template_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2557 2558 2559 2560 2561 2562 2563 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2557 def update!(**args) @data_profile_job = args[:data_profile_job] if args.key?(:data_profile_job) @discovery_config = args[:discovery_config] if args.key?(:discovery_config) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @inspect_template_modified_time = args[:inspect_template_modified_time] if args.key?(:inspect_template_modified_time) @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name) end |