Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Details about a piece of potentially sensitive information that was detected when the data resource was profiled.
Instance Attribute Summary collapse
-
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#finding_id ⇒ String
A unique identifier for the finding.
-
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
-
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
-
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
-
#quote ⇒ String
The content that was found.
-
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#timestamp ⇒ String
Timestamp when the finding was detected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
constructor
A new instance of GooglePrivacyDlpV2DataProfileFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
Returns a new instance of GooglePrivacyDlpV2DataProfileFinding.
3078 3079 3080 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
Corresponds to the JSON property dataProfileResourceName
3028 3029 3030 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3028 def data_profile_resource_name @data_profile_resource_name end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
3033 3034 3035 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3033 def data_source_type @data_source_type end |
#finding_id ⇒ String
A unique identifier for the finding.
Corresponds to the JSON property findingId
3038 3039 3040 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3038 def finding_id @finding_id end |
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
Corresponds to the JSON property fullResourceName
3044 3045 3046 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3044 def full_resource_name @full_resource_name end |
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infotype
3049 3050 3051 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3049 def infotype @infotype end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
Corresponds to the JSON property location
3054 3055 3056 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3054 def location @location end |
#quote ⇒ String
The content that was found. Even if the content is not textual, it may be
converted to a textual representation here. If the finding exceeds 4096 bytes
in length, the quote may be omitted.
Corresponds to the JSON property quote
3061 3062 3063 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3061 def quote @quote end |
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
Corresponds to the JSON property quoteInfo
3066 3067 3068 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3066 def quote_info @quote_info end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
3071 3072 3073 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3071 def resource_visibility @resource_visibility end |
#timestamp ⇒ String
Timestamp when the finding was detected.
Corresponds to the JSON property timestamp
3076 3077 3078 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3076 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3083 3084 3085 3086 3087 3088 3089 3090 3091 3092 3093 3094 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3083 def update!(**args) @data_profile_resource_name = args[:data_profile_resource_name] if args.key?(:data_profile_resource_name) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @finding_id = args[:finding_id] if args.key?(:finding_id) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @infotype = args[:infotype] if args.key?(:infotype) @location = args[:location] if args.key?(:location) @quote = args[:quote] if args.key?(:quote) @quote_info = args[:quote_info] if args.key?(:quote_info) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @timestamp = args[:timestamp] if args.key?(:timestamp) end |