Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Details about a piece of potentially sensitive information that was detected when the data resource was profiled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding

Returns a new instance of GooglePrivacyDlpV2DataProfileFinding.



3076
3077
3078
# File 'lib/google/apis/dlp_v2/classes.rb', line 3076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profile_resource_nameString

Resource name of the data profile associated with the finding. Corresponds to the JSON property dataProfileResourceName

Returns:

  • (String)


3026
3027
3028
# File 'lib/google/apis/dlp_v2/classes.rb', line 3026

def data_profile_resource_name
  @data_profile_resource_name
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



3031
3032
3033
# File 'lib/google/apis/dlp_v2/classes.rb', line 3031

def data_source_type
  @data_source_type
end

#finding_idString

A unique identifier for the finding. Corresponds to the JSON property findingId

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/dlp_v2/classes.rb', line 3036

def finding_id
  @finding_id
end

#full_resource_nameString

The full resource name of the resource profiled for this finding. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/dlp_v2/classes.rb', line 3042

def full_resource_name
  @full_resource_name
end

#infotypeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infotype



3047
3048
3049
# File 'lib/google/apis/dlp_v2/classes.rb', line 3047

def infotype
  @infotype
end

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation

Location of a data profile finding within a resource. Corresponds to the JSON property location



3052
3053
3054
# File 'lib/google/apis/dlp_v2/classes.rb', line 3052

def location
  @location
end

#quoteString

The content that was found. Even if the content is not textual, it may be converted to a textual representation here. If the finding exceeds 4096 bytes in length, the quote may be omitted. Corresponds to the JSON property quote

Returns:

  • (String)


3059
3060
3061
# File 'lib/google/apis/dlp_v2/classes.rb', line 3059

def quote
  @quote
end

#quote_infoGoogle::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo

Message for infoType-dependent details parsed from quote. Corresponds to the JSON property quoteInfo



3064
3065
3066
# File 'lib/google/apis/dlp_v2/classes.rb', line 3064

def quote_info
  @quote_info
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


3069
3070
3071
# File 'lib/google/apis/dlp_v2/classes.rb', line 3069

def resource_visibility
  @resource_visibility
end

#timestampString

Timestamp when the finding was detected. Corresponds to the JSON property timestamp

Returns:

  • (String)


3074
3075
3076
# File 'lib/google/apis/dlp_v2/classes.rb', line 3074

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3081
3082
3083
3084
3085
3086
3087
3088
3089
3090
3091
3092
# File 'lib/google/apis/dlp_v2/classes.rb', line 3081

def update!(**args)
  @data_profile_resource_name = args[:data_profile_resource_name] if args.key?(:data_profile_resource_name)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @infotype = args[:infotype] if args.key?(:infotype)
  @location = args[:location] if args.key?(:location)
  @quote = args[:quote] if args.key?(:quote)
  @quote_info = args[:quote_info] if args.key?(:quote_info)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end