Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Details about a piece of potentially sensitive information that was detected when the data resource was profiled.
Instance Attribute Summary collapse
-
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#finding_id ⇒ String
A unique identifier for the finding.
-
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
-
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
-
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
-
#quote ⇒ String
The content that was found.
-
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#timestamp ⇒ String
Timestamp when the finding was detected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
constructor
A new instance of GooglePrivacyDlpV2DataProfileFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
Returns a new instance of GooglePrivacyDlpV2DataProfileFinding.
2938 2939 2940 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
Corresponds to the JSON property dataProfileResourceName
2888 2889 2890 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2888 def data_profile_resource_name @data_profile_resource_name end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
2893 2894 2895 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2893 def data_source_type @data_source_type end |
#finding_id ⇒ String
A unique identifier for the finding.
Corresponds to the JSON property findingId
2898 2899 2900 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2898 def finding_id @finding_id end |
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
Corresponds to the JSON property fullResourceName
2904 2905 2906 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2904 def full_resource_name @full_resource_name end |
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infotype
2909 2910 2911 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2909 def infotype @infotype end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
Corresponds to the JSON property location
2914 2915 2916 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2914 def location @location end |
#quote ⇒ String
The content that was found. Even if the content is not textual, it may be
converted to a textual representation here. If the finding exceeds 4096 bytes
in length, the quote may be omitted.
Corresponds to the JSON property quote
2921 2922 2923 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2921 def quote @quote end |
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
Corresponds to the JSON property quoteInfo
2926 2927 2928 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2926 def quote_info @quote_info end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
2931 2932 2933 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2931 def resource_visibility @resource_visibility end |
#timestamp ⇒ String
Timestamp when the finding was detected.
Corresponds to the JSON property timestamp
2936 2937 2938 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2936 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2943 2944 2945 2946 2947 2948 2949 2950 2951 2952 2953 2954 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2943 def update!(**args) @data_profile_resource_name = args[:data_profile_resource_name] if args.key?(:data_profile_resource_name) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @finding_id = args[:finding_id] if args.key?(:finding_id) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @infotype = args[:infotype] if args.key?(:infotype) @location = args[:location] if args.key?(:location) @quote = args[:quote] if args.key?(:quote) @quote_info = args[:quote_info] if args.key?(:quote_info) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @timestamp = args[:timestamp] if args.key?(:timestamp) end |