Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Details about a piece of potentially sensitive information that was detected when the data resource was profiled.
Instance Attribute Summary collapse
-
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#finding_id ⇒ String
A unique identifier for the finding.
-
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
-
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
-
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
-
#quote ⇒ String
The content that was found.
-
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#timestamp ⇒ String
Timestamp when the finding was detected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
constructor
A new instance of GooglePrivacyDlpV2DataProfileFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding
Returns a new instance of GooglePrivacyDlpV2DataProfileFinding.
2749 2750 2751 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_resource_name ⇒ String
Resource name of the data profile associated with the finding.
Corresponds to the JSON property dataProfileResourceName
2699 2700 2701 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2699 def data_profile_resource_name @data_profile_resource_name end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
2704 2705 2706 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2704 def data_source_type @data_source_type end |
#finding_id ⇒ String
A unique identifier for the finding.
Corresponds to the JSON property findingId
2709 2710 2711 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2709 def finding_id @finding_id end |
#full_resource_name ⇒ String
The full resource name of the resource profiled for this finding.
Corresponds to the JSON property fullResourceName
2715 2716 2717 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2715 def full_resource_name @full_resource_name end |
#infotype ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infotype
2720 2721 2722 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2720 def infotype @infotype end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation
Location of a data profile finding within a resource.
Corresponds to the JSON property location
2725 2726 2727 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2725 def location @location end |
#quote ⇒ String
The content that was found. Even if the content is not textual, it may be
converted to a textual representation here. If the finding exceeds 4096 bytes
in length, the quote may be omitted.
Corresponds to the JSON property quote
2732 2733 2734 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2732 def quote @quote end |
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
Corresponds to the JSON property quoteInfo
2737 2738 2739 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2737 def quote_info @quote_info end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
2742 2743 2744 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2742 def resource_visibility @resource_visibility end |
#timestamp ⇒ String
Timestamp when the finding was detected.
Corresponds to the JSON property timestamp
2747 2748 2749 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2747 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2754 2755 2756 2757 2758 2759 2760 2761 2762 2763 2764 2765 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2754 def update!(**args) @data_profile_resource_name = args[:data_profile_resource_name] if args.key?(:data_profile_resource_name) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @finding_id = args[:finding_id] if args.key?(:finding_id) @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name) @infotype = args[:infotype] if args.key?(:infotype) @location = args[:location] if args.key?(:location) @quote = args[:quote] if args.key?(:quote) @quote_info = args[:quote_info] if args.key?(:quote_info) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @timestamp = args[:timestamp] if args.key?(:timestamp) end |