Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Details about a piece of potentially sensitive information that was detected when the data resource was profiled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFinding

Returns a new instance of GooglePrivacyDlpV2DataProfileFinding.



2624
2625
2626
# File 'lib/google/apis/dlp_v2/classes.rb', line 2624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_profile_resource_nameString

Resource name of the data profile associated with the finding. Corresponds to the JSON property dataProfileResourceName

Returns:

  • (String)


2574
2575
2576
# File 'lib/google/apis/dlp_v2/classes.rb', line 2574

def data_profile_resource_name
  @data_profile_resource_name
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



2579
2580
2581
# File 'lib/google/apis/dlp_v2/classes.rb', line 2579

def data_source_type
  @data_source_type
end

#finding_idString

A unique identifier for the finding. Corresponds to the JSON property findingId

Returns:

  • (String)


2584
2585
2586
# File 'lib/google/apis/dlp_v2/classes.rb', line 2584

def finding_id
  @finding_id
end

#full_resource_nameString

The full resource name of the resource profiled for this finding. Corresponds to the JSON property fullResourceName

Returns:

  • (String)


2590
2591
2592
# File 'lib/google/apis/dlp_v2/classes.rb', line 2590

def full_resource_name
  @full_resource_name
end

#infotypeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infotype



2595
2596
2597
# File 'lib/google/apis/dlp_v2/classes.rb', line 2595

def infotype
  @infotype
end

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation

Location of a data profile finding within a resource. Corresponds to the JSON property location



2600
2601
2602
# File 'lib/google/apis/dlp_v2/classes.rb', line 2600

def location
  @location
end

#quoteString

The content that was found. Even if the content is not textual, it may be converted to a textual representation here. If the finding exceeds 4096 bytes in length, the quote may be omitted. Corresponds to the JSON property quote

Returns:

  • (String)


2607
2608
2609
# File 'lib/google/apis/dlp_v2/classes.rb', line 2607

def quote
  @quote
end

#quote_infoGoogle::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo

Message for infoType-dependent details parsed from quote. Corresponds to the JSON property quoteInfo



2612
2613
2614
# File 'lib/google/apis/dlp_v2/classes.rb', line 2612

def quote_info
  @quote_info
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


2617
2618
2619
# File 'lib/google/apis/dlp_v2/classes.rb', line 2617

def resource_visibility
  @resource_visibility
end

#timestampString

Timestamp when the finding was detected. Corresponds to the JSON property timestamp

Returns:

  • (String)


2622
2623
2624
# File 'lib/google/apis/dlp_v2/classes.rb', line 2622

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2629
2630
2631
2632
2633
2634
2635
2636
2637
2638
2639
2640
# File 'lib/google/apis/dlp_v2/classes.rb', line 2629

def update!(**args)
  @data_profile_resource_name = args[:data_profile_resource_name] if args.key?(:data_profile_resource_name)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @full_resource_name = args[:full_resource_name] if args.key?(:full_resource_name)
  @infotype = args[:infotype] if args.key?(:infotype)
  @location = args[:location] if args.key?(:location)
  @quote = args[:quote] if args.key?(:quote)
  @quote_info = args[:quote_info] if args.key?(:quote_info)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end