Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Location of a data profile finding within a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingLocation

Returns a new instance of GooglePrivacyDlpV2DataProfileFindingLocation.



2817
2818
2819
# File 'lib/google/apis/dlp_v2/classes.rb', line 2817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_nameString

Name of the container where the finding is located. The top-level name is the source file name or table name. Names of some common storage containers are formatted as follows: * BigQuery tables: project_id`:`dataset_id`.`table_id

  • Cloud Storage files: gs://bucket/path` Corresponds to the JSON propertycontainerName`

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/dlp_v2/classes.rb', line 2810

def container_name
  @container_name
end

#data_profile_finding_record_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation

Location of a finding within a resource that produces a table data profile. Corresponds to the JSON property dataProfileFindingRecordLocation



2815
2816
2817
# File 'lib/google/apis/dlp_v2/classes.rb', line 2815

def data_profile_finding_record_location
  @data_profile_finding_record_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2822
2823
2824
2825
# File 'lib/google/apis/dlp_v2/classes.rb', line 2822

def update!(**args)
  @container_name = args[:container_name] if args.key?(:container_name)
  @data_profile_finding_record_location = args[:data_profile_finding_record_location] if args.key?(:data_profile_finding_record_location)
end