Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Location of a finding within a resource that produces a table data profile.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingRecordLocation
constructor
A new instance of GooglePrivacyDlpV2DataProfileFindingRecordLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingRecordLocation
Returns a new instance of GooglePrivacyDlpV2DataProfileFindingRecordLocation.
2805 2806 2807 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2805 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
2803 2804 2805 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2803 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2810 2811 2812 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2810 def update!(**args) @field = args[:field] if args.key?(:field) end |