Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileFindingRecordLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Location of a finding within a resource that produces a table data profile.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingRecordLocation
constructor
A new instance of GooglePrivacyDlpV2DataProfileFindingRecordLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileFindingRecordLocation
Returns a new instance of GooglePrivacyDlpV2DataProfileFindingRecordLocation.
2680 2681 2682 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
2678 2679 2680 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2678 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2685 2686 2687 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2685 def update!(**args) @field = args[:field] if args.key?(:field) end |