Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for setting up a job to scan resources for profile generation. Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.
Instance Attribute Summary collapse
-
#data_profile_actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of the job.
-
#inspect_templates ⇒ Array<String>
Detection logic for profile generation.
-
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileLocation
The data that will be profiled.
-
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
-
#project_id ⇒ String
The project that will run the scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileJobConfig
constructor
A new instance of GooglePrivacyDlpV2DataProfileJobConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileJobConfig
Returns a new instance of GooglePrivacyDlpV2DataProfileJobConfig.
3048 3049 3050 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of the job.
Corresponds to the JSON property dataProfileActions
3015 3016 3017 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3015 def data_profile_actions @data_profile_actions end |
#inspect_templates ⇒ Array<String>
Detection logic for profile generation. Not all template features are used by
profiles. FindingLimits, include_quote and exclude_info_types have no impact
on data profiling. Multiple templates may be provided if there is data in
multiple regions. At most one template must be specified per-region (including
"global"). Each region is scanned using the applicable template. If no region-
specific template is specified, but a "global" template is specified, it will
be copied to that region and used instead. If no global or region-specific
template is provided for a region with data, that region's data will not be
scanned. For more information, see https://cloud.google.com/sensitive-data-
protection/docs/data-profiles#data-residency.
Corresponds to the JSON property inspectTemplates
3029 3030 3031 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3029 def inspect_templates @inspect_templates end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileLocation
The data that will be profiled.
Corresponds to the JSON property location
3034 3035 3036 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3034 def location @location end |
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
Corresponds to the JSON property otherCloudStartingLocation
3039 3040 3041 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3039 def other_cloud_starting_location @other_cloud_starting_location end |
#project_id ⇒ String
The project that will run the scan. The DLP service account that exists within
this project must have access to all resources that are profiled, and the DLP
API must be enabled.
Corresponds to the JSON property projectId
3046 3047 3048 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3046 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3053 3054 3055 3056 3057 3058 3059 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3053 def update!(**args) @data_profile_actions = args[:data_profile_actions] if args.key?(:data_profile_actions) @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates) @location = args[:location] if args.key?(:location) @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location) @project_id = args[:project_id] if args.key?(:project_id) end |