Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileJobConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for setting up a job to scan resources for profile generation. Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.
Instance Attribute Summary collapse
-
#data_profile_actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of the job.
-
#inspect_templates ⇒ Array<String>
Detection logic for profile generation.
-
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileLocation
The data that will be profiled.
-
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
-
#project_id ⇒ String
The project that will run the scan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileJobConfig
constructor
A new instance of GooglePrivacyDlpV2DataProfileJobConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DataProfileJobConfig
Returns a new instance of GooglePrivacyDlpV2DataProfileJobConfig.
2891 2892 2893 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_profile_actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of the job.
Corresponds to the JSON property dataProfileActions
2858 2859 2860 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2858 def data_profile_actions @data_profile_actions end |
#inspect_templates ⇒ Array<String>
Detection logic for profile generation. Not all template features are used by
profiles. FindingLimits, include_quote and exclude_info_types have no impact
on data profiling. Multiple templates may be provided if there is data in
multiple regions. At most one template must be specified per-region (including
"global"). Each region is scanned using the applicable template. If no region-
specific template is specified, but a "global" template is specified, it will
be copied to that region and used instead. If no global or region-specific
template is provided for a region with data, that region's data will not be
scanned. For more information, see https://cloud.google.com/sensitive-data-
protection/docs/data-profiles#data-residency.
Corresponds to the JSON property inspectTemplates
2872 2873 2874 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2872 def inspect_templates @inspect_templates end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileLocation
The data that will be profiled.
Corresponds to the JSON property location
2877 2878 2879 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2877 def location @location end |
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
Corresponds to the JSON property otherCloudStartingLocation
2882 2883 2884 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2882 def other_cloud_starting_location @other_cloud_starting_location end |
#project_id ⇒ String
The project that will run the scan. The DLP service account that exists within
this project must have access to all resources that are profiled, and the DLP
API must be enabled.
Corresponds to the JSON property projectId
2889 2890 2891 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2889 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2896 2897 2898 2899 2900 2901 2902 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 2896 def update!(**args) @data_profile_actions = args[:data_profile_actions] if args.key?(:data_profile_actions) @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates) @location = args[:location] if args.key?(:location) @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location) @project_id = args[:project_id] if args.key?(:project_id) end |