Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Message used to identify the type of resource being profiled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DataSourceType

Returns a new instance of GooglePrivacyDlpV2DataSourceType.



2856
2857
2858
# File 'lib/google/apis/dlp_v2/classes.rb', line 2856

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_sourceString

A string that identifies the type of resource being profiled. Current values: * google/bigquery/table * google/project * google/sql/table * google/gcs/bucket Corresponds to the JSON property dataSource

Returns:

  • (String)


2854
2855
2856
# File 'lib/google/apis/dlp_v2/classes.rb', line 2854

def data_source
  @data_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2861
2862
2863
# File 'lib/google/apis/dlp_v2/classes.rb', line 2861

def update!(**args)
  @data_source = args[:data_source] if args.key?(:data_source)
end