Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Identifies a single database resource, like a table within a database.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DatabaseResourceReference

Returns a new instance of GooglePrivacyDlpV2DatabaseResourceReference.



3228
3229
3230
# File 'lib/google/apis/dlp_v2/classes.rb', line 3228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#databaseString

Required. Name of a database within the instance. Corresponds to the JSON property database

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/dlp_v2/classes.rb', line 3208

def database
  @database
end

#database_resourceString

Required. Name of a database resource, for example, a table within the database. Corresponds to the JSON property databaseResource

Returns:

  • (String)


3214
3215
3216
# File 'lib/google/apis/dlp_v2/classes.rb', line 3214

def database_resource
  @database_resource
end

#instanceString

Required. The instance where this resource is located. For example: Cloud SQL instance ID. Corresponds to the JSON property instance

Returns:

  • (String)


3220
3221
3222
# File 'lib/google/apis/dlp_v2/classes.rb', line 3220

def instance
  @instance
end

#project_idString

Required. If within a project-level config, then this must match the config's project ID. Corresponds to the JSON property projectId

Returns:

  • (String)


3226
3227
3228
# File 'lib/google/apis/dlp_v2/classes.rb', line 3226

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3233
3234
3235
3236
3237
3238
# File 'lib/google/apis/dlp_v2/classes.rb', line 3233

def update!(**args)
  @database = args[:database] if args.key?(:database)
  @database_resource = args[:database_resource] if args.key?(:database_resource)
  @instance = args[:instance] if args.key?(:instance)
  @project_id = args[:project_id] if args.key?(:project_id)
end