Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DatastoreOptions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DatastoreOptions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Options defining a data set within Google Cloud Datastore.
Instance Attribute Summary collapse
-
#kind ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KindExpression
A representation of a Datastore kind.
-
#partition_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PartitionId
Datastore partition ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DatastoreOptions
constructor
A new instance of GooglePrivacyDlpV2DatastoreOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DatastoreOptions
Returns a new instance of GooglePrivacyDlpV2DatastoreOptions.
3481 3482 3483 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3481 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KindExpression
A representation of a Datastore kind.
Corresponds to the JSON property kind
3472 3473 3474 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3472 def kind @kind end |
#partition_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2PartitionId
Datastore partition ID. A partition ID identifies a grouping of entities. The
grouping is always by project and namespace, however the namespace ID may be
empty. A partition ID contains several dimensions: project ID and namespace ID.
Corresponds to the JSON property partitionId
3479 3480 3481 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3479 def partition_id @partition_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3486 3487 3488 3489 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3486 def update!(**args) @kind = args[:kind] if args.key?(:kind) @partition_id = args[:partition_id] if args.key?(:partition_id) end |