Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DateShiftConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Shifts dates by random number of days, with option to be consistent for the same context. See https://docs.cloud.google.com/sensitive-data-protection/docs/ concepts-date-shifting to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DateShiftConfig

Returns a new instance of GooglePrivacyDlpV2DateShiftConfig.



3526
3527
3528
# File 'lib/google/apis/dlp_v2/classes.rb', line 3526

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contextGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property context



3503
3504
3505
# File 'lib/google/apis/dlp_v2/classes.rb', line 3503

def context
  @context
end

#crypto_keyGoogle::Apis::DlpV2::GooglePrivacyDlpV2CryptoKey

This is a data encryption key (DEK) (as opposed to a key encryption key (KEK) stored by Cloud Key Management Service (Cloud KMS). When using Cloud KMS to wrap or unwrap a DEK, be sure to set an appropriate IAM policy on the KEK to ensure an attacker cannot unwrap the DEK. Corresponds to the JSON property cryptoKey



3511
3512
3513
# File 'lib/google/apis/dlp_v2/classes.rb', line 3511

def crypto_key
  @crypto_key
end

#lower_bound_daysFixnum

Required. For example, -5 means shift date to at most 5 days back in the past. Corresponds to the JSON property lowerBoundDays

Returns:

  • (Fixnum)


3516
3517
3518
# File 'lib/google/apis/dlp_v2/classes.rb', line 3516

def lower_bound_days
  @lower_bound_days
end

#upper_bound_daysFixnum

Required. Range of shift in days. Actual shift will be selected at random within this range (inclusive ends). Negative means shift to earlier in time. Must not be more than 365250 days (1000 years) each direction. For example, 3 means shift date to at most 3 days into the future. Corresponds to the JSON property upperBoundDays

Returns:

  • (Fixnum)


3524
3525
3526
# File 'lib/google/apis/dlp_v2/classes.rb', line 3524

def upper_bound_days
  @upper_bound_days
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3531
3532
3533
3534
3535
3536
# File 'lib/google/apis/dlp_v2/classes.rb', line 3531

def update!(**args)
  @context = args[:context] if args.key?(:context)
  @crypto_key = args[:crypto_key] if args.key?(:crypto_key)
  @lower_bound_days = args[:lower_bound_days] if args.key?(:lower_bound_days)
  @upper_bound_days = args[:upper_bound_days] if args.key?(:upper_bound_days)
end