Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DateShiftConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DateShiftConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Shifts dates by random number of days, with option to be consistent for the same context. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-date-shifting to learn more.
Instance Attribute Summary collapse
-
#context ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
-
#crypto_key ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CryptoKey
This is a data encryption key (DEK) (as opposed to a key encryption key (KEK) stored by Cloud Key Management Service (Cloud KMS). When using Cloud KMS to wrap or unwrap a DEK, be sure to set an appropriate IAM policy on the KEK to ensure an attacker cannot unwrap the DEK. Corresponds to the JSON property
cryptoKey. -
#lower_bound_days ⇒ Fixnum
Required.
-
#upper_bound_days ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DateShiftConfig
constructor
A new instance of GooglePrivacyDlpV2DateShiftConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DateShiftConfig
Returns a new instance of GooglePrivacyDlpV2DateShiftConfig.
3336 3337 3338 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#context ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property context
3313 3314 3315 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3313 def context @context end |
#crypto_key ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CryptoKey
This is a data encryption key (DEK) (as opposed to a key encryption key (KEK)
stored by Cloud Key Management Service (Cloud KMS). When using Cloud KMS to
wrap or unwrap a DEK, be sure to set an appropriate IAM policy on the KEK to
ensure an attacker cannot unwrap the DEK.
Corresponds to the JSON property cryptoKey
3321 3322 3323 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3321 def crypto_key @crypto_key end |
#lower_bound_days ⇒ Fixnum
Required. For example, -5 means shift date to at most 5 days back in the past.
Corresponds to the JSON property lowerBoundDays
3326 3327 3328 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3326 def lower_bound_days @lower_bound_days end |
#upper_bound_days ⇒ Fixnum
Required. Range of shift in days. Actual shift will be selected at random
within this range (inclusive ends). Negative means shift to earlier in time.
Must not be more than 365250 days (1000 years) each direction. For example, 3
means shift date to at most 3 days into the future.
Corresponds to the JSON property upperBoundDays
3334 3335 3336 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3334 def upper_bound_days @upper_bound_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3341 3342 3343 3344 3345 3346 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3341 def update!(**args) @context = args[:context] if args.key?(:context) @crypto_key = args[:crypto_key] if args.key?(:crypto_key) @lower_bound_days = args[:lower_bound_days] if args.key?(:lower_bound_days) @upper_bound_days = args[:upper_bound_days] if args.key?(:upper_bound_days) end |