Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DateTime
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DateTime
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Message for a date time object. e.g. 2018-01-01, 5th August.
Instance Attribute Summary collapse
-
#date ⇒ Google::Apis::DlpV2::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#day_of_week ⇒ String
Day of week Corresponds to the JSON property
dayOfWeek. -
#time ⇒ Google::Apis::DlpV2::GoogleTypeTimeOfDay
Represents a time of day.
-
#time_zone ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TimeZone
Time zone of the date time object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DateTime
constructor
A new instance of GooglePrivacyDlpV2DateTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DateTime
Returns a new instance of GooglePrivacyDlpV2DateTime.
3275 3276 3277 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#date ⇒ Google::Apis::DlpV2::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property date
3256 3257 3258 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3256 def date @date end |
#day_of_week ⇒ String
Day of week
Corresponds to the JSON property dayOfWeek
3261 3262 3263 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3261 def day_of_week @day_of_week end |
#time ⇒ Google::Apis::DlpV2::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
3268 3269 3270 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3268 def time @time end |
#time_zone ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TimeZone
Time zone of the date time object.
Corresponds to the JSON property timeZone
3273 3274 3275 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3273 def time_zone @time_zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3280 3281 3282 3283 3284 3285 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3280 def update!(**args) @date = args[:date] if args.key?(:date) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @time = args[:time] if args.key?(:time) @time_zone = args[:time_zone] if args.key?(:time_zone) end |