Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Deidentify

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Create a de-identified copy of a storage bucket. Only compatible with Cloud Storage buckets. A TransformationDetail will be created for each transformation. Compatible with: Inspection of Cloud Storage

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Deidentify

Returns a new instance of GooglePrivacyDlpV2Deidentify.



3169
3170
3171
# File 'lib/google/apis/dlp_v2/classes.rb', line 3169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_storage_outputString

Required. User settable Cloud Storage bucket and folders to store de- identified files. This field must be set for Cloud Storage deidentification. The output Cloud Storage bucket must be different from the input bucket. De- identified files will overwrite files in the output path. Form of: gs://bucket/ folder/ or gs://bucket Corresponds to the JSON property cloudStorageOutput

Returns:

  • (String)


3144
3145
3146
# File 'lib/google/apis/dlp_v2/classes.rb', line 3144

def cloud_storage_output
  @cloud_storage_output
end

#file_types_to_transformArray<String>

List of user-specified file type groups to transform. If specified, only the files with these file types are transformed. If empty, all supported files are transformed. Supported types may be automatically added over time. Any unsupported file types that are set in this field are excluded from de- identification. An error is recorded for each unsupported file in the TransformationDetails output table. Currently the only file types supported are: IMAGES, TEXT_FILES, CSV, TSV. Corresponds to the JSON property fileTypesToTransform

Returns:

  • (Array<String>)


3155
3156
3157
# File 'lib/google/apis/dlp_v2/classes.rb', line 3155

def file_types_to_transform
  @file_types_to_transform
end

#transformation_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2TransformationConfig

User specified templates and configs for how to deidentify structured, unstructures, and image files. User must provide either a unstructured deidentify template or at least one redact image config. Corresponds to the JSON property transformationConfig



3162
3163
3164
# File 'lib/google/apis/dlp_v2/classes.rb', line 3162

def transformation_config
  @transformation_config
end

#transformation_details_storage_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2TransformationDetailsStorageConfig

Config for storing transformation details. Corresponds to the JSON property transformationDetailsStorageConfig



3167
3168
3169
# File 'lib/google/apis/dlp_v2/classes.rb', line 3167

def transformation_details_storage_config
  @transformation_details_storage_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3174
3175
3176
3177
3178
3179
# File 'lib/google/apis/dlp_v2/classes.rb', line 3174

def update!(**args)
  @cloud_storage_output = args[:cloud_storage_output] if args.key?(:cloud_storage_output)
  @file_types_to_transform = args[:file_types_to_transform] if args.key?(:file_types_to_transform)
  @transformation_config = args[:transformation_config] if args.key?(:transformation_config)
  @transformation_details_storage_config = args[:transformation_details_storage_config] if args.key?(:transformation_details_storage_config)
end