Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The configuration that controls how the data will change.
Instance Attribute Summary collapse
-
#image_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageTransformations
A type of transformation that is applied over images.
-
#info_type_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeTransformations
A type of transformation that will scan unstructured text and apply various
PrimitiveTransformations to each finding, where the transformation is applied to only values that were identified as a specific info_type. -
#record_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformations
A type of transformation that is applied over structured data such as a table.
-
#transformation_error_handling ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationErrorHandling
How to handle transformation errors during de-identification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyConfig
constructor
A new instance of GooglePrivacyDlpV2DeidentifyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyConfig
Returns a new instance of GooglePrivacyDlpV2DeidentifyConfig.
3214 3215 3216 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageTransformations
A type of transformation that is applied over images.
Corresponds to the JSON property imageTransformations
3189 3190 3191 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3189 def image_transformations @image_transformations end |
#info_type_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeTransformations
A type of transformation that will scan unstructured text and apply various
PrimitiveTransformations to each finding, where the transformation is applied
to only values that were identified as a specific info_type.
Corresponds to the JSON property infoTypeTransformations
3196 3197 3198 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3196 def info_type_transformations @info_type_transformations end |
#record_transformations ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformations
A type of transformation that is applied over structured data such as a table.
Corresponds to the JSON property recordTransformations
3201 3202 3203 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3201 def record_transformations @record_transformations end |
#transformation_error_handling ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationErrorHandling
How to handle transformation errors during de-identification. A transformation
error occurs when the requested transformation is incompatible with the data.
For example, trying to de-identify an IP address using a DateShift
transformation would result in a transformation error, since date info cannot
be extracted from an IP address. Information about any incompatible
transformations, and how they were handled, is returned in the response as
part of the TransformationOverviews.
Corresponds to the JSON property transformationErrorHandling
3212 3213 3214 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3212 def transformation_error_handling @transformation_error_handling end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3219 3220 3221 3222 3223 3224 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3219 def update!(**args) @image_transformations = args[:image_transformations] if args.key?(:image_transformations) @info_type_transformations = args[:info_type_transformations] if args.key?(:info_type_transformations) @record_transformations = args[:record_transformations] if args.key?(:record_transformations) @transformation_error_handling = args[:transformation_error_handling] if args.key?(:transformation_error_handling) end |