Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to de-identify a ContentItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyContentRequest

Returns a new instance of GooglePrivacyDlpV2DeidentifyContentRequest.



3268
3269
3270
# File 'lib/google/apis/dlp_v2/classes.rb', line 3268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deidentify_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig

The configuration that controls how the data will change. Corresponds to the JSON property deidentifyConfig



3234
3235
3236
# File 'lib/google/apis/dlp_v2/classes.rb', line 3234

def deidentify_config
  @deidentify_config
end

#deidentify_template_nameString

Template to use. Any configuration directly specified in deidentify_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property deidentifyTemplateName

Returns:

  • (String)


3242
3243
3244
# File 'lib/google/apis/dlp_v2/classes.rb', line 3242

def deidentify_template_name
  @deidentify_template_name
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



3248
3249
3250
# File 'lib/google/apis/dlp_v2/classes.rb', line 3248

def inspect_config
  @inspect_config
end

#inspect_template_nameString

Template to use. Any configuration directly specified in inspect_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


3256
3257
3258
# File 'lib/google/apis/dlp_v2/classes.rb', line 3256

def inspect_template_name
  @inspect_template_name
end

#itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ContentItem

Type of content to inspect. Corresponds to the JSON property item



3261
3262
3263
# File 'lib/google/apis/dlp_v2/classes.rb', line 3261

def item
  @item
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


3266
3267
3268
# File 'lib/google/apis/dlp_v2/classes.rb', line 3266

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3273
3274
3275
3276
3277
3278
3279
3280
# File 'lib/google/apis/dlp_v2/classes.rb', line 3273

def update!(**args)
  @deidentify_config = args[:deidentify_config] if args.key?(:deidentify_config)
  @deidentify_template_name = args[:deidentify_template_name] if args.key?(:deidentify_template_name)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
  @item = args[:item] if args.key?(:item)
  @location_id = args[:location_id] if args.key?(:location_id)
end