Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyDataSourceStats

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Summary of what was modified during a transformation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyDataSourceStats

Returns a new instance of GooglePrivacyDlpV2DeidentifyDataSourceStats.



3477
3478
3479
# File 'lib/google/apis/dlp_v2/classes.rb', line 3477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#transformation_countFixnum

Number of successfully applied transformations. Corresponds to the JSON property transformationCount

Returns:

  • (Fixnum)


3465
3466
3467
# File 'lib/google/apis/dlp_v2/classes.rb', line 3465

def transformation_count
  @transformation_count
end

#transformation_error_countFixnum

Number of errors encountered while trying to apply transformations. Corresponds to the JSON property transformationErrorCount

Returns:

  • (Fixnum)


3470
3471
3472
# File 'lib/google/apis/dlp_v2/classes.rb', line 3470

def transformation_error_count
  @transformation_error_count
end

#transformed_bytesFixnum

Total size in bytes that were transformed in some way. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


3475
3476
3477
# File 'lib/google/apis/dlp_v2/classes.rb', line 3475

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3482
3483
3484
3485
3486
# File 'lib/google/apis/dlp_v2/classes.rb', line 3482

def update!(**args)
  @transformation_count = args[:transformation_count] if args.key?(:transformation_count)
  @transformation_error_count = args[:transformation_error_count] if args.key?(:transformation_error_count)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end