Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
DeidentifyTemplates contains instructions on how to de-identify content. See https://docs.cloud.google.com/sensitive-data-protection/docs/concepts- templates to learn more.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#deidentify_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
The configuration that controls how the data will change.
-
#description ⇒ String
Short description (max 256 chars).
-
#display_name ⇒ String
Display name (max 256 chars).
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyTemplate
constructor
A new instance of GooglePrivacyDlpV2DeidentifyTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyTemplate
Returns a new instance of GooglePrivacyDlpV2DeidentifyTemplate.
3856 3857 3858 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of an inspectTemplate.
Corresponds to the JSON property createTime
3827 3828 3829 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3827 def create_time @create_time end |
#deidentify_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
The configuration that controls how the data will change.
Corresponds to the JSON property deidentifyConfig
3832 3833 3834 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3832 def deidentify_config @deidentify_config end |
#description ⇒ String
Short description (max 256 chars).
Corresponds to the JSON property description
3837 3838 3839 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3837 def description @description end |
#display_name ⇒ String
Display name (max 256 chars).
Corresponds to the JSON property displayName
3842 3843 3844 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3842 def display_name @display_name end |
#name ⇒ String
Output only. The template name. The template will have one of the following
formats: projects/PROJECT_ID/deidentifyTemplates/TEMPLATE_ID OR
organizations/ORGANIZATION_ID/deidentifyTemplates/TEMPLATE_ID
Corresponds to the JSON property name
3849 3850 3851 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3849 def name @name end |
#update_time ⇒ String
Output only. The last update timestamp of an inspectTemplate.
Corresponds to the JSON property updateTime
3854 3855 3856 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3854 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3861 3862 3863 3864 3865 3866 3867 3868 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3861 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @deidentify_config = args[:deidentify_config] if args.key?(:deidentify_config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |