Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

DeidentifyTemplates contains instructions on how to de-identify content. See https://cloud.google.com/sensitive-data-protection/docs/concepts-templates to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyTemplate

Returns a new instance of GooglePrivacyDlpV2DeidentifyTemplate.



3716
3717
3718
# File 'lib/google/apis/dlp_v2/classes.rb', line 3716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of an inspectTemplate. Corresponds to the JSON property createTime

Returns:

  • (String)


3687
3688
3689
# File 'lib/google/apis/dlp_v2/classes.rb', line 3687

def create_time
  @create_time
end

#deidentify_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig

The configuration that controls how the data will change. Corresponds to the JSON property deidentifyConfig



3692
3693
3694
# File 'lib/google/apis/dlp_v2/classes.rb', line 3692

def deidentify_config
  @deidentify_config
end

#descriptionString

Short description (max 256 chars). Corresponds to the JSON property description

Returns:

  • (String)


3697
3698
3699
# File 'lib/google/apis/dlp_v2/classes.rb', line 3697

def description
  @description
end

#display_nameString

Display name (max 256 chars). Corresponds to the JSON property displayName

Returns:

  • (String)


3702
3703
3704
# File 'lib/google/apis/dlp_v2/classes.rb', line 3702

def display_name
  @display_name
end

#nameString

Output only. The template name. The template will have one of the following formats: projects/PROJECT_ID/deidentifyTemplates/TEMPLATE_ID OR organizations/ORGANIZATION_ID/deidentifyTemplates/TEMPLATE_ID Corresponds to the JSON property name

Returns:

  • (String)


3709
3710
3711
# File 'lib/google/apis/dlp_v2/classes.rb', line 3709

def name
  @name
end

#update_timeString

Output only. The last update timestamp of an inspectTemplate. Corresponds to the JSON property updateTime

Returns:

  • (String)


3714
3715
3716
# File 'lib/google/apis/dlp_v2/classes.rb', line 3714

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3721
3722
3723
3724
3725
3726
3727
3728
# File 'lib/google/apis/dlp_v2/classes.rb', line 3721

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deidentify_config = args[:deidentify_config] if args.key?(:deidentify_config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end