Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

DeidentifyTemplates contains instructions on how to de-identify content. See https://cloud.google.com/sensitive-data-protection/docs/concepts-templates to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DeidentifyTemplate

Returns a new instance of GooglePrivacyDlpV2DeidentifyTemplate.



3559
3560
3561
# File 'lib/google/apis/dlp_v2/classes.rb', line 3559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of an inspectTemplate. Corresponds to the JSON property createTime

Returns:

  • (String)


3530
3531
3532
# File 'lib/google/apis/dlp_v2/classes.rb', line 3530

def create_time
  @create_time
end

#deidentify_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig

The configuration that controls how the data will change. Corresponds to the JSON property deidentifyConfig



3535
3536
3537
# File 'lib/google/apis/dlp_v2/classes.rb', line 3535

def deidentify_config
  @deidentify_config
end

#descriptionString

Short description (max 256 chars). Corresponds to the JSON property description

Returns:

  • (String)


3540
3541
3542
# File 'lib/google/apis/dlp_v2/classes.rb', line 3540

def description
  @description
end

#display_nameString

Display name (max 256 chars). Corresponds to the JSON property displayName

Returns:

  • (String)


3545
3546
3547
# File 'lib/google/apis/dlp_v2/classes.rb', line 3545

def display_name
  @display_name
end

#nameString

Output only. The template name. The template will have one of the following formats: projects/PROJECT_ID/deidentifyTemplates/TEMPLATE_ID OR organizations/ORGANIZATION_ID/deidentifyTemplates/TEMPLATE_ID Corresponds to the JSON property name

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/dlp_v2/classes.rb', line 3552

def name
  @name
end

#update_timeString

Output only. The last update timestamp of an inspectTemplate. Corresponds to the JSON property updateTime

Returns:

  • (String)


3557
3558
3559
# File 'lib/google/apis/dlp_v2/classes.rb', line 3557

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3564
3565
3566
3567
3568
3569
3570
3571
# File 'lib/google/apis/dlp_v2/classes.rb', line 3564

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deidentify_config = args[:deidentify_config] if args.key?(:deidentify_config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end