Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, dataset ID, and table ID.
Instance Attribute Summary collapse
-
#other_tables ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherBigQueryTables
Catch-all for all other tables not specified by other filters.
-
#table_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableReference
Message defining the location of a BigQuery table with the projectId inferred from the parent project.
-
#tables ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTableCollection
Specifies a collection of BigQuery tables.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryBigQueryFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryBigQueryFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryBigQueryFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryBigQueryFilter.
3970 3971 3972 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3970 def initialize(**args) update!(**args) end |
Instance Attribute Details
#other_tables ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherBigQueryTables
Catch-all for all other tables not specified by other filters. Should always
be last, except for single-table configurations, which will only have a
TableReference target.
Corresponds to the JSON property otherTables
3957 3958 3959 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3957 def other_tables @other_tables end |
#table_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableReference
Message defining the location of a BigQuery table with the projectId inferred
from the parent project.
Corresponds to the JSON property tableReference
3963 3964 3965 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3963 def table_reference @table_reference end |
#tables ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTableCollection
Specifies a collection of BigQuery tables. Used for Discovery.
Corresponds to the JSON property tables
3968 3969 3970 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3968 def tables @tables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3975 3976 3977 3978 3979 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3975 def update!(**args) @other_tables = args[:other_tables] if args.key?(:other_tables) @table_reference = args[:table_reference] if args.key?(:table_reference) @tables = args[:tables] if args.key?(:tables) end |