Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryBigQueryFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, dataset ID, and table ID.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryBigQueryFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryBigQueryFilter.



3831
3832
3833
# File 'lib/google/apis/dlp_v2/classes.rb', line 3831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#other_tablesGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherBigQueryTables

Catch-all for all other tables not specified by other filters. Should always be last, except for single-table configurations, which will only have a TableReference target. Corresponds to the JSON property otherTables



3818
3819
3820
# File 'lib/google/apis/dlp_v2/classes.rb', line 3818

def other_tables
  @other_tables
end

#table_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2TableReference

Message defining the location of a BigQuery table with the projectId inferred from the parent project. Corresponds to the JSON property tableReference



3824
3825
3826
# File 'lib/google/apis/dlp_v2/classes.rb', line 3824

def table_reference
  @table_reference
end

#tablesGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTableCollection

Specifies a collection of BigQuery tables. Used for Discovery. Corresponds to the JSON property tables



3829
3830
3831
# File 'lib/google/apis/dlp_v2/classes.rb', line 3829

def tables
  @tables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3836
3837
3838
3839
3840
# File 'lib/google/apis/dlp_v2/classes.rb', line 3836

def update!(**args)
  @other_tables = args[:other_tables] if args.key?(:other_tables)
  @table_reference = args[:table_reference] if args.key?(:table_reference)
  @tables = args[:tables] if args.key?(:tables)
end