Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection
Match database resources using regex filters.
-
#database_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference
Identifies a single database resource, like a table within a database.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources
Match database resources not covered by any other filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.
4223 4224 4225 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection
Match database resources using regex filters. Examples of database resources
are tables, views, and stored procedures.
Corresponds to the JSON property collection
4211 4212 4213 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4211 def collection @collection end |
#database_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference
Identifies a single database resource, like a table within a database.
Corresponds to the JSON property databaseResourceReference
4216 4217 4218 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4216 def database_resource_reference @database_resource_reference end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources
Match database resources not covered by any other filter.
Corresponds to the JSON property others
4221 4222 4223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4221 def others @others end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4228 4229 4230 4231 4232 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4228 def update!(**args) @collection = args[:collection] if args.key?(:collection) @database_resource_reference = args[:database_resource_reference] if args.key?(:database_resource_reference) @others = args[:others] if args.key?(:others) end |