Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.



4220
4221
4222
# File 'lib/google/apis/dlp_v2/classes.rb', line 4220

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection

Match database resources using regex filters. Examples of database resources are tables, views, and stored procedures. Corresponds to the JSON property collection



4208
4209
4210
# File 'lib/google/apis/dlp_v2/classes.rb', line 4208

def collection
  @collection
end

#database_resource_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference

Identifies a single database resource, like a table within a database. Corresponds to the JSON property databaseResourceReference



4213
4214
4215
# File 'lib/google/apis/dlp_v2/classes.rb', line 4213

def database_resource_reference
  @database_resource_reference
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources

Match database resources not covered by any other filter. Corresponds to the JSON property others



4218
4219
4220
# File 'lib/google/apis/dlp_v2/classes.rb', line 4218

def others
  @others
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4225
4226
4227
4228
4229
# File 'lib/google/apis/dlp_v2/classes.rb', line 4225

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @database_resource_reference = args[:database_resource_reference] if args.key?(:database_resource_reference)
  @others = args[:others] if args.key?(:others)
end