Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection
Match database resources using regex filters.
-
#database_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference
Identifies a single database resource, like a table within a database.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources
Match database resources not covered by any other filter.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.
4082 4083 4084 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4082 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection
Match database resources using regex filters. Examples of database resources
are tables, views, and stored procedures.
Corresponds to the JSON property collection
4070 4071 4072 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4070 def collection @collection end |
#database_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference
Identifies a single database resource, like a table within a database.
Corresponds to the JSON property databaseResourceReference
4075 4076 4077 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4075 def database_resource_reference @database_resource_reference end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources
Match database resources not covered by any other filter.
Corresponds to the JSON property others
4080 4081 4082 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4080 def others @others end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4087 4088 4089 4090 4091 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4087 def update!(**args) @collection = args[:collection] if args.key?(:collection) @database_resource_reference = args[:database_resource_reference] if args.key?(:database_resource_reference) @others = args[:others] if args.key?(:others) end |