Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines what tables will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID, location, instance, database, and database resource name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlFilter.



3925
3926
3927
# File 'lib/google/apis/dlp_v2/classes.rb', line 3925

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceCollection

Match database resources using regex filters. Examples of database resources are tables, views, and stored procedures. Corresponds to the JSON property collection



3913
3914
3915
# File 'lib/google/apis/dlp_v2/classes.rb', line 3913

def collection
  @collection
end

#database_resource_referenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatabaseResourceReference

Identifies a single database resource, like a table within a database. Corresponds to the JSON property databaseResourceReference



3918
3919
3920
# File 'lib/google/apis/dlp_v2/classes.rb', line 3918

def database_resource_reference
  @database_resource_reference
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherDatabaseResources

Match database resources not covered by any other filter. Corresponds to the JSON property others



3923
3924
3925
# File 'lib/google/apis/dlp_v2/classes.rb', line 3923

def others
  @others
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3930
3931
3932
3933
3934
# File 'lib/google/apis/dlp_v2/classes.rb', line 3930

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @database_resource_reference = args[:database_resource_reference] if args.key?(:database_resource_reference)
  @others = args[:others] if args.key?(:others)
end