Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence.



4255
4256
4257
# File 'lib/google/apis/dlp_v2/classes.rb', line 4255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_template_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change. Corresponds to the JSON property inspectTemplateModifiedCadence



4241
4242
4243
# File 'lib/google/apis/dlp_v2/classes.rb', line 4241

def inspect_template_modified_cadence
  @inspect_template_modified_cadence
end

#refresh_frequencyString

Data changes (non-schema changes) in Cloud SQL tables can't trigger reprofiling. If you set this field, profiles are refreshed at this frequency regardless of whether the underlying tables have changed. Defaults to never. Corresponds to the JSON property refreshFrequency

Returns:

  • (String)


4248
4249
4250
# File 'lib/google/apis/dlp_v2/classes.rb', line 4248

def refresh_frequency
  @refresh_frequency
end

#schema_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2SchemaModifiedCadence

How frequently to modify the profile when the table's schema is modified. Corresponds to the JSON property schemaModifiedCadence



4253
4254
4255
# File 'lib/google/apis/dlp_v2/classes.rb', line 4253

def schema_modified_cadence
  @schema_modified_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4260
4261
4262
4263
4264
# File 'lib/google/apis/dlp_v2/classes.rb', line 4260

def update!(**args)
  @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence)
  @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency)
  @schema_modified_cadence = args[:schema_modified_cadence] if args.key?(:schema_modified_cadence)
end