Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
How often existing tables should have their profiles refreshed. New tables are scanned as quickly as possible depending on system capacity.
Instance Attribute Summary collapse
-
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined by the
InspectTemplatechange. -
#refresh_frequency ⇒ String
Data changes (non-schema changes) in Cloud SQL tables can't trigger reprofiling.
-
#schema_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SchemaModifiedCadence
How frequently to modify the profile when the table's schema is modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
constructor
A new instance of GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence
Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudSqlGenerationCadence.
3803 3804 3805 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined
by the InspectTemplate change.
Corresponds to the JSON property inspectTemplateModifiedCadence
3789 3790 3791 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3789 def inspect_template_modified_cadence @inspect_template_modified_cadence end |
#refresh_frequency ⇒ String
Data changes (non-schema changes) in Cloud SQL tables can't trigger
reprofiling. If you set this field, profiles are refreshed at this frequency
regardless of whether the underlying tables have changed. Defaults to never.
Corresponds to the JSON property refreshFrequency
3796 3797 3798 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3796 def refresh_frequency @refresh_frequency end |
#schema_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SchemaModifiedCadence
How frequently to modify the profile when the table's schema is modified.
Corresponds to the JSON property schemaModifiedCadence
3801 3802 3803 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3801 def schema_modified_cadence @schema_modified_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3808 3809 3810 3811 3812 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3808 def update!(**args) @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence) @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency) @schema_modified_cadence = args[:schema_modified_cadence] if args.key?(:schema_modified_cadence) end |