Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageConditions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Requirements that must be true before a Cloud Storage bucket or object is scanned in discovery for the first time. There is an AND relationship between the top-level attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudStorageConditions

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudStorageConditions.



4287
4288
4289
# File 'lib/google/apis/dlp_v2/classes.rb', line 4287

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#included_bucket_attributesArray<String>

Required. Only objects with the specified attributes will be scanned. Defaults to [ALL_SUPPORTED_BUCKETS] if unset. Corresponds to the JSON property includedBucketAttributes

Returns:

  • (Array<String>)


4277
4278
4279
# File 'lib/google/apis/dlp_v2/classes.rb', line 4277

def included_bucket_attributes
  @included_bucket_attributes
end

#included_object_attributesArray<String>

Required. Only objects with the specified attributes will be scanned. If an object has one of the specified attributes but is inside an excluded bucket, it will not be scanned. Defaults to [ALL_SUPPORTED_OBJECTS]. A profile will be created even if no objects match the included_object_attributes. Corresponds to the JSON property includedObjectAttributes

Returns:

  • (Array<String>)


4285
4286
4287
# File 'lib/google/apis/dlp_v2/classes.rb', line 4285

def included_object_attributes
  @included_object_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4292
4293
4294
4295
# File 'lib/google/apis/dlp_v2/classes.rb', line 4292

def update!(**args)
  @included_bucket_attributes = args[:included_bucket_attributes] if args.key?(:included_bucket_attributes)
  @included_object_attributes = args[:included_object_attributes] if args.key?(:included_object_attributes)
end