Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageConditions
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageConditions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Requirements that must be true before a Cloud Storage bucket or object is scanned in discovery for the first time. There is an AND relationship between the top-level attributes.
Instance Attribute Summary collapse
-
#included_bucket_attributes ⇒ Array<String>
Required.
-
#included_object_attributes ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudStorageConditions
constructor
A new instance of GooglePrivacyDlpV2DiscoveryCloudStorageConditions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudStorageConditions
Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudStorageConditions.
4099 4100 4101 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#included_bucket_attributes ⇒ Array<String>
Required. Only objects with the specified attributes will be scanned. Defaults
to [ALL_SUPPORTED_BUCKETS] if unset.
Corresponds to the JSON property includedBucketAttributes
4089 4090 4091 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4089 def included_bucket_attributes @included_bucket_attributes end |
#included_object_attributes ⇒ Array<String>
Required. Only objects with the specified attributes will be scanned. If an
object has one of the specified attributes but is inside an excluded bucket,
it will not be scanned. Defaults to [ALL_SUPPORTED_OBJECTS]. A profile will be
created even if no objects match the included_object_attributes.
Corresponds to the JSON property includedObjectAttributes
4097 4098 4099 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4097 def included_object_attributes @included_object_attributes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4104 4105 4106 4107 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4104 def update!(**args) @included_bucket_attributes = args[:included_bucket_attributes] if args.key?(:included_bucket_attributes) @included_object_attributes = args[:included_object_attributes] if args.key?(:included_object_attributes) end |