Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageConditions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Requirements that must be true before a Cloud Storage bucket or object is scanned in discovery for the first time. There is an AND relationship between the top-level attributes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudStorageConditions

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudStorageConditions.



3835
3836
3837
# File 'lib/google/apis/dlp_v2/classes.rb', line 3835

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#included_bucket_attributesArray<String>

Required. Only objects with the specified attributes will be scanned. Defaults to [ALL_SUPPORTED_BUCKETS] if unset. Corresponds to the JSON property includedBucketAttributes

Returns:

  • (Array<String>)


3825
3826
3827
# File 'lib/google/apis/dlp_v2/classes.rb', line 3825

def included_bucket_attributes
  @included_bucket_attributes
end

#included_object_attributesArray<String>

Required. Only objects with the specified attributes will be scanned. If an object has one of the specified attributes but is inside an excluded bucket, it will not be scanned. Defaults to [ALL_SUPPORTED_OBJECTS]. A profile will be created even if no objects match the included_object_attributes. Corresponds to the JSON property includedObjectAttributes

Returns:

  • (Array<String>)


3833
3834
3835
# File 'lib/google/apis/dlp_v2/classes.rb', line 3833

def included_object_attributes
  @included_object_attributes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3840
3841
3842
3843
# File 'lib/google/apis/dlp_v2/classes.rb', line 3840

def update!(**args)
  @included_bucket_attributes = args[:included_bucket_attributes] if args.key?(:included_bucket_attributes)
  @included_object_attributes = args[:included_object_attributes] if args.key?(:included_object_attributes)
end