Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How often existing buckets should have their profiles refreshed. New buckets are scanned as quickly as possible depending on system capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryCloudStorageGenerationCadence.



3897
3898
3899
# File 'lib/google/apis/dlp_v2/classes.rb', line 3897

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_template_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change. Corresponds to the JSON property inspectTemplateModifiedCadence



3888
3889
3890
# File 'lib/google/apis/dlp_v2/classes.rb', line 3888

def inspect_template_modified_cadence
  @inspect_template_modified_cadence
end

#refresh_frequencyString

Optional. Data changes in Cloud Storage can't trigger reprofiling. If you set this field, profiles are refreshed at this frequency regardless of whether the underlying buckets have changed. Defaults to never. Corresponds to the JSON property refreshFrequency

Returns:

  • (String)


3895
3896
3897
# File 'lib/google/apis/dlp_v2/classes.rb', line 3895

def refresh_frequency
  @refresh_frequency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3902
3903
3904
3905
# File 'lib/google/apis/dlp_v2/classes.rb', line 3902

def update!(**args)
  @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence)
  @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency)
end