Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig

Returns a new instance of GooglePrivacyDlpV2DiscoveryConfig.



4261
4262
4263
# File 'lib/google/apis/dlp_v2/classes.rb', line 4261

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>

Actions to execute at the completion of scanning. Corresponds to the JSON property actions



4183
4184
4185
# File 'lib/google/apis/dlp_v2/classes.rb', line 4183

def actions
  @actions
end

#create_timeString

Output only. The creation timestamp of a DiscoveryConfig. Corresponds to the JSON property createTime

Returns:

  • (String)


4188
4189
4190
# File 'lib/google/apis/dlp_v2/classes.rb', line 4188

def create_time
  @create_time
end

#display_nameString

Display name (max 100 chars) Corresponds to the JSON property displayName

Returns:

  • (String)


4193
4194
4195
# File 'lib/google/apis/dlp_v2/classes.rb', line 4193

def display_name
  @display_name
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

Output only. A stream of errors encountered when the config was activated. Repeated errors may result in the config automatically being paused. Output only field. Will return the last 100 errors. Whenever the config is modified this list will be cleared. Corresponds to the JSON property errors



4201
4202
4203
# File 'lib/google/apis/dlp_v2/classes.rb', line 4201

def errors
  @errors
end

#inspect_templatesArray<String>

Detection logic for profile generation. Not all template features are used by Discovery. FindingLimits, include_quote and exclude_info_types have no impact on Discovery. Multiple templates may be provided if there is data in multiple regions. At most one template must be specified per-region (including "global") . Each region is scanned using the applicable template. If no region-specific template is specified, but a "global" template is specified, it will be copied to that region and used instead. If no global or region-specific template is provided for a region with data, that region's data will not be scanned. For more information, see https://cloud.google.com/sensitive-data-protection/docs/ data-profiles#data-residency. Corresponds to the JSON property inspectTemplates

Returns:

  • (Array<String>)


4215
4216
4217
# File 'lib/google/apis/dlp_v2/classes.rb', line 4215

def inspect_templates
  @inspect_templates
end

#last_run_timeString

Output only. The timestamp of the last time this config was executed. Corresponds to the JSON property lastRunTime

Returns:

  • (String)


4220
4221
4222
# File 'lib/google/apis/dlp_v2/classes.rb', line 4220

def last_run_time
  @last_run_time
end

#nameString

Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example projects/dlp-test-project/locations/ global/discoveryConfigs/53234423. Corresponds to the JSON property name

Returns:

  • (String)


4227
4228
4229
# File 'lib/google/apis/dlp_v2/classes.rb', line 4227

def name
  @name
end

#org_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig

Project and scan location information. Only set when the parent is an org. Corresponds to the JSON property orgConfig



4232
4233
4234
# File 'lib/google/apis/dlp_v2/classes.rb', line 4232

def org_config
  @org_config
end

#other_cloud_starting_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation

The other cloud starting location for discovery. Corresponds to the JSON property otherCloudStartingLocation



4237
4238
4239
# File 'lib/google/apis/dlp_v2/classes.rb', line 4237

def other_cloud_starting_location
  @other_cloud_starting_location
end

#processing_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation

Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided. Corresponds to the JSON property processingLocation



4244
4245
4246
# File 'lib/google/apis/dlp_v2/classes.rb', line 4244

def processing_location
  @processing_location
end

#statusString

Required. A status for this configuration. Corresponds to the JSON property status

Returns:

  • (String)


4249
4250
4251
# File 'lib/google/apis/dlp_v2/classes.rb', line 4249

def status
  @status
end

#targetsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>

Target to match against for determining what to scan and how frequently. Corresponds to the JSON property targets



4254
4255
4256
# File 'lib/google/apis/dlp_v2/classes.rb', line 4254

def targets
  @targets
end

#update_timeString

Output only. The last update timestamp of a DiscoveryConfig. Corresponds to the JSON property updateTime

Returns:

  • (String)


4259
4260
4261
# File 'lib/google/apis/dlp_v2/classes.rb', line 4259

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/google/apis/dlp_v2/classes.rb', line 4266

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates)
  @last_run_time = args[:last_run_time] if args.key?(:last_run_time)
  @name = args[:name] if args.key?(:name)
  @org_config = args[:org_config] if args.key?(:org_config)
  @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location)
  @processing_location = args[:processing_location] if args.key?(:processing_location)
  @status = args[:status] if args.key?(:status)
  @targets = args[:targets] if args.key?(:targets)
  @update_time = args[:update_time] if args.key?(:update_time)
end