Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig

Returns a new instance of GooglePrivacyDlpV2DiscoveryConfig.



4154
4155
4156
# File 'lib/google/apis/dlp_v2/classes.rb', line 4154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>

Actions to execute at the completion of scanning. Corresponds to the JSON property actions



4076
4077
4078
# File 'lib/google/apis/dlp_v2/classes.rb', line 4076

def actions
  @actions
end

#create_timeString

Output only. The creation timestamp of a DiscoveryConfig. Corresponds to the JSON property createTime

Returns:

  • (String)


4081
4082
4083
# File 'lib/google/apis/dlp_v2/classes.rb', line 4081

def create_time
  @create_time
end

#display_nameString

Display name (max 100 chars) Corresponds to the JSON property displayName

Returns:

  • (String)


4086
4087
4088
# File 'lib/google/apis/dlp_v2/classes.rb', line 4086

def display_name
  @display_name
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

Output only. A stream of errors encountered when the config was activated. Repeated errors may result in the config automatically being paused. Output only field. Will return the last 100 errors. Whenever the config is modified this list will be cleared. Corresponds to the JSON property errors



4094
4095
4096
# File 'lib/google/apis/dlp_v2/classes.rb', line 4094

def errors
  @errors
end

#inspect_templatesArray<String>

Detection logic for profile generation. Not all template features are used by Discovery. FindingLimits, include_quote and exclude_info_types have no impact on Discovery. Multiple templates may be provided if there is data in multiple regions. At most one template must be specified per-region (including "global") . Each region is scanned using the applicable template. If no region-specific template is specified, but a "global" template is specified, it will be copied to that region and used instead. If no global or region-specific template is provided for a region with data, that region's data will not be scanned. For more information, see https://cloud.google.com/sensitive-data-protection/docs/ data-profiles#data-residency. Corresponds to the JSON property inspectTemplates

Returns:

  • (Array<String>)


4108
4109
4110
# File 'lib/google/apis/dlp_v2/classes.rb', line 4108

def inspect_templates
  @inspect_templates
end

#last_run_timeString

Output only. The timestamp of the last time this config was executed. Corresponds to the JSON property lastRunTime

Returns:

  • (String)


4113
4114
4115
# File 'lib/google/apis/dlp_v2/classes.rb', line 4113

def last_run_time
  @last_run_time
end

#nameString

Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example projects/dlp-test-project/locations/ global/discoveryConfigs/53234423. Corresponds to the JSON property name

Returns:

  • (String)


4120
4121
4122
# File 'lib/google/apis/dlp_v2/classes.rb', line 4120

def name
  @name
end

#org_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig

Project and scan location information. Only set when the parent is an org. Corresponds to the JSON property orgConfig



4125
4126
4127
# File 'lib/google/apis/dlp_v2/classes.rb', line 4125

def org_config
  @org_config
end

#other_cloud_starting_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation

The other cloud starting location for discovery. Corresponds to the JSON property otherCloudStartingLocation



4130
4131
4132
# File 'lib/google/apis/dlp_v2/classes.rb', line 4130

def other_cloud_starting_location
  @other_cloud_starting_location
end

#processing_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation

Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided. Corresponds to the JSON property processingLocation



4137
4138
4139
# File 'lib/google/apis/dlp_v2/classes.rb', line 4137

def processing_location
  @processing_location
end

#statusString

Required. A status for this configuration. Corresponds to the JSON property status

Returns:

  • (String)


4142
4143
4144
# File 'lib/google/apis/dlp_v2/classes.rb', line 4142

def status
  @status
end

#targetsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>

Target to match against for determining what to scan and how frequently. Corresponds to the JSON property targets



4147
4148
4149
# File 'lib/google/apis/dlp_v2/classes.rb', line 4147

def targets
  @targets
end

#update_timeString

Output only. The last update timestamp of a DiscoveryConfig. Corresponds to the JSON property updateTime

Returns:

  • (String)


4152
4153
4154
# File 'lib/google/apis/dlp_v2/classes.rb', line 4152

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4159
4160
4161
4162
4163
4164
4165
4166
4167
4168
4169
4170
4171
4172
4173
# File 'lib/google/apis/dlp_v2/classes.rb', line 4159

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates)
  @last_run_time = args[:last_run_time] if args.key?(:last_run_time)
  @name = args[:name] if args.key?(:name)
  @org_config = args[:org_config] if args.key?(:org_config)
  @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location)
  @processing_location = args[:processing_location] if args.key?(:processing_location)
  @status = args[:status] if args.key?(:status)
  @targets = args[:targets] if args.key?(:targets)
  @update_time = args[:update_time] if args.key?(:update_time)
end