Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of scanning.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display name (max 100 chars) Corresponds to the JSON property
displayName. -
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only.
-
#inspect_templates ⇒ Array<String>
Detection logic for profile generation.
-
#last_run_time ⇒ String
Output only.
-
#name ⇒ String
Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example
projects/dlp-test-project/locations/ global/discoveryConfigs/53234423. -
#org_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig
Project and scan location information.
-
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
-
#processing_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
Configure processing location for discovery and inspection.
-
#status ⇒ String
Required.
-
#targets ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>
Target to match against for determining what to scan and how frequently.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig
constructor
A new instance of GooglePrivacyDlpV2DiscoveryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig
Returns a new instance of GooglePrivacyDlpV2DiscoveryConfig.
4122 4123 4124 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4122 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of scanning.
Corresponds to the JSON property actions
4044 4045 4046 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4044 def actions @actions end |
#create_time ⇒ String
Output only. The creation timestamp of a DiscoveryConfig.
Corresponds to the JSON property createTime
4049 4050 4051 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4049 def create_time @create_time end |
#display_name ⇒ String
Display name (max 100 chars)
Corresponds to the JSON property displayName
4054 4055 4056 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4054 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only. A stream of errors encountered when the config was activated.
Repeated errors may result in the config automatically being paused. Output
only field. Will return the last 100 errors. Whenever the config is modified
this list will be cleared.
Corresponds to the JSON property errors
4062 4063 4064 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4062 def errors @errors end |
#inspect_templates ⇒ Array<String>
Detection logic for profile generation. Not all template features are used by
Discovery. FindingLimits, include_quote and exclude_info_types have no impact
on Discovery. Multiple templates may be provided if there is data in multiple
regions. At most one template must be specified per-region (including "global")
. Each region is scanned using the applicable template. If no region-specific
template is specified, but a "global" template is specified, it will be copied
to that region and used instead. If no global or region-specific template is
provided for a region with data, that region's data will not be scanned. For
more information, see https://cloud.google.com/sensitive-data-protection/docs/
data-profiles#data-residency.
Corresponds to the JSON property inspectTemplates
4076 4077 4078 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4076 def inspect_templates @inspect_templates end |
#last_run_time ⇒ String
Output only. The timestamp of the last time this config was executed.
Corresponds to the JSON property lastRunTime
4081 4082 4083 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4081 def last_run_time @last_run_time end |
#name ⇒ String
Unique resource name for the DiscoveryConfig, assigned by the service when the
DiscoveryConfig is created, for example projects/dlp-test-project/locations/
global/discoveryConfigs/53234423.
Corresponds to the JSON property name
4088 4089 4090 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4088 def name @name end |
#org_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig
Project and scan location information. Only set when the parent is an org.
Corresponds to the JSON property orgConfig
4093 4094 4095 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4093 def org_config @org_config end |
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
Corresponds to the JSON property otherCloudStartingLocation
4098 4099 4100 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4098 def other_cloud_starting_location @other_cloud_starting_location end |
#processing_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
Configure processing location for discovery and inspection. For example, image
OCR is only provided in limited regions but configuring ProcessingLocation
will redirect OCR to a location where OCR is provided.
Corresponds to the JSON property processingLocation
4105 4106 4107 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4105 def processing_location @processing_location end |
#status ⇒ String
Required. A status for this configuration.
Corresponds to the JSON property status
4110 4111 4112 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4110 def status @status end |
#targets ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>
Target to match against for determining what to scan and how frequently.
Corresponds to the JSON property targets
4115 4116 4117 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4115 def targets @targets end |
#update_time ⇒ String
Output only. The last update timestamp of a DiscoveryConfig.
Corresponds to the JSON property updateTime
4120 4121 4122 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4120 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 4137 4138 4139 4140 4141 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4127 def update!(**args) @actions = args[:actions] if args.key?(:actions) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates) @last_run_time = args[:last_run_time] if args.key?(:last_run_time) @name = args[:name] if args.key?(:name) @org_config = args[:org_config] if args.key?(:org_config) @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location) @processing_location = args[:processing_location] if args.key?(:processing_location) @status = args[:status] if args.key?(:status) @targets = args[:targets] if args.key?(:targets) @update_time = args[:update_time] if args.key?(:update_time) end |