Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of scanning.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Display name (max 100 chars) Corresponds to the JSON property
displayName. -
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only.
-
#inspect_templates ⇒ Array<String>
Detection logic for profile generation.
-
#last_run_time ⇒ String
Output only.
-
#name ⇒ String
Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example
projects/dlp-test-project/locations/ global/discoveryConfigs/53234423. -
#org_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig
Project and scan location information.
-
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
-
#processing_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
Configure processing location for discovery and inspection.
-
#status ⇒ String
Required.
-
#targets ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>
Target to match against for determining what to scan and how frequently.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig
constructor
A new instance of GooglePrivacyDlpV2DiscoveryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryConfig
Returns a new instance of GooglePrivacyDlpV2DiscoveryConfig.
3997 3998 3999 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileAction>
Actions to execute at the completion of scanning.
Corresponds to the JSON property actions
3919 3920 3921 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3919 def actions @actions end |
#create_time ⇒ String
Output only. The creation timestamp of a DiscoveryConfig.
Corresponds to the JSON property createTime
3924 3925 3926 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3924 def create_time @create_time end |
#display_name ⇒ String
Display name (max 100 chars)
Corresponds to the JSON property displayName
3929 3930 3931 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3929 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only. A stream of errors encountered when the config was activated.
Repeated errors may result in the config automatically being paused. Output
only field. Will return the last 100 errors. Whenever the config is modified
this list will be cleared.
Corresponds to the JSON property errors
3937 3938 3939 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3937 def errors @errors end |
#inspect_templates ⇒ Array<String>
Detection logic for profile generation. Not all template features are used by
Discovery. FindingLimits, include_quote and exclude_info_types have no impact
on Discovery. Multiple templates may be provided if there is data in multiple
regions. At most one template must be specified per-region (including "global")
. Each region is scanned using the applicable template. If no region-specific
template is specified, but a "global" template is specified, it will be copied
to that region and used instead. If no global or region-specific template is
provided for a region with data, that region's data will not be scanned. For
more information, see https://cloud.google.com/sensitive-data-protection/docs/
data-profiles#data-residency.
Corresponds to the JSON property inspectTemplates
3951 3952 3953 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3951 def inspect_templates @inspect_templates end |
#last_run_time ⇒ String
Output only. The timestamp of the last time this config was executed.
Corresponds to the JSON property lastRunTime
3956 3957 3958 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3956 def last_run_time @last_run_time end |
#name ⇒ String
Unique resource name for the DiscoveryConfig, assigned by the service when the
DiscoveryConfig is created, for example projects/dlp-test-project/locations/
global/discoveryConfigs/53234423.
Corresponds to the JSON property name
3963 3964 3965 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3963 def name @name end |
#org_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig
Project and scan location information. Only set when the parent is an org.
Corresponds to the JSON property orgConfig
3968 3969 3970 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3968 def org_config @org_config end |
#other_cloud_starting_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation
The other cloud starting location for discovery.
Corresponds to the JSON property otherCloudStartingLocation
3973 3974 3975 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3973 def other_cloud_starting_location @other_cloud_starting_location end |
#processing_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
Configure processing location for discovery and inspection. For example, image
OCR is only provided in limited regions but configuring ProcessingLocation
will redirect OCR to a location where OCR is provided.
Corresponds to the JSON property processingLocation
3980 3981 3982 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3980 def processing_location @processing_location end |
#status ⇒ String
Required. A status for this configuration.
Corresponds to the JSON property status
3985 3986 3987 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3985 def status @status end |
#targets ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget>
Target to match against for determining what to scan and how frequently.
Corresponds to the JSON property targets
3990 3991 3992 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3990 def targets @targets end |
#update_time ⇒ String
Output only. The last update timestamp of a DiscoveryConfig.
Corresponds to the JSON property updateTime
3995 3996 3997 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 3995 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4002 4003 4004 4005 4006 4007 4008 4009 4010 4011 4012 4013 4014 4015 4016 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4002 def update!(**args) @actions = args[:actions] if args.key?(:actions) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @inspect_templates = args[:inspect_templates] if args.key?(:inspect_templates) @last_run_time = args[:last_run_time] if args.key?(:last_run_time) @name = args[:name] if args.key?(:name) @org_config = args[:org_config] if args.key?(:org_config) @other_cloud_starting_location = args[:other_cloud_starting_location] if args.key?(:other_cloud_starting_location) @processing_location = args[:processing_location] if args.key?(:processing_location) @status = args[:status] if args.key?(:status) @targets = args[:targets] if args.key?(:targets) @update_time = args[:update_time] if args.key?(:update_time) end |