Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
What must take place for a profile to be updated and how frequently it should occur. New tables are scanned as quickly as possible depending on system capacity.
Instance Attribute Summary collapse
-
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined by the
InspectTemplatechange. -
#refresh_frequency ⇒ String
Frequency at which profiles should be updated, regardless of whether the underlying resource has changed.
-
#schema_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
The cadence at which to update data profiles when a schema is modified.
-
#table_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTableModifiedCadence
The cadence at which to update data profiles when a table is modified.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryGenerationCadence
constructor
A new instance of GooglePrivacyDlpV2DiscoveryGenerationCadence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryGenerationCadence
Returns a new instance of GooglePrivacyDlpV2DiscoveryGenerationCadence.
4535 4536 4537 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined
by the InspectTemplate change.
Corresponds to the JSON property inspectTemplateModifiedCadence
4517 4518 4519 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4517 def inspect_template_modified_cadence @inspect_template_modified_cadence end |
#refresh_frequency ⇒ String
Frequency at which profiles should be updated, regardless of whether the
underlying resource has changed. Defaults to never.
Corresponds to the JSON property refreshFrequency
4523 4524 4525 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4523 def refresh_frequency @refresh_frequency end |
#schema_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
The cadence at which to update data profiles when a schema is modified.
Corresponds to the JSON property schemaModifiedCadence
4528 4529 4530 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4528 def schema_modified_cadence @schema_modified_cadence end |
#table_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTableModifiedCadence
The cadence at which to update data profiles when a table is modified.
Corresponds to the JSON property tableModifiedCadence
4533 4534 4535 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4533 def table_modified_cadence @table_modified_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4540 4541 4542 4543 4544 4545 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4540 def update!(**args) @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence) @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency) @schema_modified_cadence = args[:schema_modified_cadence] if args.key?(:schema_modified_cadence) @table_modified_cadence = args[:table_modified_cadence] if args.key?(:table_modified_cadence) end |