Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryGenerationCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

What must take place for a profile to be updated and how frequently it should occur. New tables are scanned as quickly as possible depending on system capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryGenerationCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryGenerationCadence.



4208
4209
4210
# File 'lib/google/apis/dlp_v2/classes.rb', line 4208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_template_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change. Corresponds to the JSON property inspectTemplateModifiedCadence



4190
4191
4192
# File 'lib/google/apis/dlp_v2/classes.rb', line 4190

def inspect_template_modified_cadence
  @inspect_template_modified_cadence
end

#refresh_frequencyString

Frequency at which profiles should be updated, regardless of whether the underlying resource has changed. Defaults to never. Corresponds to the JSON property refreshFrequency

Returns:

  • (String)


4196
4197
4198
# File 'lib/google/apis/dlp_v2/classes.rb', line 4196

def refresh_frequency
  @refresh_frequency
end

#schema_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence

The cadence at which to update data profiles when a schema is modified. Corresponds to the JSON property schemaModifiedCadence



4201
4202
4203
# File 'lib/google/apis/dlp_v2/classes.rb', line 4201

def schema_modified_cadence
  @schema_modified_cadence
end

#table_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTableModifiedCadence

The cadence at which to update data profiles when a table is modified. Corresponds to the JSON property tableModifiedCadence



4206
4207
4208
# File 'lib/google/apis/dlp_v2/classes.rb', line 4206

def table_modified_cadence
  @table_modified_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4213
4214
4215
4216
4217
4218
# File 'lib/google/apis/dlp_v2/classes.rb', line 4213

def update!(**args)
  @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence)
  @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency)
  @schema_modified_cadence = args[:schema_modified_cadence] if args.key?(:schema_modified_cadence)
  @table_modified_cadence = args[:table_modified_cadence] if args.key?(:table_modified_cadence)
end