Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Requirements that must be true before a resource is profiled for the first time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudConditions

Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudConditions.



4290
4291
4292
# File 'lib/google/apis/dlp_v2/classes.rb', line 4290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amazon_s3_bucket_conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2AmazonS3BucketConditions

Amazon S3 bucket conditions. Corresponds to the JSON property amazonS3BucketConditions



4282
4283
4284
# File 'lib/google/apis/dlp_v2/classes.rb', line 4282

def amazon_s3_bucket_conditions
  @amazon_s3_bucket_conditions
end

#min_ageString

Minimum age a resource must be before Cloud DLP can profile it. Value must be 1 hour or greater. Corresponds to the JSON property minAge

Returns:

  • (String)


4288
4289
4290
# File 'lib/google/apis/dlp_v2/classes.rb', line 4288

def min_age
  @min_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4295
4296
4297
4298
# File 'lib/google/apis/dlp_v2/classes.rb', line 4295

def update!(**args)
  @amazon_s3_bucket_conditions = args[:amazon_s3_bucket_conditions] if args.key?(:amazon_s3_bucket_conditions)
  @min_age = args[:min_age] if args.key?(:min_age)
end