Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Determines which resources from the other cloud will have profiles generated. Includes the ability to filter by resource names.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudFilter

Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudFilter.



4321
4322
4323
# File 'lib/google/apis/dlp_v2/classes.rb', line 4321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#collectionGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceCollection

Match resources using regex filters. Corresponds to the JSON property collection



4309
4310
4311
# File 'lib/google/apis/dlp_v2/classes.rb', line 4309

def collection
  @collection
end

#othersGoogle::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources

Match discovery resources not covered by any other filter. Corresponds to the JSON property others



4314
4315
4316
# File 'lib/google/apis/dlp_v2/classes.rb', line 4314

def others
  @others
end

#single_resourceGoogle::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudSingleResourceReference

Identifies a single resource, like a single Amazon S3 bucket. Corresponds to the JSON property singleResource



4319
4320
4321
# File 'lib/google/apis/dlp_v2/classes.rb', line 4319

def single_resource
  @single_resource
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4326
4327
4328
4329
4330
# File 'lib/google/apis/dlp_v2/classes.rb', line 4326

def update!(**args)
  @collection = args[:collection] if args.key?(:collection)
  @others = args[:others] if args.key?(:others)
  @single_resource = args[:single_resource] if args.key?(:single_resource)
end