Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines which resources from the other cloud will have profiles generated. Includes the ability to filter by resource names.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceCollection
Match resources using regex filters.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
-
#single_resource ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudSingleResourceReference
Identifies a single resource, like a single Amazon S3 bucket.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryOtherCloudFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudFilter.
4164 4165 4166 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceCollection
Match resources using regex filters.
Corresponds to the JSON property collection
4152 4153 4154 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4152 def collection @collection end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
Corresponds to the JSON property others
4157 4158 4159 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4157 def others @others end |
#single_resource ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudSingleResourceReference
Identifies a single resource, like a single Amazon S3 bucket.
Corresponds to the JSON property singleResource
4162 4163 4164 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4162 def single_resource @single_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4169 4170 4171 4172 4173 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4169 def update!(**args) @collection = args[:collection] if args.key?(:collection) @others = args[:others] if args.key?(:others) @single_resource = args[:single_resource] if args.key?(:single_resource) end |