Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How often existing resources should have their profiles refreshed. New resources are scanned as quickly as possible depending on system capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence.



4318
4319
4320
# File 'lib/google/apis/dlp_v2/classes.rb', line 4318

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_template_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change. Corresponds to the JSON property inspectTemplateModifiedCadence



4310
4311
4312
# File 'lib/google/apis/dlp_v2/classes.rb', line 4310

def inspect_template_modified_cadence
  @inspect_template_modified_cadence
end

#refresh_frequencyString

Optional. Frequency to update profiles regardless of whether the underlying resource has changes. Defaults to never. Corresponds to the JSON property refreshFrequency

Returns:

  • (String)


4316
4317
4318
# File 'lib/google/apis/dlp_v2/classes.rb', line 4316

def refresh_frequency
  @refresh_frequency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4323
4324
4325
4326
# File 'lib/google/apis/dlp_v2/classes.rb', line 4323

def update!(**args)
  @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence)
  @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency)
end