Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
How often existing resources should have their profiles refreshed. New resources are scanned as quickly as possible depending on system capacity.
Instance Attribute Summary collapse
-
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined by the
InspectTemplatechange. -
#refresh_frequency ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
constructor
A new instance of GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
Returns a new instance of GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence.
4193 4194 4195 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined
by the InspectTemplate change.
Corresponds to the JSON property inspectTemplateModifiedCadence
4185 4186 4187 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4185 def inspect_template_modified_cadence @inspect_template_modified_cadence end |
#refresh_frequency ⇒ String
Optional. Frequency to update profiles regardless of whether the underlying
resource has changes. Defaults to never.
Corresponds to the JSON property refreshFrequency
4191 4192 4193 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4191 def refresh_frequency @refresh_frequency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4198 4199 4200 4201 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4198 def update!(**args) @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence) @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency) end |