Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The cadence at which to update data profiles when a schema is modified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoverySchemaModifiedCadence

Returns a new instance of GooglePrivacyDlpV2DiscoverySchemaModifiedCadence.



4377
4378
4379
# File 'lib/google/apis/dlp_v2/classes.rb', line 4377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#frequencyString

How frequently profiles may be updated when schemas are modified. Defaults to monthly. Corresponds to the JSON property frequency

Returns:

  • (String)


4369
4370
4371
# File 'lib/google/apis/dlp_v2/classes.rb', line 4369

def frequency
  @frequency
end

#typesArray<String>

The type of events to consider when deciding if the table's schema has been modified and should have the profile updated. Defaults to NEW_COLUMNS. Corresponds to the JSON property types

Returns:

  • (Array<String>)


4375
4376
4377
# File 'lib/google/apis/dlp_v2/classes.rb', line 4375

def types
  @types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4382
4383
4384
4385
# File 'lib/google/apis/dlp_v2/classes.rb', line 4382

def update!(**args)
  @frequency = args[:frequency] if args.key?(:frequency)
  @types = args[:types] if args.key?(:types)
end