Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The cadence at which to update data profiles when a schema is modified.
Instance Attribute Summary collapse
-
#frequency ⇒ String
How frequently profiles may be updated when schemas are modified.
-
#types ⇒ Array<String>
The type of events to consider when deciding if the table's schema has been modified and should have the profile updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
constructor
A new instance of GooglePrivacyDlpV2DiscoverySchemaModifiedCadence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoverySchemaModifiedCadence
Returns a new instance of GooglePrivacyDlpV2DiscoverySchemaModifiedCadence.
4345 4346 4347 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frequency ⇒ String
How frequently profiles may be updated when schemas are modified. Defaults to
monthly.
Corresponds to the JSON property frequency
4337 4338 4339 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4337 def frequency @frequency end |
#types ⇒ Array<String>
The type of events to consider when deciding if the table's schema has been
modified and should have the profile updated. Defaults to NEW_COLUMNS.
Corresponds to the JSON property types
4343 4344 4345 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4343 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4350 4351 4352 4353 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4350 def update!(**args) @frequency = args[:frequency] if args.key?(:frequency) @types = args[:types] if args.key?(:types) end |