Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for Discovery.
Instance Attribute Summary collapse
-
#big_query_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
Target used to match against for discovery with BigQuery tables Corresponds to the JSON property
bigQueryTarget. -
#cloud_sql_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
Target used to match against for discovery with Cloud SQL tables.
-
#cloud_storage_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
Target used to match against for discovery with Cloud Storage buckets.
-
#other_cloud_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Target used to match against for discovery of resources from other clouds.
-
#secrets_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
Discovery target for credentials and secrets in cloud resource metadata.
-
#vertex_dataset_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
Target used to match against for discovery with Vertex AI datasets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2DiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2DiscoveryTarget.
4592 4593 4594 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
Target used to match against for discovery with BigQuery tables
Corresponds to the JSON property bigQueryTarget
4555 4556 4557 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4555 def big_query_target @big_query_target end |
#cloud_sql_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
Target used to match against for discovery with Cloud SQL tables.
Corresponds to the JSON property cloudSqlTarget
4560 4561 4562 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4560 def cloud_sql_target @cloud_sql_target end |
#cloud_storage_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
Target used to match against for discovery with Cloud Storage buckets.
Corresponds to the JSON property cloudStorageTarget
4565 4566 4567 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4565 def cloud_storage_target @cloud_storage_target end |
#other_cloud_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Target used to match against for discovery of resources from other clouds. An
AWS connector in Security Command Center (Enterprise is required to use this
feature.
Corresponds to the JSON property otherCloudTarget
4573 4574 4575 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4573 def other_cloud_target @other_cloud_target end |
#secrets_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
Discovery target for credentials and secrets in cloud resource metadata. This
target does not include any filtering or frequency controls. Cloud DLP will
scan cloud resource metadata for secrets daily. No inspect template should be
included in the discovery config for a security benchmarks scan. Instead, the
built-in list of secrets and credentials infoTypes will be used (see https://
cloud.google.com/sensitive-data-protection/docs/infotypes-reference#
credentials_and_secrets). Credentials and secrets discovered will be reported
as vulnerabilities to Security Command Center.
Corresponds to the JSON property secretsTarget
4585 4586 4587 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4585 def secrets_target @secrets_target end |
#vertex_dataset_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
Target used to match against for discovery with Vertex AI datasets.
Corresponds to the JSON property vertexDatasetTarget
4590 4591 4592 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4590 def vertex_dataset_target @vertex_dataset_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4597 4598 4599 4600 4601 4602 4603 4604 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4597 def update!(**args) @big_query_target = args[:big_query_target] if args.key?(:big_query_target) @cloud_sql_target = args[:cloud_sql_target] if args.key?(:cloud_sql_target) @cloud_storage_target = args[:cloud_storage_target] if args.key?(:cloud_storage_target) @other_cloud_target = args[:other_cloud_target] if args.key?(:other_cloud_target) @secrets_target = args[:secrets_target] if args.key?(:secrets_target) @vertex_dataset_target = args[:vertex_dataset_target] if args.key?(:vertex_dataset_target) end |