Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for Discovery.
Instance Attribute Summary collapse
-
#big_query_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
Target used to match against for discovery with BigQuery tables Corresponds to the JSON property
bigQueryTarget. -
#cloud_sql_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
Target used to match against for discovery with Cloud SQL tables.
-
#cloud_storage_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
Target used to match against for discovery with Cloud Storage buckets.
-
#other_cloud_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Target used to match against for discovery of resources from other clouds.
-
#secrets_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
Discovery target for credentials and secrets in cloud resource metadata.
-
#vertex_dataset_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
Target used to match against for discovery with Vertex AI datasets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2DiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2DiscoveryTarget.
4485 4486 4487 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryDiscoveryTarget
Target used to match against for discovery with BigQuery tables
Corresponds to the JSON property bigQueryTarget
4448 4449 4450 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4448 def big_query_target @big_query_target end |
#cloud_sql_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudSqlDiscoveryTarget
Target used to match against for discovery with Cloud SQL tables.
Corresponds to the JSON property cloudSqlTarget
4453 4454 4455 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4453 def cloud_sql_target @cloud_sql_target end |
#cloud_storage_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageDiscoveryTarget
Target used to match against for discovery with Cloud Storage buckets.
Corresponds to the JSON property cloudStorageTarget
4458 4459 4460 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4458 def cloud_storage_target @cloud_storage_target end |
#other_cloud_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Target used to match against for discovery of resources from other clouds. An
AWS connector in Security Command Center (Enterprise is required to use this
feature.
Corresponds to the JSON property otherCloudTarget
4466 4467 4468 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4466 def other_cloud_target @other_cloud_target end |
#secrets_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
Discovery target for credentials and secrets in cloud resource metadata. This
target does not include any filtering or frequency controls. Cloud DLP will
scan cloud resource metadata for secrets daily. No inspect template should be
included in the discovery config for a security benchmarks scan. Instead, the
built-in list of secrets and credentials infoTypes will be used (see https://
cloud.google.com/sensitive-data-protection/docs/infotypes-reference#
credentials_and_secrets). Credentials and secrets discovered will be reported
as vulnerabilities to Security Command Center.
Corresponds to the JSON property secretsTarget
4478 4479 4480 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4478 def secrets_target @secrets_target end |
#vertex_dataset_target ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
Target used to match against for discovery with Vertex AI datasets.
Corresponds to the JSON property vertexDatasetTarget
4483 4484 4485 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4483 def vertex_dataset_target @vertex_dataset_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4490 4491 4492 4493 4494 4495 4496 4497 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4490 def update!(**args) @big_query_target = args[:big_query_target] if args.key?(:big_query_target) @cloud_sql_target = args[:cloud_sql_target] if args.key?(:cloud_sql_target) @cloud_storage_target = args[:cloud_storage_target] if args.key?(:cloud_storage_target) @other_cloud_target = args[:other_cloud_target] if args.key?(:other_cloud_target) @secrets_target = args[:secrets_target] if args.key?(:secrets_target) @vertex_dataset_target = args[:vertex_dataset_target] if args.key?(:vertex_dataset_target) end |