Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetConditions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Requirements that must be true before a dataset is profiled for the first time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetConditions

Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetConditions.



4359
4360
4361
# File 'lib/google/apis/dlp_v2/classes.rb', line 4359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_afterString

Vertex AI dataset must have been created after this date. Used to avoid backfilling. Corresponds to the JSON property createdAfter

Returns:

  • (String)


4351
4352
4353
# File 'lib/google/apis/dlp_v2/classes.rb', line 4351

def created_after
  @created_after
end

#min_ageString

Minimum age a Vertex AI dataset must have. If set, the value must be 1 hour or greater. Corresponds to the JSON property minAge

Returns:

  • (String)


4357
4358
4359
# File 'lib/google/apis/dlp_v2/classes.rb', line 4357

def min_age
  @min_age
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4364
4365
4366
4367
# File 'lib/google/apis/dlp_v2/classes.rb', line 4364

def update!(**args)
  @created_after = args[:created_after] if args.key?(:created_after)
  @min_age = args[:min_age] if args.key?(:min_age)
end