Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what datasets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID or dataset regex.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
-
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
4705 4706 4707 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
Corresponds to the JSON property collection
4693 4694 4695 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4693 def collection @collection end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
Corresponds to the JSON property others
4698 4699 4700 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4698 def others @others end |
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource. Only datasets are supported.
Corresponds to the JSON property vertexDatasetResourceReference
4703 4704 4705 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4703 def vertex_dataset_resource_reference @vertex_dataset_resource_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4710 4711 4712 4713 4714 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4710 def update!(**args) @collection = args[:collection] if args.key?(:collection) @others = args[:others] if args.key?(:others) @vertex_dataset_resource_reference = args[:vertex_dataset_resource_reference] if args.key?(:vertex_dataset_resource_reference) end |