Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what datasets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID or dataset regex.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
-
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
4655 4656 4657 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4655 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
Corresponds to the JSON property collection
4643 4644 4645 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4643 def collection @collection end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
Corresponds to the JSON property others
4648 4649 4650 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4648 def others @others end |
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource. Only datasets are supported.
Corresponds to the JSON property vertexDatasetResourceReference
4653 4654 4655 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4653 def vertex_dataset_resource_reference @vertex_dataset_resource_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4660 4661 4662 4663 4664 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4660 def update!(**args) @collection = args[:collection] if args.key?(:collection) @others = args[:others] if args.key?(:others) @vertex_dataset_resource_reference = args[:vertex_dataset_resource_reference] if args.key?(:vertex_dataset_resource_reference) end |