Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Determines what datasets will have profiles generated within an organization or project. Includes the ability to filter by regular expression patterns on project ID or dataset regex.
Instance Attribute Summary collapse
-
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
-
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
-
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
constructor
A new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetFilter.
4516 4517 4518 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collection ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
Match dataset resources using regex filters.
Corresponds to the JSON property collection
4504 4505 4506 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4504 def collection @collection end |
#others ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2AllOtherResources
Match discovery resources not covered by any other filter.
Corresponds to the JSON property others
4509 4510 4511 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4509 def others @others end |
#vertex_dataset_resource_reference ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetResourceReference
Identifies a single Vertex AI resource. Only datasets are supported.
Corresponds to the JSON property vertexDatasetResourceReference
4514 4515 4516 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4514 def vertex_dataset_resource_reference @vertex_dataset_resource_reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4521 4522 4523 4524 4525 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4521 def update!(**args) @collection = args[:collection] if args.key?(:collection) @others = args[:others] if args.key?(:others) @vertex_dataset_resource_reference = args[:vertex_dataset_resource_reference] if args.key?(:vertex_dataset_resource_reference) end |