Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

How often existing datasets should have their profiles refreshed. New datasets are scanned as quickly as possible depending on system capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence

Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence.



4734
4735
4736
# File 'lib/google/apis/dlp_v2/classes.rb', line 4734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_template_modified_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence

The cadence at which to update data profiles when the inspection rules defined by the InspectTemplate change. Corresponds to the JSON property inspectTemplateModifiedCadence



4726
4727
4728
# File 'lib/google/apis/dlp_v2/classes.rb', line 4726

def inspect_template_modified_cadence
  @inspect_template_modified_cadence
end

#refresh_frequencyString

If you set this field, profiles are refreshed at this frequency regardless of whether the underlying datasets have changed. Defaults to never. Corresponds to the JSON property refreshFrequency

Returns:

  • (String)


4732
4733
4734
# File 'lib/google/apis/dlp_v2/classes.rb', line 4732

def refresh_frequency
  @refresh_frequency
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4739
4740
4741
4742
# File 'lib/google/apis/dlp_v2/classes.rb', line 4739

def update!(**args)
  @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence)
  @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency)
end