Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
How often existing datasets should have their profiles refreshed. New datasets are scanned as quickly as possible depending on system capacity.
Instance Attribute Summary collapse
-
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined by the
InspectTemplatechange. -
#refresh_frequency ⇒ String
If you set this field, profiles are refreshed at this frequency regardless of whether the underlying datasets have changed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
constructor
A new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
Returns a new instance of GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence.
4684 4685 4686 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4684 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_template_modified_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryInspectTemplateModifiedCadence
The cadence at which to update data profiles when the inspection rules defined
by the InspectTemplate change.
Corresponds to the JSON property inspectTemplateModifiedCadence
4676 4677 4678 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4676 def inspect_template_modified_cadence @inspect_template_modified_cadence end |
#refresh_frequency ⇒ String
If you set this field, profiles are refreshed at this frequency regardless of
whether the underlying datasets have changed. Defaults to never.
Corresponds to the JSON property refreshFrequency
4682 4683 4684 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4682 def refresh_frequency @refresh_frequency end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4689 4690 4691 4692 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4689 def update!(**args) @inspect_template_modified_cadence = args[:inspect_template_modified_cadence] if args.key?(:inspect_template_modified_cadence) @refresh_frequency = args[:refresh_frequency] if args.key?(:refresh_frequency) end |