Class: Google::Apis::DlpV2::GooglePrivacyDlpV2DlpJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Combines all of the information about a DLP job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2DlpJob

Returns a new instance of GooglePrivacyDlpV2DlpJob.



4810
4811
4812
# File 'lib/google/apis/dlp_v2/classes.rb', line 4810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_detailsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ActionDetails>

Events that should occur after the job has completed. Corresponds to the JSON property actionDetails



4752
4753
4754
# File 'lib/google/apis/dlp_v2/classes.rb', line 4752

def action_details
  @action_details
end

#create_timeString

Time when the job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4757
4758
4759
# File 'lib/google/apis/dlp_v2/classes.rb', line 4757

def create_time
  @create_time
end

#end_timeString

Time when the job finished. Corresponds to the JSON property endTime

Returns:

  • (String)


4762
4763
4764
# File 'lib/google/apis/dlp_v2/classes.rb', line 4762

def end_time
  @end_time
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

A stream of errors encountered running the job. Corresponds to the JSON property errors



4767
4768
4769
# File 'lib/google/apis/dlp_v2/classes.rb', line 4767

def errors
  @errors
end

#inspect_detailsGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectDataSourceDetails

The results of an inspect DataSource job. Corresponds to the JSON property inspectDetails



4772
4773
4774
# File 'lib/google/apis/dlp_v2/classes.rb', line 4772

def inspect_details
  @inspect_details
end

#job_trigger_nameString

If created by a job trigger, the resource name of the trigger that instantiated the job. Corresponds to the JSON property jobTriggerName

Returns:

  • (String)


4778
4779
4780
# File 'lib/google/apis/dlp_v2/classes.rb', line 4778

def job_trigger_name
  @job_trigger_name
end

#last_modifiedString

Time when the job was last modified by the system. Corresponds to the JSON property lastModified

Returns:

  • (String)


4783
4784
4785
# File 'lib/google/apis/dlp_v2/classes.rb', line 4783

def last_modified
  @last_modified
end

#nameString

The server-assigned name. Corresponds to the JSON property name

Returns:

  • (String)


4788
4789
4790
# File 'lib/google/apis/dlp_v2/classes.rb', line 4788

def name
  @name
end

#risk_detailsGoogle::Apis::DlpV2::GooglePrivacyDlpV2AnalyzeDataSourceRiskDetails

Result of a risk analysis operation request. Corresponds to the JSON property riskDetails



4793
4794
4795
# File 'lib/google/apis/dlp_v2/classes.rb', line 4793

def risk_details
  @risk_details
end

#start_timeString

Time when the job started. Corresponds to the JSON property startTime

Returns:

  • (String)


4798
4799
4800
# File 'lib/google/apis/dlp_v2/classes.rb', line 4798

def start_time
  @start_time
end

#stateString

State of a job. Corresponds to the JSON property state

Returns:

  • (String)


4803
4804
4805
# File 'lib/google/apis/dlp_v2/classes.rb', line 4803

def state
  @state
end

#typeString

The type of job. Corresponds to the JSON property type

Returns:

  • (String)


4808
4809
4810
# File 'lib/google/apis/dlp_v2/classes.rb', line 4808

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4815
4816
4817
4818
4819
4820
4821
4822
4823
4824
4825
4826
4827
4828
# File 'lib/google/apis/dlp_v2/classes.rb', line 4815

def update!(**args)
  @action_details = args[:action_details] if args.key?(:action_details)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_details = args[:inspect_details] if args.key?(:inspect_details)
  @job_trigger_name = args[:job_trigger_name] if args.key?(:job_trigger_name)
  @last_modified = args[:last_modified] if args.key?(:last_modified)
  @name = args[:name] if args.key?(:name)
  @risk_details = args[:risk_details] if args.key?(:risk_details)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end