Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Domain

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A domain represents a thematic category that a data profile can fall under.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Domain

Returns a new instance of GooglePrivacyDlpV2Domain.



4703
4704
4705
# File 'lib/google/apis/dlp_v2/classes.rb', line 4703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

A domain category that this profile is related to. Corresponds to the JSON property category

Returns:

  • (String)


4696
4697
4698
# File 'lib/google/apis/dlp_v2/classes.rb', line 4696

def category
  @category
end

#signalsArray<String>

The collection of signals that influenced selection of the category. Corresponds to the JSON property signals

Returns:

  • (Array<String>)


4701
4702
4703
# File 'lib/google/apis/dlp_v2/classes.rb', line 4701

def signals
  @signals
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4708
4709
4710
4711
# File 'lib/google/apis/dlp_v2/classes.rb', line 4708

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @signals = args[:signals] if args.key?(:signals)
end