Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Domain
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Domain
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A domain represents a thematic category that a data profile can fall under.
Instance Attribute Summary collapse
-
#category ⇒ String
A domain category that this profile is related to.
-
#signals ⇒ Array<String>
The collection of signals that influenced selection of the category.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Domain
constructor
A new instance of GooglePrivacyDlpV2Domain.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Domain
Returns a new instance of GooglePrivacyDlpV2Domain.
4578 4579 4580 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4578 def initialize(**args) update!(**args) end |
Instance Attribute Details
#category ⇒ String
A domain category that this profile is related to.
Corresponds to the JSON property category
4571 4572 4573 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4571 def category @category end |
#signals ⇒ Array<String>
The collection of signals that influenced selection of the category.
Corresponds to the JSON property signals
4576 4577 4578 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4576 def signals @signals end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4583 4584 4585 4586 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4583 def update!(**args) @category = args[:category] if args.key?(:category) @signals = args[:signals] if args.key?(:signals) end |