Class: Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
An entity in a dataset is a field or set of fields that correspond to a single
person. For example, in medical records the EntityId might be a patient
identifier, or for financial records it might be an account identifier. This
message is used when generalizations or analysis must take into account that
multiple rows correspond to the same entity.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2EntityId
constructor
A new instance of GooglePrivacyDlpV2EntityId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2EntityId
Returns a new instance of GooglePrivacyDlpV2EntityId.
5070 5071 5072 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
5068 5069 5070 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5068 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5075 5076 5077 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5075 def update!(**args) @field = args[:field] if args.key?(:field) end |