Class: Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
An entity in a dataset is a field or set of fields that correspond to a single
person. For example, in medical records the EntityId might be a patient
identifier, or for financial records it might be an account identifier. This
message is used when generalizations or analysis must take into account that
multiple rows correspond to the same entity.
Instance Attribute Summary collapse
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2EntityId
constructor
A new instance of GooglePrivacyDlpV2EntityId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2EntityId
Returns a new instance of GooglePrivacyDlpV2EntityId.
5067 5068 5069 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
5065 5066 5067 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5065 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5072 5073 5074 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5072 def update!(**args) @field = args[:field] if args.key?(:field) end |