Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Error
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Error
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Details information about an error encountered during job execution or the results of an unsuccessful activation of the JobTrigger.
Instance Attribute Summary collapse
-
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#extra_info ⇒ String
Additional information about the error.
-
#timestamps ⇒ Array<String>
The times the error occurred.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Error
constructor
A new instance of GooglePrivacyDlpV2Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Error
Returns a new instance of GooglePrivacyDlpV2Error.
5106 5107 5108 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5106 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property details
5093 5094 5095 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5093 def details @details end |
#extra_info ⇒ String
Additional information about the error.
Corresponds to the JSON property extraInfo
5098 5099 5100 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5098 def extra_info @extra_info end |
#timestamps ⇒ Array<String>
The times the error occurred. List includes the oldest timestamp and the last
9 timestamps.
Corresponds to the JSON property timestamps
5104 5105 5106 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5104 def @timestamps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5111 5112 5113 5114 5115 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5111 def update!(**args) @details = args[:details] if args.key?(:details) @extra_info = args[:extra_info] if args.key?(:extra_info) @timestamps = args[:timestamps] if args.key?(:timestamps) end |