Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Details information about an error encountered during job execution or the results of an unsuccessful activation of the JobTrigger.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Error

Returns a new instance of GooglePrivacyDlpV2Error.



5103
5104
5105
# File 'lib/google/apis/dlp_v2/classes.rb', line 5103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsGoogle::Apis::DlpV2::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property details



5090
5091
5092
# File 'lib/google/apis/dlp_v2/classes.rb', line 5090

def details
  @details
end

#extra_infoString

Additional information about the error. Corresponds to the JSON property extraInfo

Returns:

  • (String)


5095
5096
5097
# File 'lib/google/apis/dlp_v2/classes.rb', line 5095

def extra_info
  @extra_info
end

#timestampsArray<String>

The times the error occurred. List includes the oldest timestamp and the last 9 timestamps. Corresponds to the JSON property timestamps

Returns:

  • (Array<String>)


5101
5102
5103
# File 'lib/google/apis/dlp_v2/classes.rb', line 5101

def timestamps
  @timestamps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5108
5109
5110
5111
5112
# File 'lib/google/apis/dlp_v2/classes.rb', line 5108

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @extra_info = args[:extra_info] if args.key?(:extra_info)
  @timestamps = args[:timestamps] if args.key?(:timestamps)
end