Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Error

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Details information about an error encountered during job execution or the results of an unsuccessful activation of the JobTrigger.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Error

Returns a new instance of GooglePrivacyDlpV2Error.



4776
4777
4778
# File 'lib/google/apis/dlp_v2/classes.rb', line 4776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsGoogle::Apis::DlpV2::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property details



4763
4764
4765
# File 'lib/google/apis/dlp_v2/classes.rb', line 4763

def details
  @details
end

#extra_infoString

Additional information about the error. Corresponds to the JSON property extraInfo

Returns:

  • (String)


4768
4769
4770
# File 'lib/google/apis/dlp_v2/classes.rb', line 4768

def extra_info
  @extra_info
end

#timestampsArray<String>

The times the error occurred. List includes the oldest timestamp and the last 9 timestamps. Corresponds to the JSON property timestamps

Returns:

  • (Array<String>)


4774
4775
4776
# File 'lib/google/apis/dlp_v2/classes.rb', line 4774

def timestamps
  @timestamps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4781
4782
4783
4784
4785
# File 'lib/google/apis/dlp_v2/classes.rb', line 4781

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @extra_info = args[:extra_info] if args.key?(:extra_info)
  @timestamps = args[:timestamps] if args.key?(:timestamps)
end