Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByImageFindings
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByImageFindings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The rule to exclude image findings based on spatial relationships with other image findings. For example, exclude an image finding if it overlaps with another image finding. This rule is silently ignored if the content being inspected is not an image.
Instance Attribute Summary collapse
-
#image_containment_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType
Specifies the relationship between bounding boxes for image findings.
-
#info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>
A list of image-supported infoTypes—excluding document infoTypes—to be used as context for the exclusion rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ExcludeByImageFindings
constructor
A new instance of GooglePrivacyDlpV2ExcludeByImageFindings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ExcludeByImageFindings
Returns a new instance of GooglePrivacyDlpV2ExcludeByImageFindings.
5172 5173 5174 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#image_containment_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType
Specifies the relationship between bounding boxes for image findings.
Corresponds to the JSON property imageContainmentType
5156 5157 5158 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5156 def image_containment_type @image_containment_type end |
#info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>
A list of image-supported infoTypes—excluding document infoTypes—to be used as context for the exclusion rule. A finding is excluded
if its bounding box has the specified spatial relationship (defined by
image_containment_type) with a finding of an infoType in this list. For
example, if InspectionRuleSet.info_types includes OBJECT_TYPE/PERSON and
this exclusion_rule specifies info_types as OBJECT_TYPE/PERSON/PASSPORT
with image_containment_type set to encloses, then OBJECT_TYPE/PERSON
findings will be excluded if they are fully contained within the bounding box
of an OBJECT_TYPE/PERSON/PASSPORT finding.
Corresponds to the JSON property infoTypes
5170 5171 5172 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5170 def info_types @info_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5177 5178 5179 5180 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5177 def update!(**args) @image_containment_type = args[:image_containment_type] if args.key?(:image_containment_type) @info_types = args[:info_types] if args.key?(:info_types) end |