Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The rule that specifies conditions when findings of infoTypes specified in
InspectionRuleSet are removed from results.
Instance Attribute Summary collapse
-
#dictionary ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Dictionary
Custom information type based on a dictionary of words or phrases.
-
#exclude_by_hotword ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByHotword
The rule to exclude findings based on a hotword.
-
#exclude_by_image_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByImageFindings
The rule to exclude image findings based on spatial relationships with other image findings.
-
#exclude_info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeInfoTypes
List of excluded infoTypes.
-
#matching_type ⇒ String
How the rule is applied, see MatchingType documentation for details.
-
#regex ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Regex
Message defining a custom regular expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ExclusionRule
constructor
A new instance of GooglePrivacyDlpV2ExclusionRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ExclusionRule
Returns a new instance of GooglePrivacyDlpV2ExclusionRule.
4934 4935 4936 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dictionary ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Dictionary
Custom information type based on a dictionary of words or phrases. This can be
used to match sensitive information specific to the data, such as a list of
employee IDs or job titles. Dictionary words are case-insensitive and all
characters other than letters and digits in the unicode Basic Multilingual
Plane will be replaced with whitespace when scanning for
matches, so the dictionary phrase "Sam Johnson" will match all three phrases "
sam johnson", "Sam, Johnson", and "Sam (Johnson)". Additionally, the
characters surrounding any match must be of a different type than the adjacent
characters within the word, so letters must be next to non-letters and digits
next to non-digits. For example, the dictionary word "jen" will match the
first three letters of the text "jen123" but will return no matches for "
jennifer". Dictionary words containing a large number of characters that are
not letters or digits may result in unexpected findings because such
characters are treated as whitespace. The limits page contains details about the size limits
of dictionaries. For dictionaries that do not fit within these constraints,
consider using LargeCustomDictionaryConfig in the StoredInfoType API.
Corresponds to the JSON property dictionary
4902 4903 4904 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4902 def dictionary @dictionary end |
#exclude_by_hotword ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByHotword
The rule to exclude findings based on a hotword. For record inspection of
tables, column names are considered hotwords. An example of this is to exclude
a finding if it belongs to a BigQuery column that matches a specific pattern.
Corresponds to the JSON property excludeByHotword
4909 4910 4911 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4909 def exclude_by_hotword @exclude_by_hotword end |
#exclude_by_image_findings ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByImageFindings
The rule to exclude image findings based on spatial relationships with other
image findings. For example, exclude an image finding if it overlaps with
another image finding. This rule is silently ignored if the content being
inspected is not an image.
Corresponds to the JSON property excludeByImageFindings
4917 4918 4919 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4917 def exclude_by_image_findings @exclude_by_image_findings end |
#exclude_info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ExcludeInfoTypes
List of excluded infoTypes.
Corresponds to the JSON property excludeInfoTypes
4922 4923 4924 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4922 def exclude_info_types @exclude_info_types end |
#matching_type ⇒ String
How the rule is applied, see MatchingType documentation for details.
Corresponds to the JSON property matchingType
4927 4928 4929 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4927 def matching_type @matching_type end |
#regex ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Regex
Message defining a custom regular expression.
Corresponds to the JSON property regex
4932 4933 4934 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4932 def regex @regex end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4939 4940 4941 4942 4943 4944 4945 4946 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4939 def update!(**args) @dictionary = args[:dictionary] if args.key?(:dictionary) @exclude_by_hotword = args[:exclude_by_hotword] if args.key?(:exclude_by_hotword) @exclude_by_image_findings = args[:exclude_by_image_findings] if args.key?(:exclude_by_image_findings) @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types) @matching_type = args[:matching_type] if args.key?(:matching_type) @regex = args[:regex] if args.key?(:regex) end |