Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The rule that specifies conditions when findings of infoTypes specified in InspectionRuleSet are removed from results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ExclusionRule

Returns a new instance of GooglePrivacyDlpV2ExclusionRule.



4751
4752
4753
# File 'lib/google/apis/dlp_v2/classes.rb', line 4751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dictionaryGoogle::Apis::DlpV2::GooglePrivacyDlpV2Dictionary

Custom information type based on a dictionary of words or phrases. This can be used to match sensitive information specific to the data, such as a list of employee IDs or job titles. Dictionary words are case-insensitive and all characters other than letters and digits in the unicode Basic Multilingual Plane will be replaced with whitespace when scanning for matches, so the dictionary phrase "Sam Johnson" will match all three phrases " sam johnson", "Sam, Johnson", and "Sam (Johnson)". Additionally, the characters surrounding any match must be of a different type than the adjacent characters within the word, so letters must be next to non-letters and digits next to non-digits. For example, the dictionary word "jen" will match the first three letters of the text "jen123" but will return no matches for " jennifer". Dictionary words containing a large number of characters that are not letters or digits may result in unexpected findings because such characters are treated as whitespace. The limits page contains details about the size limits of dictionaries. For dictionaries that do not fit within these constraints, consider using LargeCustomDictionaryConfig in the StoredInfoType API. Corresponds to the JSON property dictionary



4727
4728
4729
# File 'lib/google/apis/dlp_v2/classes.rb', line 4727

def dictionary
  @dictionary
end

#exclude_by_hotwordGoogle::Apis::DlpV2::GooglePrivacyDlpV2ExcludeByHotword

The rule to exclude findings based on a hotword. For record inspection of tables, column names are considered hotwords. An example of this is to exclude a finding if it belongs to a BigQuery column that matches a specific pattern. Corresponds to the JSON property excludeByHotword



4734
4735
4736
# File 'lib/google/apis/dlp_v2/classes.rb', line 4734

def exclude_by_hotword
  @exclude_by_hotword
end

#exclude_info_typesGoogle::Apis::DlpV2::GooglePrivacyDlpV2ExcludeInfoTypes

List of excluded infoTypes. Corresponds to the JSON property excludeInfoTypes



4739
4740
4741
# File 'lib/google/apis/dlp_v2/classes.rb', line 4739

def exclude_info_types
  @exclude_info_types
end

#matching_typeString

How the rule is applied, see MatchingType documentation for details. Corresponds to the JSON property matchingType

Returns:

  • (String)


4744
4745
4746
# File 'lib/google/apis/dlp_v2/classes.rb', line 4744

def matching_type
  @matching_type
end

#regexGoogle::Apis::DlpV2::GooglePrivacyDlpV2Regex

Message defining a custom regular expression. Corresponds to the JSON property regex



4749
4750
4751
# File 'lib/google/apis/dlp_v2/classes.rb', line 4749

def regex
  @regex
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4756
4757
4758
4759
4760
4761
4762
# File 'lib/google/apis/dlp_v2/classes.rb', line 4756

def update!(**args)
  @dictionary = args[:dictionary] if args.key?(:dictionary)
  @exclude_by_hotword = args[:exclude_by_hotword] if args.key?(:exclude_by_hotword)
  @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types)
  @matching_type = args[:matching_type] if args.key?(:matching_type)
  @regex = args[:regex] if args.key?(:regex)
end