Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Export
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Export
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
If set, the detailed data profiles will be persisted to the location of your choice whenever updated.
Instance Attribute Summary collapse
-
#profile_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Export
constructor
A new instance of GooglePrivacyDlpV2Export.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Export
Returns a new instance of GooglePrivacyDlpV2Export.
4784 4785 4786 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#profile_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property profileTable
4775 4776 4777 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4775 def profile_table @profile_table end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
4782 4783 4784 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4782 def sample_findings_table @sample_findings_table end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4789 4790 4791 4792 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 4789 def update!(**args) @profile_table = args[:profile_table] if args.key?(:profile_table) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) end |