Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The file cluster summary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileClusterSummary

Returns a new instance of GooglePrivacyDlpV2FileClusterSummary.



5450
5451
5452
# File 'lib/google/apis/dlp_v2/classes.rb', line 5450

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



5406
5407
5408
# File 'lib/google/apis/dlp_v2/classes.rb', line 5406

def data_risk_level
  @data_risk_level
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

A list of errors detected while scanning this cluster. The list is truncated to 10 per cluster. Corresponds to the JSON property errors



5412
5413
5414
# File 'lib/google/apis/dlp_v2/classes.rb', line 5412

def errors
  @errors
end

#file_cluster_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2FileClusterType

Message used to identify file cluster type being profiled. Corresponds to the JSON property fileClusterType



5417
5418
5419
# File 'lib/google/apis/dlp_v2/classes.rb', line 5417

def file_cluster_type
  @file_cluster_type
end

#file_extensions_scannedArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types scanned in this cluster. Empty if no files were scanned. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsScanned



5423
5424
5425
# File 'lib/google/apis/dlp_v2/classes.rb', line 5423

def file_extensions_scanned
  @file_extensions_scanned
end

#file_extensions_seenArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types seen in this cluster. Empty if no files were seen. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsSeen



5429
5430
5431
# File 'lib/google/apis/dlp_v2/classes.rb', line 5429

def file_extensions_seen
  @file_extensions_seen
end

#file_store_info_type_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>

InfoTypes detected in this cluster. Corresponds to the JSON property fileStoreInfoTypeSummaries



5434
5435
5436
# File 'lib/google/apis/dlp_v2/classes.rb', line 5434

def file_store_info_type_summaries
  @file_store_info_type_summaries
end

#no_files_existBoolean Also known as: no_files_exist?

True if no files exist in this cluster. If the file store had more files than could be listed, this will be false even if no files for this cluster were seen and file_extensions_seen is empty. Corresponds to the JSON property noFilesExist

Returns:

  • (Boolean)


5441
5442
5443
# File 'lib/google/apis/dlp_v2/classes.rb', line 5441

def no_files_exist
  @no_files_exist
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



5448
5449
5450
# File 'lib/google/apis/dlp_v2/classes.rb', line 5448

def sensitivity_score
  @sensitivity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5455
5456
5457
5458
5459
5460
5461
5462
5463
5464
# File 'lib/google/apis/dlp_v2/classes.rb', line 5455

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @errors = args[:errors] if args.key?(:errors)
  @file_cluster_type = args[:file_cluster_type] if args.key?(:file_cluster_type)
  @file_extensions_scanned = args[:file_extensions_scanned] if args.key?(:file_extensions_scanned)
  @file_extensions_seen = args[:file_extensions_seen] if args.key?(:file_extensions_seen)
  @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries)
  @no_files_exist = args[:no_files_exist] if args.key?(:no_files_exist)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
end