Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The file cluster summary.
Instance Attribute Summary collapse
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
A list of errors detected while scanning this cluster.
-
#file_cluster_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterType
Message used to identify file cluster type being profiled.
-
#file_extensions_scanned ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>
A sample of file types scanned in this cluster.
-
#file_extensions_seen ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>
A sample of file types seen in this cluster.
-
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this cluster.
-
#no_files_exist ⇒ Boolean
(also: #no_files_exist?)
True if no files exist in this cluster.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FileClusterSummary
constructor
A new instance of GooglePrivacyDlpV2FileClusterSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FileClusterSummary
Returns a new instance of GooglePrivacyDlpV2FileClusterSummary.
5258 5259 5260 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
5214 5215 5216 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5214 def data_risk_level @data_risk_level end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
A list of errors detected while scanning this cluster. The list is truncated
to 10 per cluster.
Corresponds to the JSON property errors
5220 5221 5222 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5220 def errors @errors end |
#file_cluster_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterType
Message used to identify file cluster type being profiled.
Corresponds to the JSON property fileClusterType
5225 5226 5227 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5225 def file_cluster_type @file_cluster_type end |
#file_extensions_scanned ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>
A sample of file types scanned in this cluster. Empty if no files were scanned.
File extensions can be derived from the file name or the file content.
Corresponds to the JSON property fileExtensionsScanned
5231 5232 5233 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5231 def file_extensions_scanned @file_extensions_scanned end |
#file_extensions_seen ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>
A sample of file types seen in this cluster. Empty if no files were seen. File
extensions can be derived from the file name or the file content.
Corresponds to the JSON property fileExtensionsSeen
5237 5238 5239 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5237 def file_extensions_seen @file_extensions_seen end |
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this cluster.
Corresponds to the JSON property fileStoreInfoTypeSummaries
5242 5243 5244 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5242 def file_store_info_type_summaries @file_store_info_type_summaries end |
#no_files_exist ⇒ Boolean Also known as: no_files_exist?
True if no files exist in this cluster. If the file store had more files than
could be listed, this will be false even if no files for this cluster were
seen and file_extensions_seen is empty.
Corresponds to the JSON property noFilesExist
5249 5250 5251 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5249 def no_files_exist @no_files_exist end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
5256 5257 5258 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5256 def sensitivity_score @sensitivity_score end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5263 5264 5265 5266 5267 5268 5269 5270 5271 5272 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5263 def update!(**args) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @errors = args[:errors] if args.key?(:errors) @file_cluster_type = args[:file_cluster_type] if args.key?(:file_cluster_type) @file_extensions_scanned = args[:file_extensions_scanned] if args.key?(:file_extensions_scanned) @file_extensions_seen = args[:file_extensions_seen] if args.key?(:file_extensions_seen) @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries) @no_files_exist = args[:no_files_exist] if args.key?(:no_files_exist) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) end |