Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The file cluster summary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileClusterSummary

Returns a new instance of GooglePrivacyDlpV2FileClusterSummary.



5151
5152
5153
# File 'lib/google/apis/dlp_v2/classes.rb', line 5151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



5107
5108
5109
# File 'lib/google/apis/dlp_v2/classes.rb', line 5107

def data_risk_level
  @data_risk_level
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

A list of errors detected while scanning this cluster. The list is truncated to 10 per cluster. Corresponds to the JSON property errors



5113
5114
5115
# File 'lib/google/apis/dlp_v2/classes.rb', line 5113

def errors
  @errors
end

#file_cluster_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2FileClusterType

Message used to identify file cluster type being profiled. Corresponds to the JSON property fileClusterType



5118
5119
5120
# File 'lib/google/apis/dlp_v2/classes.rb', line 5118

def file_cluster_type
  @file_cluster_type
end

#file_extensions_scannedArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types scanned in this cluster. Empty if no files were scanned. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsScanned



5124
5125
5126
# File 'lib/google/apis/dlp_v2/classes.rb', line 5124

def file_extensions_scanned
  @file_extensions_scanned
end

#file_extensions_seenArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types seen in this cluster. Empty if no files were seen. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsSeen



5130
5131
5132
# File 'lib/google/apis/dlp_v2/classes.rb', line 5130

def file_extensions_seen
  @file_extensions_seen
end

#file_store_info_type_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>

InfoTypes detected in this cluster. Corresponds to the JSON property fileStoreInfoTypeSummaries



5135
5136
5137
# File 'lib/google/apis/dlp_v2/classes.rb', line 5135

def file_store_info_type_summaries
  @file_store_info_type_summaries
end

#no_files_existBoolean Also known as: no_files_exist?

True if no files exist in this cluster. If the file store had more files than could be listed, this will be false even if no files for this cluster were seen and file_extensions_seen is empty. Corresponds to the JSON property noFilesExist

Returns:

  • (Boolean)


5142
5143
5144
# File 'lib/google/apis/dlp_v2/classes.rb', line 5142

def no_files_exist
  @no_files_exist
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



5149
5150
5151
# File 'lib/google/apis/dlp_v2/classes.rb', line 5149

def sensitivity_score
  @sensitivity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5156
5157
5158
5159
5160
5161
5162
5163
5164
5165
# File 'lib/google/apis/dlp_v2/classes.rb', line 5156

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @errors = args[:errors] if args.key?(:errors)
  @file_cluster_type = args[:file_cluster_type] if args.key?(:file_cluster_type)
  @file_extensions_scanned = args[:file_extensions_scanned] if args.key?(:file_extensions_scanned)
  @file_extensions_seen = args[:file_extensions_seen] if args.key?(:file_extensions_seen)
  @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries)
  @no_files_exist = args[:no_files_exist] if args.key?(:no_files_exist)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
end