Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The file cluster summary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileClusterSummary

Returns a new instance of GooglePrivacyDlpV2FileClusterSummary.



4935
4936
4937
# File 'lib/google/apis/dlp_v2/classes.rb', line 4935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



4891
4892
4893
# File 'lib/google/apis/dlp_v2/classes.rb', line 4891

def data_risk_level
  @data_risk_level
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

A list of errors detected while scanning this cluster. The list is truncated to 10 per cluster. Corresponds to the JSON property errors



4897
4898
4899
# File 'lib/google/apis/dlp_v2/classes.rb', line 4897

def errors
  @errors
end

#file_cluster_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2FileClusterType

Message used to identify file cluster type being profiled. Corresponds to the JSON property fileClusterType



4902
4903
4904
# File 'lib/google/apis/dlp_v2/classes.rb', line 4902

def file_cluster_type
  @file_cluster_type
end

#file_extensions_scannedArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types scanned in this cluster. Empty if no files were scanned. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsScanned



4908
4909
4910
# File 'lib/google/apis/dlp_v2/classes.rb', line 4908

def file_extensions_scanned
  @file_extensions_scanned
end

#file_extensions_seenArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileExtensionInfo>

A sample of file types seen in this cluster. Empty if no files were seen. File extensions can be derived from the file name or the file content. Corresponds to the JSON property fileExtensionsSeen



4914
4915
4916
# File 'lib/google/apis/dlp_v2/classes.rb', line 4914

def file_extensions_seen
  @file_extensions_seen
end

#file_store_info_type_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>

InfoTypes detected in this cluster. Corresponds to the JSON property fileStoreInfoTypeSummaries



4919
4920
4921
# File 'lib/google/apis/dlp_v2/classes.rb', line 4919

def file_store_info_type_summaries
  @file_store_info_type_summaries
end

#no_files_existBoolean Also known as: no_files_exist?

True if no files exist in this cluster. If the file store had more files than could be listed, this will be false even if no files for this cluster were seen and file_extensions_seen is empty. Corresponds to the JSON property noFilesExist

Returns:

  • (Boolean)


4926
4927
4928
# File 'lib/google/apis/dlp_v2/classes.rb', line 4926

def no_files_exist
  @no_files_exist
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



4933
4934
4935
# File 'lib/google/apis/dlp_v2/classes.rb', line 4933

def sensitivity_score
  @sensitivity_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
# File 'lib/google/apis/dlp_v2/classes.rb', line 4940

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @errors = args[:errors] if args.key?(:errors)
  @file_cluster_type = args[:file_cluster_type] if args.key?(:file_cluster_type)
  @file_extensions_scanned = args[:file_extensions_scanned] if args.key?(:file_extensions_scanned)
  @file_extensions_seen = args[:file_extensions_seen] if args.key?(:file_extensions_seen)
  @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries)
  @no_files_exist = args[:no_files_exist] if args.key?(:no_files_exist)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
end