Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a file store. * Cloud Storage: maps 1:1 with a bucket. * Amazon S3: maps 1:1 with a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile

Returns a new instance of GooglePrivacyDlpV2FileStoreDataProfile.



5793
5794
5795
# File 'lib/google/apis/dlp_v2/classes.rb', line 5793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_snapshotGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Snapshot of the configurations used to generate the profile. Corresponds to the JSON property configSnapshot



5638
5639
5640
# File 'lib/google/apis/dlp_v2/classes.rb', line 5638

def config_snapshot
  @config_snapshot
end

#create_timeString

The time the file store was first created. Corresponds to the JSON property createTime

Returns:

  • (String)


5643
5644
5645
# File 'lib/google/apis/dlp_v2/classes.rb', line 5643

def create_time
  @create_time
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



5649
5650
5651
# File 'lib/google/apis/dlp_v2/classes.rb', line 5649

def data_risk_level
  @data_risk_level
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



5654
5655
5656
# File 'lib/google/apis/dlp_v2/classes.rb', line 5654

def data_source_type
  @data_source_type
end

#data_storage_locationsArray<String>

For resources that have multiple storage locations, these are those regions. For Cloud Storage this is the list of regions chosen for dual-region storage. file_store_location will normally be the corresponding multi-region for the list of individual locations. The first region is always picked as the processing and storage location for the data profile. Corresponds to the JSON property dataStorageLocations

Returns:

  • (Array<String>)


5663
5664
5665
# File 'lib/google/apis/dlp_v2/classes.rb', line 5663

def data_storage_locations
  @data_storage_locations
end

#domainsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>

Domains associated with the profile. Corresponds to the JSON property domains



5668
5669
5670
# File 'lib/google/apis/dlp_v2/classes.rb', line 5668

def domains
  @domains
end

#file_cluster_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>

FileClusterSummary per each cluster. Corresponds to the JSON property fileClusterSummaries



5673
5674
5675
# File 'lib/google/apis/dlp_v2/classes.rb', line 5673

def file_cluster_summaries
  @file_cluster_summaries
end

#file_store_info_type_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>

InfoTypes detected in this file store. Corresponds to the JSON property fileStoreInfoTypeSummaries



5678
5679
5680
# File 'lib/google/apis/dlp_v2/classes.rb', line 5678

def file_store_info_type_summaries
  @file_store_info_type_summaries
end

#file_store_is_emptyBoolean Also known as: file_store_is_empty?

The file store does not have any files. If the profiling operation failed, this is false. Corresponds to the JSON property fileStoreIsEmpty

Returns:

  • (Boolean)


5684
5685
5686
# File 'lib/google/apis/dlp_v2/classes.rb', line 5684

def file_store_is_empty
  @file_store_is_empty
end

#file_store_locationString

The location of the file store. * Cloud Storage: https://docs.cloud.google.com/ storage/docs/locations#available-locations * Amazon S3: https://docs.aws. amazon.com/general/latest/gr/rande.html#regional-endpoints Corresponds to the JSON property fileStoreLocation

Returns:

  • (String)


5692
5693
5694
# File 'lib/google/apis/dlp_v2/classes.rb', line 5692

def file_store_location
  @file_store_location
end

#file_store_pathString

The file store path. * Cloud Storage: gs://bucket* Amazon S3: `s3://` bucket * Vertex AI dataset: projects/project_number/locations/location/ datasets/dataset_id` Corresponds to the JSON propertyfileStorePath`

Returns:

  • (String)


5699
5700
5701
# File 'lib/google/apis/dlp_v2/classes.rb', line 5699

def file_store_path
  @file_store_path
end

#full_resourceString

The resource name of the resource profiled. https://cloud.google.com/apis/ design/resource_names#full_resource_name Example format of an S3 bucket full resource name: //cloudasset.googleapis.com/organizations/org_id/ otherCloudConnections/aws/arn:aws:s3:::bucket_name` Corresponds to the JSON propertyfullResource`

Returns:

  • (String)


5707
5708
5709
# File 'lib/google/apis/dlp_v2/classes.rb', line 5707

def full_resource
  @full_resource
end

#last_modified_timeString

The time the file store was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


5712
5713
5714
# File 'lib/google/apis/dlp_v2/classes.rb', line 5712

def last_modified_time
  @last_modified_time
end

#location_typeString

The location type of the file store (region, dual-region, multi-region, etc). If dual-region, expect data_storage_locations to be populated. Corresponds to the JSON property locationType

Returns:

  • (String)


5718
5719
5720
# File 'lib/google/apis/dlp_v2/classes.rb', line 5718

def location_type
  @location_type
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


5723
5724
5725
# File 'lib/google/apis/dlp_v2/classes.rb', line 5723

def name
  @name
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


5728
5729
5730
# File 'lib/google/apis/dlp_v2/classes.rb', line 5728

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



5733
5734
5735
# File 'lib/google/apis/dlp_v2/classes.rb', line 5733

def profile_status
  @profile_status
end

#project_data_profileString

The resource name of the project data profile for this file store. Corresponds to the JSON property projectDataProfile

Returns:

  • (String)


5738
5739
5740
# File 'lib/google/apis/dlp_v2/classes.rb', line 5738

def project_data_profile
  @project_data_profile
end

#project_idString

The Google Cloud project ID that owns the resource. For Amazon S3 buckets, this is the AWS Account Id. Corresponds to the JSON property projectId

Returns:

  • (String)


5744
5745
5746
# File 'lib/google/apis/dlp_v2/classes.rb', line 5744

def project_id
  @project_id
end

Resources related to this profile. Corresponds to the JSON property relatedResources



5749
5750
5751
# File 'lib/google/apis/dlp_v2/classes.rb', line 5749

def related_resources
  @related_resources
end

#resource_attributesHash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>

Attributes of the resource being profiled. Currently used attributes: * customer_managed_encryption: boolean - true: the resource is encrypted with a customer-managed key. - false: the resource is encrypted with a provider- managed key. Corresponds to the JSON property resourceAttributes



5757
5758
5759
# File 'lib/google/apis/dlp_v2/classes.rb', line 5757

def resource_attributes
  @resource_attributes
end

#resource_labelsHash<String,String>

The labels applied to the resource at the time the profile was generated. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


5762
5763
5764
# File 'lib/google/apis/dlp_v2/classes.rb', line 5762

def resource_labels
  @resource_labels
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


5767
5768
5769
# File 'lib/google/apis/dlp_v2/classes.rb', line 5767

def resource_visibility
  @resource_visibility
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



5774
5775
5776
# File 'lib/google/apis/dlp_v2/classes.rb', line 5774

def sample_findings_table
  @sample_findings_table
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



5780
5781
5782
# File 'lib/google/apis/dlp_v2/classes.rb', line 5780

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. Corresponds to the JSON property state

Returns:

  • (String)


5785
5786
5787
# File 'lib/google/apis/dlp_v2/classes.rb', line 5785

def state
  @state
end

#tagsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>

The tags attached to the resource, including any tags attached during profiling. Corresponds to the JSON property tags



5791
5792
5793
# File 'lib/google/apis/dlp_v2/classes.rb', line 5791

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5798
5799
5800
5801
5802
5803
5804
5805
5806
5807
5808
5809
5810
5811
5812
5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
5825
5826
# File 'lib/google/apis/dlp_v2/classes.rb', line 5798

def update!(**args)
  @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @data_storage_locations = args[:data_storage_locations] if args.key?(:data_storage_locations)
  @domains = args[:domains] if args.key?(:domains)
  @file_cluster_summaries = args[:file_cluster_summaries] if args.key?(:file_cluster_summaries)
  @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries)
  @file_store_is_empty = args[:file_store_is_empty] if args.key?(:file_store_is_empty)
  @file_store_location = args[:file_store_location] if args.key?(:file_store_location)
  @file_store_path = args[:file_store_path] if args.key?(:file_store_path)
  @full_resource = args[:full_resource] if args.key?(:full_resource)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @location_type = args[:location_type] if args.key?(:location_type)
  @name = args[:name] if args.key?(:name)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile)
  @project_id = args[:project_id] if args.key?(:project_id)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @tags = args[:tags] if args.key?(:tags)
end