Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a file store. * Cloud Storage: maps 1:1 with a bucket. * Amazon S3: maps 1:1 with a bucket.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time the file store was first created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#data_storage_locations ⇒ Array<String>
For resources that have multiple storage locations, these are those regions.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#file_cluster_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>
FileClusterSummary per each cluster.
-
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this file store.
-
#file_store_is_empty ⇒ Boolean
(also: #file_store_is_empty?)
The file store does not have any files.
-
#file_store_location ⇒ String
The location of the file store.
-
#file_store_path ⇒ String
The file store path.
-
#full_resource ⇒ String
The resource name of the resource profiled.
-
#last_modified_time ⇒ String
The time the file store was last modified.
-
#location_type ⇒ String
The location type of the file store (region, dual-region, multi-region, etc).
-
#name ⇒ String
The name of the profile.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this file store.
-
#project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_attributes ⇒ Hash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
Attributes of the resource being profiled.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the resource, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile
constructor
A new instance of GooglePrivacyDlpV2FileStoreDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile
Returns a new instance of GooglePrivacyDlpV2FileStoreDataProfile.
5789 5790 5791 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
5634 5635 5636 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5634 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time the file store was first created.
Corresponds to the JSON property createTime
5639 5640 5641 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5639 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
5645 5646 5647 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5645 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
5650 5651 5652 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5650 def data_source_type @data_source_type end |
#data_storage_locations ⇒ Array<String>
For resources that have multiple storage locations, these are those regions.
For Cloud Storage this is the list of regions chosen for dual-region storage.
file_store_location will normally be the corresponding multi-region for the
list of individual locations. The first region is always picked as the
processing and storage location for the data profile.
Corresponds to the JSON property dataStorageLocations
5659 5660 5661 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5659 def data_storage_locations @data_storage_locations end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
5664 5665 5666 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5664 def domains @domains end |
#file_cluster_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>
FileClusterSummary per each cluster.
Corresponds to the JSON property fileClusterSummaries
5669 5670 5671 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5669 def file_cluster_summaries @file_cluster_summaries end |
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this file store.
Corresponds to the JSON property fileStoreInfoTypeSummaries
5674 5675 5676 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5674 def file_store_info_type_summaries @file_store_info_type_summaries end |
#file_store_is_empty ⇒ Boolean Also known as: file_store_is_empty?
The file store does not have any files. If the profiling operation failed,
this is false.
Corresponds to the JSON property fileStoreIsEmpty
5680 5681 5682 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5680 def file_store_is_empty @file_store_is_empty end |
#file_store_location ⇒ String
The location of the file store. * Cloud Storage: https://cloud.google.com/
storage/docs/locations#available-locations * Amazon S3: https://docs.aws.
amazon.com/general/latest/gr/rande.html#regional-endpoints
Corresponds to the JSON property fileStoreLocation
5688 5689 5690 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5688 def file_store_location @file_store_location end |
#file_store_path ⇒ String
The file store path. * Cloud Storage: gs://bucket* Amazon S3: `s3://`
bucket * Vertex AI dataset: projects/project_number/locations/location/
datasets/dataset_id`
Corresponds to the JSON propertyfileStorePath`
5695 5696 5697 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5695 def file_store_path @file_store_path end |
#full_resource ⇒ String
The resource name of the resource profiled. https://cloud.google.com/apis/
design/resource_names#full_resource_name Example format of an S3 bucket full
resource name: //cloudasset.googleapis.com/organizations/org_id/
otherCloudConnections/aws/arn:aws:s3:::bucket_name`
Corresponds to the JSON propertyfullResource`
5703 5704 5705 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5703 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time the file store was last modified.
Corresponds to the JSON property lastModifiedTime
5708 5709 5710 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5708 def last_modified_time @last_modified_time end |
#location_type ⇒ String
The location type of the file store (region, dual-region, multi-region, etc).
If dual-region, expect data_storage_locations to be populated.
Corresponds to the JSON property locationType
5714 5715 5716 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5714 def location_type @location_type end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
5719 5720 5721 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5719 def name @name end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
5724 5725 5726 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5724 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
5729 5730 5731 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5729 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this file store.
Corresponds to the JSON property projectDataProfile
5734 5735 5736 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5734 def project_data_profile @project_data_profile end |
#project_id ⇒ String
The Google Cloud project ID that owns the resource. For Amazon S3 buckets,
this is the AWS Account Id.
Corresponds to the JSON property projectId
5740 5741 5742 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5740 def project_id @project_id end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
5745 5746 5747 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5745 def @related_resources end |
#resource_attributes ⇒ Hash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
Attributes of the resource being profiled. Currently used attributes: *
customer_managed_encryption: boolean - true: the resource is encrypted with a
customer-managed key. - false: the resource is encrypted with a provider-
managed key.
Corresponds to the JSON property resourceAttributes
5753 5754 5755 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5753 def resource_attributes @resource_attributes end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
5758 5759 5760 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5758 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
5763 5764 5765 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5763 def resource_visibility @resource_visibility end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
5770 5771 5772 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5770 def sample_findings_table @sample_findings_table end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
5776 5777 5778 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5776 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile.
Corresponds to the JSON property state
5781 5782 5783 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5781 def state @state end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the resource, including any tags attached during
profiling.
Corresponds to the JSON property tags
5787 5788 5789 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5787 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 5804 5805 5806 5807 5808 5809 5810 5811 5812 5813 5814 5815 5816 5817 5818 5819 5820 5821 5822 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5794 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @data_storage_locations = args[:data_storage_locations] if args.key?(:data_storage_locations) @domains = args[:domains] if args.key?(:domains) @file_cluster_summaries = args[:file_cluster_summaries] if args.key?(:file_cluster_summaries) @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries) @file_store_is_empty = args[:file_store_is_empty] if args.key?(:file_store_is_empty) @file_store_location = args[:file_store_location] if args.key?(:file_store_location) @file_store_path = args[:file_store_path] if args.key?(:file_store_path) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @location_type = args[:location_type] if args.key?(:location_type) @name = args[:name] if args.key?(:name) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @project_id = args[:project_id] if args.key?(:project_id) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) end |