Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a file store. * Cloud Storage: maps 1:1 with a bucket. * Amazon S3: maps 1:1 with a bucket.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time the file store was first created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#data_storage_locations ⇒ Array<String>
For resources that have multiple storage locations, these are those regions.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#file_cluster_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>
FileClusterSummary per each cluster.
-
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this file store.
-
#file_store_is_empty ⇒ Boolean
(also: #file_store_is_empty?)
The file store does not have any files.
-
#file_store_location ⇒ String
The location of the file store.
-
#file_store_path ⇒ String
The file store path.
-
#full_resource ⇒ String
The resource name of the resource profiled.
-
#last_modified_time ⇒ String
The time the file store was last modified.
-
#location_type ⇒ String
The location type of the file store (region, dual-region, multi-region, etc).
-
#name ⇒ String
The name of the profile.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this file store.
-
#project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_attributes ⇒ Hash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
Attributes of the resource being profiled.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the resource, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile
constructor
A new instance of GooglePrivacyDlpV2FileStoreDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile
Returns a new instance of GooglePrivacyDlpV2FileStoreDataProfile.
5444 5445 5446 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
5289 5290 5291 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5289 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time the file store was first created.
Corresponds to the JSON property createTime
5294 5295 5296 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5294 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
5300 5301 5302 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5300 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
5305 5306 5307 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5305 def data_source_type @data_source_type end |
#data_storage_locations ⇒ Array<String>
For resources that have multiple storage locations, these are those regions.
For Cloud Storage this is the list of regions chosen for dual-region storage.
file_store_location will normally be the corresponding multi-region for the
list of individual locations. The first region is always picked as the
processing and storage location for the data profile.
Corresponds to the JSON property dataStorageLocations
5314 5315 5316 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5314 def data_storage_locations @data_storage_locations end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
5319 5320 5321 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5319 def domains @domains end |
#file_cluster_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>
FileClusterSummary per each cluster.
Corresponds to the JSON property fileClusterSummaries
5324 5325 5326 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5324 def file_cluster_summaries @file_cluster_summaries end |
#file_store_info_type_summaries ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>
InfoTypes detected in this file store.
Corresponds to the JSON property fileStoreInfoTypeSummaries
5329 5330 5331 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5329 def file_store_info_type_summaries @file_store_info_type_summaries end |
#file_store_is_empty ⇒ Boolean Also known as: file_store_is_empty?
The file store does not have any files. If the profiling operation failed,
this is false.
Corresponds to the JSON property fileStoreIsEmpty
5335 5336 5337 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5335 def file_store_is_empty @file_store_is_empty end |
#file_store_location ⇒ String
The location of the file store. * Cloud Storage: https://cloud.google.com/
storage/docs/locations#available-locations * Amazon S3: https://docs.aws.
amazon.com/general/latest/gr/rande.html#regional-endpoints
Corresponds to the JSON property fileStoreLocation
5343 5344 5345 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5343 def file_store_location @file_store_location end |
#file_store_path ⇒ String
The file store path. * Cloud Storage: gs://bucket* Amazon S3: `s3://`
bucket * Vertex AI dataset: projects/project_number/locations/location/
datasets/dataset_id`
Corresponds to the JSON propertyfileStorePath`
5350 5351 5352 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5350 def file_store_path @file_store_path end |
#full_resource ⇒ String
The resource name of the resource profiled. https://cloud.google.com/apis/
design/resource_names#full_resource_name Example format of an S3 bucket full
resource name: //cloudasset.googleapis.com/organizations/org_id/
otherCloudConnections/aws/arn:aws:s3:::bucket_name`
Corresponds to the JSON propertyfullResource`
5358 5359 5360 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5358 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time the file store was last modified.
Corresponds to the JSON property lastModifiedTime
5363 5364 5365 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5363 def last_modified_time @last_modified_time end |
#location_type ⇒ String
The location type of the file store (region, dual-region, multi-region, etc).
If dual-region, expect data_storage_locations to be populated.
Corresponds to the JSON property locationType
5369 5370 5371 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5369 def location_type @location_type end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
5374 5375 5376 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5374 def name @name end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
5379 5380 5381 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5379 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
5384 5385 5386 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5384 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this file store.
Corresponds to the JSON property projectDataProfile
5389 5390 5391 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5389 def project_data_profile @project_data_profile end |
#project_id ⇒ String
The Google Cloud project ID that owns the resource. For Amazon S3 buckets,
this is the AWS Account Id.
Corresponds to the JSON property projectId
5395 5396 5397 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5395 def project_id @project_id end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
5400 5401 5402 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5400 def @related_resources end |
#resource_attributes ⇒ Hash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
Attributes of the resource being profiled. Currently used attributes: *
customer_managed_encryption: boolean - true: the resource is encrypted with a
customer-managed key. - false: the resource is encrypted with a provider-
managed key.
Corresponds to the JSON property resourceAttributes
5408 5409 5410 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5408 def resource_attributes @resource_attributes end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
5413 5414 5415 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5413 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
5418 5419 5420 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5418 def resource_visibility @resource_visibility end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
5425 5426 5427 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5425 def sample_findings_table @sample_findings_table end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
5431 5432 5433 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5431 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile.
Corresponds to the JSON property state
5436 5437 5438 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5436 def state @state end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the resource, including any tags attached during
profiling.
Corresponds to the JSON property tags
5442 5443 5444 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5442 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5449 5450 5451 5452 5453 5454 5455 5456 5457 5458 5459 5460 5461 5462 5463 5464 5465 5466 5467 5468 5469 5470 5471 5472 5473 5474 5475 5476 5477 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5449 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @data_storage_locations = args[:data_storage_locations] if args.key?(:data_storage_locations) @domains = args[:domains] if args.key?(:domains) @file_cluster_summaries = args[:file_cluster_summaries] if args.key?(:file_cluster_summaries) @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries) @file_store_is_empty = args[:file_store_is_empty] if args.key?(:file_store_is_empty) @file_store_location = args[:file_store_location] if args.key?(:file_store_location) @file_store_path = args[:file_store_path] if args.key?(:file_store_path) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @location_type = args[:location_type] if args.key?(:location_type) @name = args[:name] if args.key?(:name) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @project_id = args[:project_id] if args.key?(:project_id) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) end |