Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a file store. * Cloud Storage: maps 1:1 with a bucket. * Amazon S3: maps 1:1 with a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreDataProfile

Returns a new instance of GooglePrivacyDlpV2FileStoreDataProfile.



5412
5413
5414
# File 'lib/google/apis/dlp_v2/classes.rb', line 5412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_snapshotGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Snapshot of the configurations used to generate the profile. Corresponds to the JSON property configSnapshot



5257
5258
5259
# File 'lib/google/apis/dlp_v2/classes.rb', line 5257

def config_snapshot
  @config_snapshot
end

#create_timeString

The time the file store was first created. Corresponds to the JSON property createTime

Returns:

  • (String)


5262
5263
5264
# File 'lib/google/apis/dlp_v2/classes.rb', line 5262

def create_time
  @create_time
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



5268
5269
5270
# File 'lib/google/apis/dlp_v2/classes.rb', line 5268

def data_risk_level
  @data_risk_level
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



5273
5274
5275
# File 'lib/google/apis/dlp_v2/classes.rb', line 5273

def data_source_type
  @data_source_type
end

#data_storage_locationsArray<String>

For resources that have multiple storage locations, these are those regions. For Cloud Storage this is the list of regions chosen for dual-region storage. file_store_location will normally be the corresponding multi-region for the list of individual locations. The first region is always picked as the processing and storage location for the data profile. Corresponds to the JSON property dataStorageLocations

Returns:

  • (Array<String>)


5282
5283
5284
# File 'lib/google/apis/dlp_v2/classes.rb', line 5282

def data_storage_locations
  @data_storage_locations
end

#domainsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>

Domains associated with the profile. Corresponds to the JSON property domains



5287
5288
5289
# File 'lib/google/apis/dlp_v2/classes.rb', line 5287

def domains
  @domains
end

#file_cluster_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileClusterSummary>

FileClusterSummary per each cluster. Corresponds to the JSON property fileClusterSummaries



5292
5293
5294
# File 'lib/google/apis/dlp_v2/classes.rb', line 5292

def file_cluster_summaries
  @file_cluster_summaries
end

#file_store_info_type_summariesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreInfoTypeSummary>

InfoTypes detected in this file store. Corresponds to the JSON property fileStoreInfoTypeSummaries



5297
5298
5299
# File 'lib/google/apis/dlp_v2/classes.rb', line 5297

def file_store_info_type_summaries
  @file_store_info_type_summaries
end

#file_store_is_emptyBoolean Also known as: file_store_is_empty?

The file store does not have any files. If the profiling operation failed, this is false. Corresponds to the JSON property fileStoreIsEmpty

Returns:

  • (Boolean)


5303
5304
5305
# File 'lib/google/apis/dlp_v2/classes.rb', line 5303

def file_store_is_empty
  @file_store_is_empty
end

#file_store_locationString

The location of the file store. * Cloud Storage: https://cloud.google.com/ storage/docs/locations#available-locations * Amazon S3: https://docs.aws. amazon.com/general/latest/gr/rande.html#regional-endpoints Corresponds to the JSON property fileStoreLocation

Returns:

  • (String)


5311
5312
5313
# File 'lib/google/apis/dlp_v2/classes.rb', line 5311

def file_store_location
  @file_store_location
end

#file_store_pathString

The file store path. * Cloud Storage: gs://bucket* Amazon S3: `s3://` bucket * Vertex AI dataset: projects/project_number/locations/location/ datasets/dataset_id` Corresponds to the JSON propertyfileStorePath`

Returns:

  • (String)


5318
5319
5320
# File 'lib/google/apis/dlp_v2/classes.rb', line 5318

def file_store_path
  @file_store_path
end

#full_resourceString

The resource name of the resource profiled. https://cloud.google.com/apis/ design/resource_names#full_resource_name Example format of an S3 bucket full resource name: //cloudasset.googleapis.com/organizations/org_id/ otherCloudConnections/aws/arn:aws:s3:::bucket_name` Corresponds to the JSON propertyfullResource`

Returns:

  • (String)


5326
5327
5328
# File 'lib/google/apis/dlp_v2/classes.rb', line 5326

def full_resource
  @full_resource
end

#last_modified_timeString

The time the file store was last modified. Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


5331
5332
5333
# File 'lib/google/apis/dlp_v2/classes.rb', line 5331

def last_modified_time
  @last_modified_time
end

#location_typeString

The location type of the file store (region, dual-region, multi-region, etc). If dual-region, expect data_storage_locations to be populated. Corresponds to the JSON property locationType

Returns:

  • (String)


5337
5338
5339
# File 'lib/google/apis/dlp_v2/classes.rb', line 5337

def location_type
  @location_type
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


5342
5343
5344
# File 'lib/google/apis/dlp_v2/classes.rb', line 5342

def name
  @name
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


5347
5348
5349
# File 'lib/google/apis/dlp_v2/classes.rb', line 5347

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



5352
5353
5354
# File 'lib/google/apis/dlp_v2/classes.rb', line 5352

def profile_status
  @profile_status
end

#project_data_profileString

The resource name of the project data profile for this file store. Corresponds to the JSON property projectDataProfile

Returns:

  • (String)


5357
5358
5359
# File 'lib/google/apis/dlp_v2/classes.rb', line 5357

def project_data_profile
  @project_data_profile
end

#project_idString

The Google Cloud project ID that owns the resource. For Amazon S3 buckets, this is the AWS Account Id. Corresponds to the JSON property projectId

Returns:

  • (String)


5363
5364
5365
# File 'lib/google/apis/dlp_v2/classes.rb', line 5363

def project_id
  @project_id
end

Resources related to this profile. Corresponds to the JSON property relatedResources



5368
5369
5370
# File 'lib/google/apis/dlp_v2/classes.rb', line 5368

def related_resources
  @related_resources
end

#resource_attributesHash<String,Google::Apis::DlpV2::GooglePrivacyDlpV2Value>

Attributes of the resource being profiled. Currently used attributes: * customer_managed_encryption: boolean - true: the resource is encrypted with a customer-managed key. - false: the resource is encrypted with a provider- managed key. Corresponds to the JSON property resourceAttributes



5376
5377
5378
# File 'lib/google/apis/dlp_v2/classes.rb', line 5376

def resource_attributes
  @resource_attributes
end

#resource_labelsHash<String,String>

The labels applied to the resource at the time the profile was generated. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


5381
5382
5383
# File 'lib/google/apis/dlp_v2/classes.rb', line 5381

def resource_labels
  @resource_labels
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


5386
5387
5388
# File 'lib/google/apis/dlp_v2/classes.rb', line 5386

def resource_visibility
  @resource_visibility
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



5393
5394
5395
# File 'lib/google/apis/dlp_v2/classes.rb', line 5393

def sample_findings_table
  @sample_findings_table
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



5399
5400
5401
# File 'lib/google/apis/dlp_v2/classes.rb', line 5399

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. Corresponds to the JSON property state

Returns:

  • (String)


5404
5405
5406
# File 'lib/google/apis/dlp_v2/classes.rb', line 5404

def state
  @state
end

#tagsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>

The tags attached to the resource, including any tags attached during profiling. Corresponds to the JSON property tags



5410
5411
5412
# File 'lib/google/apis/dlp_v2/classes.rb', line 5410

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5417
5418
5419
5420
5421
5422
5423
5424
5425
5426
5427
5428
5429
5430
5431
5432
5433
5434
5435
5436
5437
5438
5439
5440
5441
5442
5443
5444
5445
# File 'lib/google/apis/dlp_v2/classes.rb', line 5417

def update!(**args)
  @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @data_storage_locations = args[:data_storage_locations] if args.key?(:data_storage_locations)
  @domains = args[:domains] if args.key?(:domains)
  @file_cluster_summaries = args[:file_cluster_summaries] if args.key?(:file_cluster_summaries)
  @file_store_info_type_summaries = args[:file_store_info_type_summaries] if args.key?(:file_store_info_type_summaries)
  @file_store_is_empty = args[:file_store_is_empty] if args.key?(:file_store_is_empty)
  @file_store_location = args[:file_store_location] if args.key?(:file_store_location)
  @file_store_path = args[:file_store_path] if args.key?(:file_store_path)
  @full_resource = args[:full_resource] if args.key?(:full_resource)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @location_type = args[:location_type] if args.key?(:location_type)
  @name = args[:name] if args.key?(:name)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile)
  @project_id = args[:project_id] if args.key?(:project_id)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_attributes = args[:resource_attributes] if args.key?(:resource_attributes)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @tags = args[:tags] if args.key?(:tags)
end