Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegexes
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegexes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A collection of regular expressions to determine what file store to match against.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreRegexes
constructor
A new instance of GooglePrivacyDlpV2FileStoreRegexes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreRegexes
Returns a new instance of GooglePrivacyDlpV2FileStoreRegexes.
5882 5883 5884 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5882 def initialize(**args) update!(**args) end |
Instance Attribute Details
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegex>
Required. The group of regular expression patterns to match against one or
more file stores. Maximum of 100 entries. The sum of all regular expression's
length can't exceed 10 KiB.
Corresponds to the JSON property patterns
5880 5881 5882 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5880 def patterns @patterns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5887 5888 5889 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5887 def update!(**args) @patterns = args[:patterns] if args.key?(:patterns) end |