Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegexes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A collection of regular expressions to determine what file store to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FileStoreRegexes

Returns a new instance of GooglePrivacyDlpV2FileStoreRegexes.



5640
5641
5642
# File 'lib/google/apis/dlp_v2/classes.rb', line 5640

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patternsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FileStoreRegex>

Required. The group of regular expression patterns to match against one or more file stores. Maximum of 100 entries. The sum of all regular expression's length can't exceed 10 KiB. Corresponds to the JSON property patterns



5638
5639
5640
# File 'lib/google/apis/dlp_v2/classes.rb', line 5638

def patterns
  @patterns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5645
5646
5647
# File 'lib/google/apis/dlp_v2/classes.rb', line 5645

def update!(**args)
  @patterns = args[:patterns] if args.key?(:patterns)
end