Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Represents a piece of potentially sensitive content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Finding

Returns a new instance of GooglePrivacyDlpV2Finding.



5966
5967
5968
# File 'lib/google/apis/dlp_v2/classes.rb', line 5966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Timestamp when finding was detected. Corresponds to the JSON property createTime

Returns:

  • (String)


5895
5896
5897
# File 'lib/google/apis/dlp_v2/classes.rb', line 5895

def create_time
  @create_time
end

#finding_idString

The unique finding id. Corresponds to the JSON property findingId

Returns:

  • (String)


5900
5901
5902
# File 'lib/google/apis/dlp_v2/classes.rb', line 5900

def finding_id
  @finding_id
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



5905
5906
5907
# File 'lib/google/apis/dlp_v2/classes.rb', line 5905

def info_type
  @info_type
end

#job_create_timeString

Time the job started that produced this finding. Corresponds to the JSON property jobCreateTime

Returns:

  • (String)


5910
5911
5912
# File 'lib/google/apis/dlp_v2/classes.rb', line 5910

def job_create_time
  @job_create_time
end

#job_nameString

The job that stored the finding. Corresponds to the JSON property jobName

Returns:

  • (String)


5915
5916
5917
# File 'lib/google/apis/dlp_v2/classes.rb', line 5915

def job_name
  @job_name
end

#labelsHash<String,String>

The labels associated with this Finding. Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([- a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. No more than 10 labels can be associated with a given finding. Examples: * " environment" : "production" * "pipeline" : "etl" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5925
5926
5927
# File 'lib/google/apis/dlp_v2/classes.rb', line 5925

def labels
  @labels
end

#likelihoodString

Confidence of how likely it is that the info_type is correct. Corresponds to the JSON property likelihood

Returns:

  • (String)


5930
5931
5932
# File 'lib/google/apis/dlp_v2/classes.rb', line 5930

def likelihood
  @likelihood
end

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2Location

Specifies the location of the finding. Corresponds to the JSON property location



5935
5936
5937
# File 'lib/google/apis/dlp_v2/classes.rb', line 5935

def location
  @location
end

#nameString

Resource name in format projects/project/locations/location/findings/ finding Populated only when viewing persisted findings. Corresponds to the JSON property name

Returns:

  • (String)


5941
5942
5943
# File 'lib/google/apis/dlp_v2/classes.rb', line 5941

def name
  @name
end

#quoteString

The content that was found. Even if the content is not textual, it may be converted to a textual representation here. Provided if include_quote is true and the finding is less than or equal to 4096 bytes long. If the finding exceeds 4096 bytes in length, the quote may be omitted. Corresponds to the JSON property quote

Returns:

  • (String)


5949
5950
5951
# File 'lib/google/apis/dlp_v2/classes.rb', line 5949

def quote
  @quote
end

#quote_infoGoogle::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo

Message for infoType-dependent details parsed from quote. Corresponds to the JSON property quoteInfo



5954
5955
5956
# File 'lib/google/apis/dlp_v2/classes.rb', line 5954

def quote_info
  @quote_info
end

#resource_nameString

The job that stored the finding. Corresponds to the JSON property resourceName

Returns:

  • (String)


5959
5960
5961
# File 'lib/google/apis/dlp_v2/classes.rb', line 5959

def resource_name
  @resource_name
end

#trigger_nameString

Job trigger name, if applicable, for this finding. Corresponds to the JSON property triggerName

Returns:

  • (String)


5964
5965
5966
# File 'lib/google/apis/dlp_v2/classes.rb', line 5964

def trigger_name
  @trigger_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5971
5972
5973
5974
5975
5976
5977
5978
5979
5980
5981
5982
5983
5984
5985
# File 'lib/google/apis/dlp_v2/classes.rb', line 5971

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @info_type = args[:info_type] if args.key?(:info_type)
  @job_create_time = args[:job_create_time] if args.key?(:job_create_time)
  @job_name = args[:job_name] if args.key?(:job_name)
  @labels = args[:labels] if args.key?(:labels)
  @likelihood = args[:likelihood] if args.key?(:likelihood)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @quote = args[:quote] if args.key?(:quote)
  @quote_info = args[:quote_info] if args.key?(:quote_info)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @trigger_name = args[:trigger_name] if args.key?(:trigger_name)
end