Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Finding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Represents a piece of potentially sensitive content.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Finding

Returns a new instance of GooglePrivacyDlpV2Finding.



5621
5622
5623
# File 'lib/google/apis/dlp_v2/classes.rb', line 5621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Timestamp when finding was detected. Corresponds to the JSON property createTime

Returns:

  • (String)


5550
5551
5552
# File 'lib/google/apis/dlp_v2/classes.rb', line 5550

def create_time
  @create_time
end

#finding_idString

The unique finding id. Corresponds to the JSON property findingId

Returns:

  • (String)


5555
5556
5557
# File 'lib/google/apis/dlp_v2/classes.rb', line 5555

def finding_id
  @finding_id
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



5560
5561
5562
# File 'lib/google/apis/dlp_v2/classes.rb', line 5560

def info_type
  @info_type
end

#job_create_timeString

Time the job started that produced this finding. Corresponds to the JSON property jobCreateTime

Returns:

  • (String)


5565
5566
5567
# File 'lib/google/apis/dlp_v2/classes.rb', line 5565

def job_create_time
  @job_create_time
end

#job_nameString

The job that stored the finding. Corresponds to the JSON property jobName

Returns:

  • (String)


5570
5571
5572
# File 'lib/google/apis/dlp_v2/classes.rb', line 5570

def job_name
  @job_name
end

#labelsHash<String,String>

The labels associated with this Finding. Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [a-z]([- a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. No more than 10 labels can be associated with a given finding. Examples: * " environment" : "production" * "pipeline" : "etl" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5580
5581
5582
# File 'lib/google/apis/dlp_v2/classes.rb', line 5580

def labels
  @labels
end

#likelihoodString

Confidence of how likely it is that the info_type is correct. Corresponds to the JSON property likelihood

Returns:

  • (String)


5585
5586
5587
# File 'lib/google/apis/dlp_v2/classes.rb', line 5585

def likelihood
  @likelihood
end

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2Location

Specifies the location of the finding. Corresponds to the JSON property location



5590
5591
5592
# File 'lib/google/apis/dlp_v2/classes.rb', line 5590

def location
  @location
end

#nameString

Resource name in format projects/project/locations/location/findings/ finding Populated only when viewing persisted findings. Corresponds to the JSON property name

Returns:

  • (String)


5596
5597
5598
# File 'lib/google/apis/dlp_v2/classes.rb', line 5596

def name
  @name
end

#quoteString

The content that was found. Even if the content is not textual, it may be converted to a textual representation here. Provided if include_quote is true and the finding is less than or equal to 4096 bytes long. If the finding exceeds 4096 bytes in length, the quote may be omitted. Corresponds to the JSON property quote

Returns:

  • (String)


5604
5605
5606
# File 'lib/google/apis/dlp_v2/classes.rb', line 5604

def quote
  @quote
end

#quote_infoGoogle::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo

Message for infoType-dependent details parsed from quote. Corresponds to the JSON property quoteInfo



5609
5610
5611
# File 'lib/google/apis/dlp_v2/classes.rb', line 5609

def quote_info
  @quote_info
end

#resource_nameString

The job that stored the finding. Corresponds to the JSON property resourceName

Returns:

  • (String)


5614
5615
5616
# File 'lib/google/apis/dlp_v2/classes.rb', line 5614

def resource_name
  @resource_name
end

#trigger_nameString

Job trigger name, if applicable, for this finding. Corresponds to the JSON property triggerName

Returns:

  • (String)


5619
5620
5621
# File 'lib/google/apis/dlp_v2/classes.rb', line 5619

def trigger_name
  @trigger_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5626
5627
5628
5629
5630
5631
5632
5633
5634
5635
5636
5637
5638
5639
5640
# File 'lib/google/apis/dlp_v2/classes.rb', line 5626

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @info_type = args[:info_type] if args.key?(:info_type)
  @job_create_time = args[:job_create_time] if args.key?(:job_create_time)
  @job_name = args[:job_name] if args.key?(:job_name)
  @labels = args[:labels] if args.key?(:labels)
  @likelihood = args[:likelihood] if args.key?(:likelihood)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @quote = args[:quote] if args.key?(:quote)
  @quote_info = args[:quote_info] if args.key?(:quote_info)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @trigger_name = args[:trigger_name] if args.key?(:trigger_name)
end