Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Finding
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Finding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Represents a piece of potentially sensitive content.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Timestamp when finding was detected.
-
#finding_id ⇒ String
The unique finding id.
-
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
-
#job_create_time ⇒ String
Time the job started that produced this finding.
-
#job_name ⇒ String
The job that stored the finding.
-
#labels ⇒ Hash<String,String>
The labels associated with this
Finding. -
#likelihood ⇒ String
Confidence of how likely it is that the
info_typeis correct. -
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Location
Specifies the location of the finding.
-
#name ⇒ String
Resource name in format projects/
project/locations/location/findings/findingPopulated only when viewing persisted findings. -
#quote ⇒ String
The content that was found.
-
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
-
#resource_name ⇒ String
The job that stored the finding.
-
#trigger_name ⇒ String
Job trigger name, if applicable, for this finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Finding
constructor
A new instance of GooglePrivacyDlpV2Finding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Finding
Returns a new instance of GooglePrivacyDlpV2Finding.
5405 5406 5407 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Timestamp when finding was detected.
Corresponds to the JSON property createTime
5334 5335 5336 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5334 def create_time @create_time end |
#finding_id ⇒ String
The unique finding id.
Corresponds to the JSON property findingId
5339 5340 5341 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5339 def finding_id @finding_id end |
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infoType
5344 5345 5346 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5344 def info_type @info_type end |
#job_create_time ⇒ String
Time the job started that produced this finding.
Corresponds to the JSON property jobCreateTime
5349 5350 5351 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5349 def job_create_time @job_create_time end |
#job_name ⇒ String
The job that stored the finding.
Corresponds to the JSON property jobName
5354 5355 5356 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5354 def job_name @job_name end |
#labels ⇒ Hash<String,String>
The labels associated with this Finding. Label keys must be between 1 and 63
characters long and must conform to the following regular expression: [a-z]([-
a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and
must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?. No
more than 10 labels can be associated with a given finding. Examples: * "
environment" : "production" * "pipeline" : "etl"
Corresponds to the JSON property labels
5364 5365 5366 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5364 def labels @labels end |
#likelihood ⇒ String
Confidence of how likely it is that the info_type is correct.
Corresponds to the JSON property likelihood
5369 5370 5371 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5369 def likelihood @likelihood end |
#location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Location
Specifies the location of the finding.
Corresponds to the JSON property location
5374 5375 5376 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5374 def location @location end |
#name ⇒ String
Resource name in format projects/project/locations/location/findings/
finding Populated only when viewing persisted findings.
Corresponds to the JSON property name
5380 5381 5382 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5380 def name @name end |
#quote ⇒ String
The content that was found. Even if the content is not textual, it may be
converted to a textual representation here. Provided if include_quote is
true and the finding is less than or equal to 4096 bytes long. If the finding
exceeds 4096 bytes in length, the quote may be omitted.
Corresponds to the JSON property quote
5388 5389 5390 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5388 def quote @quote end |
#quote_info ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2QuoteInfo
Message for infoType-dependent details parsed from quote.
Corresponds to the JSON property quoteInfo
5393 5394 5395 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5393 def quote_info @quote_info end |
#resource_name ⇒ String
The job that stored the finding.
Corresponds to the JSON property resourceName
5398 5399 5400 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5398 def resource_name @resource_name end |
#trigger_name ⇒ String
Job trigger name, if applicable, for this finding.
Corresponds to the JSON property triggerName
5403 5404 5405 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5403 def trigger_name @trigger_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5410 5411 5412 5413 5414 5415 5416 5417 5418 5419 5420 5421 5422 5423 5424 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5410 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @finding_id = args[:finding_id] if args.key?(:finding_id) @info_type = args[:info_type] if args.key?(:info_type) @job_create_time = args[:job_create_time] if args.key?(:job_create_time) @job_name = args[:job_name] if args.key?(:job_name) @labels = args[:labels] if args.key?(:labels) @likelihood = args[:likelihood] if args.key?(:likelihood) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @quote = args[:quote] if args.key?(:quote) @quote_info = args[:quote_info] if args.key?(:quote_info) @resource_name = args[:resource_name] if args.key?(:resource_name) @trigger_name = args[:trigger_name] if args.key?(:trigger_name) end |