Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration to control the number of findings returned for inspection. This is not used for de-identification or data profiling. When redacting sensitive data from images, finding limits don't apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don't include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2FindingLimits

Returns a new instance of GooglePrivacyDlpV2FindingLimits.



5783
5784
5785
# File 'lib/google/apis/dlp_v2/classes.rb', line 5783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_findings_per_info_typeArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLimit>

Configuration of findings limit given for specified infoTypes. Corresponds to the JSON property maxFindingsPerInfoType



5761
5762
5763
# File 'lib/google/apis/dlp_v2/classes.rb', line 5761

def max_findings_per_info_type
  @max_findings_per_info_type
end

#max_findings_per_itemFixnum

Max number of findings that are returned for each item scanned. When set within an InspectContentRequest, this field is ignored. This value isn't a hard limit. If the number of findings for an item reaches this limit, the inspection of that item ends gradually, not abruptly. Therefore, the actual number of findings that Cloud DLP returns for the item can be multiple times higher than this value. Corresponds to the JSON property maxFindingsPerItem

Returns:

  • (Fixnum)


5771
5772
5773
# File 'lib/google/apis/dlp_v2/classes.rb', line 5771

def max_findings_per_item
  @max_findings_per_item
end

#max_findings_per_requestFixnum

Max number of findings that are returned per request or job. If you set this field in an InspectContentRequest, the resulting maximum value is the value that you set or 3,000, whichever is lower. This value isn't a hard limit. If an inspection reaches this limit, the inspection ends gradually, not abruptly. Therefore, the actual number of findings that Cloud DLP returns can be multiple times higher than this value. Corresponds to the JSON property maxFindingsPerRequest

Returns:

  • (Fixnum)


5781
5782
5783
# File 'lib/google/apis/dlp_v2/classes.rb', line 5781

def max_findings_per_request
  @max_findings_per_request
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5788
5789
5790
5791
5792
# File 'lib/google/apis/dlp_v2/classes.rb', line 5788

def update!(**args)
  @max_findings_per_info_type = args[:max_findings_per_info_type] if args.key?(:max_findings_per_info_type)
  @max_findings_per_item = args[:max_findings_per_item] if args.key?(:max_findings_per_item)
  @max_findings_per_request = args[:max_findings_per_request] if args.key?(:max_findings_per_request)
end