Class: Google::Apis::DlpV2::GooglePrivacyDlpV2FixedSizeBucketingConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2FixedSizeBucketingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Buckets values based on fixed size ranges. The Bucketing transformation can
provide all of this functionality, but requires more configuration. This
message is provided as a convenience to the user for simple bucketing
strategies. The transformed value will be a hyphenated string of lower_bound-
upper_bound. For example, if lower_bound = 10 and upper_bound = 20, all
values that are within this bucket will be replaced with "10-20". This can be
used on data of type: double, long. If the bound Value type differs from the
type of data being transformed, we will first attempt converting the type of
the data to be transformed to match the type of the bound before comparing.
See https://docs.cloud.google.com/sensitive-data-protection/docs/concepts-
bucketing to learn more.
Instance Attribute Summary collapse
-
#bucket_size ⇒ Float
Required.
-
#lower_bound ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system.
-
#upper_bound ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2FixedSizeBucketingConfig
constructor
A new instance of GooglePrivacyDlpV2FixedSizeBucketingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2FixedSizeBucketingConfig
Returns a new instance of GooglePrivacyDlpV2FixedSizeBucketingConfig.
6091 6092 6093 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bucket_size ⇒ Float
Required. Size of each bucket (except for minimum and maximum buckets). So if
lower_bound = 10, upper_bound = 89, and bucket_size = 10, then the
following buckets would be used: -10, 10-20, 20-30, 30-40, 40-50, 50-60, 60-70,
70-80, 80-89, 89+. Precision up to 2 decimals works.
Corresponds to the JSON property bucketSize
6071 6072 6073 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6071 def bucket_size @bucket_size end |
#lower_bound ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system. Note that for the purposes of
inspection or transformation, the number of bytes considered to comprise a '
Value' is based on its representation as a UTF-8 encoded string. For example,
if 'integer_value' is set to 123456789, the number of bytes would be counted
as 9, even though an int64 only holds up to 8 bytes of data.
Corresponds to the JSON property lowerBound
6080 6081 6082 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6080 def lower_bound @lower_bound end |
#upper_bound ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system. Note that for the purposes of
inspection or transformation, the number of bytes considered to comprise a '
Value' is based on its representation as a UTF-8 encoded string. For example,
if 'integer_value' is set to 123456789, the number of bytes would be counted
as 9, even though an int64 only holds up to 8 bytes of data.
Corresponds to the JSON property upperBound
6089 6090 6091 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6089 def upper_bound @upper_bound end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6096 6097 6098 6099 6100 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6096 def update!(**args) @bucket_size = args[:bucket_size] if args.key?(:bucket_size) @lower_bound = args[:lower_bound] if args.key?(:lower_bound) @upper_bound = args[:upper_bound] if args.key?(:upper_bound) end |