Class: Google::Apis::DlpV2::GooglePrivacyDlpV2HybridFindingDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Populate to associate additional data with each finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2HybridFindingDetails

Returns a new instance of GooglePrivacyDlpV2HybridFindingDetails.



6276
6277
6278
# File 'lib/google/apis/dlp_v2/classes.rb', line 6276

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_detailsGoogle::Apis::DlpV2::GooglePrivacyDlpV2Container

Represents a container that may contain DLP findings. Examples of a container include a file, table, or database record. Corresponds to the JSON property containerDetails



6243
6244
6245
# File 'lib/google/apis/dlp_v2/classes.rb', line 6243

def container_details
  @container_details
end

#file_offsetFixnum

Offset in bytes of the line, from the beginning of the file, where the finding is located. Populate if the item being scanned is only part of a bigger item, such as a shard of a file and you want to track the absolute position of the finding. Corresponds to the JSON property fileOffset

Returns:

  • (Fixnum)


6251
6252
6253
# File 'lib/google/apis/dlp_v2/classes.rb', line 6251

def file_offset
  @file_offset
end

#labelsHash<String,String>

Labels to represent user provided metadata about the data being inspected. If configured by the job, some key values may be required. The labels associated with Finding's produced by hybrid inspection. Label keys must be between 1 and 63 characters long and must conform to the following regular expression: [ a-z]([-a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)? . No more than 10 labels can be associated with a given finding. Examples: * " environment" : "production" * "pipeline" : "etl" Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6263
6264
6265
# File 'lib/google/apis/dlp_v2/classes.rb', line 6263

def labels
  @labels
end

#row_offsetFixnum

Offset of the row for tables. Populate if the row(s) being scanned are part of a bigger dataset and you want to keep track of their absolute position. Corresponds to the JSON property rowOffset

Returns:

  • (Fixnum)


6269
6270
6271
# File 'lib/google/apis/dlp_v2/classes.rb', line 6269

def row_offset
  @row_offset
end

#table_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2TableOptions

Instructions regarding the table content being inspected. Corresponds to the JSON property tableOptions



6274
6275
6276
# File 'lib/google/apis/dlp_v2/classes.rb', line 6274

def table_options
  @table_options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6281
6282
6283
6284
6285
6286
6287
# File 'lib/google/apis/dlp_v2/classes.rb', line 6281

def update!(**args)
  @container_details = args[:container_details] if args.key?(:container_details)
  @file_offset = args[:file_offset] if args.key?(:file_offset)
  @labels = args[:labels] if args.key?(:labels)
  @row_offset = args[:row_offset] if args.key?(:row_offset)
  @table_options = args[:table_options] if args.key?(:table_options)
end