Class: Google::Apis::DlpV2::GooglePrivacyDlpV2HybridFindingDetails
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2HybridFindingDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Populate to associate additional data with each finding.
Instance Attribute Summary collapse
-
#container_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Container
Represents a container that may contain DLP findings.
-
#file_offset ⇒ Fixnum
Offset in bytes of the line, from the beginning of the file, where the finding is located.
-
#labels ⇒ Hash<String,String>
Labels to represent user provided metadata about the data being inspected.
-
#row_offset ⇒ Fixnum
Offset of the row for tables.
-
#table_options ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableOptions
Instructions regarding the table content being inspected.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridFindingDetails
constructor
A new instance of GooglePrivacyDlpV2HybridFindingDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2HybridFindingDetails
Returns a new instance of GooglePrivacyDlpV2HybridFindingDetails.
5847 5848 5849 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5847 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Container
Represents a container that may contain DLP findings. Examples of a container
include a file, table, or database record.
Corresponds to the JSON property containerDetails
5814 5815 5816 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5814 def container_details @container_details end |
#file_offset ⇒ Fixnum
Offset in bytes of the line, from the beginning of the file, where the finding
is located. Populate if the item being scanned is only part of a bigger item,
such as a shard of a file and you want to track the absolute position of the
finding.
Corresponds to the JSON property fileOffset
5822 5823 5824 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5822 def file_offset @file_offset end |
#labels ⇒ Hash<String,String>
Labels to represent user provided metadata about the data being inspected. If
configured by the job, some key values may be required. The labels associated
with Finding's produced by hybrid inspection. Label keys must be between 1
and 63 characters long and must conform to the following regular expression: [
a-z]([-a-z0-9]*[a-z0-9])?. Label values must be between 0 and 63 characters
long and must conform to the regular expression ([a-z]([-a-z0-9]*[a-z0-9])?)?
. No more than 10 labels can be associated with a given finding. Examples: * "
environment" : "production" * "pipeline" : "etl"
Corresponds to the JSON property labels
5834 5835 5836 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5834 def labels @labels end |
#row_offset ⇒ Fixnum
Offset of the row for tables. Populate if the row(s) being scanned are part of
a bigger dataset and you want to keep track of their absolute position.
Corresponds to the JSON property rowOffset
5840 5841 5842 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5840 def row_offset @row_offset end |
#table_options ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TableOptions
Instructions regarding the table content being inspected.
Corresponds to the JSON property tableOptions
5845 5846 5847 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5845 def @table_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5852 5853 5854 5855 5856 5857 5858 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 5852 def update!(**args) @container_details = args[:container_details] if args.key?(:container_details) @file_offset = args[:file_offset] if args.key?(:file_offset) @labels = args[:labels] if args.key?(:labels) @row_offset = args[:row_offset] if args.key?(:row_offset) @table_options = args[:table_options] if args.key?(:table_options) end |