Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the relationship between bounding boxes for image findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ImageContainmentType

Returns a new instance of GooglePrivacyDlpV2ImageContainmentType.



6155
6156
6157
# File 'lib/google/apis/dlp_v2/classes.rb', line 6155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enclosesGoogle::Apis::DlpV2::GooglePrivacyDlpV2Encloses

Defines a condition where one bounding box encloses another. Corresponds to the JSON property encloses



6143
6144
6145
# File 'lib/google/apis/dlp_v2/classes.rb', line 6143

def encloses
  @encloses
end

#fully_insideGoogle::Apis::DlpV2::GooglePrivacyDlpV2FullyInside

Defines a condition where one bounding box is fully inside another. Corresponds to the JSON property fullyInside



6148
6149
6150
# File 'lib/google/apis/dlp_v2/classes.rb', line 6148

def fully_inside
  @fully_inside
end

#overlapsGoogle::Apis::DlpV2::GooglePrivacyDlpV2Overlap

Defines a condition for overlapping bounding boxes. Corresponds to the JSON property overlaps



6153
6154
6155
# File 'lib/google/apis/dlp_v2/classes.rb', line 6153

def overlaps
  @overlaps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6160
6161
6162
6163
6164
# File 'lib/google/apis/dlp_v2/classes.rb', line 6160

def update!(**args)
  @encloses = args[:encloses] if args.key?(:encloses)
  @fully_inside = args[:fully_inside] if args.key?(:fully_inside)
  @overlaps = args[:overlaps] if args.key?(:overlaps)
end