Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ImageContainmentType
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Specifies the relationship between bounding boxes for image findings.
Instance Attribute Summary collapse
-
#encloses ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Encloses
Defines a condition where one bounding box encloses another.
-
#fully_inside ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FullyInside
Defines a condition where one bounding box is fully inside another.
-
#overlaps ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Overlap
Defines a condition for overlapping bounding boxes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ImageContainmentType
constructor
A new instance of GooglePrivacyDlpV2ImageContainmentType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ImageContainmentType
Returns a new instance of GooglePrivacyDlpV2ImageContainmentType.
6048 6049 6050 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6048 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encloses ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Encloses
Defines a condition where one bounding box encloses another.
Corresponds to the JSON property encloses
6036 6037 6038 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6036 def encloses @encloses end |
#fully_inside ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FullyInside
Defines a condition where one bounding box is fully inside another.
Corresponds to the JSON property fullyInside
6041 6042 6043 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6041 def fully_inside @fully_inside end |
#overlaps ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Overlap
Defines a condition for overlapping bounding boxes.
Corresponds to the JSON property overlaps
6046 6047 6048 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6046 def overlaps @overlaps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6053 6054 6055 6056 6057 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6053 def update!(**args) @encloses = args[:encloses] if args.key?(:encloses) @fully_inside = args[:fully_inside] if args.key?(:fully_inside) @overlaps = args[:overlaps] if args.key?(:overlaps) end |