Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCondition
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A info type based condition.
Instance Attribute Summary collapse
-
#any_info_type ⇒ Google::Apis::DlpV2::GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
-
#info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypes
Info types to match.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeCondition
constructor
A new instance of GooglePrivacyDlpV2InfoTypeCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeCondition
Returns a new instance of GooglePrivacyDlpV2InfoTypeCondition.
6678 6679 6680 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#any_info_type ⇒ Google::Apis::DlpV2::GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty
messages in your APIs. A typical example is to use it as the request or the
response type of an API method. For instance: service Foo rpc Bar(google.
protobuf.Empty) returns (google.protobuf.Empty);
Corresponds to the JSON property anyInfoType
6671 6672 6673 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6671 def any_info_type @any_info_type end |
#info_types ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypes
Info types to match.
Corresponds to the JSON property infoTypes
6676 6677 6678 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6676 def info_types @info_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6683 6684 6685 6686 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6683 def update!(**args) @any_info_type = args[:any_info_type] if args.key?(:any_info_type) @info_types = args[:info_types] if args.key?(:info_types) end |