Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

InfoType description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription

Returns a new instance of GooglePrivacyDlpV2InfoTypeDescription.



6754
6755
6756
# File 'lib/google/apis/dlp_v2/classes.rb', line 6754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>

The category of the infoType. Corresponds to the JSON property categories



6696
6697
6698
# File 'lib/google/apis/dlp_v2/classes.rb', line 6696

def categories
  @categories
end

#descriptionString

Description of the infotype. Translated when language is provided in the request. Corresponds to the JSON property description

Returns:

  • (String)


6702
6703
6704
# File 'lib/google/apis/dlp_v2/classes.rb', line 6702

def description
  @description
end

#display_nameString

Human readable form of the infoType name. Corresponds to the JSON property displayName

Returns:

  • (String)


6707
6708
6709
# File 'lib/google/apis/dlp_v2/classes.rb', line 6707

def display_name
  @display_name
end

#exampleString

A sample that is a true positive for this infoType. Corresponds to the JSON property example

Returns:

  • (String)


6712
6713
6714
# File 'lib/google/apis/dlp_v2/classes.rb', line 6712

def example
  @example
end

#launch_statusString

The launch status of the infoType. Corresponds to the JSON property launchStatus

Returns:

  • (String)


6717
6718
6719
# File 'lib/google/apis/dlp_v2/classes.rb', line 6717

def launch_status
  @launch_status
end

#location_supportGoogle::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport

Locations at which a feature can be used. Corresponds to the JSON property locationSupport



6722
6723
6724
# File 'lib/google/apis/dlp_v2/classes.rb', line 6722

def location_support
  @location_support
end

#nameString

Internal name of the infoType. Corresponds to the JSON property name

Returns:

  • (String)


6727
6728
6729
# File 'lib/google/apis/dlp_v2/classes.rb', line 6727

def name
  @name
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



6733
6734
6735
# File 'lib/google/apis/dlp_v2/classes.rb', line 6733

def sensitivity_score
  @sensitivity_score
end

#specific_info_typesArray<String>

If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it. General infoTypes are infoTypes that encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA" general infoType would have set for this field "LOCATION", " LOCATION_COORDINATES", and "STREET_ADDRESS". Corresponds to the JSON property specificInfoTypes

Returns:

  • (Array<String>)


6742
6743
6744
# File 'lib/google/apis/dlp_v2/classes.rb', line 6742

def specific_info_types
  @specific_info_types
end

#supported_byArray<String>

Which parts of the API supports this InfoType. Corresponds to the JSON property supportedBy

Returns:

  • (Array<String>)


6747
6748
6749
# File 'lib/google/apis/dlp_v2/classes.rb', line 6747

def supported_by
  @supported_by
end

#versionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>

A list of available versions for the infotype. Corresponds to the JSON property versions



6752
6753
6754
# File 'lib/google/apis/dlp_v2/classes.rb', line 6752

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6759
6760
6761
6762
6763
6764
6765
6766
6767
6768
6769
6770
6771
# File 'lib/google/apis/dlp_v2/classes.rb', line 6759

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example = args[:example] if args.key?(:example)
  @launch_status = args[:launch_status] if args.key?(:launch_status)
  @location_support = args[:location_support] if args.key?(:location_support)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @specific_info_types = args[:specific_info_types] if args.key?(:specific_info_types)
  @supported_by = args[:supported_by] if args.key?(:supported_by)
  @versions = args[:versions] if args.key?(:versions)
end