Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

InfoType description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription

Returns a new instance of GooglePrivacyDlpV2InfoTypeDescription.



6436
6437
6438
# File 'lib/google/apis/dlp_v2/classes.rb', line 6436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>

The category of the infoType. Corresponds to the JSON property categories



6378
6379
6380
# File 'lib/google/apis/dlp_v2/classes.rb', line 6378

def categories
  @categories
end

#descriptionString

Description of the infotype. Translated when language is provided in the request. Corresponds to the JSON property description

Returns:

  • (String)


6384
6385
6386
# File 'lib/google/apis/dlp_v2/classes.rb', line 6384

def description
  @description
end

#display_nameString

Human readable form of the infoType name. Corresponds to the JSON property displayName

Returns:

  • (String)


6389
6390
6391
# File 'lib/google/apis/dlp_v2/classes.rb', line 6389

def display_name
  @display_name
end

#exampleString

A sample that is a true positive for this infoType. Corresponds to the JSON property example

Returns:

  • (String)


6394
6395
6396
# File 'lib/google/apis/dlp_v2/classes.rb', line 6394

def example
  @example
end

#launch_statusString

The launch status of the infoType. Corresponds to the JSON property launchStatus

Returns:

  • (String)


6399
6400
6401
# File 'lib/google/apis/dlp_v2/classes.rb', line 6399

def launch_status
  @launch_status
end

#location_supportGoogle::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport

Locations at which a feature can be used. Corresponds to the JSON property locationSupport



6404
6405
6406
# File 'lib/google/apis/dlp_v2/classes.rb', line 6404

def location_support
  @location_support
end

#nameString

Internal name of the infoType. Corresponds to the JSON property name

Returns:

  • (String)


6409
6410
6411
# File 'lib/google/apis/dlp_v2/classes.rb', line 6409

def name
  @name
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



6415
6416
6417
# File 'lib/google/apis/dlp_v2/classes.rb', line 6415

def sensitivity_score
  @sensitivity_score
end

#specific_info_typesArray<String>

If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it. General infoTypes are infoTypes that encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA" general infoType would have set for this field "LOCATION", " LOCATION_COORDINATES", and "STREET_ADDRESS". Corresponds to the JSON property specificInfoTypes

Returns:

  • (Array<String>)


6424
6425
6426
# File 'lib/google/apis/dlp_v2/classes.rb', line 6424

def specific_info_types
  @specific_info_types
end

#supported_byArray<String>

Which parts of the API supports this InfoType. Corresponds to the JSON property supportedBy

Returns:

  • (Array<String>)


6429
6430
6431
# File 'lib/google/apis/dlp_v2/classes.rb', line 6429

def supported_by
  @supported_by
end

#versionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>

A list of available versions for the infotype. Corresponds to the JSON property versions



6434
6435
6436
# File 'lib/google/apis/dlp_v2/classes.rb', line 6434

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6441
6442
6443
6444
6445
6446
6447
6448
6449
6450
6451
6452
6453
# File 'lib/google/apis/dlp_v2/classes.rb', line 6441

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example = args[:example] if args.key?(:example)
  @launch_status = args[:launch_status] if args.key?(:launch_status)
  @location_support = args[:location_support] if args.key?(:location_support)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @specific_info_types = args[:specific_info_types] if args.key?(:specific_info_types)
  @supported_by = args[:supported_by] if args.key?(:supported_by)
  @versions = args[:versions] if args.key?(:versions)
end