Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

InfoType description.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription

Returns a new instance of GooglePrivacyDlpV2InfoTypeDescription.



6297
6298
6299
# File 'lib/google/apis/dlp_v2/classes.rb', line 6297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoriesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>

The category of the infoType. Corresponds to the JSON property categories



6239
6240
6241
# File 'lib/google/apis/dlp_v2/classes.rb', line 6239

def categories
  @categories
end

#descriptionString

Description of the infotype. Translated when language is provided in the request. Corresponds to the JSON property description

Returns:

  • (String)


6245
6246
6247
# File 'lib/google/apis/dlp_v2/classes.rb', line 6245

def description
  @description
end

#display_nameString

Human readable form of the infoType name. Corresponds to the JSON property displayName

Returns:

  • (String)


6250
6251
6252
# File 'lib/google/apis/dlp_v2/classes.rb', line 6250

def display_name
  @display_name
end

#exampleString

A sample that is a true positive for this infoType. Corresponds to the JSON property example

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/dlp_v2/classes.rb', line 6255

def example
  @example
end

#launch_statusString

The launch status of the infoType. Corresponds to the JSON property launchStatus

Returns:

  • (String)


6260
6261
6262
# File 'lib/google/apis/dlp_v2/classes.rb', line 6260

def launch_status
  @launch_status
end

#location_supportGoogle::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport

Locations at which a feature can be used. Corresponds to the JSON property locationSupport



6265
6266
6267
# File 'lib/google/apis/dlp_v2/classes.rb', line 6265

def location_support
  @location_support
end

#nameString

Internal name of the infoType. Corresponds to the JSON property name

Returns:

  • (String)


6270
6271
6272
# File 'lib/google/apis/dlp_v2/classes.rb', line 6270

def name
  @name
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



6276
6277
6278
# File 'lib/google/apis/dlp_v2/classes.rb', line 6276

def sensitivity_score
  @sensitivity_score
end

#specific_info_typesArray<String>

If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it. General infoTypes are infoTypes that encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA" general infoType would have set for this field "LOCATION", " LOCATION_COORDINATES", and "STREET_ADDRESS". Corresponds to the JSON property specificInfoTypes

Returns:

  • (Array<String>)


6285
6286
6287
# File 'lib/google/apis/dlp_v2/classes.rb', line 6285

def specific_info_types
  @specific_info_types
end

#supported_byArray<String>

Which parts of the API supports this InfoType. Corresponds to the JSON property supportedBy

Returns:

  • (Array<String>)


6290
6291
6292
# File 'lib/google/apis/dlp_v2/classes.rb', line 6290

def supported_by
  @supported_by
end

#versionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>

A list of available versions for the infotype. Corresponds to the JSON property versions



6295
6296
6297
# File 'lib/google/apis/dlp_v2/classes.rb', line 6295

def versions
  @versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6302
6303
6304
6305
6306
6307
6308
6309
6310
6311
6312
6313
6314
# File 'lib/google/apis/dlp_v2/classes.rb', line 6302

def update!(**args)
  @categories = args[:categories] if args.key?(:categories)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @example = args[:example] if args.key?(:example)
  @launch_status = args[:launch_status] if args.key?(:launch_status)
  @location_support = args[:location_support] if args.key?(:location_support)
  @name = args[:name] if args.key?(:name)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @specific_info_types = args[:specific_info_types] if args.key?(:specific_info_types)
  @supported_by = args[:supported_by] if args.key?(:supported_by)
  @versions = args[:versions] if args.key?(:versions)
end