Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeDescription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
InfoType description.
Instance Attribute Summary collapse
-
#categories ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>
The category of the infoType.
-
#description ⇒ String
Description of the infotype.
-
#display_name ⇒ String
Human readable form of the infoType name.
-
#example ⇒ String
A sample that is a true positive for this infoType.
-
#launch_status ⇒ String
The launch status of the infoType.
-
#location_support ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport
Locations at which a feature can be used.
-
#name ⇒ String
Internal name of the infoType.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#specific_info_types ⇒ Array<String>
If this field is set, this infoType is a general infoType and these specific infoTypes are contained within it.
-
#supported_by ⇒ Array<String>
Which parts of the API supports this InfoType.
-
#versions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>
A list of available versions for the infotype.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription
constructor
A new instance of GooglePrivacyDlpV2InfoTypeDescription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InfoTypeDescription
Returns a new instance of GooglePrivacyDlpV2InfoTypeDescription.
6069 6070 6071 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categories ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeCategory>
The category of the infoType.
Corresponds to the JSON property categories
6011 6012 6013 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6011 def categories @categories end |
#description ⇒ String
Description of the infotype. Translated when language is provided in the
request.
Corresponds to the JSON property description
6017 6018 6019 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6017 def description @description end |
#display_name ⇒ String
Human readable form of the infoType name.
Corresponds to the JSON property displayName
6022 6023 6024 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6022 def display_name @display_name end |
#example ⇒ String
A sample that is a true positive for this infoType.
Corresponds to the JSON property example
6027 6028 6029 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6027 def example @example end |
#launch_status ⇒ String
The launch status of the infoType.
Corresponds to the JSON property launchStatus
6032 6033 6034 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6032 def launch_status @launch_status end |
#location_support ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LocationSupport
Locations at which a feature can be used.
Corresponds to the JSON property locationSupport
6037 6038 6039 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6037 def location_support @location_support end |
#name ⇒ String
Internal name of the infoType.
Corresponds to the JSON property name
6042 6043 6044 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6042 def name @name end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
6048 6049 6050 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6048 def sensitivity_score @sensitivity_score end |
#specific_info_types ⇒ Array<String>
If this field is set, this infoType is a general infoType and these specific
infoTypes are contained within it. General infoTypes are infoTypes that
encompass multiple specific infoTypes. For example, the "GEOGRAPHIC_DATA"
general infoType would have set for this field "LOCATION", "
LOCATION_COORDINATES", and "STREET_ADDRESS".
Corresponds to the JSON property specificInfoTypes
6057 6058 6059 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6057 def specific_info_types @specific_info_types end |
#supported_by ⇒ Array<String>
Which parts of the API supports this InfoType.
Corresponds to the JSON property supportedBy
6062 6063 6064 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6062 def supported_by @supported_by end |
#versions ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2VersionDescription>
A list of available versions for the infotype.
Corresponds to the JSON property versions
6067 6068 6069 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6067 def versions @versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6074 6075 6076 6077 6078 6079 6080 6081 6082 6083 6084 6085 6086 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6074 def update!(**args) @categories = args[:categories] if args.key?(:categories) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @example = args[:example] if args.key?(:example) @launch_status = args[:launch_status] if args.key?(:launch_status) @location_support = args[:location_support] if args.key?(:location_support) @name = args[:name] if args.key?(:name) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @specific_info_types = args[:specific_info_types] if args.key?(:specific_info_types) @supported_by = args[:supported_by] if args.key?(:supported_by) @versions = args[:versions] if args.key?(:versions) end |