Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used.
Instance Attribute Summary collapse
-
#content_options ⇒ Array<String>
Deprecated and unused.
-
#custom_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2CustomInfoType>
CustomInfoTypes provided by the user.
-
#exclude_info_types ⇒ Boolean
(also: #exclude_info_types?)
When true, excludes type information of the findings.
-
#include_quote ⇒ Boolean
(also: #include_quote?)
When true, a contextual quote from the data that triggered a finding is included in the response; see Finding.quote.
-
#info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>
Restricts what info_types to look for.
-
#limits ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits
Configuration to control the number of findings returned for inspection.
-
#min_likelihood ⇒ String
Only returns findings equal to or above this threshold.
-
#min_likelihood_per_info_type ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLikelihood>
Minimum likelihood per infotype.
-
#rule_set ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRuleSet>
Set of rules to apply to the findings for this InspectConfig.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectConfig
constructor
A new instance of GooglePrivacyDlpV2InspectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectConfig
Returns a new instance of GooglePrivacyDlpV2InspectConfig.
6547 6548 6549 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6547 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_options ⇒ Array<String>
Deprecated and unused.
Corresponds to the JSON property contentOptions
6479 6480 6481 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6479 def @content_options end |
#custom_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2CustomInfoType>
CustomInfoTypes provided by the user. See https://cloud.google.com/sensitive-
data-protection/docs/creating-custom-infotypes to learn more.
Corresponds to the JSON property customInfoTypes
6485 6486 6487 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6485 def custom_info_types @custom_info_types end |
#exclude_info_types ⇒ Boolean Also known as: exclude_info_types?
When true, excludes type information of the findings. This is not used for
data profiling.
Corresponds to the JSON property excludeInfoTypes
6491 6492 6493 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6491 def exclude_info_types @exclude_info_types end |
#include_quote ⇒ Boolean Also known as: include_quote?
When true, a contextual quote from the data that triggered a finding is
included in the response; see Finding.quote. This is not used for data
profiling.
Corresponds to the JSON property includeQuote
6499 6500 6501 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6499 def include_quote @include_quote end |
#info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>
Restricts what info_types to look for. The values must correspond to InfoType
values returned by ListInfoTypes or listed at https://cloud.google.com/
sensitive-data-protection/docs/infotypes-reference. When no InfoTypes or
CustomInfoTypes are specified in a request, the system may automatically
choose a default list of detectors to run, which may change over time. If you
need precise control and predictability as to what detectors are run you
should specify specific InfoTypes listed in the reference, otherwise a default
list will be used, which may change over time.
Corresponds to the JSON property infoTypes
6512 6513 6514 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6512 def info_types @info_types end |
#limits ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits
Configuration to control the number of findings returned for inspection. This
is not used for de-identification or data profiling. When redacting sensitive
data from images, finding limits don't apply. They can cause unexpected or
inconsistent results, where only some data is redacted. Don't include finding
limits in RedactImage requests. Otherwise, Cloud DLP returns an error.
Corresponds to the JSON property limits
6521 6522 6523 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6521 def limits @limits end |
#min_likelihood ⇒ String
Only returns findings equal to or above this threshold. The default is
POSSIBLE. In general, the highest likelihood setting yields the fewest
findings in results and the lowest chance of a false positive. For more
information, see Match likelihood.
Corresponds to the JSON property minLikelihood
6530 6531 6532 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6530 def min_likelihood @min_likelihood end |
#min_likelihood_per_info_type ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLikelihood>
Minimum likelihood per infotype. For each infotype, a user can specify a
minimum likelihood. The system only returns a finding if its likelihood is
above this threshold. If this field is not set, the system uses the
InspectConfig min_likelihood.
Corresponds to the JSON property minLikelihoodPerInfoType
6538 6539 6540 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6538 def min_likelihood_per_info_type @min_likelihood_per_info_type end |
#rule_set ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRuleSet>
Set of rules to apply to the findings for this InspectConfig. Exclusion rules,
contained in the set are executed in the end, other rules are executed in the
order they are specified for each info type.
Corresponds to the JSON property ruleSet
6545 6546 6547 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6545 def rule_set @rule_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6552 6553 6554 6555 6556 6557 6558 6559 6560 6561 6562 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6552 def update!(**args) @content_options = args[:content_options] if args.key?(:content_options) @custom_info_types = args[:custom_info_types] if args.key?(:custom_info_types) @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types) @include_quote = args[:include_quote] if args.key?(:include_quote) @info_types = args[:info_types] if args.key?(:info_types) @limits = args[:limits] if args.key?(:limits) @min_likelihood = args[:min_likelihood] if args.key?(:min_likelihood) @min_likelihood_per_info_type = args[:min_likelihood_per_info_type] if args.key?(:min_likelihood_per_info_type) @rule_set = args[:rule_set] if args.key?(:rule_set) end |