Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectConfig

Returns a new instance of GooglePrivacyDlpV2InspectConfig.



6319
6320
6321
# File 'lib/google/apis/dlp_v2/classes.rb', line 6319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#content_optionsArray<String>

Deprecated and unused. Corresponds to the JSON property contentOptions

Returns:

  • (Array<String>)


6251
6252
6253
# File 'lib/google/apis/dlp_v2/classes.rb', line 6251

def content_options
  @content_options
end

#custom_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2CustomInfoType>

CustomInfoTypes provided by the user. See https://cloud.google.com/sensitive- data-protection/docs/creating-custom-infotypes to learn more. Corresponds to the JSON property customInfoTypes



6257
6258
6259
# File 'lib/google/apis/dlp_v2/classes.rb', line 6257

def custom_info_types
  @custom_info_types
end

#exclude_info_typesBoolean Also known as: exclude_info_types?

When true, excludes type information of the findings. This is not used for data profiling. Corresponds to the JSON property excludeInfoTypes

Returns:

  • (Boolean)


6263
6264
6265
# File 'lib/google/apis/dlp_v2/classes.rb', line 6263

def exclude_info_types
  @exclude_info_types
end

#include_quoteBoolean Also known as: include_quote?

When true, a contextual quote from the data that triggered a finding is included in the response; see Finding.quote. This is not used for data profiling. Corresponds to the JSON property includeQuote

Returns:

  • (Boolean)


6271
6272
6273
# File 'lib/google/apis/dlp_v2/classes.rb', line 6271

def include_quote
  @include_quote
end

#info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType>

Restricts what info_types to look for. The values must correspond to InfoType values returned by ListInfoTypes or listed at https://cloud.google.com/ sensitive-data-protection/docs/infotypes-reference. When no InfoTypes or CustomInfoTypes are specified in a request, the system may automatically choose a default list of detectors to run, which may change over time. If you need precise control and predictability as to what detectors are run you should specify specific InfoTypes listed in the reference, otherwise a default list will be used, which may change over time. Corresponds to the JSON property infoTypes



6284
6285
6286
# File 'lib/google/apis/dlp_v2/classes.rb', line 6284

def info_types
  @info_types
end

#limitsGoogle::Apis::DlpV2::GooglePrivacyDlpV2FindingLimits

Configuration to control the number of findings returned for inspection. This is not used for de-identification or data profiling. When redacting sensitive data from images, finding limits don't apply. They can cause unexpected or inconsistent results, where only some data is redacted. Don't include finding limits in RedactImage requests. Otherwise, Cloud DLP returns an error. Corresponds to the JSON property limits



6293
6294
6295
# File 'lib/google/apis/dlp_v2/classes.rb', line 6293

def limits
  @limits
end

#min_likelihoodString

Only returns findings equal to or above this threshold. The default is POSSIBLE. In general, the highest likelihood setting yields the fewest findings in results and the lowest chance of a false positive. For more information, see Match likelihood. Corresponds to the JSON property minLikelihood

Returns:

  • (String)


6302
6303
6304
# File 'lib/google/apis/dlp_v2/classes.rb', line 6302

def min_likelihood
  @min_likelihood
end

#min_likelihood_per_info_typeArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeLikelihood>

Minimum likelihood per infotype. For each infotype, a user can specify a minimum likelihood. The system only returns a finding if its likelihood is above this threshold. If this field is not set, the system uses the InspectConfig min_likelihood. Corresponds to the JSON property minLikelihoodPerInfoType



6310
6311
6312
# File 'lib/google/apis/dlp_v2/classes.rb', line 6310

def min_likelihood_per_info_type
  @min_likelihood_per_info_type
end

#rule_setArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRuleSet>

Set of rules to apply to the findings for this InspectConfig. Exclusion rules, contained in the set are executed in the end, other rules are executed in the order they are specified for each info type. Corresponds to the JSON property ruleSet



6317
6318
6319
# File 'lib/google/apis/dlp_v2/classes.rb', line 6317

def rule_set
  @rule_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6324
6325
6326
6327
6328
6329
6330
6331
6332
6333
6334
# File 'lib/google/apis/dlp_v2/classes.rb', line 6324

def update!(**args)
  @content_options = args[:content_options] if args.key?(:content_options)
  @custom_info_types = args[:custom_info_types] if args.key?(:custom_info_types)
  @exclude_info_types = args[:exclude_info_types] if args.key?(:exclude_info_types)
  @include_quote = args[:include_quote] if args.key?(:include_quote)
  @info_types = args[:info_types] if args.key?(:info_types)
  @limits = args[:limits] if args.key?(:limits)
  @min_likelihood = args[:min_likelihood] if args.key?(:min_likelihood)
  @min_likelihood_per_info_type = args[:min_likelihood_per_info_type] if args.key?(:min_likelihood_per_info_type)
  @rule_set = args[:rule_set] if args.key?(:rule_set)
end