Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to search for potentially sensitive info in a ContentItem.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectContentRequest

Returns a new instance of GooglePrivacyDlpV2InspectContentRequest.



6365
6366
6367
# File 'lib/google/apis/dlp_v2/classes.rb', line 6365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



6345
6346
6347
# File 'lib/google/apis/dlp_v2/classes.rb', line 6345

def inspect_config
  @inspect_config
end

#inspect_template_nameString

Template to use. Any configuration directly specified in inspect_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


6353
6354
6355
# File 'lib/google/apis/dlp_v2/classes.rb', line 6353

def inspect_template_name
  @inspect_template_name
end

#itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ContentItem

Type of content to inspect. Corresponds to the JSON property item



6358
6359
6360
# File 'lib/google/apis/dlp_v2/classes.rb', line 6358

def item
  @item
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


6363
6364
6365
# File 'lib/google/apis/dlp_v2/classes.rb', line 6363

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6370
6371
6372
6373
6374
6375
# File 'lib/google/apis/dlp_v2/classes.rb', line 6370

def update!(**args)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
  @item = args[:item] if args.key?(:item)
  @location_id = args[:location_id] if args.key?(:location_id)
end