Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectResult
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
All the findings for a single scanned item.
Instance Attribute Summary collapse
-
#findings ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Finding>
List of findings for an item.
-
#findings_truncated ⇒ Boolean
(also: #findings_truncated?)
If true, then this item might have more findings than were returned, and the findings returned are an arbitrary subset of all findings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectResult
constructor
A new instance of GooglePrivacyDlpV2InspectResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectResult
Returns a new instance of GooglePrivacyDlpV2InspectResult.
7186 7187 7188 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7186 def initialize(**args) update!(**args) end |
Instance Attribute Details
#findings ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Finding>
List of findings for an item.
Corresponds to the JSON property findings
7174 7175 7176 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7174 def findings @findings end |
#findings_truncated ⇒ Boolean Also known as: findings_truncated?
If true, then this item might have more findings than were returned, and the
findings returned are an arbitrary subset of all findings. The findings list
might be truncated because the input items were too large, or because the
server reached the maximum amount of resources allowed for a single API call.
For best results, divide the input into smaller batches.
Corresponds to the JSON property findingsTruncated
7183 7184 7185 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7183 def findings_truncated @findings_truncated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7191 7192 7193 7194 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7191 def update!(**args) @findings = args[:findings] if args.key?(:findings) @findings_truncated = args[:findings_truncated] if args.key?(:findings_truncated) end |