Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

All the findings for a single scanned item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectResult

Returns a new instance of GooglePrivacyDlpV2InspectResult.



6709
6710
6711
# File 'lib/google/apis/dlp_v2/classes.rb', line 6709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#findingsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Finding>

List of findings for an item. Corresponds to the JSON property findings



6697
6698
6699
# File 'lib/google/apis/dlp_v2/classes.rb', line 6697

def findings
  @findings
end

#findings_truncatedBoolean Also known as: findings_truncated?

If true, then this item might have more findings than were returned, and the findings returned are an arbitrary subset of all findings. The findings list might be truncated because the input items were too large, or because the server reached the maximum amount of resources allowed for a single API call. For best results, divide the input into smaller batches. Corresponds to the JSON property findingsTruncated

Returns:

  • (Boolean)


6706
6707
6708
# File 'lib/google/apis/dlp_v2/classes.rb', line 6706

def findings_truncated
  @findings_truncated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6714
6715
6716
6717
# File 'lib/google/apis/dlp_v2/classes.rb', line 6714

def update!(**args)
  @findings = args[:findings] if args.key?(:findings)
  @findings_truncated = args[:findings_truncated] if args.key?(:findings_truncated)
end