Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more.
Instance Attribute Summary collapse
-
#allow_limited_availability_info_types ⇒ Boolean
(also: #allow_limited_availability_info_types?)
Optional.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Short description (max 256 chars).
-
#display_name ⇒ String
Display name (max 256 chars).
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectTemplate
constructor
A new instance of GooglePrivacyDlpV2InspectTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectTemplate
Returns a new instance of GooglePrivacyDlpV2InspectTemplate.
6910 6911 6912 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6910 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_limited_availability_info_types ⇒ Boolean Also known as: allow_limited_availability_info_types?
Optional. Enables the use of limited-availability built-in infoTypes in inspect_config. These infoTypes are
supported only in specific regions and can cause scanning errors if used
elsewhere.
Corresponds to the JSON property allowLimitedAvailabilityInfoTypes
6874 6875 6876 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6874 def allow_limited_availability_info_types @allow_limited_availability_info_types end |
#create_time ⇒ String
Output only. The creation timestamp of an inspectTemplate.
Corresponds to the JSON property createTime
6880 6881 6882 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6880 def create_time @create_time end |
#description ⇒ String
Short description (max 256 chars).
Corresponds to the JSON property description
6885 6886 6887 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6885 def description @description end |
#display_name ⇒ String
Display name (max 256 chars).
Corresponds to the JSON property displayName
6890 6891 6892 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6890 def display_name @display_name end |
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
6896 6897 6898 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6896 def inspect_config @inspect_config end |
#name ⇒ String
Output only. The template name. The template will have one of the following
formats: projects/PROJECT_ID/inspectTemplates/TEMPLATE_ID OR organizations/
ORGANIZATION_ID/inspectTemplates/TEMPLATE_ID;
Corresponds to the JSON property name
6903 6904 6905 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6903 def name @name end |
#update_time ⇒ String
Output only. The last update timestamp of an inspectTemplate.
Corresponds to the JSON property updateTime
6908 6909 6910 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6908 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6915 6916 6917 6918 6919 6920 6921 6922 6923 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6915 def update!(**args) @allow_limited_availability_info_types = args[:allow_limited_availability_info_types] if args.key?(:allow_limited_availability_info_types) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |