Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Short description (max 256 chars).
-
#display_name ⇒ String
Display name (max 256 chars).
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectTemplate
constructor
A new instance of GooglePrivacyDlpV2InspectTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2InspectTemplate
Returns a new instance of GooglePrivacyDlpV2InspectTemplate.
6760 6761 6762 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6760 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of an inspectTemplate.
Corresponds to the JSON property createTime
6730 6731 6732 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6730 def create_time @create_time end |
#description ⇒ String
Short description (max 256 chars).
Corresponds to the JSON property description
6735 6736 6737 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6735 def description @description end |
#display_name ⇒ String
Display name (max 256 chars).
Corresponds to the JSON property displayName
6740 6741 6742 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6740 def display_name @display_name end |
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
6746 6747 6748 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6746 def inspect_config @inspect_config end |
#name ⇒ String
Output only. The template name. The template will have one of the following
formats: projects/PROJECT_ID/inspectTemplates/TEMPLATE_ID OR organizations/
ORGANIZATION_ID/inspectTemplates/TEMPLATE_ID;
Corresponds to the JSON property name
6753 6754 6755 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6753 def name @name end |
#update_time ⇒ String
Output only. The last update timestamp of an inspectTemplate.
Corresponds to the JSON property updateTime
6758 6759 6760 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6758 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6765 6766 6767 6768 6769 6770 6771 6772 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6765 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |