Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectTemplate

Returns a new instance of GooglePrivacyDlpV2InspectTemplate.



6532
6533
6534
# File 'lib/google/apis/dlp_v2/classes.rb', line 6532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of an inspectTemplate. Corresponds to the JSON property createTime

Returns:

  • (String)


6502
6503
6504
# File 'lib/google/apis/dlp_v2/classes.rb', line 6502

def create_time
  @create_time
end

#descriptionString

Short description (max 256 chars). Corresponds to the JSON property description

Returns:

  • (String)


6507
6508
6509
# File 'lib/google/apis/dlp_v2/classes.rb', line 6507

def description
  @description
end

#display_nameString

Display name (max 256 chars). Corresponds to the JSON property displayName

Returns:

  • (String)


6512
6513
6514
# File 'lib/google/apis/dlp_v2/classes.rb', line 6512

def display_name
  @display_name
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



6518
6519
6520
# File 'lib/google/apis/dlp_v2/classes.rb', line 6518

def inspect_config
  @inspect_config
end

#nameString

Output only. The template name. The template will have one of the following formats: projects/PROJECT_ID/inspectTemplates/TEMPLATE_ID OR organizations/ ORGANIZATION_ID/inspectTemplates/TEMPLATE_ID; Corresponds to the JSON property name

Returns:

  • (String)


6525
6526
6527
# File 'lib/google/apis/dlp_v2/classes.rb', line 6525

def name
  @name
end

#update_timeString

Output only. The last update timestamp of an inspectTemplate. Corresponds to the JSON property updateTime

Returns:

  • (String)


6530
6531
6532
# File 'lib/google/apis/dlp_v2/classes.rb', line 6530

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6537
6538
6539
6540
6541
6542
6543
6544
# File 'lib/google/apis/dlp_v2/classes.rb', line 6537

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end