Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A single inspection rule to be applied to infoTypes, specified in InspectionRuleSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectionRule

Returns a new instance of GooglePrivacyDlpV2InspectionRule.



7293
7294
7295
# File 'lib/google/apis/dlp_v2/classes.rb', line 7293

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule

Rule that specifies conditions when a certain infoType's finding details should be adjusted. Corresponds to the JSON property adjustmentRule



7279
7280
7281
# File 'lib/google/apis/dlp_v2/classes.rb', line 7279

def adjustment_rule
  @adjustment_rule
end

#exclusion_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule

The rule that specifies conditions when findings of infoTypes specified in InspectionRuleSet are removed from results. Corresponds to the JSON property exclusionRule



7285
7286
7287
# File 'lib/google/apis/dlp_v2/classes.rb', line 7285

def exclusion_rule
  @exclusion_rule
end

#hotword_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2HotwordRule

The rule that adjusts the likelihood of findings within a certain proximity of hotwords. Corresponds to the JSON property hotwordRule



7291
7292
7293
# File 'lib/google/apis/dlp_v2/classes.rb', line 7291

def hotword_rule
  @hotword_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7298
7299
7300
7301
7302
# File 'lib/google/apis/dlp_v2/classes.rb', line 7298

def update!(**args)
  @adjustment_rule = args[:adjustment_rule] if args.key?(:adjustment_rule)
  @exclusion_rule = args[:exclusion_rule] if args.key?(:exclusion_rule)
  @hotword_rule = args[:hotword_rule] if args.key?(:hotword_rule)
end