Class: Google::Apis::DlpV2::GooglePrivacyDlpV2InspectionRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A single inspection rule to be applied to infoTypes, specified in InspectionRuleSet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2InspectionRule

Returns a new instance of GooglePrivacyDlpV2InspectionRule.



6798
6799
6800
# File 'lib/google/apis/dlp_v2/classes.rb', line 6798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adjustment_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2AdjustmentRule

Rule that specifies conditions when a certain infoType's finding details should be adjusted. Corresponds to the JSON property adjustmentRule



6784
6785
6786
# File 'lib/google/apis/dlp_v2/classes.rb', line 6784

def adjustment_rule
  @adjustment_rule
end

#exclusion_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2ExclusionRule

The rule that specifies conditions when findings of infoTypes specified in InspectionRuleSet are removed from results. Corresponds to the JSON property exclusionRule



6790
6791
6792
# File 'lib/google/apis/dlp_v2/classes.rb', line 6790

def exclusion_rule
  @exclusion_rule
end

#hotword_ruleGoogle::Apis::DlpV2::GooglePrivacyDlpV2HotwordRule

The rule that adjusts the likelihood of findings within a certain proximity of hotwords. Corresponds to the JSON property hotwordRule



6796
6797
6798
# File 'lib/google/apis/dlp_v2/classes.rb', line 6796

def hotword_rule
  @hotword_rule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6803
6804
6805
6806
6807
# File 'lib/google/apis/dlp_v2/classes.rb', line 6803

def update!(**args)
  @adjustment_rule = args[:adjustment_rule] if args.key?(:adjustment_rule)
  @exclusion_rule = args[:exclusion_rule] if args.key?(:exclusion_rule)
  @hotword_rule = args[:hotword_rule] if args.key?(:hotword_rule)
end