Class: Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Contains a configuration to make API calls on a repeating basis. See https:// docs.cloud.google.com/sensitive-data-protection/docs/concepts-job-triggers to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2JobTrigger

Returns a new instance of GooglePrivacyDlpV2JobTrigger.



7413
7414
7415
# File 'lib/google/apis/dlp_v2/classes.rb', line 7413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of a triggeredJob. Corresponds to the JSON property createTime

Returns:

  • (String)


7359
7360
7361
# File 'lib/google/apis/dlp_v2/classes.rb', line 7359

def create_time
  @create_time
end

#descriptionString

User provided description (max 256 chars) Corresponds to the JSON property description

Returns:

  • (String)


7364
7365
7366
# File 'lib/google/apis/dlp_v2/classes.rb', line 7364

def description
  @description
end

#display_nameString

Display name (max 100 chars) Corresponds to the JSON property displayName

Returns:

  • (String)


7369
7370
7371
# File 'lib/google/apis/dlp_v2/classes.rb', line 7369

def display_name
  @display_name
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

Output only. A stream of errors encountered when the trigger was activated. Repeated errors may result in the JobTrigger automatically being paused. Will return the last 100 errors. Whenever the JobTrigger is modified this list will be cleared. Corresponds to the JSON property errors



7377
7378
7379
# File 'lib/google/apis/dlp_v2/classes.rb', line 7377

def errors
  @errors
end

#inspect_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig

Controls what and how to inspect for findings. Corresponds to the JSON property inspectJob



7382
7383
7384
# File 'lib/google/apis/dlp_v2/classes.rb', line 7382

def inspect_job
  @inspect_job
end

#last_run_timeString

Output only. The timestamp of the last time this trigger executed. Corresponds to the JSON property lastRunTime

Returns:

  • (String)


7387
7388
7389
# File 'lib/google/apis/dlp_v2/classes.rb', line 7387

def last_run_time
  @last_run_time
end

#nameString

Output only. Unique resource name for the triggeredJob, assigned by the service when the triggeredJob is created, for example projects/dlp-test- project/jobTriggers/53234423. Corresponds to the JSON property name

Returns:

  • (String)


7394
7395
7396
# File 'lib/google/apis/dlp_v2/classes.rb', line 7394

def name
  @name
end

#statusString

Required. A status for this trigger. Corresponds to the JSON property status

Returns:

  • (String)


7399
7400
7401
# File 'lib/google/apis/dlp_v2/classes.rb', line 7399

def status
  @status
end

#triggersArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Trigger>

A list of triggers which will be OR'ed together. Only one in the list needs to trigger for a job to be started. The list may contain only a single Schedule trigger and must have at least one object. Corresponds to the JSON property triggers



7406
7407
7408
# File 'lib/google/apis/dlp_v2/classes.rb', line 7406

def triggers
  @triggers
end

#update_timeString

Output only. The last update timestamp of a triggeredJob. Corresponds to the JSON property updateTime

Returns:

  • (String)


7411
7412
7413
# File 'lib/google/apis/dlp_v2/classes.rb', line 7411

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
# File 'lib/google/apis/dlp_v2/classes.rb', line 7418

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_job = args[:inspect_job] if args.key?(:inspect_job)
  @last_run_time = args[:last_run_time] if args.key?(:last_run_time)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @triggers = args[:triggers] if args.key?(:triggers)
  @update_time = args[:update_time] if args.key?(:update_time)
end