Class: Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Contains a configuration to make API calls on a repeating basis. See https:// cloud.google.com/sensitive-data-protection/docs/concepts-job-triggers to learn more.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
User provided description (max 256 chars) Corresponds to the JSON property
description. -
#display_name ⇒ String
Display name (max 100 chars) Corresponds to the JSON property
displayName. -
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only.
-
#inspect_job ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig
Controls what and how to inspect for findings.
-
#last_run_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#status ⇒ String
Required.
-
#triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Trigger>
A list of triggers which will be OR'ed together.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2JobTrigger
constructor
A new instance of GooglePrivacyDlpV2JobTrigger.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2JobTrigger
Returns a new instance of GooglePrivacyDlpV2JobTrigger.
7409 7410 7411 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The creation timestamp of a triggeredJob.
Corresponds to the JSON property createTime
7355 7356 7357 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7355 def create_time @create_time end |
#description ⇒ String
User provided description (max 256 chars)
Corresponds to the JSON property description
7360 7361 7362 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7360 def description @description end |
#display_name ⇒ String
Display name (max 100 chars)
Corresponds to the JSON property displayName
7365 7366 7367 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7365 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>
Output only. A stream of errors encountered when the trigger was activated.
Repeated errors may result in the JobTrigger automatically being paused. Will
return the last 100 errors. Whenever the JobTrigger is modified this list will
be cleared.
Corresponds to the JSON property errors
7373 7374 7375 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7373 def errors @errors end |
#inspect_job ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig
Controls what and how to inspect for findings.
Corresponds to the JSON property inspectJob
7378 7379 7380 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7378 def inspect_job @inspect_job end |
#last_run_time ⇒ String
Output only. The timestamp of the last time this trigger executed.
Corresponds to the JSON property lastRunTime
7383 7384 7385 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7383 def last_run_time @last_run_time end |
#name ⇒ String
Output only. Unique resource name for the triggeredJob, assigned by the
service when the triggeredJob is created, for example projects/dlp-test-
project/jobTriggers/53234423.
Corresponds to the JSON property name
7390 7391 7392 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7390 def name @name end |
#status ⇒ String
Required. A status for this trigger.
Corresponds to the JSON property status
7395 7396 7397 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7395 def status @status end |
#triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Trigger>
A list of triggers which will be OR'ed together. Only one in the list needs to
trigger for a job to be started. The list may contain only a single Schedule
trigger and must have at least one object.
Corresponds to the JSON property triggers
7402 7403 7404 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7402 def triggers @triggers end |
#update_time ⇒ String
Output only. The last update timestamp of a triggeredJob.
Corresponds to the JSON property updateTime
7407 7408 7409 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7407 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7414 7415 7416 7417 7418 7419 7420 7421 7422 7423 7424 7425 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7414 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @inspect_job = args[:inspect_job] if args.key?(:inspect_job) @last_run_time = args[:last_run_time] if args.key?(:last_run_time) @name = args[:name] if args.key?(:name) @status = args[:status] if args.key?(:status) @triggers = args[:triggers] if args.key?(:triggers) @update_time = args[:update_time] if args.key?(:update_time) end |