Class: Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Contains a configuration to make API calls on a repeating basis. See https:// cloud.google.com/sensitive-data-protection/docs/concepts-job-triggers to learn more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2JobTrigger

Returns a new instance of GooglePrivacyDlpV2JobTrigger.



7115
7116
7117
# File 'lib/google/apis/dlp_v2/classes.rb', line 7115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The creation timestamp of a triggeredJob. Corresponds to the JSON property createTime

Returns:

  • (String)


7061
7062
7063
# File 'lib/google/apis/dlp_v2/classes.rb', line 7061

def create_time
  @create_time
end

#descriptionString

User provided description (max 256 chars) Corresponds to the JSON property description

Returns:

  • (String)


7066
7067
7068
# File 'lib/google/apis/dlp_v2/classes.rb', line 7066

def description
  @description
end

#display_nameString

Display name (max 100 chars) Corresponds to the JSON property displayName

Returns:

  • (String)


7071
7072
7073
# File 'lib/google/apis/dlp_v2/classes.rb', line 7071

def display_name
  @display_name
end

#errorsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Error>

Output only. A stream of errors encountered when the trigger was activated. Repeated errors may result in the JobTrigger automatically being paused. Will return the last 100 errors. Whenever the JobTrigger is modified this list will be cleared. Corresponds to the JSON property errors



7079
7080
7081
# File 'lib/google/apis/dlp_v2/classes.rb', line 7079

def errors
  @errors
end

#inspect_jobGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectJobConfig

Controls what and how to inspect for findings. Corresponds to the JSON property inspectJob



7084
7085
7086
# File 'lib/google/apis/dlp_v2/classes.rb', line 7084

def inspect_job
  @inspect_job
end

#last_run_timeString

Output only. The timestamp of the last time this trigger executed. Corresponds to the JSON property lastRunTime

Returns:

  • (String)


7089
7090
7091
# File 'lib/google/apis/dlp_v2/classes.rb', line 7089

def last_run_time
  @last_run_time
end

#nameString

Unique resource name for the triggeredJob, assigned by the service when the triggeredJob is created, for example projects/dlp-test-project/jobTriggers/ 53234423. Corresponds to the JSON property name

Returns:

  • (String)


7096
7097
7098
# File 'lib/google/apis/dlp_v2/classes.rb', line 7096

def name
  @name
end

#statusString

Required. A status for this trigger. Corresponds to the JSON property status

Returns:

  • (String)


7101
7102
7103
# File 'lib/google/apis/dlp_v2/classes.rb', line 7101

def status
  @status
end

#triggersArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Trigger>

A list of triggers which will be OR'ed together. Only one in the list needs to trigger for a job to be started. The list may contain only a single Schedule trigger and must have at least one object. Corresponds to the JSON property triggers



7108
7109
7110
# File 'lib/google/apis/dlp_v2/classes.rb', line 7108

def triggers
  @triggers
end

#update_timeString

Output only. The last update timestamp of a triggeredJob. Corresponds to the JSON property updateTime

Returns:

  • (String)


7113
7114
7115
# File 'lib/google/apis/dlp_v2/classes.rb', line 7113

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7120
7121
7122
7123
7124
7125
7126
7127
7128
7129
7130
7131
# File 'lib/google/apis/dlp_v2/classes.rb', line 7120

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @inspect_job = args[:inspect_job] if args.key?(:inspect_job)
  @last_run_time = args[:last_run_time] if args.key?(:last_run_time)
  @name = args[:name] if args.key?(:name)
  @status = args[:status] if args.key?(:status)
  @triggers = args[:triggers] if args.key?(:triggers)
  @update_time = args[:update_time] if args.key?(:update_time)
end