Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
k-anonymity metric, used for analysis of reidentification risk.
Instance Attribute Summary collapse
-
#entity_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
An entity in a dataset is a field or set of fields that correspond to a single person.
-
#quasi_ids ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>
Set of fields to compute k-anonymity over.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2KAnonymityConfig
constructor
A new instance of GooglePrivacyDlpV2KAnonymityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2KAnonymityConfig
Returns a new instance of GooglePrivacyDlpV2KAnonymityConfig.
6719 6720 6721 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity_id ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2EntityId
An entity in a dataset is a field or set of fields that correspond to a single
person. For example, in medical records the EntityId might be a patient
identifier, or for financial records it might be an account identifier. This
message is used when generalizations or analysis must take into account that
multiple rows correspond to the same entity.
Corresponds to the JSON property entityId
6709 6710 6711 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6709 def entity_id @entity_id end |
#quasi_ids ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>
Set of fields to compute k-anonymity over. When multiple fields are specified,
they are considered a single composite key. Structs and repeated data types
are not supported; however, nested fields are supported so long as they are
not structs themselves or nested within a repeated field.
Corresponds to the JSON property quasiIds
6717 6718 6719 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6717 def quasi_ids @quasi_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6724 6725 6726 6727 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 6724 def update!(**args) @entity_id = args[:entity_id] if args.key?(:entity_id) @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids) end |