Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Reidentifiability metric. This corresponds to a risk model similar to what is called "journalist risk" in the literature, except the attack dataset is statistically modeled instead of being perfectly known. This can be done using publicly available data (like the US Census), or using a custom statistical model (indicated as one or several BigQuery tables), or by extrapolating from the distribution of values in the input dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2KMapEstimationConfig

Returns a new instance of GooglePrivacyDlpV2KMapEstimationConfig.



7584
7585
7586
# File 'lib/google/apis/dlp_v2/classes.rb', line 7584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auxiliary_tablesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2AuxiliaryTable>

Several auxiliary tables can be used in the analysis. Each custom_tag used to tag a quasi-identifiers column must appear in exactly one column of one auxiliary table. Corresponds to the JSON property auxiliaryTables



7569
7570
7571
# File 'lib/google/apis/dlp_v2/classes.rb', line 7569

def auxiliary_tables
  @auxiliary_tables
end

#quasi_idsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2TaggedField>

Required. Fields considered to be quasi-identifiers. No two columns can have the same tag. Corresponds to the JSON property quasiIds



7575
7576
7577
# File 'lib/google/apis/dlp_v2/classes.rb', line 7575

def quasi_ids
  @quasi_ids
end

#region_codeString

ISO 3166-1 alpha-2 region code to use in the statistical modeling. Set if no column is tagged with a region-specific InfoType (like US_ZIP_5) or a region code. Corresponds to the JSON property regionCode

Returns:

  • (String)


7582
7583
7584
# File 'lib/google/apis/dlp_v2/classes.rb', line 7582

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7589
7590
7591
7592
7593
# File 'lib/google/apis/dlp_v2/classes.rb', line 7589

def update!(**args)
  @auxiliary_tables = args[:auxiliary_tables] if args.key?(:auxiliary_tables)
  @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids)
  @region_code = args[:region_code] if args.key?(:region_code)
end