Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Reidentifiability metric. This corresponds to a risk model similar to what is called "journalist risk" in the literature, except the attack dataset is statistically modeled instead of being perfectly known. This can be done using publicly available data (like the US Census), or using a custom statistical model (indicated as one or several BigQuery tables), or by extrapolating from the distribution of values in the input dataset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2KMapEstimationConfig

Returns a new instance of GooglePrivacyDlpV2KMapEstimationConfig.



7573
7574
7575
# File 'lib/google/apis/dlp_v2/classes.rb', line 7573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auxiliary_tablesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2AuxiliaryTable>

Several auxiliary tables can be used in the analysis. Each custom_tag used to tag a quasi-identifiers column must appear in exactly one column of one auxiliary table. Corresponds to the JSON property auxiliaryTables



7558
7559
7560
# File 'lib/google/apis/dlp_v2/classes.rb', line 7558

def auxiliary_tables
  @auxiliary_tables
end

#quasi_idsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2TaggedField>

Required. Fields considered to be quasi-identifiers. No two columns can have the same tag. Corresponds to the JSON property quasiIds



7564
7565
7566
# File 'lib/google/apis/dlp_v2/classes.rb', line 7564

def quasi_ids
  @quasi_ids
end

#region_codeString

ISO 3166-1 alpha-2 region code to use in the statistical modeling. Set if no column is tagged with a region-specific InfoType (like US_ZIP_5) or a region code. Corresponds to the JSON property regionCode

Returns:

  • (String)


7571
7572
7573
# File 'lib/google/apis/dlp_v2/classes.rb', line 7571

def region_code
  @region_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7578
7579
7580
7581
7582
# File 'lib/google/apis/dlp_v2/classes.rb', line 7578

def update!(**args)
  @auxiliary_tables = args[:auxiliary_tables] if args.key?(:auxiliary_tables)
  @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids)
  @region_code = args[:region_code] if args.key?(:region_code)
end