Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Reidentifiability metric. This corresponds to a risk model similar to what is called "journalist risk" in the literature, except the attack dataset is statistically modeled instead of being perfectly known. This can be done using publicly available data (like the US Census), or using a custom statistical model (indicated as one or several BigQuery tables), or by extrapolating from the distribution of values in the input dataset.
Instance Attribute Summary collapse
-
#auxiliary_tables ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2AuxiliaryTable>
Several auxiliary tables can be used in the analysis.
-
#quasi_ids ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TaggedField>
Required.
-
#region_code ⇒ String
ISO 3166-1 alpha-2 region code to use in the statistical modeling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2KMapEstimationConfig
constructor
A new instance of GooglePrivacyDlpV2KMapEstimationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2KMapEstimationConfig
Returns a new instance of GooglePrivacyDlpV2KMapEstimationConfig.
7236 7237 7238 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auxiliary_tables ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2AuxiliaryTable>
Several auxiliary tables can be used in the analysis. Each custom_tag used to
tag a quasi-identifiers column must appear in exactly one column of one
auxiliary table.
Corresponds to the JSON property auxiliaryTables
7221 7222 7223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7221 def auxiliary_tables @auxiliary_tables end |
#quasi_ids ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TaggedField>
Required. Fields considered to be quasi-identifiers. No two columns can have
the same tag.
Corresponds to the JSON property quasiIds
7227 7228 7229 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7227 def quasi_ids @quasi_ids end |
#region_code ⇒ String
ISO 3166-1 alpha-2 region code to use in the statistical modeling. Set if no
column is tagged with a region-specific InfoType (like US_ZIP_5) or a region
code.
Corresponds to the JSON property regionCode
7234 7235 7236 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7234 def region_code @region_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7241 7242 7243 7244 7245 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7241 def update!(**args) @auxiliary_tables = args[:auxiliary_tables] if args.key?(:auxiliary_tables) @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids) @region_code = args[:region_code] if args.key?(:region_code) end |