Class: Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationHistogramBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A KMapEstimationHistogramBucket message with the following values: min_anonymity: 3 max_anonymity: 5 frequency: 42 means that there are 42 records whose quasi-identifier values correspond to 3, 4 or 5 people in the overlying population. An important particular case is when min_anonymity = max_anonymity = 1: the frequency field then corresponds to the number of uniquely identifiable records.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2KMapEstimationHistogramBucket

Returns a new instance of GooglePrivacyDlpV2KMapEstimationHistogramBucket.



7165
7166
7167
# File 'lib/google/apis/dlp_v2/classes.rb', line 7165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_sizeFixnum

Number of records within these anonymity bounds. Corresponds to the JSON property bucketSize

Returns:

  • (Fixnum)


7142
7143
7144
# File 'lib/google/apis/dlp_v2/classes.rb', line 7142

def bucket_size
  @bucket_size
end

#bucket_value_countFixnum

Total number of distinct quasi-identifier tuple values in this bucket. Corresponds to the JSON property bucketValueCount

Returns:

  • (Fixnum)


7147
7148
7149
# File 'lib/google/apis/dlp_v2/classes.rb', line 7147

def bucket_value_count
  @bucket_value_count
end

#bucket_valuesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationQuasiIdValues>

Sample of quasi-identifier tuple values in this bucket. The total number of classes returned per bucket is capped at 20. Corresponds to the JSON property bucketValues



7153
7154
7155
# File 'lib/google/apis/dlp_v2/classes.rb', line 7153

def bucket_values
  @bucket_values
end

#max_anonymityFixnum

Always greater than or equal to min_anonymity. Corresponds to the JSON property maxAnonymity

Returns:

  • (Fixnum)


7158
7159
7160
# File 'lib/google/apis/dlp_v2/classes.rb', line 7158

def max_anonymity
  @max_anonymity
end

#min_anonymityFixnum

Always positive. Corresponds to the JSON property minAnonymity

Returns:

  • (Fixnum)


7163
7164
7165
# File 'lib/google/apis/dlp_v2/classes.rb', line 7163

def min_anonymity
  @min_anonymity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7170
7171
7172
7173
7174
7175
7176
# File 'lib/google/apis/dlp_v2/classes.rb', line 7170

def update!(**args)
  @bucket_size = args[:bucket_size] if args.key?(:bucket_size)
  @bucket_value_count = args[:bucket_value_count] if args.key?(:bucket_value_count)
  @bucket_values = args[:bucket_values] if args.key?(:bucket_values)
  @max_anonymity = args[:max_anonymity] if args.key?(:max_anonymity)
  @min_anonymity = args[:min_anonymity] if args.key?(:min_anonymity)
end