Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LDiversityConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

l-diversity metric, used for analysis of reidentification risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2LDiversityConfig

Returns a new instance of GooglePrivacyDlpV2LDiversityConfig.



7545
7546
7547
# File 'lib/google/apis/dlp_v2/classes.rb', line 7545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#quasi_idsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId>

Set of quasi-identifiers indicating how equivalence classes are defined for the l-diversity computation. When multiple fields are specified, they are considered a single composite key. Corresponds to the JSON property quasiIds



7538
7539
7540
# File 'lib/google/apis/dlp_v2/classes.rb', line 7538

def quasi_ids
  @quasi_ids
end

#sensitive_attributeGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property sensitiveAttribute



7543
7544
7545
# File 'lib/google/apis/dlp_v2/classes.rb', line 7543

def sensitive_attribute
  @sensitive_attribute
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7550
7551
7552
7553
# File 'lib/google/apis/dlp_v2/classes.rb', line 7550

def update!(**args)
  @quasi_ids = args[:quasi_ids] if args.key?(:quasi_ids)
  @sensitive_attribute = args[:sensitive_attribute] if args.key?(:sensitive_attribute)
end