Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LDiversityHistogramBucket

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Histogram of l-diversity equivalence class sensitive value frequencies.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2LDiversityHistogramBucket

Returns a new instance of GooglePrivacyDlpV2LDiversityHistogramBucket.



7576
7577
7578
# File 'lib/google/apis/dlp_v2/classes.rb', line 7576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_sizeFixnum

Total number of equivalence classes in this bucket. Corresponds to the JSON property bucketSize

Returns:

  • (Fixnum)


7551
7552
7553
# File 'lib/google/apis/dlp_v2/classes.rb', line 7551

def bucket_size
  @bucket_size
end

#bucket_value_countFixnum

Total number of distinct equivalence classes in this bucket. Corresponds to the JSON property bucketValueCount

Returns:

  • (Fixnum)


7556
7557
7558
# File 'lib/google/apis/dlp_v2/classes.rb', line 7556

def bucket_value_count
  @bucket_value_count
end

#bucket_valuesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2LDiversityEquivalenceClass>

Sample of equivalence classes in this bucket. The total number of classes returned per bucket is capped at 20. Corresponds to the JSON property bucketValues



7562
7563
7564
# File 'lib/google/apis/dlp_v2/classes.rb', line 7562

def bucket_values
  @bucket_values
end

#sensitive_value_frequency_lower_boundFixnum

Lower bound on the sensitive value frequencies of the equivalence classes in this bucket. Corresponds to the JSON property sensitiveValueFrequencyLowerBound

Returns:

  • (Fixnum)


7568
7569
7570
# File 'lib/google/apis/dlp_v2/classes.rb', line 7568

def sensitive_value_frequency_lower_bound
  @sensitive_value_frequency_lower_bound
end

#sensitive_value_frequency_upper_boundFixnum

Upper bound on the sensitive value frequencies of the equivalence classes in this bucket. Corresponds to the JSON property sensitiveValueFrequencyUpperBound

Returns:

  • (Fixnum)


7574
7575
7576
# File 'lib/google/apis/dlp_v2/classes.rb', line 7574

def sensitive_value_frequency_upper_bound
  @sensitive_value_frequency_upper_bound
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7581
7582
7583
7584
7585
7586
7587
# File 'lib/google/apis/dlp_v2/classes.rb', line 7581

def update!(**args)
  @bucket_size = args[:bucket_size] if args.key?(:bucket_size)
  @bucket_value_count = args[:bucket_value_count] if args.key?(:bucket_value_count)
  @bucket_values = args[:bucket_values] if args.key?(:bucket_values)
  @sensitive_value_frequency_lower_bound = args[:sensitive_value_frequency_lower_bound] if args.key?(:sensitive_value_frequency_lower_bound)
  @sensitive_value_frequency_upper_bound = args[:sensitive_value_frequency_upper_bound] if args.key?(:sensitive_value_frequency_upper_bound)
end