Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LabelFieldMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The field values of the Google Drive label

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2LabelFieldMetadata

Returns a new instance of GooglePrivacyDlpV2LabelFieldMetadata.



7996
7997
7998
# File 'lib/google/apis/dlp_v2/classes.rb', line 7996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The identifier of the Label Field. Corresponds to the JSON property id

Returns:

  • (String)


7985
7986
7987
# File 'lib/google/apis/dlp_v2/classes.rb', line 7985

def id
  @id
end

#valueGoogle::Apis::DlpV2::GooglePrivacyDlpV2Value

Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data. Corresponds to the JSON property value



7994
7995
7996
# File 'lib/google/apis/dlp_v2/classes.rb', line 7994

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8001
8002
8003
8004
# File 'lib/google/apis/dlp_v2/classes.rb', line 8001

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @value = args[:value] if args.key?(:value)
end