Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for a custom dictionary created from a data source of any size up to the maximum size defined in the limits page. The artifacts of dictionary creation are stored in the specified Cloud Storage location. Consider using CustomInfoType.Dictionary for smaller dictionaries that satisfy the size requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig

Returns a new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.



8024
8025
8026
# File 'lib/google/apis/dlp_v2/classes.rb', line 8024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField

Message defining a field of a BigQuery table. Corresponds to the JSON property bigQueryField



8012
8013
8014
# File 'lib/google/apis/dlp_v2/classes.rb', line 8012

def big_query_field
  @big_query_field
end

#cloud_storage_file_setGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet

Message representing a set of files in Cloud Storage. Corresponds to the JSON property cloudStorageFileSet



8017
8018
8019
# File 'lib/google/apis/dlp_v2/classes.rb', line 8017

def cloud_storage_file_set
  @cloud_storage_file_set
end

#output_pathGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath

Message representing a single file or path in Cloud Storage. Corresponds to the JSON property outputPath



8022
8023
8024
# File 'lib/google/apis/dlp_v2/classes.rb', line 8022

def output_path
  @output_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8029
8030
8031
8032
8033
# File 'lib/google/apis/dlp_v2/classes.rb', line 8029

def update!(**args)
  @big_query_field = args[:big_query_field] if args.key?(:big_query_field)
  @cloud_storage_file_set = args[:cloud_storage_file_set] if args.key?(:cloud_storage_file_set)
  @output_path = args[:output_path] if args.key?(:output_path)
end