Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for a custom dictionary created from a data source of any size
up to the maximum size defined in the limits page. The artifacts of dictionary creation
are stored in the specified Cloud Storage location. Consider using
CustomInfoType.Dictionary for smaller dictionaries that satisfy the size
requirements.
Instance Attribute Summary collapse
-
#big_query_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField
Message defining a field of a BigQuery table.
-
#cloud_storage_file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet
Message representing a set of files in Cloud Storage.
-
#output_path ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath
Message representing a single file or path in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig
constructor
A new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig
Returns a new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.
7683 7684 7685 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField
Message defining a field of a BigQuery table.
Corresponds to the JSON property bigQueryField
7671 7672 7673 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7671 def big_query_field @big_query_field end |
#cloud_storage_file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet
Message representing a set of files in Cloud Storage.
Corresponds to the JSON property cloudStorageFileSet
7676 7677 7678 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7676 def cloud_storage_file_set @cloud_storage_file_set end |
#output_path ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath
Message representing a single file or path in Cloud Storage.
Corresponds to the JSON property outputPath
7681 7682 7683 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7681 def output_path @output_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7688 7689 7690 7691 7692 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7688 def update!(**args) @big_query_field = args[:big_query_field] if args.key?(:big_query_field) @cloud_storage_file_set = args[:cloud_storage_file_set] if args.key?(:cloud_storage_file_set) @output_path = args[:output_path] if args.key?(:output_path) end |