Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configuration for a custom dictionary created from a data source of any size
up to the maximum size defined in the limits page. The artifacts of dictionary creation
are stored in the specified Cloud Storage location. Consider using
CustomInfoType.Dictionary for smaller dictionaries that satisfy the size
requirements.
Instance Attribute Summary collapse
-
#big_query_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField
Message defining a field of a BigQuery table.
-
#cloud_storage_file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet
Message representing a set of files in Cloud Storage.
-
#output_path ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath
Message representing a single file or path in Cloud Storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig
constructor
A new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig
Returns a new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.
7436 7437 7438 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#big_query_field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField
Message defining a field of a BigQuery table.
Corresponds to the JSON property bigQueryField
7424 7425 7426 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7424 def big_query_field @big_query_field end |
#cloud_storage_file_set ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet
Message representing a set of files in Cloud Storage.
Corresponds to the JSON property cloudStorageFileSet
7429 7430 7431 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7429 def cloud_storage_file_set @cloud_storage_file_set end |
#output_path ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath
Message representing a single file or path in Cloud Storage.
Corresponds to the JSON property outputPath
7434 7435 7436 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7434 def output_path @output_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7441 7442 7443 7444 7445 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7441 def update!(**args) @big_query_field = args[:big_query_field] if args.key?(:big_query_field) @cloud_storage_file_set = args[:cloud_storage_file_set] if args.key?(:cloud_storage_file_set) @output_path = args[:output_path] if args.key?(:output_path) end |