Class: Google::Apis::DlpV2::GooglePrivacyDlpV2LargeCustomDictionaryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configuration for a custom dictionary created from a data source of any size up to the maximum size defined in the limits page. The artifacts of dictionary creation are stored in the specified Cloud Storage location. Consider using CustomInfoType.Dictionary for smaller dictionaries that satisfy the size requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2LargeCustomDictionaryConfig

Returns a new instance of GooglePrivacyDlpV2LargeCustomDictionaryConfig.



7201
7202
7203
# File 'lib/google/apis/dlp_v2/classes.rb', line 7201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryField

Message defining a field of a BigQuery table. Corresponds to the JSON property bigQueryField



7189
7190
7191
# File 'lib/google/apis/dlp_v2/classes.rb', line 7189

def big_query_field
  @big_query_field
end

#cloud_storage_file_setGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageFileSet

Message representing a set of files in Cloud Storage. Corresponds to the JSON property cloudStorageFileSet



7194
7195
7196
# File 'lib/google/apis/dlp_v2/classes.rb', line 7194

def cloud_storage_file_set
  @cloud_storage_file_set
end

#output_pathGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath

Message representing a single file or path in Cloud Storage. Corresponds to the JSON property outputPath



7199
7200
7201
# File 'lib/google/apis/dlp_v2/classes.rb', line 7199

def output_path
  @output_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7206
7207
7208
7209
7210
# File 'lib/google/apis/dlp_v2/classes.rb', line 7206

def update!(**args)
  @big_query_field = args[:big_query_field] if args.key?(:big_query_field)
  @cloud_storage_file_set = args[:cloud_storage_file_set] if args.key?(:cloud_storage_file_set)
  @output_path = args[:output_path] if args.key?(:output_path)
end