Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListDiscoveryConfigsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ListDiscoveryConfigsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Response message for ListDiscoveryConfigs.
Instance Attribute Summary collapse
-
#discovery_configs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig>
List of configs, up to page_size in ListDiscoveryConfigsRequest.
-
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be used in the following ListDiscoveryConfigs request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ListDiscoveryConfigsResponse
constructor
A new instance of GooglePrivacyDlpV2ListDiscoveryConfigsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ListDiscoveryConfigsResponse
Returns a new instance of GooglePrivacyDlpV2ListDiscoveryConfigsResponse.
8221 8222 8223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovery_configs ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig>
List of configs, up to page_size in ListDiscoveryConfigsRequest.
Corresponds to the JSON property discoveryConfigs
8213 8214 8215 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8213 def discovery_configs @discovery_configs end |
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be
used in the following ListDiscoveryConfigs request.
Corresponds to the JSON property nextPageToken
8219 8220 8221 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8219 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8226 8227 8228 8229 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8226 def update!(**args) @discovery_configs = args[:discovery_configs] if args.key?(:discovery_configs) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |