Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListDiscoveryConfigsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Response message for ListDiscoveryConfigs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ListDiscoveryConfigsResponse

Returns a new instance of GooglePrivacyDlpV2ListDiscoveryConfigsResponse.



7854
7855
7856
# File 'lib/google/apis/dlp_v2/classes.rb', line 7854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_configsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig>

List of configs, up to page_size in ListDiscoveryConfigsRequest. Corresponds to the JSON property discoveryConfigs



7846
7847
7848
# File 'lib/google/apis/dlp_v2/classes.rb', line 7846

def discovery_configs
  @discovery_configs
end

#next_page_tokenString

If the next page is available then this value is the next page token to be used in the following ListDiscoveryConfigs request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7852
7853
7854
# File 'lib/google/apis/dlp_v2/classes.rb', line 7852

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7859
7860
7861
7862
# File 'lib/google/apis/dlp_v2/classes.rb', line 7859

def update!(**args)
  @discovery_configs = args[:discovery_configs] if args.key?(:discovery_configs)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end