Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListJobTriggersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Response message for ListJobTriggers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ListJobTriggersResponse

Returns a new instance of GooglePrivacyDlpV2ListJobTriggersResponse.



8353
8354
8355
# File 'lib/google/apis/dlp_v2/classes.rb', line 8353

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#job_triggersArray<Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger>

List of triggeredJobs, up to page_size in ListJobTriggersRequest. Corresponds to the JSON property jobTriggers



8345
8346
8347
# File 'lib/google/apis/dlp_v2/classes.rb', line 8345

def job_triggers
  @job_triggers
end

#next_page_tokenString

If the next page is available then this value is the next page token to be used in the following ListJobTriggers request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8351
8352
8353
# File 'lib/google/apis/dlp_v2/classes.rb', line 8351

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8358
8359
8360
8361
# File 'lib/google/apis/dlp_v2/classes.rb', line 8358

def update!(**args)
  @job_triggers = args[:job_triggers] if args.key?(:job_triggers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end