Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListJobTriggersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ListJobTriggersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Response message for ListJobTriggers.
Instance Attribute Summary collapse
-
#job_triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger>
List of triggeredJobs, up to page_size in ListJobTriggersRequest.
-
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be used in the following ListJobTriggers request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ListJobTriggersResponse
constructor
A new instance of GooglePrivacyDlpV2ListJobTriggersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ListJobTriggersResponse
Returns a new instance of GooglePrivacyDlpV2ListJobTriggersResponse.
8349 8350 8351 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger>
List of triggeredJobs, up to page_size in ListJobTriggersRequest.
Corresponds to the JSON property jobTriggers
8341 8342 8343 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8341 def job_triggers @job_triggers end |
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be
used in the following ListJobTriggers request.
Corresponds to the JSON property nextPageToken
8347 8348 8349 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8347 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8354 8355 8356 8357 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8354 def update!(**args) @job_triggers = args[:job_triggers] if args.key?(:job_triggers) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |