Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ListJobTriggersResponse
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ListJobTriggersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Response message for ListJobTriggers.
Instance Attribute Summary collapse
-
#job_triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger>
List of triggeredJobs, up to page_size in ListJobTriggersRequest.
-
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be used in the following ListJobTriggers request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ListJobTriggersResponse
constructor
A new instance of GooglePrivacyDlpV2ListJobTriggersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ListJobTriggersResponse
Returns a new instance of GooglePrivacyDlpV2ListJobTriggersResponse.
7807 7808 7809 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7807 def initialize(**args) update!(**args) end |
Instance Attribute Details
#job_triggers ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2JobTrigger>
List of triggeredJobs, up to page_size in ListJobTriggersRequest.
Corresponds to the JSON property jobTriggers
7799 7800 7801 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7799 def job_triggers @job_triggers end |
#next_page_token ⇒ String
If the next page is available then this value is the next page token to be
used in the following ListJobTriggers request.
Corresponds to the JSON property nextPageToken
7805 7806 7807 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7805 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7812 7813 7814 7815 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7812 def update!(**args) @job_triggers = args[:job_triggers] if args.key?(:job_triggers) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |