Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the location of the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Location

Returns a new instance of GooglePrivacyDlpV2Location.



7920
7921
7922
# File 'lib/google/apis/dlp_v2/classes.rb', line 7920

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property byteRange



7901
7902
7903
# File 'lib/google/apis/dlp_v2/classes.rb', line 7901

def byte_range
  @byte_range
end

#codepoint_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property codepointRange



7906
7907
7908
# File 'lib/google/apis/dlp_v2/classes.rb', line 7906

def codepoint_range
  @codepoint_range
end

#containerGoogle::Apis::DlpV2::GooglePrivacyDlpV2Container

Represents a container that may contain DLP findings. Examples of a container include a file, table, or database record. Corresponds to the JSON property container



7912
7913
7914
# File 'lib/google/apis/dlp_v2/classes.rb', line 7912

def container
  @container
end

#content_locationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation>

List of nested objects pointing to the precise location of the finding within the file or record. Corresponds to the JSON property contentLocations



7918
7919
7920
# File 'lib/google/apis/dlp_v2/classes.rb', line 7918

def content_locations
  @content_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7925
7926
7927
7928
7929
7930
# File 'lib/google/apis/dlp_v2/classes.rb', line 7925

def update!(**args)
  @byte_range = args[:byte_range] if args.key?(:byte_range)
  @codepoint_range = args[:codepoint_range] if args.key?(:codepoint_range)
  @container = args[:container] if args.key?(:container)
  @content_locations = args[:content_locations] if args.key?(:content_locations)
end