Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Location

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the location of the finding.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Location

Returns a new instance of GooglePrivacyDlpV2Location.



7606
7607
7608
# File 'lib/google/apis/dlp_v2/classes.rb', line 7606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property byteRange



7587
7588
7589
# File 'lib/google/apis/dlp_v2/classes.rb', line 7587

def byte_range
  @byte_range
end

#codepoint_rangeGoogle::Apis::DlpV2::GooglePrivacyDlpV2Range

Generic half-open interval [start, end) Corresponds to the JSON property codepointRange



7592
7593
7594
# File 'lib/google/apis/dlp_v2/classes.rb', line 7592

def codepoint_range
  @codepoint_range
end

#containerGoogle::Apis::DlpV2::GooglePrivacyDlpV2Container

Represents a container that may contain DLP findings. Examples of a container include a file, table, or database record. Corresponds to the JSON property container



7598
7599
7600
# File 'lib/google/apis/dlp_v2/classes.rb', line 7598

def container
  @container
end

#content_locationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ContentLocation>

List of nested objects pointing to the precise location of the finding within the file or record. Corresponds to the JSON property contentLocations



7604
7605
7606
# File 'lib/google/apis/dlp_v2/classes.rb', line 7604

def content_locations
  @content_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7611
7612
7613
7614
7615
7616
# File 'lib/google/apis/dlp_v2/classes.rb', line 7611

def update!(**args)
  @byte_range = args[:byte_range] if args.key?(:byte_range)
  @codepoint_range = args[:codepoint_range] if args.key?(:codepoint_range)
  @container = args[:container] if args.key?(:container)
  @content_locations = args[:content_locations] if args.key?(:content_locations)
end