Class: Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Metadata Location
Instance Attribute Summary collapse
-
#key_value_metadata_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KeyValueMetadataLabel
The metadata key that contains a finding.
-
#storage_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageMetadataLabel
Storage metadata label to indicate which metadata entry contains findings.
-
#type ⇒ String
Type of metadata containing the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2MetadataLocation
constructor
A new instance of GooglePrivacyDlpV2MetadataLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2MetadataLocation
Returns a new instance of GooglePrivacyDlpV2MetadataLocation.
8017 8018 8019 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_value_metadata_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KeyValueMetadataLabel
The metadata key that contains a finding.
Corresponds to the JSON property keyValueMetadataLabel
8005 8006 8007 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8005 def @key_value_metadata_label end |
#storage_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageMetadataLabel
Storage metadata label to indicate which metadata entry contains findings.
Corresponds to the JSON property storageLabel
8010 8011 8012 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8010 def storage_label @storage_label end |
#type ⇒ String
Type of metadata containing the finding.
Corresponds to the JSON property type
8015 8016 8017 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8015 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8022 8023 8024 8025 8026 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8022 def update!(**args) @key_value_metadata_label = args[:key_value_metadata_label] if args.key?(:key_value_metadata_label) @storage_label = args[:storage_label] if args.key?(:storage_label) @type = args[:type] if args.key?(:type) end |