Class: Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2MetadataLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Metadata Location
Instance Attribute Summary collapse
-
#storage_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageMetadataLabel
Storage metadata label to indicate which metadata entry contains findings.
-
#type ⇒ String
Type of metadata containing the finding.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2MetadataLocation
constructor
A new instance of GooglePrivacyDlpV2MetadataLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2MetadataLocation
Returns a new instance of GooglePrivacyDlpV2MetadataLocation.
7672 7673 7674 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#storage_label ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2StorageMetadataLabel
Storage metadata label to indicate which metadata entry contains findings.
Corresponds to the JSON property storageLabel
7665 7666 7667 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7665 def storage_label @storage_label end |
#type ⇒ String
Type of metadata containing the finding.
Corresponds to the JSON property type
7670 7671 7672 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7670 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7677 7678 7679 7680 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7677 def update!(**args) @storage_label = args[:storage_label] if args.key?(:storage_label) @type = args[:type] if args.key?(:type) end |