Class: Google::Apis::DlpV2::GooglePrivacyDlpV2NumericalStatsResult
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2NumericalStatsResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Result of the numerical stats computation.
Instance Attribute Summary collapse
-
#max_value ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system.
-
#min_value ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system.
-
#quantile_values ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
List of 99 values that partition the set of field values into 100 equal sized buckets.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2NumericalStatsResult
constructor
A new instance of GooglePrivacyDlpV2NumericalStatsResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2NumericalStatsResult
Returns a new instance of GooglePrivacyDlpV2NumericalStatsResult.
8091 8092 8093 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system. Note that for the purposes of
inspection or transformation, the number of bytes considered to comprise a '
Value' is based on its representation as a UTF-8 encoded string. For example,
if 'integer_value' is set to 123456789, the number of bytes would be counted
as 9, even though an int64 only holds up to 8 bytes of data.
Corresponds to the JSON property maxValue
8074 8075 8076 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8074 def max_value @max_value end |
#min_value ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Value
Set of primitive values supported by the system. Note that for the purposes of
inspection or transformation, the number of bytes considered to comprise a '
Value' is based on its representation as a UTF-8 encoded string. For example,
if 'integer_value' is set to 123456789, the number of bytes would be counted
as 9, even though an int64 only holds up to 8 bytes of data.
Corresponds to the JSON property minValue
8083 8084 8085 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8083 def min_value @min_value end |
#quantile_values ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Value>
List of 99 values that partition the set of field values into 100 equal sized
buckets.
Corresponds to the JSON property quantileValues
8089 8090 8091 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8089 def quantile_values @quantile_values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8096 8097 8098 8099 8100 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8096 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) @quantile_values = args[:quantile_values] if args.key?(:quantile_values) end |