Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Project and scan location information. Only set when the parent is an org.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2OrgConfig

Returns a new instance of GooglePrivacyDlpV2OrgConfig.



8148
8149
8150
# File 'lib/google/apis/dlp_v2/classes.rb', line 8148

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryStartingLocation

The location to begin a discovery scan. Denotes an organization ID or folder ID within an organization. Corresponds to the JSON property location



8139
8140
8141
# File 'lib/google/apis/dlp_v2/classes.rb', line 8139

def location
  @location
end

#project_idString

The project that will run the scan. The DLP service account that exists within this project must have access to all resources that are profiled, and the DLP API must be enabled. Corresponds to the JSON property projectId

Returns:

  • (String)


8146
8147
8148
# File 'lib/google/apis/dlp_v2/classes.rb', line 8146

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8153
8154
8155
8156
# File 'lib/google/apis/dlp_v2/classes.rb', line 8153

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @project_id = args[:project_id] if args.key?(:project_id)
end