Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OrgConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Project and scan location information. Only set when the parent is an org.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2OrgConfig

Returns a new instance of GooglePrivacyDlpV2OrgConfig.



8037
8038
8039
# File 'lib/google/apis/dlp_v2/classes.rb', line 8037

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryStartingLocation

The location to begin a discovery scan. Denotes an organization ID or folder ID within an organization. Corresponds to the JSON property location



8028
8029
8030
# File 'lib/google/apis/dlp_v2/classes.rb', line 8028

def location
  @location
end

#project_idString

The project that will run the scan. The DLP service account that exists within this project must have access to all resources that are profiled, and the DLP API must be enabled. Corresponds to the JSON property projectId

Returns:

  • (String)


8035
8036
8037
# File 'lib/google/apis/dlp_v2/classes.rb', line 8035

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8042
8043
8044
8045
# File 'lib/google/apis/dlp_v2/classes.rb', line 8042

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @project_id = args[:project_id] if args.key?(:project_id)
end