Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Target used to match against for discovery of resources from other clouds. An AWS connector in Security Command Center (Enterprise is required to use this feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2OtherCloudDiscoveryTarget.



8331
8332
8333
# File 'lib/google/apis/dlp_v2/classes.rb', line 8331

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions

Requirements that must be true before a resource is profiled for the first time. Corresponds to the JSON property conditions



8307
8308
8309
# File 'lib/google/apis/dlp_v2/classes.rb', line 8307

def conditions
  @conditions
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



8312
8313
8314
# File 'lib/google/apis/dlp_v2/classes.rb', line 8312

def data_source_type
  @data_source_type
end

#disabledGoogle::Apis::DlpV2::GooglePrivacyDlpV2Disabled

Do not profile the tables. Corresponds to the JSON property disabled



8317
8318
8319
# File 'lib/google/apis/dlp_v2/classes.rb', line 8317

def disabled
  @disabled
end

#filterGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter

Determines which resources from the other cloud will have profiles generated. Includes the ability to filter by resource names. Corresponds to the JSON property filter



8323
8324
8325
# File 'lib/google/apis/dlp_v2/classes.rb', line 8323

def filter
  @filter
end

#generation_cadenceGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence

How often existing resources should have their profiles refreshed. New resources are scanned as quickly as possible depending on system capacity. Corresponds to the JSON property generationCadence



8329
8330
8331
# File 'lib/google/apis/dlp_v2/classes.rb', line 8329

def generation_cadence
  @generation_cadence
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8336
8337
8338
8339
8340
8341
8342
# File 'lib/google/apis/dlp_v2/classes.rb', line 8336

def update!(**args)
  @conditions = args[:conditions] if args.key?(:conditions)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @disabled = args[:disabled] if args.key?(:disabled)
  @filter = args[:filter] if args.key?(:filter)
  @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence)
end