Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery of resources from other clouds. An AWS connector in Security Command Center (Enterprise is required to use this feature.
Instance Attribute Summary collapse
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
Requirements that must be true before a resource is profiled for the first time.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
Determines which resources from the other cloud will have profiles generated.
-
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
How often existing resources should have their profiles refreshed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2OtherCloudDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2OtherCloudDiscoveryTarget.
8102 8103 8104 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
Requirements that must be true before a resource is profiled for the first
time.
Corresponds to the JSON property conditions
8078 8079 8080 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8078 def conditions @conditions end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
8083 8084 8085 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8083 def data_source_type @data_source_type end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
8088 8089 8090 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8088 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
Determines which resources from the other cloud will have profiles generated.
Includes the ability to filter by resource names.
Corresponds to the JSON property filter
8094 8095 8096 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8094 def filter @filter end |
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
How often existing resources should have their profiles refreshed. New
resources are scanned as quickly as possible depending on system capacity.
Corresponds to the JSON property generationCadence
8100 8101 8102 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8100 def generation_cadence @generation_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8107 8108 8109 8110 8111 8112 8113 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8107 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence) end |