Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery of resources from other clouds. An AWS connector in Security Command Center (Enterprise is required to use this feature.
Instance Attribute Summary collapse
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
Requirements that must be true before a resource is profiled for the first time.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
Determines which resources from the other cloud will have profiles generated.
-
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
How often existing resources should have their profiles refreshed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2OtherCloudDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2OtherCloudDiscoveryTarget.
7867 7868 7869 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudConditions
Requirements that must be true before a resource is profiled for the first
time.
Corresponds to the JSON property conditions
7843 7844 7845 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7843 def conditions @conditions end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
7848 7849 7850 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7848 def data_source_type @data_source_type end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
7853 7854 7855 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7853 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudFilter
Determines which resources from the other cloud will have profiles generated.
Includes the ability to filter by resource names.
Corresponds to the JSON property filter
7859 7860 7861 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7859 def filter @filter end |
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryOtherCloudGenerationCadence
How often existing resources should have their profiles refreshed. New
resources are scanned as quickly as possible depending on system capacity.
Corresponds to the JSON property generationCadence
7865 7866 7867 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7865 def generation_cadence @generation_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7872 7873 7874 7875 7876 7877 7878 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 7872 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence) end |