Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A collection of regular expressions to determine what resources to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes

Returns a new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.



8865
8866
8867
# File 'lib/google/apis/dlp_v2/classes.rb', line 8865

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patternsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>

A group of regular expression patterns to match against one or more resources. Maximum of 100 entries. The sum of all regular expression's length can't exceed 10 KiB. Corresponds to the JSON property patterns



8863
8864
8865
# File 'lib/google/apis/dlp_v2/classes.rb', line 8863

def patterns
  @patterns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8870
8871
8872
# File 'lib/google/apis/dlp_v2/classes.rb', line 8870

def update!(**args)
  @patterns = args[:patterns] if args.key?(:patterns)
end