Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A collection of regular expressions to determine what resources to match against.
Instance Attribute Summary collapse
-
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
constructor
A new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
Returns a new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
8398 8399 8400 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Maximum of 100 entries. The sum of all regular expression's length can't
exceed 10 KiB.
Corresponds to the JSON property patterns
8396 8397 8398 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8396 def patterns @patterns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8403 8404 8405 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8403 def update!(**args) @patterns = args[:patterns] if args.key?(:patterns) end |