Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A collection of regular expressions to determine what resources to match against.
Instance Attribute Summary collapse
-
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
constructor
A new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
Returns a new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
8280 8281 8282 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Maximum of 100 entries. The sum of all regular expression's length can't
exceed 10 KiB.
Corresponds to the JSON property patterns
8278 8279 8280 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8278 def patterns @patterns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8285 8286 8287 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8285 def update!(**args) @patterns = args[:patterns] if args.key?(:patterns) end |