Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegexes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A collection of regular expressions to determine what resources to match against.
Instance Attribute Summary collapse
-
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
constructor
A new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2OtherCloudResourceRegexes
Returns a new instance of GooglePrivacyDlpV2OtherCloudResourceRegexes.
8169 8170 8171 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherCloudResourceRegex>
A group of regular expression patterns to match against one or more resources.
Maximum of 100 entries. The sum of all regular expression's length can't
exceed 10 KiB.
Corresponds to the JSON property patterns
8167 8168 8169 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8167 def patterns @patterns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8174 8175 8176 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8174 def update!(**args) @patterns = args[:patterns] if args.key?(:patterns) end |