Class: Google::Apis::DlpV2::GooglePrivacyDlpV2OutputStorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Cloud repository for storing output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2OutputStorageConfig

Returns a new instance of GooglePrivacyDlpV2OutputStorageConfig.



8025
8026
8027
# File 'lib/google/apis/dlp_v2/classes.rb', line 8025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#output_schemaString

Schema used for writing the findings for Inspect jobs. This field is only used for Inspect and must be unspecified for Risk jobs. Columns are derived from the Finding object. If appending to an existing table, any columns from the predefined schema that are missing will be added. No columns in the existing table will be deleted. If unspecified, then all available columns will be used for a new table or an (existing) table with no schema, and no changes will be made to an existing table that has a schema. Only for use with external storage. Corresponds to the JSON property outputSchema

Returns:

  • (String)


8011
8012
8013
# File 'lib/google/apis/dlp_v2/classes.rb', line 8011

def output_schema
  @output_schema
end

#storage_pathGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStoragePath

Message representing a single file or path in Cloud Storage. Corresponds to the JSON property storagePath



8016
8017
8018
# File 'lib/google/apis/dlp_v2/classes.rb', line 8016

def storage_path
  @storage_path
end

#tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property table



8023
8024
8025
# File 'lib/google/apis/dlp_v2/classes.rb', line 8023

def table
  @table
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8030
8031
8032
8033
8034
# File 'lib/google/apis/dlp_v2/classes.rb', line 8030

def update!(**args)
  @output_schema = args[:output_schema] if args.key?(:output_schema)
  @storage_path = args[:storage_path] if args.key?(:storage_path)
  @table = args[:table] if args.key?(:table)
end