Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PartitionId

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Datastore partition ID. A partition ID identifies a grouping of entities. The grouping is always by project and namespace, however the namespace ID may be empty. A partition ID contains several dimensions: project ID and namespace ID.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PartitionId

Returns a new instance of GooglePrivacyDlpV2PartitionId.



8301
8302
8303
# File 'lib/google/apis/dlp_v2/classes.rb', line 8301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_idString

If not empty, the ID of the namespace to which the entities belong. Corresponds to the JSON property namespaceId

Returns:

  • (String)


8294
8295
8296
# File 'lib/google/apis/dlp_v2/classes.rb', line 8294

def namespace_id
  @namespace_id
end

#project_idString

The ID of the project to which the entities belong. Corresponds to the JSON property projectId

Returns:

  • (String)


8299
8300
8301
# File 'lib/google/apis/dlp_v2/classes.rb', line 8299

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8306
8307
8308
8309
# File 'lib/google/apis/dlp_v2/classes.rb', line 8306

def update!(**args)
  @namespace_id = args[:namespace_id] if args.key?(:namespace_id)
  @project_id = args[:project_id] if args.key?(:project_id)
end