Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2PolicyAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A possible action to take when applying a content policy.
Instance Attribute Summary collapse
-
#return_verdict ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2PolicyAction
constructor
A new instance of GooglePrivacyDlpV2PolicyAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2PolicyAction
Returns a new instance of GooglePrivacyDlpV2PolicyAction.
9053 9054 9055 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#return_verdict ⇒ String
Optional. If set, the verdict will be returned to the user.
Corresponds to the JSON property returnVerdict
9051 9052 9053 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9051 def return_verdict @return_verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9058 9059 9060 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9058 def update!(**args) @return_verdict = args[:return_verdict] if args.key?(:return_verdict) end |