Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PrivacyMetric
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2PrivacyMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Privacy metric to compute for reidentification risk analysis.
Instance Attribute Summary collapse
-
#categorical_stats_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig
Compute numerical stats over an individual column, including number of distinct values and value count distribution.
-
#delta_presence_estimation_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeltaPresenceEstimationConfig
δ-presence metric, used to estimate how likely it is for an attacker to figure out that one given individual appears in a de-identified dataset.
-
#k_anonymity_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig
k-anonymity metric, used for analysis of reidentification risk.
-
#k_map_estimation_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig
Reidentifiability metric.
-
#l_diversity_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LDiversityConfig
l-diversity metric, used for analysis of reidentification risk.
-
#numerical_stats_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2NumericalStatsConfig
Compute numerical stats over an individual column, including min, max, and quantiles.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2PrivacyMetric
constructor
A new instance of GooglePrivacyDlpV2PrivacyMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2PrivacyMetric
Returns a new instance of GooglePrivacyDlpV2PrivacyMetric.
9300 9301 9302 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#categorical_stats_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig
Compute numerical stats over an individual column, including number of
distinct values and value count distribution.
Corresponds to the JSON property categoricalStatsConfig
9264 9265 9266 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9264 def categorical_stats_config @categorical_stats_config end |
#delta_presence_estimation_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeltaPresenceEstimationConfig
δ-presence metric, used to estimate how likely it is for an attacker to figure
out that one given individual appears in a de-identified dataset. Similarly to
the k-map metric, we cannot compute δ-presence exactly without knowing the
attack dataset, so we use a statistical model instead.
Corresponds to the JSON property deltaPresenceEstimationConfig
9272 9273 9274 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9272 def delta_presence_estimation_config @delta_presence_estimation_config end |
#k_anonymity_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig
k-anonymity metric, used for analysis of reidentification risk.
Corresponds to the JSON property kAnonymityConfig
9277 9278 9279 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9277 def k_anonymity_config @k_anonymity_config end |
#k_map_estimation_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig
Reidentifiability metric. This corresponds to a risk model similar to what is
called "journalist risk" in the literature, except the attack dataset is
statistically modeled instead of being perfectly known. This can be done using
publicly available data (like the US Census), or using a custom statistical
model (indicated as one or several BigQuery tables), or by extrapolating from
the distribution of values in the input dataset.
Corresponds to the JSON property kMapEstimationConfig
9287 9288 9289 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9287 def k_map_estimation_config @k_map_estimation_config end |
#l_diversity_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2LDiversityConfig
l-diversity metric, used for analysis of reidentification risk.
Corresponds to the JSON property lDiversityConfig
9292 9293 9294 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9292 def l_diversity_config @l_diversity_config end |
#numerical_stats_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2NumericalStatsConfig
Compute numerical stats over an individual column, including min, max, and
quantiles.
Corresponds to the JSON property numericalStatsConfig
9298 9299 9300 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9298 def numerical_stats_config @numerical_stats_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9305 def update!(**args) @categorical_stats_config = args[:categorical_stats_config] if args.key?(:categorical_stats_config) @delta_presence_estimation_config = args[:delta_presence_estimation_config] if args.key?(:delta_presence_estimation_config) @k_anonymity_config = args[:k_anonymity_config] if args.key?(:k_anonymity_config) @k_map_estimation_config = args[:k_map_estimation_config] if args.key?(:k_map_estimation_config) @l_diversity_config = args[:l_diversity_config] if args.key?(:l_diversity_config) @numerical_stats_config = args[:numerical_stats_config] if args.key?(:numerical_stats_config) end |