Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PrivacyMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Privacy metric to compute for reidentification risk analysis.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PrivacyMetric

Returns a new instance of GooglePrivacyDlpV2PrivacyMetric.



8521
8522
8523
# File 'lib/google/apis/dlp_v2/classes.rb', line 8521

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categorical_stats_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2CategoricalStatsConfig

Compute numerical stats over an individual column, including number of distinct values and value count distribution. Corresponds to the JSON property categoricalStatsConfig



8485
8486
8487
# File 'lib/google/apis/dlp_v2/classes.rb', line 8485

def categorical_stats_config
  @categorical_stats_config
end

#delta_presence_estimation_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeltaPresenceEstimationConfig

δ-presence metric, used to estimate how likely it is for an attacker to figure out that one given individual appears in a de-identified dataset. Similarly to the k-map metric, we cannot compute δ-presence exactly without knowing the attack dataset, so we use a statistical model instead. Corresponds to the JSON property deltaPresenceEstimationConfig



8493
8494
8495
# File 'lib/google/apis/dlp_v2/classes.rb', line 8493

def delta_presence_estimation_config
  @delta_presence_estimation_config
end

#k_anonymity_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2KAnonymityConfig

k-anonymity metric, used for analysis of reidentification risk. Corresponds to the JSON property kAnonymityConfig



8498
8499
8500
# File 'lib/google/apis/dlp_v2/classes.rb', line 8498

def k_anonymity_config
  @k_anonymity_config
end

#k_map_estimation_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2KMapEstimationConfig

Reidentifiability metric. This corresponds to a risk model similar to what is called "journalist risk" in the literature, except the attack dataset is statistically modeled instead of being perfectly known. This can be done using publicly available data (like the US Census), or using a custom statistical model (indicated as one or several BigQuery tables), or by extrapolating from the distribution of values in the input dataset. Corresponds to the JSON property kMapEstimationConfig



8508
8509
8510
# File 'lib/google/apis/dlp_v2/classes.rb', line 8508

def k_map_estimation_config
  @k_map_estimation_config
end

#l_diversity_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2LDiversityConfig

l-diversity metric, used for analysis of reidentification risk. Corresponds to the JSON property lDiversityConfig



8513
8514
8515
# File 'lib/google/apis/dlp_v2/classes.rb', line 8513

def l_diversity_config
  @l_diversity_config
end

#numerical_stats_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2NumericalStatsConfig

Compute numerical stats over an individual column, including min, max, and quantiles. Corresponds to the JSON property numericalStatsConfig



8519
8520
8521
# File 'lib/google/apis/dlp_v2/classes.rb', line 8519

def numerical_stats_config
  @numerical_stats_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8526
8527
8528
8529
8530
8531
8532
8533
# File 'lib/google/apis/dlp_v2/classes.rb', line 8526

def update!(**args)
  @categorical_stats_config = args[:categorical_stats_config] if args.key?(:categorical_stats_config)
  @delta_presence_estimation_config = args[:delta_presence_estimation_config] if args.key?(:delta_presence_estimation_config)
  @k_anonymity_config = args[:k_anonymity_config] if args.key?(:k_anonymity_config)
  @k_map_estimation_config = args[:k_map_estimation_config] if args.key?(:k_map_estimation_config)
  @l_diversity_config = args[:l_diversity_config] if args.key?(:l_diversity_config)
  @numerical_stats_config = args[:numerical_stats_config] if args.key?(:numerical_stats_config)
end