Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ProcessingLocation

Returns a new instance of GooglePrivacyDlpV2ProcessingLocation.



8783
8784
8785
# File 'lib/google/apis/dlp_v2/classes.rb', line 8783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#document_fallback_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2DocumentFallbackLocation

Configure document processing to fall back to any of the following processing options if document processing is unavailable in the original request location. Corresponds to the JSON property documentFallbackLocation



8775
8776
8777
# File 'lib/google/apis/dlp_v2/classes.rb', line 8775

def document_fallback_location
  @document_fallback_location
end

#image_fallback_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2ImageFallbackLocation

Configure image processing to fall back to any of the following processing options if image processing is unavailable in the original request location. Corresponds to the JSON property imageFallbackLocation



8781
8782
8783
# File 'lib/google/apis/dlp_v2/classes.rb', line 8781

def image_fallback_location
  @image_fallback_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8788
8789
8790
8791
# File 'lib/google/apis/dlp_v2/classes.rb', line 8788

def update!(**args)
  @document_fallback_location = args[:document_fallback_location] if args.key?(:document_fallback_location)
  @image_fallback_location = args[:image_fallback_location] if args.key?(:image_fallback_location)
end