Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ProcessingLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Configure processing location for discovery and inspection. For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided.
Instance Attribute Summary collapse
-
#document_fallback_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentFallbackLocation
Configure document processing to fall back to any of the following processing options if document processing is unavailable in the original request location.
-
#image_fallback_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageFallbackLocation
Configure image processing to fall back to any of the following processing options if image processing is unavailable in the original request location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ProcessingLocation
constructor
A new instance of GooglePrivacyDlpV2ProcessingLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ProcessingLocation
Returns a new instance of GooglePrivacyDlpV2ProcessingLocation.
8554 8555 8556 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#document_fallback_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DocumentFallbackLocation
Configure document processing to fall back to any of the following processing
options if document processing is unavailable in the original request location.
Corresponds to the JSON property documentFallbackLocation
8546 8547 8548 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8546 def document_fallback_location @document_fallback_location end |
#image_fallback_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ImageFallbackLocation
Configure image processing to fall back to any of the following processing
options if image processing is unavailable in the original request location.
Corresponds to the JSON property imageFallbackLocation
8552 8553 8554 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8552 def image_fallback_location @image_fallback_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8559 8560 8561 8562 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8559 def update!(**args) @document_fallback_location = args[:document_fallback_location] if args.key?(:document_fallback_location) @image_fallback_location = args[:image_fallback_location] if args.key?(:image_fallback_location) end |