Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Success or errors for the profile generation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ProfileStatus

Returns a new instance of GooglePrivacyDlpV2ProfileStatus.



9359
9360
9361
# File 'lib/google/apis/dlp_v2/classes.rb', line 9359

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#statusGoogle::Apis::DlpV2::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property status



9352
9353
9354
# File 'lib/google/apis/dlp_v2/classes.rb', line 9352

def status
  @status
end

#timestampString

Time when the profile generation status was updated Corresponds to the JSON property timestamp

Returns:

  • (String)


9357
9358
9359
# File 'lib/google/apis/dlp_v2/classes.rb', line 9357

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9364
9365
9366
9367
# File 'lib/google/apis/dlp_v2/classes.rb', line 9364

def update!(**args)
  @status = args[:status] if args.key?(:status)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end