Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Success or errors for the profile generation.
Instance Attribute Summary collapse
-
#status ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#timestamp ⇒ String
Time when the profile generation status was updated Corresponds to the JSON property
timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ProfileStatus
constructor
A new instance of GooglePrivacyDlpV2ProfileStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ProfileStatus
Returns a new instance of GooglePrivacyDlpV2ProfileStatus.
8863 8864 8865 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8863 def initialize(**args) update!(**args) end |
Instance Attribute Details
#status ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
8856 8857 8858 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8856 def status @status end |
#timestamp ⇒ String
Time when the profile generation status was updated
Corresponds to the JSON property timestamp
8861 8862 8863 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8861 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8868 8869 8870 8871 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8868 def update!(**args) @status = args[:status] if args.key?(:status) @timestamp = args[:timestamp] if args.key?(:timestamp) end |