Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProjectDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

An aggregated profile for this project, based on the resources profiled within it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ProjectDataProfile

Returns a new instance of GooglePrivacyDlpV2ProjectDataProfile.



8753
8754
8755
# File 'lib/google/apis/dlp_v2/classes.rb', line 8753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



8715
8716
8717
# File 'lib/google/apis/dlp_v2/classes.rb', line 8715

def data_risk_level
  @data_risk_level
end

#file_store_data_profile_countFixnum

The number of file store data profiles generated for this project. Corresponds to the JSON property fileStoreDataProfileCount

Returns:

  • (Fixnum)


8720
8721
8722
# File 'lib/google/apis/dlp_v2/classes.rb', line 8720

def file_store_data_profile_count
  @file_store_data_profile_count
end

#nameString

The resource name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


8725
8726
8727
# File 'lib/google/apis/dlp_v2/classes.rb', line 8725

def name
  @name
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


8730
8731
8732
# File 'lib/google/apis/dlp_v2/classes.rb', line 8730

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



8735
8736
8737
# File 'lib/google/apis/dlp_v2/classes.rb', line 8735

def profile_status
  @profile_status
end

#project_idString

Project ID or account that was profiled. Corresponds to the JSON property projectId

Returns:

  • (String)


8740
8741
8742
# File 'lib/google/apis/dlp_v2/classes.rb', line 8740

def project_id
  @project_id
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



8746
8747
8748
# File 'lib/google/apis/dlp_v2/classes.rb', line 8746

def sensitivity_score
  @sensitivity_score
end

#table_data_profile_countFixnum

The number of table data profiles generated for this project. Corresponds to the JSON property tableDataProfileCount

Returns:

  • (Fixnum)


8751
8752
8753
# File 'lib/google/apis/dlp_v2/classes.rb', line 8751

def table_data_profile_count
  @table_data_profile_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8758
8759
8760
8761
8762
8763
8764
8765
8766
8767
# File 'lib/google/apis/dlp_v2/classes.rb', line 8758

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @file_store_data_profile_count = args[:file_store_data_profile_count] if args.key?(:file_store_data_profile_count)
  @name = args[:name] if args.key?(:name)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_id = args[:project_id] if args.key?(:project_id)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @table_data_profile_count = args[:table_data_profile_count] if args.key?(:table_data_profile_count)
end