Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ProjectDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

An aggregated profile for this project, based on the resources profiled within it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ProjectDataProfile

Returns a new instance of GooglePrivacyDlpV2ProjectDataProfile.



8642
8643
8644
# File 'lib/google/apis/dlp_v2/classes.rb', line 8642

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



8604
8605
8606
# File 'lib/google/apis/dlp_v2/classes.rb', line 8604

def data_risk_level
  @data_risk_level
end

#file_store_data_profile_countFixnum

The number of file store data profiles generated for this project. Corresponds to the JSON property fileStoreDataProfileCount

Returns:

  • (Fixnum)


8609
8610
8611
# File 'lib/google/apis/dlp_v2/classes.rb', line 8609

def file_store_data_profile_count
  @file_store_data_profile_count
end

#nameString

The resource name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


8614
8615
8616
# File 'lib/google/apis/dlp_v2/classes.rb', line 8614

def name
  @name
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


8619
8620
8621
# File 'lib/google/apis/dlp_v2/classes.rb', line 8619

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



8624
8625
8626
# File 'lib/google/apis/dlp_v2/classes.rb', line 8624

def profile_status
  @profile_status
end

#project_idString

Project ID or account that was profiled. Corresponds to the JSON property projectId

Returns:

  • (String)


8629
8630
8631
# File 'lib/google/apis/dlp_v2/classes.rb', line 8629

def project_id
  @project_id
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



8635
8636
8637
# File 'lib/google/apis/dlp_v2/classes.rb', line 8635

def sensitivity_score
  @sensitivity_score
end

#table_data_profile_countFixnum

The number of table data profiles generated for this project. Corresponds to the JSON property tableDataProfileCount

Returns:

  • (Fixnum)


8640
8641
8642
# File 'lib/google/apis/dlp_v2/classes.rb', line 8640

def table_data_profile_count
  @table_data_profile_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8647
8648
8649
8650
8651
8652
8653
8654
8655
8656
# File 'lib/google/apis/dlp_v2/classes.rb', line 8647

def update!(**args)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @file_store_data_profile_count = args[:file_store_data_profile_count] if args.key?(:file_store_data_profile_count)
  @name = args[:name] if args.key?(:name)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_id = args[:project_id] if args.key?(:project_id)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @table_data_profile_count = args[:table_data_profile_count] if args.key?(:table_data_profile_count)
end