Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Proximity
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Proximity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Message for specifying a window around a finding to apply a detection rule.
Instance Attribute Summary collapse
-
#window_after ⇒ Fixnum
Number of characters after the finding to consider.
-
#window_before ⇒ Fixnum
Number of characters before the finding to consider.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Proximity
constructor
A new instance of GooglePrivacyDlpV2Proximity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Proximity
Returns a new instance of GooglePrivacyDlpV2Proximity.
8906 8907 8908 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8906 def initialize(**args) update!(**args) end |
Instance Attribute Details
#window_after ⇒ Fixnum
Number of characters after the finding to consider.
Corresponds to the JSON property windowAfter
8895 8896 8897 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8895 def window_after @window_after end |
#window_before ⇒ Fixnum
Number of characters before the finding to consider. For tabular data, if you
want to modify the likelihood of an entire column of findngs, set this to 1.
For more information, see Hotword example: Set the match likelihood of a
table column.
Corresponds to the JSON property windowBefore
8904 8905 8906 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8904 def window_before @window_before end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8911 8912 8913 8914 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8911 def update!(**args) @window_after = args[:window_after] if args.key?(:window_after) @window_before = args[:window_before] if args.key?(:window_before) end |