Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Proximity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Message for specifying a window around a finding to apply a detection rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Proximity

Returns a new instance of GooglePrivacyDlpV2Proximity.



8677
8678
8679
# File 'lib/google/apis/dlp_v2/classes.rb', line 8677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#window_afterFixnum

Number of characters after the finding to consider. Corresponds to the JSON property windowAfter

Returns:

  • (Fixnum)


8666
8667
8668
# File 'lib/google/apis/dlp_v2/classes.rb', line 8666

def window_after
  @window_after
end

#window_beforeFixnum

Number of characters before the finding to consider. For tabular data, if you want to modify the likelihood of an entire column of findngs, set this to 1. For more information, see Hotword example: Set the match likelihood of a table column. Corresponds to the JSON property windowBefore

Returns:

  • (Fixnum)


8675
8676
8677
# File 'lib/google/apis/dlp_v2/classes.rb', line 8675

def window_before
  @window_before
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8682
8683
8684
8685
# File 'lib/google/apis/dlp_v2/classes.rb', line 8682

def update!(**args)
  @window_after = args[:window_after] if args.key?(:window_after)
  @window_before = args[:window_before] if args.key?(:window_before)
end