Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubNotification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Send a Pub/Sub message into the given Pub/Sub topic to connect other systems to data profile generation. The message payload data will be the byte serialization of DataProfilePubSubMessage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PubSubNotification

Returns a new instance of GooglePrivacyDlpV2PubSubNotification.



8997
8998
8999
# File 'lib/google/apis/dlp_v2/classes.rb', line 8997

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detail_of_messageString

How much data to include in the Pub/Sub message. If the user wishes to limit the size of the message, they can use resource_name and fetch the profile fields they wish to. Per table profile (not per column). Corresponds to the JSON property detailOfMessage

Returns:

  • (String)


8978
8979
8980
# File 'lib/google/apis/dlp_v2/classes.rb', line 8978

def detail_of_message
  @detail_of_message
end

#eventString

The type of event that triggers a Pub/Sub. At most one PubSubNotification per EventType is permitted. Corresponds to the JSON property event

Returns:

  • (String)


8984
8985
8986
# File 'lib/google/apis/dlp_v2/classes.rb', line 8984

def event
  @event
end

#pubsub_conditionGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfilePubSubCondition

A condition for determining whether a Pub/Sub should be triggered. Corresponds to the JSON property pubsubCondition



8989
8990
8991
# File 'lib/google/apis/dlp_v2/classes.rb', line 8989

def pubsub_condition
  @pubsub_condition
end

#topicString

Cloud Pub/Sub topic to send notifications to. Format is projects/project/ topics/topic. Corresponds to the JSON property topic

Returns:

  • (String)


8995
8996
8997
# File 'lib/google/apis/dlp_v2/classes.rb', line 8995

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9002
9003
9004
9005
9006
9007
# File 'lib/google/apis/dlp_v2/classes.rb', line 9002

def update!(**args)
  @detail_of_message = args[:detail_of_message] if args.key?(:detail_of_message)
  @event = args[:event] if args.key?(:event)
  @pubsub_condition = args[:pubsub_condition] if args.key?(:pubsub_condition)
  @topic = args[:topic] if args.key?(:topic)
end