Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PubSubNotification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Send a Pub/Sub message into the given Pub/Sub topic to connect other systems to data profile generation. The message payload data will be the byte serialization of DataProfilePubSubMessage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2PubSubNotification

Returns a new instance of GooglePrivacyDlpV2PubSubNotification.



8879
8880
8881
# File 'lib/google/apis/dlp_v2/classes.rb', line 8879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detail_of_messageString

How much data to include in the Pub/Sub message. If the user wishes to limit the size of the message, they can use resource_name and fetch the profile fields they wish to. Per table profile (not per column). Corresponds to the JSON property detailOfMessage

Returns:

  • (String)


8860
8861
8862
# File 'lib/google/apis/dlp_v2/classes.rb', line 8860

def detail_of_message
  @detail_of_message
end

#eventString

The type of event that triggers a Pub/Sub. At most one PubSubNotification per EventType is permitted. Corresponds to the JSON property event

Returns:

  • (String)


8866
8867
8868
# File 'lib/google/apis/dlp_v2/classes.rb', line 8866

def event
  @event
end

#pubsub_conditionGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfilePubSubCondition

A condition for determining whether a Pub/Sub should be triggered. Corresponds to the JSON property pubsubCondition



8871
8872
8873
# File 'lib/google/apis/dlp_v2/classes.rb', line 8871

def pubsub_condition
  @pubsub_condition
end

#topicString

Cloud Pub/Sub topic to send notifications to. Format is projects/project/ topics/topic. Corresponds to the JSON property topic

Returns:

  • (String)


8877
8878
8879
# File 'lib/google/apis/dlp_v2/classes.rb', line 8877

def topic
  @topic
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8884
8885
8886
8887
8888
8889
# File 'lib/google/apis/dlp_v2/classes.rb', line 8884

def update!(**args)
  @detail_of_message = args[:detail_of_message] if args.key?(:detail_of_message)
  @event = args[:event] if args.key?(:event)
  @pubsub_condition = args[:pubsub_condition] if args.key?(:pubsub_condition)
  @topic = args[:topic] if args.key?(:topic)
end