Class: Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToDataplexCatalog
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2PublishToDataplexCatalog
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Create Dataplex Universal Catalog aspects for profiled resources with the aspect type Sensitive Data Protection Profile. To learn more about aspects, see https://cloud.google.com/sensitive-data-protection/docs/add-aspects.
Instance Attribute Summary collapse
-
#lower_data_risk_to_low ⇒ Boolean
(also: #lower_data_risk_to_low?)
Whether creating a Dataplex Universal Catalog aspect for a profiled resource should lower the risk of the profile for that resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2PublishToDataplexCatalog
constructor
A new instance of GooglePrivacyDlpV2PublishToDataplexCatalog.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2PublishToDataplexCatalog
Returns a new instance of GooglePrivacyDlpV2PublishToDataplexCatalog.
9154 9155 9156 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lower_data_risk_to_low ⇒ Boolean Also known as: lower_data_risk_to_low?
Whether creating a Dataplex Universal Catalog aspect for a profiled resource
should lower the risk of the profile for that resource. This also lowers the
data risk of resources at the lower levels of the resource hierarchy. For
example, reducing the data risk of a table data profile also reduces the data
risk of the constituent column data profiles.
Corresponds to the JSON property lowerDataRiskToLow
9151 9152 9153 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9151 def lower_data_risk_to_low @lower_data_risk_to_low end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9159 9160 9161 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9159 def update!(**args) @lower_data_risk_to_low = args[:lower_data_risk_to_low] if args.key?(:lower_data_risk_to_low) end |