Class: Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiId
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A column with a semantic tag attached.
Instance Attribute Summary collapse
-
#custom_tag ⇒ String
A column can be tagged with a custom tag.
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
-
#inferred ⇒ Google::Apis::DlpV2::GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
-
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiId
constructor
A new instance of GooglePrivacyDlpV2QuasiId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiId
Returns a new instance of GooglePrivacyDlpV2QuasiId.
9080 9081 9082 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_tag ⇒ String
A column can be tagged with a custom tag. In this case, the user must indicate
an auxiliary table that contains statistical information on the possible
values of this column.
Corresponds to the JSON property customTag
9060 9061 9062 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9060 def custom_tag @custom_tag end |
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
9065 9066 9067 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9065 def field @field end |
#inferred ⇒ Google::Apis::DlpV2::GoogleProtobufEmpty
A generic empty message that you can re-use to avoid defining duplicated empty
messages in your APIs. A typical example is to use it as the request or the
response type of an API method. For instance: service Foo rpc Bar(google.
protobuf.Empty) returns (google.protobuf.Empty);
Corresponds to the JSON property inferred
9073 9074 9075 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9073 def inferred @inferred end |
#info_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InfoType
Type of information detected by the API.
Corresponds to the JSON property infoType
9078 9079 9080 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9078 def info_type @info_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9085 9086 9087 9088 9089 9090 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9085 def update!(**args) @custom_tag = args[:custom_tag] if args.key?(:custom_tag) @field = args[:field] if args.key?(:field) @inferred = args[:inferred] if args.key?(:inferred) @info_type = args[:info_type] if args.key?(:info_type) end |