Class: Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdentifierField
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdentifierField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A quasi-identifier column has a custom_tag, used to know which column in the data corresponds to which column in the statistical model.
Instance Attribute Summary collapse
-
#custom_tag ⇒ String
A column can be tagged with a custom tag.
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdentifierField
constructor
A new instance of GooglePrivacyDlpV2QuasiIdentifierField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdentifierField
Returns a new instance of GooglePrivacyDlpV2QuasiIdentifierField.
9800 9801 9802 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9800 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_tag ⇒ String
A column can be tagged with a custom tag. In this case, the user must indicate
an auxiliary table that contains statistical information on the possible
values of this column.
Corresponds to the JSON property customTag
9793 9794 9795 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9793 def custom_tag @custom_tag end |
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
9798 9799 9800 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9798 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9805 9806 9807 9808 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9805 def update!(**args) @custom_tag = args[:custom_tag] if args.key?(:custom_tag) @field = args[:field] if args.key?(:field) end |