Class: Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdentifierField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A quasi-identifier column has a custom_tag, used to know which column in the data corresponds to which column in the statistical model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdentifierField

Returns a new instance of GooglePrivacyDlpV2QuasiIdentifierField.



9136
9137
9138
# File 'lib/google/apis/dlp_v2/classes.rb', line 9136

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_tagString

A column can be tagged with a custom tag. In this case, the user must indicate an auxiliary table that contains statistical information on the possible values of this column. Corresponds to the JSON property customTag

Returns:

  • (String)


9129
9130
9131
# File 'lib/google/apis/dlp_v2/classes.rb', line 9129

def custom_tag
  @custom_tag
end

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



9134
9135
9136
# File 'lib/google/apis/dlp_v2/classes.rb', line 9134

def field
  @field
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9141
9142
9143
9144
# File 'lib/google/apis/dlp_v2/classes.rb', line 9141

def update!(**args)
  @custom_tag = args[:custom_tag] if args.key?(:custom_tag)
  @field = args[:field] if args.key?(:field)
end