Class: Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdentifierField
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2QuasiIdentifierField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A quasi-identifier column has a custom_tag, used to know which column in the data corresponds to which column in the statistical model.
Instance Attribute Summary collapse
-
#custom_tag ⇒ String
A column can be tagged with a custom tag.
-
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdentifierField
constructor
A new instance of GooglePrivacyDlpV2QuasiIdentifierField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2QuasiIdentifierField
Returns a new instance of GooglePrivacyDlpV2QuasiIdentifierField.
8777 8778 8779 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_tag ⇒ String
A column can be tagged with a custom tag. In this case, the user must indicate
an auxiliary table that contains statistical information on the possible
values of this column.
Corresponds to the JSON property customTag
8770 8771 8772 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8770 def custom_tag @custom_tag end |
#field ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2FieldId
General identifier of a data field in a storage service.
Corresponds to the JSON property field
8775 8776 8777 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8775 def field @field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8782 8783 8784 8785 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 8782 def update!(**args) @custom_tag = args[:custom_tag] if args.key?(:custom_tag) @field = args[:field] if args.key?(:field) end |