Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Range
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Range
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Generic half-open interval [start, end)
Instance Attribute Summary collapse
-
#end ⇒ Fixnum
Index of the last character of the range (exclusive).
-
#start ⇒ Fixnum
Index of the first character of the range (inclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Range
constructor
A new instance of GooglePrivacyDlpV2Range.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Range
Returns a new instance of GooglePrivacyDlpV2Range.
9837 9838 9839 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Fixnum
Index of the last character of the range (exclusive).
Corresponds to the JSON property end
9830 9831 9832 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9830 def end @end end |
#start ⇒ Fixnum
Index of the first character of the range (inclusive).
Corresponds to the JSON property start
9835 9836 9837 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9835 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9842 9843 9844 9845 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9842 def update!(**args) @end = args[:end] if args.key?(:end) @start = args[:start] if args.key?(:start) end |