Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RecordLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Location of a finding within a row or record.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RecordLocation

Returns a new instance of GooglePrivacyDlpV2RecordLocation.



8903
8904
8905
# File 'lib/google/apis/dlp_v2/classes.rb', line 8903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#field_idGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property fieldId



8891
8892
8893
# File 'lib/google/apis/dlp_v2/classes.rb', line 8891

def field_id
  @field_id
end

#record_keyGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordKey

Message for a unique key indicating a record that contains a finding. Corresponds to the JSON property recordKey



8896
8897
8898
# File 'lib/google/apis/dlp_v2/classes.rb', line 8896

def record_key
  @record_key
end

#table_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2TableLocation

Location of a finding within a table. Corresponds to the JSON property tableLocation



8901
8902
8903
# File 'lib/google/apis/dlp_v2/classes.rb', line 8901

def table_location
  @table_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8908
8909
8910
8911
8912
# File 'lib/google/apis/dlp_v2/classes.rb', line 8908

def update!(**args)
  @field_id = args[:field_id] if args.key?(:field_id)
  @record_key = args[:record_key] if args.key?(:record_key)
  @table_location = args[:table_location] if args.key?(:table_location)
end