Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RedactImageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to search for potentially sensitive info in an image and redact it by covering it with a colored rectangle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RedactImageRequest

Returns a new instance of GooglePrivacyDlpV2RedactImageRequest.



9417
9418
9419
# File 'lib/google/apis/dlp_v2/classes.rb', line 9417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ByteContentItem

Container for bytes to inspect or redact. Corresponds to the JSON property byteItem



9375
9376
9377
# File 'lib/google/apis/dlp_v2/classes.rb', line 9375

def byte_item
  @byte_item
end

#deidentify_templateString

The full resource name of the de-identification template to use. Settings in the main image_redaction_configs field override the corresponding settings in this de-identification template. The request fails if the type of the template's deidentify_config is not image_transformations. Corresponds to the JSON property deidentifyTemplate

Returns:

  • (String)


9383
9384
9385
# File 'lib/google/apis/dlp_v2/classes.rb', line 9383

def deidentify_template
  @deidentify_template
end

#image_redaction_configsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ImageRedactionConfig>

The configuration for specifying what content to redact from images. Corresponds to the JSON property imageRedactionConfigs



9388
9389
9390
# File 'lib/google/apis/dlp_v2/classes.rb', line 9388

def image_redaction_configs
  @image_redaction_configs
end

#include_findingsBoolean Also known as: include_findings?

Whether the response should include findings along with the redacted image. Corresponds to the JSON property includeFindings

Returns:

  • (Boolean)


9393
9394
9395
# File 'lib/google/apis/dlp_v2/classes.rb', line 9393

def include_findings
  @include_findings
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



9400
9401
9402
# File 'lib/google/apis/dlp_v2/classes.rb', line 9400

def inspect_config
  @inspect_config
end

#inspect_templateString

The full resource name of the inspection template to use. Settings in the main inspect_config field override the corresponding settings in this inspection template. The merge behavior is as follows: - Singular field: The main field's value replaces the value of the corresponding field in the template. - Repeated fields: The field values are appended to the list defined in the template. - Sub-messages and groups: The fields are recursively merged. Corresponds to the JSON property inspectTemplate

Returns:

  • (String)


9410
9411
9412
# File 'lib/google/apis/dlp_v2/classes.rb', line 9410

def inspect_template
  @inspect_template
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


9415
9416
9417
# File 'lib/google/apis/dlp_v2/classes.rb', line 9415

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9422
9423
9424
9425
9426
9427
9428
9429
9430
# File 'lib/google/apis/dlp_v2/classes.rb', line 9422

def update!(**args)
  @byte_item = args[:byte_item] if args.key?(:byte_item)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @image_redaction_configs = args[:image_redaction_configs] if args.key?(:image_redaction_configs)
  @include_findings = args[:include_findings] if args.key?(:include_findings)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
  @location_id = args[:location_id] if args.key?(:location_id)
end