Class: Google::Apis::DlpV2::GooglePrivacyDlpV2RedactImageRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to search for potentially sensitive info in an image and redact it by covering it with a colored rectangle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2RedactImageRequest

Returns a new instance of GooglePrivacyDlpV2RedactImageRequest.



9306
9307
9308
# File 'lib/google/apis/dlp_v2/classes.rb', line 9306

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byte_itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ByteContentItem

Container for bytes to inspect or redact. Corresponds to the JSON property byteItem



9264
9265
9266
# File 'lib/google/apis/dlp_v2/classes.rb', line 9264

def byte_item
  @byte_item
end

#deidentify_templateString

The full resource name of the de-identification template to use. Settings in the main image_redaction_configs field override the corresponding settings in this de-identification template. The request fails if the type of the template's deidentify_config is not image_transformations. Corresponds to the JSON property deidentifyTemplate

Returns:

  • (String)


9272
9273
9274
# File 'lib/google/apis/dlp_v2/classes.rb', line 9272

def deidentify_template
  @deidentify_template
end

#image_redaction_configsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2ImageRedactionConfig>

The configuration for specifying what content to redact from images. Corresponds to the JSON property imageRedactionConfigs



9277
9278
9279
# File 'lib/google/apis/dlp_v2/classes.rb', line 9277

def image_redaction_configs
  @image_redaction_configs
end

#include_findingsBoolean Also known as: include_findings?

Whether the response should include findings along with the redacted image. Corresponds to the JSON property includeFindings

Returns:

  • (Boolean)


9282
9283
9284
# File 'lib/google/apis/dlp_v2/classes.rb', line 9282

def include_findings
  @include_findings
end

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



9289
9290
9291
# File 'lib/google/apis/dlp_v2/classes.rb', line 9289

def inspect_config
  @inspect_config
end

#inspect_templateString

The full resource name of the inspection template to use. Settings in the main inspect_config field override the corresponding settings in this inspection template. The merge behavior is as follows: - Singular field: The main field's value replaces the value of the corresponding field in the template. - Repeated fields: The field values are appended to the list defined in the template. - Sub-messages and groups: The fields are recursively merged. Corresponds to the JSON property inspectTemplate

Returns:

  • (String)


9299
9300
9301
# File 'lib/google/apis/dlp_v2/classes.rb', line 9299

def inspect_template
  @inspect_template
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


9304
9305
9306
# File 'lib/google/apis/dlp_v2/classes.rb', line 9304

def location_id
  @location_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9311
9312
9313
9314
9315
9316
9317
9318
9319
# File 'lib/google/apis/dlp_v2/classes.rb', line 9311

def update!(**args)
  @byte_item = args[:byte_item] if args.key?(:byte_item)
  @deidentify_template = args[:deidentify_template] if args.key?(:deidentify_template)
  @image_redaction_configs = args[:image_redaction_configs] if args.key?(:image_redaction_configs)
  @include_findings = args[:include_findings] if args.key?(:include_findings)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
  @location_id = args[:location_id] if args.key?(:location_id)
end