Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ReidentifyContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to re-identify an item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ReidentifyContentRequest

Returns a new instance of GooglePrivacyDlpV2ReidentifyContentRequest.



9655
9656
9657
# File 'lib/google/apis/dlp_v2/classes.rb', line 9655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



9620
9621
9622
# File 'lib/google/apis/dlp_v2/classes.rb', line 9620

def inspect_config
  @inspect_config
end

#inspect_template_nameString

Template to use. Any configuration directly specified in inspect_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


9628
9629
9630
# File 'lib/google/apis/dlp_v2/classes.rb', line 9628

def inspect_template_name
  @inspect_template_name
end

#itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ContentItem

Type of content to inspect. Corresponds to the JSON property item



9633
9634
9635
# File 'lib/google/apis/dlp_v2/classes.rb', line 9633

def item
  @item
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


9638
9639
9640
# File 'lib/google/apis/dlp_v2/classes.rb', line 9638

def location_id
  @location_id
end

#reidentify_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig

The configuration that controls how the data will change. Corresponds to the JSON property reidentifyConfig



9643
9644
9645
# File 'lib/google/apis/dlp_v2/classes.rb', line 9643

def reidentify_config
  @reidentify_config
end

#reidentify_template_nameString

Template to use. References an instance of DeidentifyTemplate. Any configuration directly specified in reidentify_config or inspect_config will override those set in the template. The DeidentifyTemplate used must include only reversible transformations. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property reidentifyTemplateName

Returns:

  • (String)


9653
9654
9655
# File 'lib/google/apis/dlp_v2/classes.rb', line 9653

def reidentify_template_name
  @reidentify_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9660
9661
9662
9663
9664
9665
9666
9667
# File 'lib/google/apis/dlp_v2/classes.rb', line 9660

def update!(**args)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
  @item = args[:item] if args.key?(:item)
  @location_id = args[:location_id] if args.key?(:location_id)
  @reidentify_config = args[:reidentify_config] if args.key?(:reidentify_config)
  @reidentify_template_name = args[:reidentify_template_name] if args.key?(:reidentify_template_name)
end