Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ReidentifyContentRequest
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2ReidentifyContentRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Request to re-identify an item.
Instance Attribute Summary collapse
-
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process.
-
#inspect_template_name ⇒ String
Template to use.
-
#item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
Type of content to inspect.
-
#location_id ⇒ String
Deprecated.
-
#reidentify_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
The configuration that controls how the data will change.
-
#reidentify_template_name ⇒ String
Template to use.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2ReidentifyContentRequest
constructor
A new instance of GooglePrivacyDlpV2ReidentifyContentRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2ReidentifyContentRequest
Returns a new instance of GooglePrivacyDlpV2ReidentifyContentRequest.
9537 9538 9539 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inspect_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig
Configuration description of the scanning process. When used with
redactContent only info_types and min_likelihood are currently used.
Corresponds to the JSON property inspectConfig
9502 9503 9504 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9502 def inspect_config @inspect_config end |
#inspect_template_name ⇒ String
Template to use. Any configuration directly specified in inspect_config will
override those set in the template. Singular fields that are set in this
request will replace their corresponding fields in the template. Repeated
fields are appended. Singular sub-messages and groups are recursively merged.
Corresponds to the JSON property inspectTemplateName
9510 9511 9512 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9510 def inspect_template_name @inspect_template_name end |
#item ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ContentItem
Type of content to inspect.
Corresponds to the JSON property item
9515 9516 9517 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9515 def item @item end |
#location_id ⇒ String
Deprecated. This field has no effect.
Corresponds to the JSON property locationId
9520 9521 9522 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9520 def location_id @location_id end |
#reidentify_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig
The configuration that controls how the data will change.
Corresponds to the JSON property reidentifyConfig
9525 9526 9527 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9525 def reidentify_config @reidentify_config end |
#reidentify_template_name ⇒ String
Template to use. References an instance of DeidentifyTemplate. Any
configuration directly specified in reidentify_config or inspect_config
will override those set in the template. The DeidentifyTemplate used must
include only reversible transformations. Singular fields that are set in this
request will replace their corresponding fields in the template. Repeated
fields are appended. Singular sub-messages and groups are recursively merged.
Corresponds to the JSON property reidentifyTemplateName
9535 9536 9537 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9535 def reidentify_template_name @reidentify_template_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9542 9543 9544 9545 9546 9547 9548 9549 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9542 def update!(**args) @inspect_config = args[:inspect_config] if args.key?(:inspect_config) @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name) @item = args[:item] if args.key?(:item) @location_id = args[:location_id] if args.key?(:location_id) @reidentify_config = args[:reidentify_config] if args.key?(:reidentify_config) @reidentify_template_name = args[:reidentify_template_name] if args.key?(:reidentify_template_name) end |