Class: Google::Apis::DlpV2::GooglePrivacyDlpV2ReidentifyContentRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request to re-identify an item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2ReidentifyContentRequest

Returns a new instance of GooglePrivacyDlpV2ReidentifyContentRequest.



9426
9427
9428
# File 'lib/google/apis/dlp_v2/classes.rb', line 9426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectConfig

Configuration description of the scanning process. When used with redactContent only info_types and min_likelihood are currently used. Corresponds to the JSON property inspectConfig



9391
9392
9393
# File 'lib/google/apis/dlp_v2/classes.rb', line 9391

def inspect_config
  @inspect_config
end

#inspect_template_nameString

Template to use. Any configuration directly specified in inspect_config will override those set in the template. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property inspectTemplateName

Returns:

  • (String)


9399
9400
9401
# File 'lib/google/apis/dlp_v2/classes.rb', line 9399

def inspect_template_name
  @inspect_template_name
end

#itemGoogle::Apis::DlpV2::GooglePrivacyDlpV2ContentItem

Type of content to inspect. Corresponds to the JSON property item



9404
9405
9406
# File 'lib/google/apis/dlp_v2/classes.rb', line 9404

def item
  @item
end

#location_idString

Deprecated. This field has no effect. Corresponds to the JSON property locationId

Returns:

  • (String)


9409
9410
9411
# File 'lib/google/apis/dlp_v2/classes.rb', line 9409

def location_id
  @location_id
end

#reidentify_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DeidentifyConfig

The configuration that controls how the data will change. Corresponds to the JSON property reidentifyConfig



9414
9415
9416
# File 'lib/google/apis/dlp_v2/classes.rb', line 9414

def reidentify_config
  @reidentify_config
end

#reidentify_template_nameString

Template to use. References an instance of DeidentifyTemplate. Any configuration directly specified in reidentify_config or inspect_config will override those set in the template. The DeidentifyTemplate used must include only reversible transformations. Singular fields that are set in this request will replace their corresponding fields in the template. Repeated fields are appended. Singular sub-messages and groups are recursively merged. Corresponds to the JSON property reidentifyTemplateName

Returns:

  • (String)


9424
9425
9426
# File 'lib/google/apis/dlp_v2/classes.rb', line 9424

def reidentify_template_name
  @reidentify_template_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9431
9432
9433
9434
9435
9436
9437
9438
# File 'lib/google/apis/dlp_v2/classes.rb', line 9431

def update!(**args)
  @inspect_config = args[:inspect_config] if args.key?(:inspect_config)
  @inspect_template_name = args[:inspect_template_name] if args.key?(:inspect_template_name)
  @item = args[:item] if args.key?(:item)
  @location_id = args[:location_id] if args.key?(:location_id)
  @reidentify_config = args[:reidentify_config] if args.key?(:reidentify_config)
  @reidentify_template_name = args[:reidentify_template_name] if args.key?(:reidentify_template_name)
end