Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Result
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Result
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
All Result fields are updated while the job is processing.
Instance Attribute Summary collapse
-
#hybrid_stats ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2HybridInspectStatistics
Statistics related to processing hybrid inspect requests.
-
#info_type_stats ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeStats>
Statistics of how many instances of each info type were found during inspect job.
-
#num_rows_processed ⇒ Fixnum
Number of rows scanned after sampling and time filtering (applicable for row based stores such as BigQuery).
-
#processed_bytes ⇒ Fixnum
Total size in bytes that were processed.
-
#total_estimated_bytes ⇒ Fixnum
Estimate of the number of bytes to process.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Result
constructor
A new instance of GooglePrivacyDlpV2Result.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Result
Returns a new instance of GooglePrivacyDlpV2Result.
9886 9887 9888 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9886 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hybrid_stats ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2HybridInspectStatistics
Statistics related to processing hybrid inspect requests.
Corresponds to the JSON property hybridStats
9862 9863 9864 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9862 def hybrid_stats @hybrid_stats end |
#info_type_stats ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeStats>
Statistics of how many instances of each info type were found during inspect
job.
Corresponds to the JSON property infoTypeStats
9868 9869 9870 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9868 def info_type_stats @info_type_stats end |
#num_rows_processed ⇒ Fixnum
Number of rows scanned after sampling and time filtering (applicable for row
based stores such as BigQuery).
Corresponds to the JSON property numRowsProcessed
9874 9875 9876 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9874 def num_rows_processed @num_rows_processed end |
#processed_bytes ⇒ Fixnum
Total size in bytes that were processed.
Corresponds to the JSON property processedBytes
9879 9880 9881 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9879 def processed_bytes @processed_bytes end |
#total_estimated_bytes ⇒ Fixnum
Estimate of the number of bytes to process.
Corresponds to the JSON property totalEstimatedBytes
9884 9885 9886 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9884 def total_estimated_bytes @total_estimated_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9891 9892 9893 9894 9895 9896 9897 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 9891 def update!(**args) @hybrid_stats = args[:hybrid_stats] if args.key?(:hybrid_stats) @info_type_stats = args[:info_type_stats] if args.key?(:info_type_stats) @num_rows_processed = args[:num_rows_processed] if args.key?(:num_rows_processed) @processed_bytes = args[:processed_bytes] if args.key?(:processed_bytes) @total_estimated_bytes = args[:total_estimated_bytes] if args.key?(:total_estimated_bytes) end |