Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Result

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

All Result fields are updated while the job is processing.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2Result

Returns a new instance of GooglePrivacyDlpV2Result.



9409
9410
9411
# File 'lib/google/apis/dlp_v2/classes.rb', line 9409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hybrid_statsGoogle::Apis::DlpV2::GooglePrivacyDlpV2HybridInspectStatistics

Statistics related to processing hybrid inspect requests. Corresponds to the JSON property hybridStats



9385
9386
9387
# File 'lib/google/apis/dlp_v2/classes.rb', line 9385

def hybrid_stats
  @hybrid_stats
end

#info_type_statsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeStats>

Statistics of how many instances of each info type were found during inspect job. Corresponds to the JSON property infoTypeStats



9391
9392
9393
# File 'lib/google/apis/dlp_v2/classes.rb', line 9391

def info_type_stats
  @info_type_stats
end

#num_rows_processedFixnum

Number of rows scanned after sampling and time filtering (applicable for row based stores such as BigQuery). Corresponds to the JSON property numRowsProcessed

Returns:

  • (Fixnum)


9397
9398
9399
# File 'lib/google/apis/dlp_v2/classes.rb', line 9397

def num_rows_processed
  @num_rows_processed
end

#processed_bytesFixnum

Total size in bytes that were processed. Corresponds to the JSON property processedBytes

Returns:

  • (Fixnum)


9402
9403
9404
# File 'lib/google/apis/dlp_v2/classes.rb', line 9402

def processed_bytes
  @processed_bytes
end

#total_estimated_bytesFixnum

Estimate of the number of bytes to process. Corresponds to the JSON property totalEstimatedBytes

Returns:

  • (Fixnum)


9407
9408
9409
# File 'lib/google/apis/dlp_v2/classes.rb', line 9407

def total_estimated_bytes
  @total_estimated_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9414
9415
9416
9417
9418
9419
9420
# File 'lib/google/apis/dlp_v2/classes.rb', line 9414

def update!(**args)
  @hybrid_stats = args[:hybrid_stats] if args.key?(:hybrid_stats)
  @info_type_stats = args[:info_type_stats] if args.key?(:info_type_stats)
  @num_rows_processed = args[:num_rows_processed] if args.key?(:num_rows_processed)
  @processed_bytes = args[:processed_bytes] if args.key?(:processed_bytes)
  @total_estimated_bytes = args[:total_estimated_bytes] if args.key?(:total_estimated_bytes)
end