Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SaveToGcsFindingsOutput

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Collection of findings saved to a Cloud Storage bucket. This is used as the proto schema for textproto files created when specifying a cloud storage path to save Inspect findings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SaveToGcsFindingsOutput

Returns a new instance of GooglePrivacyDlpV2SaveToGcsFindingsOutput.



9509
9510
9511
# File 'lib/google/apis/dlp_v2/classes.rb', line 9509

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#findingsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Finding>

List of findings. Corresponds to the JSON property findings



9507
9508
9509
# File 'lib/google/apis/dlp_v2/classes.rb', line 9507

def findings
  @findings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9514
9515
9516
# File 'lib/google/apis/dlp_v2/classes.rb', line 9514

def update!(**args)
  @findings = args[:findings] if args.key?(:findings)
end