Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SearchConnectionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Response message for SearchConnections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SearchConnectionsResponse

Returns a new instance of GooglePrivacyDlpV2SearchConnectionsResponse.



9585
9586
9587
# File 'lib/google/apis/dlp_v2/classes.rb', line 9585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Connection>

List of connections that match the search query. Note that only a subset of the fields will be populated, and only "name" is guaranteed to be set. For full details of a Connection, call GetConnection with the name. Corresponds to the JSON property connections



9577
9578
9579
# File 'lib/google/apis/dlp_v2/classes.rb', line 9577

def connections
  @connections
end

#next_page_tokenString

Token to retrieve the next page of results. An empty value means there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9583
9584
9585
# File 'lib/google/apis/dlp_v2/classes.rb', line 9583

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9590
9591
9592
9593
# File 'lib/google/apis/dlp_v2/classes.rb', line 9590

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end