Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Discovery target for credentials and secrets in cloud resource metadata. This target does not include any filtering or frequency controls. Cloud DLP will scan cloud resource metadata for secrets daily. No inspect template should be included in the discovery config for a security benchmarks scan. Instead, the built-in list of secrets and credentials infoTypes will be used (see https:// cloud.google.com/sensitive-data-protection/docs/infotypes-reference# credentials_and_secrets). Credentials and secrets discovered will be reported as vulnerabilities to Security Command Center.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2SecretsDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2SecretsDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2SecretsDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2SecretsDiscoveryTarget.
10658 10659 10660 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10658 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10663 10664 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10663 def update!(**args) end |