Class: Google::Apis::DlpV2::GooglePrivacyDlpV2SecretsDiscoveryTarget

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Discovery target for credentials and secrets in cloud resource metadata. This target does not include any filtering or frequency controls. Cloud DLP will scan cloud resource metadata for secrets daily. No inspect template should be included in the discovery config for a security benchmarks scan. Instead, the built-in list of secrets and credentials infoTypes will be used (see https:// cloud.google.com/sensitive-data-protection/docs/infotypes-reference# credentials_and_secrets). Credentials and secrets discovered will be reported as vulnerabilities to Security Command Center.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2SecretsDiscoveryTarget

Returns a new instance of GooglePrivacyDlpV2SecretsDiscoveryTarget.



10112
10113
10114
# File 'lib/google/apis/dlp_v2/classes.rb', line 10112

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10117
10118
# File 'lib/google/apis/dlp_v2/classes.rb', line 10117

def update!(**args)
end