Class: Google::Apis::DlpV2::GooglePrivacyDlpV2StorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Shared message indicating Cloud storage type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2StorageConfig

Returns a new instance of GooglePrivacyDlpV2StorageConfig.



9753
9754
9755
# File 'lib/google/apis/dlp_v2/classes.rb', line 9753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_query_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryOptions

Options defining BigQuery table and row identifiers. Corresponds to the JSON property bigQueryOptions



9729
9730
9731
# File 'lib/google/apis/dlp_v2/classes.rb', line 9729

def big_query_options
  @big_query_options
end

#cloud_storage_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2CloudStorageOptions

Options defining a file or a set of files within a Cloud Storage bucket. Corresponds to the JSON property cloudStorageOptions



9734
9735
9736
# File 'lib/google/apis/dlp_v2/classes.rb', line 9734

def cloud_storage_options
  @cloud_storage_options
end

#datastore_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2DatastoreOptions

Options defining a data set within Google Cloud Datastore. Corresponds to the JSON property datastoreOptions



9739
9740
9741
# File 'lib/google/apis/dlp_v2/classes.rb', line 9739

def datastore_options
  @datastore_options
end

#hybrid_optionsGoogle::Apis::DlpV2::GooglePrivacyDlpV2HybridOptions

Configuration to control jobs where the content being inspected is outside of Google Cloud Platform. Corresponds to the JSON property hybridOptions



9745
9746
9747
# File 'lib/google/apis/dlp_v2/classes.rb', line 9745

def hybrid_options
  @hybrid_options
end

#timespan_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2TimespanConfig

Configuration of the timespan of the items to include in scanning. Currently only supported when inspecting Cloud Storage and BigQuery. Corresponds to the JSON property timespanConfig



9751
9752
9753
# File 'lib/google/apis/dlp_v2/classes.rb', line 9751

def timespan_config
  @timespan_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9758
9759
9760
9761
9762
9763
9764
# File 'lib/google/apis/dlp_v2/classes.rb', line 9758

def update!(**args)
  @big_query_options = args[:big_query_options] if args.key?(:big_query_options)
  @cloud_storage_options = args[:cloud_storage_options] if args.key?(:cloud_storage_options)
  @datastore_options = args[:datastore_options] if args.key?(:datastore_options)
  @hybrid_options = args[:hybrid_options] if args.key?(:hybrid_options)
  @timespan_config = args[:timespan_config] if args.key?(:timespan_config)
end