Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a scanned table.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time at which the table was created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
-
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#encryption_status ⇒ String
How the table is encrypted.
-
#expiration_time ⇒ String
Optional.
-
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
-
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile.
-
#last_modified_time ⇒ String
The time when this table was last modified Corresponds to the JSON property
lastModifiedTime. -
#name ⇒ String
The name of the profile.
-
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
-
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#table_id ⇒ String
The table ID.
-
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
constructor
A new instance of GooglePrivacyDlpV2TableDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
Returns a new instance of GooglePrivacyDlpV2TableDataProfile.
11321 11322 11323 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
11163 11164 11165 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11163 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time at which the table was created.
Corresponds to the JSON property createTime
11168 11169 11170 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11168 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
11174 11175 11176 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11174 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
11179 11180 11181 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11179 def data_source_type @data_source_type end |
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
Corresponds to the JSON property datasetId
11184 11185 11186 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11184 def dataset_id @dataset_id end |
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored. See https://
docs.cloud.google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property datasetLocation
11190 11191 11192 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11190 def dataset_location @dataset_location end |
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
Corresponds to the JSON property datasetProjectId
11195 11196 11197 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11195 def dataset_project_id @dataset_project_id end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
11200 11201 11202 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11200 def domains @domains end |
#encryption_status ⇒ String
How the table is encrypted.
Corresponds to the JSON property encryptionStatus
11205 11206 11207 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11205 def encryption_status @encryption_status end |
#expiration_time ⇒ String
Optional. The time when this table expires.
Corresponds to the JSON property expirationTime
11210 11211 11212 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11210 def expiration_time @expiration_time end |
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
Corresponds to the JSON property failedColumnCount
11215 11216 11217 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11215 def failed_column_count @failed_column_count end |
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this
TableDataProfile. https://cloud.google.com/apis/design/resource_names#
full_resource_name
Corresponds to the JSON property fullResource
11222 11223 11224 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11222 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time when this table was last modified
Corresponds to the JSON property lastModifiedTime
11227 11228 11229 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11227 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
11232 11233 11234 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11232 def name @name end |
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
Corresponds to the JSON property otherInfoTypes
11237 11238 11239 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11237 def other_info_types @other_info_types end |
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
Corresponds to the JSON property predictedInfoTypes
11242 11243 11244 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11242 def predicted_info_types @predicted_info_types end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
11247 11248 11249 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11247 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
11252 11253 11254 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11252 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
Corresponds to the JSON property projectDataProfile
11257 11258 11259 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11257 def project_data_profile @project_data_profile end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
11262 11263 11264 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11262 def @related_resources end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
11267 11268 11269 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11267 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
11272 11273 11274 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11272 def resource_visibility @resource_visibility end |
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated. This will not be
populated for BigLake tables.
Corresponds to the JSON property rowCount
11278 11279 11280 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11278 def row_count @row_count end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
11285 11286 11287 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11285 def sample_findings_table @sample_findings_table end |
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
Corresponds to the JSON property scannedColumnCount
11290 11291 11292 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11290 def scanned_column_count @scanned_column_count end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
11296 11297 11298 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11296 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile. This will always be set to DONE when the table data
profile is written to another service like BigQuery or Pub/Sub.
Corresponds to the JSON property state
11302 11303 11304 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11302 def state @state end |
#table_id ⇒ String
The table ID.
Corresponds to the JSON property tableId
11307 11308 11309 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11307 def table_id @table_id end |
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
Corresponds to the JSON property tableSizeBytes
11312 11313 11314 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11312 def table_size_bytes @table_size_bytes end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Because tags are attached to Cloud SQL instances rather than Cloud SQL tables,
this field is empty for Cloud SQL table profiles.
Corresponds to the JSON property tags
11319 11320 11321 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11319 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11326 11327 11328 11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 11344 11345 11346 11347 11348 11349 11350 11351 11352 11353 11354 11355 11356 11357 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11326 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @dataset_location = args[:dataset_location] if args.key?(:dataset_location) @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id) @domains = args[:domains] if args.key?(:domains) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @other_info_types = args[:other_info_types] if args.key?(:other_info_types) @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @row_count = args[:row_count] if args.key?(:row_count) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @table_id = args[:table_id] if args.key?(:table_id) @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes) @tags = args[:tags] if args.key?(:tags) end |