Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a scanned table.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time at which the table was created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
-
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#encryption_status ⇒ String
How the table is encrypted.
-
#expiration_time ⇒ String
Optional.
-
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
-
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile.
-
#last_modified_time ⇒ String
The time when this table was last modified Corresponds to the JSON property
lastModifiedTime. -
#name ⇒ String
The name of the profile.
-
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
-
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#table_id ⇒ String
The table ID.
-
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
constructor
A new instance of GooglePrivacyDlpV2TableDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
Returns a new instance of GooglePrivacyDlpV2TableDataProfile.
11315 11316 11317 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11315 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
11157 11158 11159 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11157 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time at which the table was created.
Corresponds to the JSON property createTime
11162 11163 11164 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11162 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
11168 11169 11170 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11168 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
11173 11174 11175 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11173 def data_source_type @data_source_type end |
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
Corresponds to the JSON property datasetId
11178 11179 11180 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11178 def dataset_id @dataset_id end |
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored. See https://
cloud.google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property datasetLocation
11184 11185 11186 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11184 def dataset_location @dataset_location end |
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
Corresponds to the JSON property datasetProjectId
11189 11190 11191 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11189 def dataset_project_id @dataset_project_id end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
11194 11195 11196 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11194 def domains @domains end |
#encryption_status ⇒ String
How the table is encrypted.
Corresponds to the JSON property encryptionStatus
11199 11200 11201 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11199 def encryption_status @encryption_status end |
#expiration_time ⇒ String
Optional. The time when this table expires.
Corresponds to the JSON property expirationTime
11204 11205 11206 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11204 def expiration_time @expiration_time end |
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
Corresponds to the JSON property failedColumnCount
11209 11210 11211 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11209 def failed_column_count @failed_column_count end |
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this
TableDataProfile. https://cloud.google.com/apis/design/resource_names#
full_resource_name
Corresponds to the JSON property fullResource
11216 11217 11218 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11216 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time when this table was last modified
Corresponds to the JSON property lastModifiedTime
11221 11222 11223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11221 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
11226 11227 11228 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11226 def name @name end |
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
Corresponds to the JSON property otherInfoTypes
11231 11232 11233 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11231 def other_info_types @other_info_types end |
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
Corresponds to the JSON property predictedInfoTypes
11236 11237 11238 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11236 def predicted_info_types @predicted_info_types end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
11241 11242 11243 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11241 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
11246 11247 11248 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11246 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
Corresponds to the JSON property projectDataProfile
11251 11252 11253 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11251 def project_data_profile @project_data_profile end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
11256 11257 11258 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11256 def @related_resources end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
11261 11262 11263 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11261 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
11266 11267 11268 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11266 def resource_visibility @resource_visibility end |
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated. This will not be
populated for BigLake tables.
Corresponds to the JSON property rowCount
11272 11273 11274 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11272 def row_count @row_count end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
11279 11280 11281 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11279 def sample_findings_table @sample_findings_table end |
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
Corresponds to the JSON property scannedColumnCount
11284 11285 11286 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11284 def scanned_column_count @scanned_column_count end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
11290 11291 11292 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11290 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile. This will always be set to DONE when the table data
profile is written to another service like BigQuery or Pub/Sub.
Corresponds to the JSON property state
11296 11297 11298 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11296 def state @state end |
#table_id ⇒ String
The table ID.
Corresponds to the JSON property tableId
11301 11302 11303 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11301 def table_id @table_id end |
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
Corresponds to the JSON property tableSizeBytes
11306 11307 11308 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11306 def table_size_bytes @table_size_bytes end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Because tags are attached to Cloud SQL instances rather than Cloud SQL tables,
this field is empty for Cloud SQL table profiles.
Corresponds to the JSON property tags
11313 11314 11315 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11313 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11320 11321 11322 11323 11324 11325 11326 11327 11328 11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 11344 11345 11346 11347 11348 11349 11350 11351 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11320 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @dataset_location = args[:dataset_location] if args.key?(:dataset_location) @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id) @domains = args[:domains] if args.key?(:domains) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @other_info_types = args[:other_info_types] if args.key?(:other_info_types) @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @row_count = args[:row_count] if args.key?(:row_count) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @table_id = args[:table_id] if args.key?(:table_id) @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes) @tags = args[:tags] if args.key?(:tags) end |