Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a scanned table.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time at which the table was created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
-
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#encryption_status ⇒ String
How the table is encrypted.
-
#expiration_time ⇒ String
Optional.
-
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
-
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile.
-
#last_modified_time ⇒ String
The time when this table was last modified Corresponds to the JSON property
lastModifiedTime. -
#name ⇒ String
The name of the profile.
-
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
-
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#table_id ⇒ String
The table ID.
-
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
constructor
A new instance of GooglePrivacyDlpV2TableDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
Returns a new instance of GooglePrivacyDlpV2TableDataProfile.
11308 11309 11310 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
11150 11151 11152 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11150 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time at which the table was created.
Corresponds to the JSON property createTime
11155 11156 11157 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11155 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
11161 11162 11163 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11161 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
11166 11167 11168 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11166 def data_source_type @data_source_type end |
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
Corresponds to the JSON property datasetId
11171 11172 11173 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11171 def dataset_id @dataset_id end |
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored. See https://
cloud.google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property datasetLocation
11177 11178 11179 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11177 def dataset_location @dataset_location end |
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
Corresponds to the JSON property datasetProjectId
11182 11183 11184 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11182 def dataset_project_id @dataset_project_id end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
11187 11188 11189 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11187 def domains @domains end |
#encryption_status ⇒ String
How the table is encrypted.
Corresponds to the JSON property encryptionStatus
11192 11193 11194 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11192 def encryption_status @encryption_status end |
#expiration_time ⇒ String
Optional. The time when this table expires.
Corresponds to the JSON property expirationTime
11197 11198 11199 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11197 def expiration_time @expiration_time end |
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
Corresponds to the JSON property failedColumnCount
11202 11203 11204 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11202 def failed_column_count @failed_column_count end |
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this
TableDataProfile. https://cloud.google.com/apis/design/resource_names#
full_resource_name
Corresponds to the JSON property fullResource
11209 11210 11211 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11209 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time when this table was last modified
Corresponds to the JSON property lastModifiedTime
11214 11215 11216 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11214 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
11219 11220 11221 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11219 def name @name end |
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
Corresponds to the JSON property otherInfoTypes
11224 11225 11226 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11224 def other_info_types @other_info_types end |
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
Corresponds to the JSON property predictedInfoTypes
11229 11230 11231 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11229 def predicted_info_types @predicted_info_types end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
11234 11235 11236 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11234 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
11239 11240 11241 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11239 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
Corresponds to the JSON property projectDataProfile
11244 11245 11246 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11244 def project_data_profile @project_data_profile end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
11249 11250 11251 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11249 def @related_resources end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
11254 11255 11256 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11254 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
11259 11260 11261 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11259 def resource_visibility @resource_visibility end |
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated. This will not be
populated for BigLake tables.
Corresponds to the JSON property rowCount
11265 11266 11267 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11265 def row_count @row_count end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
11272 11273 11274 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11272 def sample_findings_table @sample_findings_table end |
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
Corresponds to the JSON property scannedColumnCount
11277 11278 11279 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11277 def scanned_column_count @scanned_column_count end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
11283 11284 11285 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11283 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile. This will always be set to DONE when the table data
profile is written to another service like BigQuery or Pub/Sub.
Corresponds to the JSON property state
11289 11290 11291 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11289 def state @state end |
#table_id ⇒ String
The table ID.
Corresponds to the JSON property tableId
11294 11295 11296 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11294 def table_id @table_id end |
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
Corresponds to the JSON property tableSizeBytes
11299 11300 11301 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11299 def table_size_bytes @table_size_bytes end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Because tags are attached to Cloud SQL instances rather than Cloud SQL tables,
this field is empty for Cloud SQL table profiles.
Corresponds to the JSON property tags
11306 11307 11308 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11306 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11313 11314 11315 11316 11317 11318 11319 11320 11321 11322 11323 11324 11325 11326 11327 11328 11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 11339 11340 11341 11342 11343 11344 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11313 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @dataset_location = args[:dataset_location] if args.key?(:dataset_location) @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id) @domains = args[:domains] if args.key?(:domains) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @other_info_types = args[:other_info_types] if args.key?(:other_info_types) @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @row_count = args[:row_count] if args.key?(:row_count) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @table_id = args[:table_id] if args.key?(:table_id) @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes) @tags = args[:tags] if args.key?(:tags) end |