Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile

Returns a new instance of GooglePrivacyDlpV2TableDataProfile.



10781
10782
10783
# File 'lib/google/apis/dlp_v2/classes.rb', line 10781

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_snapshotGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Snapshot of the configurations used to generate the profile. Corresponds to the JSON property configSnapshot



10623
10624
10625
# File 'lib/google/apis/dlp_v2/classes.rb', line 10623

def config_snapshot
  @config_snapshot
end

#create_timeString

The time at which the table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10628
10629
10630
# File 'lib/google/apis/dlp_v2/classes.rb', line 10628

def create_time
  @create_time
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



10634
10635
10636
# File 'lib/google/apis/dlp_v2/classes.rb', line 10634

def data_risk_level
  @data_risk_level
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



10639
10640
10641
# File 'lib/google/apis/dlp_v2/classes.rb', line 10639

def data_source_type
  @data_source_type
end

#dataset_idString

If the resource is BigQuery, the dataset ID. Corresponds to the JSON property datasetId

Returns:

  • (String)


10644
10645
10646
# File 'lib/google/apis/dlp_v2/classes.rb', line 10644

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// cloud.google.com/bigquery/docs/locations for supported locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


10650
10651
10652
# File 'lib/google/apis/dlp_v2/classes.rb', line 10650

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


10655
10656
10657
# File 'lib/google/apis/dlp_v2/classes.rb', line 10655

def dataset_project_id
  @dataset_project_id
end

#domainsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>

Domains associated with the profile. Corresponds to the JSON property domains



10660
10661
10662
# File 'lib/google/apis/dlp_v2/classes.rb', line 10660

def domains
  @domains
end

#encryption_statusString

How the table is encrypted. Corresponds to the JSON property encryptionStatus

Returns:

  • (String)


10665
10666
10667
# File 'lib/google/apis/dlp_v2/classes.rb', line 10665

def encryption_status
  @encryption_status
end

#expiration_timeString

Optional. The time when this table expires. Corresponds to the JSON property expirationTime

Returns:

  • (String)


10670
10671
10672
# File 'lib/google/apis/dlp_v2/classes.rb', line 10670

def expiration_time
  @expiration_time
end

#failed_column_countFixnum

The number of columns skipped in the table because of an error. Corresponds to the JSON property failedColumnCount

Returns:

  • (Fixnum)


10675
10676
10677
# File 'lib/google/apis/dlp_v2/classes.rb', line 10675

def failed_column_count
  @failed_column_count
end

#full_resourceString

The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile. https://cloud.google.com/apis/design/resource_names# full_resource_name Corresponds to the JSON property fullResource

Returns:

  • (String)


10682
10683
10684
# File 'lib/google/apis/dlp_v2/classes.rb', line 10682

def full_resource
  @full_resource
end

#last_modified_timeString

The time when this table was last modified Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


10687
10688
10689
# File 'lib/google/apis/dlp_v2/classes.rb', line 10687

def last_modified_time
  @last_modified_time
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


10692
10693
10694
# File 'lib/google/apis/dlp_v2/classes.rb', line 10692

def name
  @name
end

#other_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other infoTypes found in this table's data. Corresponds to the JSON property otherInfoTypes



10697
10698
10699
# File 'lib/google/apis/dlp_v2/classes.rb', line 10697

def other_info_types
  @other_info_types
end

#predicted_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>

The infoTypes predicted from this table's data. Corresponds to the JSON property predictedInfoTypes



10702
10703
10704
# File 'lib/google/apis/dlp_v2/classes.rb', line 10702

def predicted_info_types
  @predicted_info_types
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


10707
10708
10709
# File 'lib/google/apis/dlp_v2/classes.rb', line 10707

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



10712
10713
10714
# File 'lib/google/apis/dlp_v2/classes.rb', line 10712

def profile_status
  @profile_status
end

#project_data_profileString

The resource name of the project data profile for this table. Corresponds to the JSON property projectDataProfile

Returns:

  • (String)


10717
10718
10719
# File 'lib/google/apis/dlp_v2/classes.rb', line 10717

def project_data_profile
  @project_data_profile
end

Resources related to this profile. Corresponds to the JSON property relatedResources



10722
10723
10724
# File 'lib/google/apis/dlp_v2/classes.rb', line 10722

def related_resources
  @related_resources
end

#resource_labelsHash<String,String>

The labels applied to the resource at the time the profile was generated. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


10727
10728
10729
# File 'lib/google/apis/dlp_v2/classes.rb', line 10727

def resource_labels
  @resource_labels
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


10732
10733
10734
# File 'lib/google/apis/dlp_v2/classes.rb', line 10732

def resource_visibility
  @resource_visibility
end

#row_countFixnum

Number of rows in the table when the profile was generated. This will not be populated for BigLake tables. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


10738
10739
10740
# File 'lib/google/apis/dlp_v2/classes.rb', line 10738

def row_count
  @row_count
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



10745
10746
10747
# File 'lib/google/apis/dlp_v2/classes.rb', line 10745

def sample_findings_table
  @sample_findings_table
end

#scanned_column_countFixnum

The number of columns profiled in the table. Corresponds to the JSON property scannedColumnCount

Returns:

  • (Fixnum)


10750
10751
10752
# File 'lib/google/apis/dlp_v2/classes.rb', line 10750

def scanned_column_count
  @scanned_column_count
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



10756
10757
10758
# File 'lib/google/apis/dlp_v2/classes.rb', line 10756

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. This will always be set to DONE when the table data profile is written to another service like BigQuery or Pub/Sub. Corresponds to the JSON property state

Returns:

  • (String)


10762
10763
10764
# File 'lib/google/apis/dlp_v2/classes.rb', line 10762

def state
  @state
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


10767
10768
10769
# File 'lib/google/apis/dlp_v2/classes.rb', line 10767

def table_id
  @table_id
end

#table_size_bytesFixnum

The size of the table when the profile was generated. Corresponds to the JSON property tableSizeBytes

Returns:

  • (Fixnum)


10772
10773
10774
# File 'lib/google/apis/dlp_v2/classes.rb', line 10772

def table_size_bytes
  @table_size_bytes
end

#tagsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>

The tags attached to the table, including any tags attached during profiling. Because tags are attached to Cloud SQL instances rather than Cloud SQL tables, this field is empty for Cloud SQL table profiles. Corresponds to the JSON property tags



10779
10780
10781
# File 'lib/google/apis/dlp_v2/classes.rb', line 10779

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10786
10787
10788
10789
10790
10791
10792
10793
10794
10795
10796
10797
10798
10799
10800
10801
10802
10803
10804
10805
10806
10807
10808
10809
10810
10811
10812
10813
10814
10815
10816
10817
# File 'lib/google/apis/dlp_v2/classes.rb', line 10786

def update!(**args)
  @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @domains = args[:domains] if args.key?(:domains)
  @encryption_status = args[:encryption_status] if args.key?(:encryption_status)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count)
  @full_resource = args[:full_resource] if args.key?(:full_resource)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @other_info_types = args[:other_info_types] if args.key?(:other_info_types)
  @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @row_count = args[:row_count] if args.key?(:row_count)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
  @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_id = args[:table_id] if args.key?(:table_id)
  @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes)
  @tags = args[:tags] if args.key?(:tags)
end