Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The profile for a scanned table.
Instance Attribute Summary collapse
-
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
-
#create_time ⇒ String
The time at which the table was created.
-
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile.
-
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
-
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
-
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored.
-
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
-
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
-
#encryption_status ⇒ String
How the table is encrypted.
-
#expiration_time ⇒ String
Optional.
-
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
-
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile.
-
#last_modified_time ⇒ String
The time when this table was last modified Corresponds to the JSON property
lastModifiedTime. -
#name ⇒ String
The name of the profile.
-
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
-
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
-
#profile_last_generated ⇒ String
The last time the profile was generated.
-
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
-
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
-
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
-
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
-
#resource_visibility ⇒ String
How broadly a resource has been shared.
-
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated.
-
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table.
-
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#state ⇒ String
State of a profile.
-
#table_id ⇒ String
The table ID.
-
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
-
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
constructor
A new instance of GooglePrivacyDlpV2TableDataProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile
Returns a new instance of GooglePrivacyDlpV2TableDataProfile.
10594 10595 10596 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10594 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config_snapshot ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot
Snapshot of the configurations used to generate the profile.
Corresponds to the JSON property configSnapshot
10436 10437 10438 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10436 def config_snapshot @config_snapshot end |
#create_time ⇒ String
The time at which the table was created.
Corresponds to the JSON property createTime
10441 10442 10443 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10441 def create_time @create_time end |
#data_risk_level ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel
Score is a summary of all elements in the data profile. A higher number means
more risk.
Corresponds to the JSON property dataRiskLevel
10447 10448 10449 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10447 def data_risk_level @data_risk_level end |
#data_source_type ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType
Message used to identify the type of resource being profiled.
Corresponds to the JSON property dataSourceType
10452 10453 10454 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10452 def data_source_type @data_source_type end |
#dataset_id ⇒ String
If the resource is BigQuery, the dataset ID.
Corresponds to the JSON property datasetId
10457 10458 10459 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10457 def dataset_id @dataset_id end |
#dataset_location ⇒ String
If supported, the location where the dataset's data is stored. See https://
cloud.google.com/bigquery/docs/locations for supported locations.
Corresponds to the JSON property datasetLocation
10463 10464 10465 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10463 def dataset_location @dataset_location end |
#dataset_project_id ⇒ String
The Google Cloud project ID that owns the resource.
Corresponds to the JSON property datasetProjectId
10468 10469 10470 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10468 def dataset_project_id @dataset_project_id end |
#domains ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>
Domains associated with the profile.
Corresponds to the JSON property domains
10473 10474 10475 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10473 def domains @domains end |
#encryption_status ⇒ String
How the table is encrypted.
Corresponds to the JSON property encryptionStatus
10478 10479 10480 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10478 def encryption_status @encryption_status end |
#expiration_time ⇒ String
Optional. The time when this table expires.
Corresponds to the JSON property expirationTime
10483 10484 10485 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10483 def expiration_time @expiration_time end |
#failed_column_count ⇒ Fixnum
The number of columns skipped in the table because of an error.
Corresponds to the JSON property failedColumnCount
10488 10489 10490 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10488 def failed_column_count @failed_column_count end |
#full_resource ⇒ String
The Cloud Asset Inventory resource that was profiled in order to generate this
TableDataProfile. https://cloud.google.com/apis/design/resource_names#
full_resource_name
Corresponds to the JSON property fullResource
10495 10496 10497 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10495 def full_resource @full_resource end |
#last_modified_time ⇒ String
The time when this table was last modified
Corresponds to the JSON property lastModifiedTime
10500 10501 10502 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10500 def last_modified_time @last_modified_time end |
#name ⇒ String
The name of the profile.
Corresponds to the JSON property name
10505 10506 10507 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10505 def name @name end |
#other_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>
Other infoTypes found in this table's data.
Corresponds to the JSON property otherInfoTypes
10510 10511 10512 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10510 def other_info_types @other_info_types end |
#predicted_info_types ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>
The infoTypes predicted from this table's data.
Corresponds to the JSON property predictedInfoTypes
10515 10516 10517 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10515 def predicted_info_types @predicted_info_types end |
#profile_last_generated ⇒ String
The last time the profile was generated.
Corresponds to the JSON property profileLastGenerated
10520 10521 10522 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10520 def profile_last_generated @profile_last_generated end |
#profile_status ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus
Success or errors for the profile generation.
Corresponds to the JSON property profileStatus
10525 10526 10527 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10525 def profile_status @profile_status end |
#project_data_profile ⇒ String
The resource name of the project data profile for this table.
Corresponds to the JSON property projectDataProfile
10530 10531 10532 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10530 def project_data_profile @project_data_profile end |
#related_resources ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2RelatedResource>
Resources related to this profile.
Corresponds to the JSON property relatedResources
10535 10536 10537 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10535 def @related_resources end |
#resource_labels ⇒ Hash<String,String>
The labels applied to the resource at the time the profile was generated.
Corresponds to the JSON property resourceLabels
10540 10541 10542 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10540 def resource_labels @resource_labels end |
#resource_visibility ⇒ String
How broadly a resource has been shared.
Corresponds to the JSON property resourceVisibility
10545 10546 10547 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10545 def resource_visibility @resource_visibility end |
#row_count ⇒ Fixnum
Number of rows in the table when the profile was generated. This will not be
populated for BigLake tables.
Corresponds to the JSON property rowCount
10551 10552 10553 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10551 def row_count @row_count end |
#sample_findings_table ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable
Message defining the location of a BigQuery table. A table is uniquely
identified by its project_id, dataset_id, and table_name. Within a query a
table is often referenced with a string in the format of: :. or ...
Corresponds to the JSON property sampleFindingsTable
10558 10559 10560 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10558 def sample_findings_table @sample_findings_table end |
#scanned_column_count ⇒ Fixnum
The number of columns profiled in the table.
Corresponds to the JSON property scannedColumnCount
10563 10564 10565 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10563 def scanned_column_count @scanned_column_count end |
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
10569 10570 10571 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10569 def sensitivity_score @sensitivity_score end |
#state ⇒ String
State of a profile. This will always be set to DONE when the table data
profile is written to another service like BigQuery or Pub/Sub.
Corresponds to the JSON property state
10575 10576 10577 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10575 def state @state end |
#table_id ⇒ String
The table ID.
Corresponds to the JSON property tableId
10580 10581 10582 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10580 def table_id @table_id end |
#table_size_bytes ⇒ Fixnum
The size of the table when the profile was generated.
Corresponds to the JSON property tableSizeBytes
10585 10586 10587 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10585 def table_size_bytes @table_size_bytes end |
#tags ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>
The tags attached to the table, including any tags attached during profiling.
Because tags are attached to Cloud SQL instances rather than Cloud SQL tables,
this field is empty for Cloud SQL table profiles.
Corresponds to the JSON property tags
10592 10593 10594 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10592 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10599 10600 10601 10602 10603 10604 10605 10606 10607 10608 10609 10610 10611 10612 10613 10614 10615 10616 10617 10618 10619 10620 10621 10622 10623 10624 10625 10626 10627 10628 10629 10630 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10599 def update!(**args) @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot) @create_time = args[:create_time] if args.key?(:create_time) @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level) @data_source_type = args[:data_source_type] if args.key?(:data_source_type) @dataset_id = args[:dataset_id] if args.key?(:dataset_id) @dataset_location = args[:dataset_location] if args.key?(:dataset_location) @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id) @domains = args[:domains] if args.key?(:domains) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count) @full_resource = args[:full_resource] if args.key?(:full_resource) @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time) @name = args[:name] if args.key?(:name) @other_info_types = args[:other_info_types] if args.key?(:other_info_types) @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types) @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated) @profile_status = args[:profile_status] if args.key?(:profile_status) @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile) @related_resources = args[:related_resources] if args.key?(:related_resources) @resource_labels = args[:resource_labels] if args.key?(:resource_labels) @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility) @row_count = args[:row_count] if args.key?(:row_count) @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table) @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @state = args[:state] if args.key?(:state) @table_id = args[:table_id] if args.key?(:table_id) @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes) @tags = args[:tags] if args.key?(:tags) end |