Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableDataProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

The profile for a scanned table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TableDataProfile

Returns a new instance of GooglePrivacyDlpV2TableDataProfile.



10483
10484
10485
# File 'lib/google/apis/dlp_v2/classes.rb', line 10483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_snapshotGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataProfileConfigSnapshot

Snapshot of the configurations used to generate the profile. Corresponds to the JSON property configSnapshot



10325
10326
10327
# File 'lib/google/apis/dlp_v2/classes.rb', line 10325

def config_snapshot
  @config_snapshot
end

#create_timeString

The time at which the table was created. Corresponds to the JSON property createTime

Returns:

  • (String)


10330
10331
10332
# File 'lib/google/apis/dlp_v2/classes.rb', line 10330

def create_time
  @create_time
end

#data_risk_levelGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataRiskLevel

Score is a summary of all elements in the data profile. A higher number means more risk. Corresponds to the JSON property dataRiskLevel



10336
10337
10338
# File 'lib/google/apis/dlp_v2/classes.rb', line 10336

def data_risk_level
  @data_risk_level
end

#data_source_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2DataSourceType

Message used to identify the type of resource being profiled. Corresponds to the JSON property dataSourceType



10341
10342
10343
# File 'lib/google/apis/dlp_v2/classes.rb', line 10341

def data_source_type
  @data_source_type
end

#dataset_idString

If the resource is BigQuery, the dataset ID. Corresponds to the JSON property datasetId

Returns:

  • (String)


10346
10347
10348
# File 'lib/google/apis/dlp_v2/classes.rb', line 10346

def dataset_id
  @dataset_id
end

#dataset_locationString

If supported, the location where the dataset's data is stored. See https:// cloud.google.com/bigquery/docs/locations for supported locations. Corresponds to the JSON property datasetLocation

Returns:

  • (String)


10352
10353
10354
# File 'lib/google/apis/dlp_v2/classes.rb', line 10352

def dataset_location
  @dataset_location
end

#dataset_project_idString

The Google Cloud project ID that owns the resource. Corresponds to the JSON property datasetProjectId

Returns:

  • (String)


10357
10358
10359
# File 'lib/google/apis/dlp_v2/classes.rb', line 10357

def dataset_project_id
  @dataset_project_id
end

#domainsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Domain>

Domains associated with the profile. Corresponds to the JSON property domains



10362
10363
10364
# File 'lib/google/apis/dlp_v2/classes.rb', line 10362

def domains
  @domains
end

#encryption_statusString

How the table is encrypted. Corresponds to the JSON property encryptionStatus

Returns:

  • (String)


10367
10368
10369
# File 'lib/google/apis/dlp_v2/classes.rb', line 10367

def encryption_status
  @encryption_status
end

#expiration_timeString

Optional. The time when this table expires. Corresponds to the JSON property expirationTime

Returns:

  • (String)


10372
10373
10374
# File 'lib/google/apis/dlp_v2/classes.rb', line 10372

def expiration_time
  @expiration_time
end

#failed_column_countFixnum

The number of columns skipped in the table because of an error. Corresponds to the JSON property failedColumnCount

Returns:

  • (Fixnum)


10377
10378
10379
# File 'lib/google/apis/dlp_v2/classes.rb', line 10377

def failed_column_count
  @failed_column_count
end

#full_resourceString

The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile. https://cloud.google.com/apis/design/resource_names# full_resource_name Corresponds to the JSON property fullResource

Returns:

  • (String)


10384
10385
10386
# File 'lib/google/apis/dlp_v2/classes.rb', line 10384

def full_resource
  @full_resource
end

#last_modified_timeString

The time when this table was last modified Corresponds to the JSON property lastModifiedTime

Returns:

  • (String)


10389
10390
10391
# File 'lib/google/apis/dlp_v2/classes.rb', line 10389

def last_modified_time
  @last_modified_time
end

#nameString

The name of the profile. Corresponds to the JSON property name

Returns:

  • (String)


10394
10395
10396
# File 'lib/google/apis/dlp_v2/classes.rb', line 10394

def name
  @name
end

#other_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2OtherInfoTypeSummary>

Other infoTypes found in this table's data. Corresponds to the JSON property otherInfoTypes



10399
10400
10401
# File 'lib/google/apis/dlp_v2/classes.rb', line 10399

def other_info_types
  @other_info_types
end

#predicted_info_typesArray<Google::Apis::DlpV2::GooglePrivacyDlpV2InfoTypeSummary>

The infoTypes predicted from this table's data. Corresponds to the JSON property predictedInfoTypes



10404
10405
10406
# File 'lib/google/apis/dlp_v2/classes.rb', line 10404

def predicted_info_types
  @predicted_info_types
end

#profile_last_generatedString

The last time the profile was generated. Corresponds to the JSON property profileLastGenerated

Returns:

  • (String)


10409
10410
10411
# File 'lib/google/apis/dlp_v2/classes.rb', line 10409

def profile_last_generated
  @profile_last_generated
end

#profile_statusGoogle::Apis::DlpV2::GooglePrivacyDlpV2ProfileStatus

Success or errors for the profile generation. Corresponds to the JSON property profileStatus



10414
10415
10416
# File 'lib/google/apis/dlp_v2/classes.rb', line 10414

def profile_status
  @profile_status
end

#project_data_profileString

The resource name of the project data profile for this table. Corresponds to the JSON property projectDataProfile

Returns:

  • (String)


10419
10420
10421
# File 'lib/google/apis/dlp_v2/classes.rb', line 10419

def project_data_profile
  @project_data_profile
end

Resources related to this profile. Corresponds to the JSON property relatedResources



10424
10425
10426
# File 'lib/google/apis/dlp_v2/classes.rb', line 10424

def related_resources
  @related_resources
end

#resource_labelsHash<String,String>

The labels applied to the resource at the time the profile was generated. Corresponds to the JSON property resourceLabels

Returns:

  • (Hash<String,String>)


10429
10430
10431
# File 'lib/google/apis/dlp_v2/classes.rb', line 10429

def resource_labels
  @resource_labels
end

#resource_visibilityString

How broadly a resource has been shared. Corresponds to the JSON property resourceVisibility

Returns:

  • (String)


10434
10435
10436
# File 'lib/google/apis/dlp_v2/classes.rb', line 10434

def resource_visibility
  @resource_visibility
end

#row_countFixnum

Number of rows in the table when the profile was generated. This will not be populated for BigLake tables. Corresponds to the JSON property rowCount

Returns:

  • (Fixnum)


10440
10441
10442
# File 'lib/google/apis/dlp_v2/classes.rb', line 10440

def row_count
  @row_count
end

#sample_findings_tableGoogle::Apis::DlpV2::GooglePrivacyDlpV2BigQueryTable

Message defining the location of a BigQuery table. A table is uniquely identified by its project_id, dataset_id, and table_name. Within a query a table is often referenced with a string in the format of: :. or ... Corresponds to the JSON property sampleFindingsTable



10447
10448
10449
# File 'lib/google/apis/dlp_v2/classes.rb', line 10447

def sample_findings_table
  @sample_findings_table
end

#scanned_column_countFixnum

The number of columns profiled in the table. Corresponds to the JSON property scannedColumnCount

Returns:

  • (Fixnum)


10452
10453
10454
# File 'lib/google/apis/dlp_v2/classes.rb', line 10452

def scanned_column_count
  @scanned_column_count
end

#sensitivity_scoreGoogle::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive. Corresponds to the JSON property sensitivityScore



10458
10459
10460
# File 'lib/google/apis/dlp_v2/classes.rb', line 10458

def sensitivity_score
  @sensitivity_score
end

#stateString

State of a profile. This will always be set to DONE when the table data profile is written to another service like BigQuery or Pub/Sub. Corresponds to the JSON property state

Returns:

  • (String)


10464
10465
10466
# File 'lib/google/apis/dlp_v2/classes.rb', line 10464

def state
  @state
end

#table_idString

The table ID. Corresponds to the JSON property tableId

Returns:

  • (String)


10469
10470
10471
# File 'lib/google/apis/dlp_v2/classes.rb', line 10469

def table_id
  @table_id
end

#table_size_bytesFixnum

The size of the table when the profile was generated. Corresponds to the JSON property tableSizeBytes

Returns:

  • (Fixnum)


10474
10475
10476
# File 'lib/google/apis/dlp_v2/classes.rb', line 10474

def table_size_bytes
  @table_size_bytes
end

#tagsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2Tag>

The tags attached to the table, including any tags attached during profiling. Because tags are attached to Cloud SQL instances rather than Cloud SQL tables, this field is empty for Cloud SQL table profiles. Corresponds to the JSON property tags



10481
10482
10483
# File 'lib/google/apis/dlp_v2/classes.rb', line 10481

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10488
10489
10490
10491
10492
10493
10494
10495
10496
10497
10498
10499
10500
10501
10502
10503
10504
10505
10506
10507
10508
10509
10510
10511
10512
10513
10514
10515
10516
10517
10518
10519
# File 'lib/google/apis/dlp_v2/classes.rb', line 10488

def update!(**args)
  @config_snapshot = args[:config_snapshot] if args.key?(:config_snapshot)
  @create_time = args[:create_time] if args.key?(:create_time)
  @data_risk_level = args[:data_risk_level] if args.key?(:data_risk_level)
  @data_source_type = args[:data_source_type] if args.key?(:data_source_type)
  @dataset_id = args[:dataset_id] if args.key?(:dataset_id)
  @dataset_location = args[:dataset_location] if args.key?(:dataset_location)
  @dataset_project_id = args[:dataset_project_id] if args.key?(:dataset_project_id)
  @domains = args[:domains] if args.key?(:domains)
  @encryption_status = args[:encryption_status] if args.key?(:encryption_status)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @failed_column_count = args[:failed_column_count] if args.key?(:failed_column_count)
  @full_resource = args[:full_resource] if args.key?(:full_resource)
  @last_modified_time = args[:last_modified_time] if args.key?(:last_modified_time)
  @name = args[:name] if args.key?(:name)
  @other_info_types = args[:other_info_types] if args.key?(:other_info_types)
  @predicted_info_types = args[:predicted_info_types] if args.key?(:predicted_info_types)
  @profile_last_generated = args[:profile_last_generated] if args.key?(:profile_last_generated)
  @profile_status = args[:profile_status] if args.key?(:profile_status)
  @project_data_profile = args[:project_data_profile] if args.key?(:project_data_profile)
  @related_resources = args[:related_resources] if args.key?(:related_resources)
  @resource_labels = args[:resource_labels] if args.key?(:resource_labels)
  @resource_visibility = args[:resource_visibility] if args.key?(:resource_visibility)
  @row_count = args[:row_count] if args.key?(:row_count)
  @sample_findings_table = args[:sample_findings_table] if args.key?(:sample_findings_table)
  @scanned_column_count = args[:scanned_column_count] if args.key?(:scanned_column_count)
  @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score)
  @state = args[:state] if args.key?(:state)
  @table_id = args[:table_id] if args.key?(:table_id)
  @table_size_bytes = args[:table_size_bytes] if args.key?(:table_size_bytes)
  @tags = args[:tags] if args.key?(:tags)
end