Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TableLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TableLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Location of a finding within a table.
Instance Attribute Summary collapse
-
#row_index ⇒ Fixnum
The zero-based index of the row where the finding is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TableLocation
constructor
A new instance of GooglePrivacyDlpV2TableLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TableLocation
Returns a new instance of GooglePrivacyDlpV2TableLocation.
10646 10647 10648 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#row_index ⇒ Fixnum
The zero-based index of the row where the finding is located. Only populated
for resources that have a natural ordering, not BigQuery. In BigQuery, to
identify the row a finding came from, populate BigQueryOptions.
identifying_fields with your primary key column names and when you store the
findings the value of those columns will be stored inside of Finding.
Corresponds to the JSON property rowIndex
10644 10645 10646 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10644 def row_index @row_index end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10651 10652 10653 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10651 def update!(**args) @row_index = args[:row_index] if args.key?(:row_index) end |