Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Tag
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Tag
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A tag associated with a resource.
Instance Attribute Summary collapse
-
#key ⇒ String
The key of a tag key-value pair.
-
#namespaced_tag_value ⇒ String
The namespaced name for the tag value to attach to Google Cloud resources.
-
#value ⇒ String
The value of a tag key-value pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Tag
constructor
A new instance of GooglePrivacyDlpV2Tag.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Tag
Returns a new instance of GooglePrivacyDlpV2Tag.
10378 10379 10380 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
The key of a tag key-value pair. For Google Cloud resources, this is the
resource name of the key, for example, "tagKeys/123456".
Corresponds to the JSON property key
10361 10362 10363 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10361 def key @key end |
#namespaced_tag_value ⇒ String
The namespaced name for the tag value to attach to Google Cloud resources.
Must be in the format parent_id`/`tag_key_short_name`/`short_name, for
example, "123456/environment/prod" for an organization parent, or "my-project/
environment/prod" for a project parent. This is only set for Google Cloud
resources.
Corresponds to the JSON property namespacedTagValue
10370 10371 10372 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10370 def namespaced_tag_value @namespaced_tag_value end |
#value ⇒ String
The value of a tag key-value pair. For Google Cloud resources, this is the
resource name of the value, for example, "tagValues/123456".
Corresponds to the JSON property value
10376 10377 10378 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10376 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10383 10384 10385 10386 10387 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10383 def update!(**args) @key = args[:key] if args.key?(:key) @namespaced_tag_value = args[:namespaced_tag_value] if args.key?(:namespaced_tag_value) @value = args[:value] if args.key?(:value) end |