Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TagCondition
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TagCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The tag to attach to profiles matching the condition. At most one
TagCondition can be specified per sensitivity level.
Instance Attribute Summary collapse
-
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile.
-
#tag ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TagValue
A value of a tag.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TagCondition
constructor
A new instance of GooglePrivacyDlpV2TagCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TagCondition
Returns a new instance of GooglePrivacyDlpV2TagCondition.
10406 10407 10408 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10406 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sensitivity_score ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2SensitivityScore
Score is calculated from of all elements in the data profile. A higher level
means the data is more sensitive.
Corresponds to the JSON property sensitivityScore
10399 10400 10401 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10399 def sensitivity_score @sensitivity_score end |
#tag ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TagValue
A value of a tag.
Corresponds to the JSON property tag
10404 10405 10406 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10404 def tag @tag end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10411 10412 10413 10414 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10411 def update!(**args) @sensitivity_score = args[:sensitivity_score] if args.key?(:sensitivity_score) @tag = args[:tag] if args.key?(:tag) end |