Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TagResources

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

If set, attaches the tags provided to profiled resources. Tags support access control. You can conditionally grant or deny access to a resource based on whether the resource has a specific tag.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TagResources

Returns a new instance of GooglePrivacyDlpV2TagResources.



10501
10502
10503
# File 'lib/google/apis/dlp_v2/classes.rb', line 10501

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#lower_data_risk_to_lowBoolean Also known as: lower_data_risk_to_low?

Whether applying a tag to a resource should lower the risk of the profile for that resource. For example, in conjunction with an IAM deny policy, you can deny all principals a permission if a tag value is present, mitigating the risk of the resource. This also lowers the data risk of resources at the lower levels of the resource hierarchy. For example, reducing the data risk of a table data profile also reduces the data risk of the constituent column data profiles. Corresponds to the JSON property lowerDataRiskToLow

Returns:

  • (Boolean)


10483
10484
10485
# File 'lib/google/apis/dlp_v2/classes.rb', line 10483

def lower_data_risk_to_low
  @lower_data_risk_to_low
end

#profile_generations_to_tagArray<String>

The profile generations for which the tag should be attached to resources. If you attach a tag to only new profiles, then if the sensitivity score of a profile subsequently changes, its tag doesn't change. By default, this field includes only new profiles. To include both new and updated profiles for tagging, this field should explicitly include both PROFILE_GENERATION_NEW and PROFILE_GENERATION_UPDATE. Corresponds to the JSON property profileGenerationsToTag

Returns:

  • (Array<String>)


10494
10495
10496
# File 'lib/google/apis/dlp_v2/classes.rb', line 10494

def profile_generations_to_tag
  @profile_generations_to_tag
end

#tag_conditionsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2TagCondition>

The tags to associate with different conditions. Corresponds to the JSON property tagConditions



10499
10500
10501
# File 'lib/google/apis/dlp_v2/classes.rb', line 10499

def tag_conditions
  @tag_conditions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10506
10507
10508
10509
10510
# File 'lib/google/apis/dlp_v2/classes.rb', line 10506

def update!(**args)
  @lower_data_risk_to_low = args[:lower_data_risk_to_low] if args.key?(:lower_data_risk_to_low)
  @profile_generations_to_tag = args[:profile_generations_to_tag] if args.key?(:profile_generations_to_tag)
  @tag_conditions = args[:tag_conditions] if args.key?(:tag_conditions)
end