Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TaggedField

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A column with a semantic tag attached.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TaggedField

Returns a new instance of GooglePrivacyDlpV2TaggedField.



11110
11111
11112
# File 'lib/google/apis/dlp_v2/classes.rb', line 11110

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_tagString

A column can be tagged with a custom tag. In this case, the user must indicate an auxiliary table that contains statistical information on the possible values of this column. Corresponds to the JSON property customTag

Returns:

  • (String)


11090
11091
11092
# File 'lib/google/apis/dlp_v2/classes.rb', line 11090

def custom_tag
  @custom_tag
end

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



11095
11096
11097
# File 'lib/google/apis/dlp_v2/classes.rb', line 11095

def field
  @field
end

#inferredGoogle::Apis::DlpV2::GoogleProtobufEmpty

A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo rpc Bar(google. protobuf.Empty) returns (google.protobuf.Empty); Corresponds to the JSON property inferred



11103
11104
11105
# File 'lib/google/apis/dlp_v2/classes.rb', line 11103

def inferred
  @inferred
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



11108
11109
11110
# File 'lib/google/apis/dlp_v2/classes.rb', line 11108

def info_type
  @info_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11115
11116
11117
11118
11119
11120
# File 'lib/google/apis/dlp_v2/classes.rb', line 11115

def update!(**args)
  @custom_tag = args[:custom_tag] if args.key?(:custom_tag)
  @field = args[:field] if args.key?(:field)
  @inferred = args[:inferred] if args.key?(:inferred)
  @info_type = args[:info_type] if args.key?(:info_type)
end