Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Details about a single transformation. This object contains a description of the transformation, information about whether the transformation was successfully applied, and the precise location where the transformation occurred. These details are stored in a user-specified BigQuery table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationDetails

Returns a new instance of GooglePrivacyDlpV2TransformationDetails.



11358
11359
11360
# File 'lib/google/apis/dlp_v2/classes.rb', line 11358

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_nameString

The top level name of the container where the transformation is located (this will be the source file name or table name). Corresponds to the JSON property containerName

Returns:

  • (String)


11325
11326
11327
# File 'lib/google/apis/dlp_v2/classes.rb', line 11325

def container_name
  @container_name
end

#resource_nameString

The name of the job that completed the transformation. Corresponds to the JSON property resourceName

Returns:

  • (String)


11330
11331
11332
# File 'lib/google/apis/dlp_v2/classes.rb', line 11330

def resource_name
  @resource_name
end

#status_detailsGoogle::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus

The outcome of a transformation. Corresponds to the JSON property statusDetails



11335
11336
11337
# File 'lib/google/apis/dlp_v2/classes.rb', line 11335

def status_details
  @status_details
end

#transformationArray<Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDescription>

Description of transformation. This would only contain more than one element if there were multiple matching transformations and which one to apply was ambiguous. Not set for states that contain no transformation, currently only state that contains no transformation is TransformationResultStateType. METADATA_UNRETRIEVABLE. Corresponds to the JSON property transformation



11344
11345
11346
# File 'lib/google/apis/dlp_v2/classes.rb', line 11344

def transformation
  @transformation
end

#transformation_locationGoogle::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation

Specifies the location of a transformation. Corresponds to the JSON property transformationLocation



11349
11350
11351
# File 'lib/google/apis/dlp_v2/classes.rb', line 11349

def transformation_location
  @transformation_location
end

#transformed_bytesFixnum

The number of bytes that were transformed. If transformation was unsuccessful or did not take place because there was no content to transform, this will be zero. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


11356
11357
11358
# File 'lib/google/apis/dlp_v2/classes.rb', line 11356

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11363
11364
11365
11366
11367
11368
11369
11370
# File 'lib/google/apis/dlp_v2/classes.rb', line 11363

def update!(**args)
  @container_name = args[:container_name] if args.key?(:container_name)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @status_details = args[:status_details] if args.key?(:status_details)
  @transformation = args[:transformation] if args.key?(:transformation)
  @transformation_location = args[:transformation_location] if args.key?(:transformation_location)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end