Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDetails
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Details about a single transformation. This object contains a description of the transformation, information about whether the transformation was successfully applied, and the precise location where the transformation occurred. These details are stored in a user-specified BigQuery table.
Instance Attribute Summary collapse
-
#container_name ⇒ String
The top level name of the container where the transformation is located (this will be the source file name or table name).
-
#resource_name ⇒ String
The name of the job that completed the transformation.
-
#status_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
The outcome of a transformation.
-
#transformation ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDescription>
Description of transformation.
-
#transformation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation
Specifies the location of a transformation.
-
#transformed_bytes ⇒ Fixnum
The number of bytes that were transformed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationDetails
constructor
A new instance of GooglePrivacyDlpV2TransformationDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationDetails
Returns a new instance of GooglePrivacyDlpV2TransformationDetails.
11171 11172 11173 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_name ⇒ String
The top level name of the container where the transformation is located (this
will be the source file name or table name).
Corresponds to the JSON property containerName
11138 11139 11140 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11138 def container_name @container_name end |
#resource_name ⇒ String
The name of the job that completed the transformation.
Corresponds to the JSON property resourceName
11143 11144 11145 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11143 def resource_name @resource_name end |
#status_details ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
The outcome of a transformation.
Corresponds to the JSON property statusDetails
11148 11149 11150 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11148 def status_details @status_details end |
#transformation ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationDescription>
Description of transformation. This would only contain more than one element
if there were multiple matching transformations and which one to apply was
ambiguous. Not set for states that contain no transformation, currently only
state that contains no transformation is TransformationResultStateType.
METADATA_UNRETRIEVABLE.
Corresponds to the JSON property transformation
11157 11158 11159 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11157 def transformation @transformation end |
#transformation_location ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation
Specifies the location of a transformation.
Corresponds to the JSON property transformationLocation
11162 11163 11164 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11162 def transformation_location @transformation_location end |
#transformed_bytes ⇒ Fixnum
The number of bytes that were transformed. If transformation was unsuccessful
or did not take place because there was no content to transform, this will be
zero.
Corresponds to the JSON property transformedBytes
11169 11170 11171 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11169 def transformed_bytes @transformed_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11176 11177 11178 11179 11180 11181 11182 11183 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11176 def update!(**args) @container_name = args[:container_name] if args.key?(:container_name) @resource_name = args[:resource_name] if args.key?(:resource_name) @status_details = args[:status_details] if args.key?(:status_details) @transformation = args[:transformation] if args.key?(:transformation) @transformation_location = args[:transformation_location] if args.key?(:transformation_location) @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes) end |