Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the location of a transformation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationLocation

Returns a new instance of GooglePrivacyDlpV2TransformationLocation.



11451
11452
11453
# File 'lib/google/apis/dlp_v2/classes.rb', line 11451

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

Information about the functionality of the container where this finding occurred, if available. Corresponds to the JSON property containerType

Returns:

  • (String)


11435
11436
11437
# File 'lib/google/apis/dlp_v2/classes.rb', line 11435

def container_type
  @container_type
end

#finding_idString

For infotype transformations, link to the corresponding findings ID so that location information does not need to be duplicated. Each findings ID correlates to an entry in the findings output table, this table only gets created when users specify to save findings (add the save findings action to the request). Corresponds to the JSON property findingId

Returns:

  • (String)


11444
11445
11446
# File 'lib/google/apis/dlp_v2/classes.rb', line 11444

def finding_id
  @finding_id
end

#record_transformationGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation

The field in a record to transform. Corresponds to the JSON property recordTransformation



11449
11450
11451
# File 'lib/google/apis/dlp_v2/classes.rb', line 11449

def record_transformation
  @record_transformation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11456
11457
11458
11459
11460
# File 'lib/google/apis/dlp_v2/classes.rb', line 11456

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @record_transformation = args[:record_transformation] if args.key?(:record_transformation)
end