Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Specifies the location of a transformation.
Instance Attribute Summary collapse
-
#container_type ⇒ String
Information about the functionality of the container where this finding occurred, if available.
-
#finding_id ⇒ String
For infotype transformations, link to the corresponding findings ID so that location information does not need to be duplicated.
-
#record_transformation ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation
The field in a record to transform.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationLocation
constructor
A new instance of GooglePrivacyDlpV2TransformationLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationLocation
Returns a new instance of GooglePrivacyDlpV2TransformationLocation.
11153 11154 11155 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#container_type ⇒ String
Information about the functionality of the container where this finding
occurred, if available.
Corresponds to the JSON property containerType
11137 11138 11139 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11137 def container_type @container_type end |
#finding_id ⇒ String
For infotype transformations, link to the corresponding findings ID so that
location information does not need to be duplicated. Each findings ID
correlates to an entry in the findings output table, this table only gets
created when users specify to save findings (add the save findings action to
the request).
Corresponds to the JSON property findingId
11146 11147 11148 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11146 def finding_id @finding_id end |
#record_transformation ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation
The field in a record to transform.
Corresponds to the JSON property recordTransformation
11151 11152 11153 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11151 def record_transformation @record_transformation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11158 11159 11160 11161 11162 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11158 def update!(**args) @container_type = args[:container_type] if args.key?(:container_type) @finding_id = args[:finding_id] if args.key?(:finding_id) @record_transformation = args[:record_transformation] if args.key?(:record_transformation) end |