Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Specifies the location of a transformation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationLocation

Returns a new instance of GooglePrivacyDlpV2TransformationLocation.



10905
10906
10907
# File 'lib/google/apis/dlp_v2/classes.rb', line 10905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

Information about the functionality of the container where this finding occurred, if available. Corresponds to the JSON property containerType

Returns:

  • (String)


10889
10890
10891
# File 'lib/google/apis/dlp_v2/classes.rb', line 10889

def container_type
  @container_type
end

#finding_idString

For infotype transformations, link to the corresponding findings ID so that location information does not need to be duplicated. Each findings ID correlates to an entry in the findings output table, this table only gets created when users specify to save findings (add the save findings action to the request). Corresponds to the JSON property findingId

Returns:

  • (String)


10898
10899
10900
# File 'lib/google/apis/dlp_v2/classes.rb', line 10898

def finding_id
  @finding_id
end

#record_transformationGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordTransformation

The field in a record to transform. Corresponds to the JSON property recordTransformation



10903
10904
10905
# File 'lib/google/apis/dlp_v2/classes.rb', line 10903

def record_transformation
  @record_transformation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10910
10911
10912
10913
10914
# File 'lib/google/apis/dlp_v2/classes.rb', line 10910

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @finding_id = args[:finding_id] if args.key?(:finding_id)
  @record_transformation = args[:record_transformation] if args.key?(:record_transformation)
end