Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The outcome of a transformation.
Instance Attribute Summary collapse
-
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#result_status_type ⇒ String
Transformation result status type, this will be either SUCCESS, or it will be the reason for why the transformation was not completely successful.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationResultStatus
constructor
A new instance of GooglePrivacyDlpV2TransformationResultStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationResultStatus
Returns a new instance of GooglePrivacyDlpV2TransformationResultStatus.
11321 11322 11323 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property details
11313 11314 11315 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11313 def details @details end |
#result_status_type ⇒ String
Transformation result status type, this will be either SUCCESS, or it will be
the reason for why the transformation was not completely successful.
Corresponds to the JSON property resultStatusType
11319 11320 11321 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11319 def result_status_type @result_status_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11326 11327 11328 11329 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11326 def update!(**args) @details = args[:details] if args.key?(:details) @result_status_type = args[:result_status_type] if args.key?(:result_status_type) end |