Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationResultStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
The outcome of a transformation.
Instance Attribute Summary collapse
-
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#result_status_type ⇒ String
Transformation result status type, this will be either SUCCESS, or it will be the reason for why the transformation was not completely successful.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationResultStatus
constructor
A new instance of GooglePrivacyDlpV2TransformationResultStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationResultStatus
Returns a new instance of GooglePrivacyDlpV2TransformationResultStatus.
10962 10963 10964 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10962 def initialize(**args) update!(**args) end |
Instance Attribute Details
#details ⇒ Google::Apis::DlpV2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property details
10954 10955 10956 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10954 def details @details end |
#result_status_type ⇒ String
Transformation result status type, this will be either SUCCESS, or it will be
the reason for why the transformation was not completely successful.
Corresponds to the JSON property resultStatusType
10960 10961 10962 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10960 def result_status_type @result_status_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10967 10968 10969 10970 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 10967 def update!(**args) @details = args[:details] if args.key?(:details) @result_status_type = args[:result_status_type] if args.key?(:result_status_type) end |