Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Summary of a single transformation. Only one of 'transformation', ' field_transformation', or 'record_suppress' will be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationSummary

Returns a new instance of GooglePrivacyDlpV2TransformationSummary.



11493
11494
11495
# File 'lib/google/apis/dlp_v2/classes.rb', line 11493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



11458
11459
11460
# File 'lib/google/apis/dlp_v2/classes.rb', line 11458

def field
  @field
end

#field_transformationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldTransformation>

The field transformation that was applied. If multiple field transformations are requested for a single field, this list will contain all of them; otherwise, only one is supplied. Corresponds to the JSON property fieldTransformations



11465
11466
11467
# File 'lib/google/apis/dlp_v2/classes.rb', line 11465

def field_transformations
  @field_transformations
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



11470
11471
11472
# File 'lib/google/apis/dlp_v2/classes.rb', line 11470

def info_type
  @info_type
end

#record_suppressGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordSuppression

Configuration to suppress records whose suppression conditions evaluate to true. Corresponds to the JSON property recordSuppress



11476
11477
11478
# File 'lib/google/apis/dlp_v2/classes.rb', line 11476

def record_suppress
  @record_suppress
end

#resultsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2SummaryResult>

Collection of all transformations that took place or had an error. Corresponds to the JSON property results



11481
11482
11483
# File 'lib/google/apis/dlp_v2/classes.rb', line 11481

def results
  @results
end

#transformationGoogle::Apis::DlpV2::GooglePrivacyDlpV2PrimitiveTransformation

A rule for transforming a value. Corresponds to the JSON property transformation



11486
11487
11488
# File 'lib/google/apis/dlp_v2/classes.rb', line 11486

def transformation
  @transformation
end

#transformed_bytesFixnum

Total size in bytes that were transformed in some way. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


11491
11492
11493
# File 'lib/google/apis/dlp_v2/classes.rb', line 11491

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11498
11499
11500
11501
11502
11503
11504
11505
11506
# File 'lib/google/apis/dlp_v2/classes.rb', line 11498

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @field_transformations = args[:field_transformations] if args.key?(:field_transformations)
  @info_type = args[:info_type] if args.key?(:info_type)
  @record_suppress = args[:record_suppress] if args.key?(:record_suppress)
  @results = args[:results] if args.key?(:results)
  @transformation = args[:transformation] if args.key?(:transformation)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end