Class: Google::Apis::DlpV2::GooglePrivacyDlpV2TransformationSummary

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Summary of a single transformation. Only one of 'transformation', ' field_transformation', or 'record_suppress' will be set.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2TransformationSummary

Returns a new instance of GooglePrivacyDlpV2TransformationSummary.



11264
11265
11266
# File 'lib/google/apis/dlp_v2/classes.rb', line 11264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldGoogle::Apis::DlpV2::GooglePrivacyDlpV2FieldId

General identifier of a data field in a storage service. Corresponds to the JSON property field



11229
11230
11231
# File 'lib/google/apis/dlp_v2/classes.rb', line 11229

def field
  @field
end

#field_transformationsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2FieldTransformation>

The field transformation that was applied. If multiple field transformations are requested for a single field, this list will contain all of them; otherwise, only one is supplied. Corresponds to the JSON property fieldTransformations



11236
11237
11238
# File 'lib/google/apis/dlp_v2/classes.rb', line 11236

def field_transformations
  @field_transformations
end

#info_typeGoogle::Apis::DlpV2::GooglePrivacyDlpV2InfoType

Type of information detected by the API. Corresponds to the JSON property infoType



11241
11242
11243
# File 'lib/google/apis/dlp_v2/classes.rb', line 11241

def info_type
  @info_type
end

#record_suppressGoogle::Apis::DlpV2::GooglePrivacyDlpV2RecordSuppression

Configuration to suppress records whose suppression conditions evaluate to true. Corresponds to the JSON property recordSuppress



11247
11248
11249
# File 'lib/google/apis/dlp_v2/classes.rb', line 11247

def record_suppress
  @record_suppress
end

#resultsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2SummaryResult>

Collection of all transformations that took place or had an error. Corresponds to the JSON property results



11252
11253
11254
# File 'lib/google/apis/dlp_v2/classes.rb', line 11252

def results
  @results
end

#transformationGoogle::Apis::DlpV2::GooglePrivacyDlpV2PrimitiveTransformation

A rule for transforming a value. Corresponds to the JSON property transformation



11257
11258
11259
# File 'lib/google/apis/dlp_v2/classes.rb', line 11257

def transformation
  @transformation
end

#transformed_bytesFixnum

Total size in bytes that were transformed in some way. Corresponds to the JSON property transformedBytes

Returns:

  • (Fixnum)


11262
11263
11264
# File 'lib/google/apis/dlp_v2/classes.rb', line 11262

def transformed_bytes
  @transformed_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11269
11270
11271
11272
11273
11274
11275
11276
11277
# File 'lib/google/apis/dlp_v2/classes.rb', line 11269

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @field_transformations = args[:field_transformations] if args.key?(:field_transformations)
  @info_type = args[:info_type] if args.key?(:info_type)
  @record_suppress = args[:record_suppress] if args.key?(:record_suppress)
  @results = args[:results] if args.key?(:results)
  @transformation = args[:transformation] if args.key?(:transformation)
  @transformed_bytes = args[:transformed_bytes] if args.key?(:transformed_bytes)
end