Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for UpdateDiscoveryConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Returns a new instance of GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.



11719
11720
11721
# File 'lib/google/apis/dlp_v2/classes.rb', line 11719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



11712
11713
11714
# File 'lib/google/apis/dlp_v2/classes.rb', line 11712

def discovery_config
  @discovery_config
end

#update_maskString

Mask to control which fields get updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


11717
11718
11719
# File 'lib/google/apis/dlp_v2/classes.rb', line 11717

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11724
11725
11726
11727
# File 'lib/google/apis/dlp_v2/classes.rb', line 11724

def update!(**args)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end