Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateDiscoveryConfigRequest
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateDiscoveryConfigRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Request message for UpdateDiscoveryConfig.
Instance Attribute Summary collapse
-
#discovery_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
Configuration for discovery to scan resources for profile generation.
-
#update_mask ⇒ String
Mask to control which fields get updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateDiscoveryConfigRequest
constructor
A new instance of GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateDiscoveryConfigRequest
Returns a new instance of GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.
11650 11651 11652 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#discovery_config ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig
Configuration for discovery to scan resources for profile generation. Only one
discovery configuration may exist per organization, folder, or project. The
generated data profiles are retained according to the data retention policy.
Corresponds to the JSON property discoveryConfig
11643 11644 11645 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11643 def discovery_config @discovery_config end |
#update_mask ⇒ String
Mask to control which fields get updated.
Corresponds to the JSON property updateMask
11648 11649 11650 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11648 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11655 11656 11657 11658 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11655 def update!(**args) @discovery_config = args[:discovery_config] if args.key?(:discovery_config) @update_mask = args[:update_mask] if args.key?(:update_mask) end |