Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for UpdateDiscoveryConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateDiscoveryConfigRequest

Returns a new instance of GooglePrivacyDlpV2UpdateDiscoveryConfigRequest.



11532
11533
11534
# File 'lib/google/apis/dlp_v2/classes.rb', line 11532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discovery_configGoogle::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryConfig

Configuration for discovery to scan resources for profile generation. Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy. Corresponds to the JSON property discoveryConfig



11525
11526
11527
# File 'lib/google/apis/dlp_v2/classes.rb', line 11525

def discovery_config
  @discovery_config
end

#update_maskString

Mask to control which fields get updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


11530
11531
11532
# File 'lib/google/apis/dlp_v2/classes.rb', line 11530

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11537
11538
11539
11540
# File 'lib/google/apis/dlp_v2/classes.rb', line 11537

def update!(**args)
  @discovery_config = args[:discovery_config] if args.key?(:discovery_config)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end