Class: Google::Apis::DlpV2::GooglePrivacyDlpV2UpdateInspectTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Request message for UpdateInspectTemplate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2UpdateInspectTemplateRequest

Returns a new instance of GooglePrivacyDlpV2UpdateInspectTemplateRequest.



11201
11202
11203
# File 'lib/google/apis/dlp_v2/classes.rb', line 11201

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inspect_templateGoogle::Apis::DlpV2::GooglePrivacyDlpV2InspectTemplate

The inspectTemplate contains a configuration (set of types of sensitive data to be detected) to be used anywhere you otherwise would normally specify InspectConfig. See https://cloud.google.com/sensitive-data-protection/docs/ concepts-templates to learn more. Corresponds to the JSON property inspectTemplate



11194
11195
11196
# File 'lib/google/apis/dlp_v2/classes.rb', line 11194

def inspect_template
  @inspect_template
end

#update_maskString

Mask to control which fields get updated. Corresponds to the JSON property updateMask

Returns:

  • (String)


11199
11200
11201
# File 'lib/google/apis/dlp_v2/classes.rb', line 11199

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11206
11207
11208
11209
# File 'lib/google/apis/dlp_v2/classes.rb', line 11206

def update!(**args)
  @inspect_template = args[:inspect_template] if args.key?(:inspect_template)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end