Class: Google::Apis::DlpV2::GooglePrivacyDlpV2Value
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2Value
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Set of primitive values supported by the system. Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a ' Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data.
Instance Attribute Summary collapse
-
#boolean_value ⇒ Boolean
(also: #boolean_value?)
boolean Corresponds to the JSON property
booleanValue. -
#date_value ⇒ Google::Apis::DlpV2::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday.
-
#day_of_week_value ⇒ String
day of week Corresponds to the JSON property
dayOfWeekValue. -
#float_value ⇒ Float
float Corresponds to the JSON property
floatValue. -
#integer_value ⇒ Fixnum
integer Corresponds to the JSON property
integerValue. -
#string_value ⇒ String
string Corresponds to the JSON property
stringValue. -
#time_value ⇒ Google::Apis::DlpV2::GoogleTypeTimeOfDay
Represents a time of day.
-
#timestamp_value ⇒ String
timestamp Corresponds to the JSON property
timestampValue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2Value
constructor
A new instance of GooglePrivacyDlpV2Value.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2Value
Returns a new instance of GooglePrivacyDlpV2Value.
11324 11325 11326 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#boolean_value ⇒ Boolean Also known as: boolean_value?
boolean
Corresponds to the JSON property booleanValue
11277 11278 11279 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11277 def boolean_value @boolean_value end |
#date_value ⇒ Google::Apis::DlpV2::GoogleTypeDate
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property dateValue
11290 11291 11292 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11290 def date_value @date_value end |
#day_of_week_value ⇒ String
day of week
Corresponds to the JSON property dayOfWeekValue
11295 11296 11297 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11295 def day_of_week_value @day_of_week_value end |
#float_value ⇒ Float
float
Corresponds to the JSON property floatValue
11300 11301 11302 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11300 def float_value @float_value end |
#integer_value ⇒ Fixnum
integer
Corresponds to the JSON property integerValue
11305 11306 11307 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11305 def integer_value @integer_value end |
#string_value ⇒ String
string
Corresponds to the JSON property stringValue
11310 11311 11312 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11310 def string_value @string_value end |
#time_value ⇒ Google::Apis::DlpV2::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property timeValue
11317 11318 11319 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11317 def time_value @time_value end |
#timestamp_value ⇒ String
timestamp
Corresponds to the JSON property timestampValue
11322 11323 11324 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11322 def @timestamp_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11329 11330 11331 11332 11333 11334 11335 11336 11337 11338 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11329 def update!(**args) @boolean_value = args[:boolean_value] if args.key?(:boolean_value) @date_value = args[:date_value] if args.key?(:date_value) @day_of_week_value = args[:day_of_week_value] if args.key?(:day_of_week_value) @float_value = args[:float_value] if args.key?(:float_value) @integer_value = args[:integer_value] if args.key?(:integer_value) @string_value = args[:string_value] if args.key?(:string_value) @time_value = args[:time_value] if args.key?(:time_value) @timestamp_value = args[:timestamp_value] if args.key?(:timestamp_value) end |