Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetCollection
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Match dataset resources using regex filters.
Instance Attribute Summary collapse
-
#vertex_dataset_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
A collection of regular expressions to determine what datasets to match against.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetCollection
constructor
A new instance of GooglePrivacyDlpV2VertexDatasetCollection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetCollection
Returns a new instance of GooglePrivacyDlpV2VertexDatasetCollection.
11653 11654 11655 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11653 def initialize(**args) update!(**args) end |
Instance Attribute Details
#vertex_dataset_regexes ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
A collection of regular expressions to determine what datasets to match
against.
Corresponds to the JSON property vertexDatasetRegexes
11651 11652 11653 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11651 def vertex_dataset_regexes @vertex_dataset_regexes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11658 11659 11660 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11658 def update!(**args) @vertex_dataset_regexes = args[:vertex_dataset_regexes] if args.key?(:vertex_dataset_regexes) end |