Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Target used to match against for discovery with Vertex AI datasets.
Instance Attribute Summary collapse
-
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetConditions
Requirements that must be true before a dataset is profiled for the first time.
-
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
-
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
Determines what datasets will have profiles generated within an organization or project.
-
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
How often existing datasets should have their profiles refreshed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
constructor
A new instance of GooglePrivacyDlpV2VertexDatasetDiscoveryTarget.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetDiscoveryTarget
Returns a new instance of GooglePrivacyDlpV2VertexDatasetDiscoveryTarget.
11801 11802 11803 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conditions ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetConditions
Requirements that must be true before a dataset is profiled for the first time.
Corresponds to the JSON property conditions
11781 11782 11783 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11781 def conditions @conditions end |
#disabled ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2Disabled
Do not profile the tables.
Corresponds to the JSON property disabled
11786 11787 11788 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11786 def disabled @disabled end |
#filter ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetFilter
Determines what datasets will have profiles generated within an organization
or project. Includes the ability to filter by regular expression patterns on
project ID or dataset regex.
Corresponds to the JSON property filter
11793 11794 11795 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11793 def filter @filter end |
#generation_cadence ⇒ Google::Apis::DlpV2::GooglePrivacyDlpV2DiscoveryVertexDatasetGenerationCadence
How often existing datasets should have their profiles refreshed. New datasets
are scanned as quickly as possible depending on system capacity.
Corresponds to the JSON property generationCadence
11799 11800 11801 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11799 def generation_cadence @generation_cadence end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11806 11807 11808 11809 11810 11811 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11806 def update!(**args) @conditions = args[:conditions] if args.key?(:conditions) @disabled = args[:disabled] if args.key?(:disabled) @filter = args[:filter] if args.key?(:filter) @generation_cadence = args[:generation_cadence] if args.key?(:generation_cadence) end |