Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

A collection of regular expressions to determine what datasets to match against.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetRegexes

Returns a new instance of GooglePrivacyDlpV2VertexDatasetRegexes.



11964
11965
11966
# File 'lib/google/apis/dlp_v2/classes.rb', line 11964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#patternsArray<Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegex>

Required. The group of regular expression patterns to match against one or more datasets. Maximum of 100 entries. The sum of the lengths of all regular expressions can't exceed 10 KiB. Corresponds to the JSON property patterns



11962
11963
11964
# File 'lib/google/apis/dlp_v2/classes.rb', line 11962

def patterns
  @patterns
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11969
11970
11971
# File 'lib/google/apis/dlp_v2/classes.rb', line 11969

def update!(**args)
  @patterns = args[:patterns] if args.key?(:patterns)
end