Class: Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegexes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
A collection of regular expressions to determine what datasets to match against.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetRegexes
constructor
A new instance of GooglePrivacyDlpV2VertexDatasetRegexes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePrivacyDlpV2VertexDatasetRegexes
Returns a new instance of GooglePrivacyDlpV2VertexDatasetRegexes.
11487 11488 11489 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#patterns ⇒ Array<Google::Apis::DlpV2::GooglePrivacyDlpV2VertexDatasetRegex>
Required. The group of regular expression patterns to match against one or
more datasets. Maximum of 100 entries. The sum of the lengths of all regular
expressions can't exceed 10 KiB.
Corresponds to the JSON property patterns
11485 11486 11487 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11485 def patterns @patterns end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11492 11493 11494 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 11492 def update!(**args) @patterns = args[:patterns] if args.key?(:patterns) end |