Class: Google::Apis::DlpV2::GoogleTypeTimeOfDay

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleTypeTimeOfDay

Returns a new instance of GoogleTypeTimeOfDay.



12778
12779
12780
# File 'lib/google/apis/dlp_v2/classes.rb', line 12778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hoursFixnum

Hours of a day in 24 hour format. Must be greater than or equal to 0 and typically must be less than or equal to 23. An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


12757
12758
12759
# File 'lib/google/apis/dlp_v2/classes.rb', line 12757

def hours
  @hours
end

#minutesFixnum

Minutes of an hour. Must be greater than or equal to 0 and less than or equal to 59. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


12763
12764
12765
# File 'lib/google/apis/dlp_v2/classes.rb', line 12763

def minutes
  @minutes
end

#nanosFixnum

Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and less than or equal to 999,999,999. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


12769
12770
12771
# File 'lib/google/apis/dlp_v2/classes.rb', line 12769

def nanos
  @nanos
end

#secondsFixnum

Seconds of a minute. Must be greater than or equal to 0 and typically must be less than or equal to 59. An API may allow the value 60 if it allows leap- seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


12776
12777
12778
# File 'lib/google/apis/dlp_v2/classes.rb', line 12776

def seconds
  @seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12783
12784
12785
12786
12787
12788
# File 'lib/google/apis/dlp_v2/classes.rb', line 12783

def update!(**args)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
end