Class: Google::Apis::DlpV2::GoogleTypeTimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GoogleTypeTimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeTimeOfDay
constructor
A new instance of GoogleTypeTimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeTimeOfDay
Returns a new instance of GoogleTypeTimeOfDay.
12213 12214 12215 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
12192 12193 12194 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12192 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
12198 12199 12200 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12198 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
12204 12205 12206 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12204 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
12211 12212 12213 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12211 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12218 12219 12220 12221 12222 12223 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12218 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |