Class: Google::Apis::DlpV2::GoogleTypeTimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::DlpV2::GoogleTypeTimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeTimeOfDay
constructor
A new instance of GoogleTypeTimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeTimeOfDay
Returns a new instance of GoogleTypeTimeOfDay.
12026 12027 12028 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
12005 12006 12007 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12005 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
12011 12012 12013 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12011 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
12017 12018 12019 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12017 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
12024 12025 12026 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12024 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12031 12032 12033 12034 12035 12036 |
# File 'lib/google/apis/dlp_v2/classes.rb', line 12031 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |