Class: Google::Apis::DlpV2::UtilStatusProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/dlp_v2/classes.rb,
lib/google/apis/dlp_v2/representations.rb,
lib/google/apis/dlp_v2/representations.rb

Overview

Wire-format for a Status object

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UtilStatusProto

Returns a new instance of UtilStatusProto.



12222
12223
12224
# File 'lib/google/apis/dlp_v2/classes.rb', line 12222

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#canonical_codeFixnum

copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6; Corresponds to the JSON property canonicalCode

Returns:

  • (Fixnum)


12186
12187
12188
# File 'lib/google/apis/dlp_v2/classes.rb', line 12186

def canonical_code
  @canonical_code
end

#codeFixnum

Numeric code drawn from the space specified below. Often, this is the canonical error space, and code is drawn from google3/util/task/codes.proto copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 code = 1; Corresponds to the JSON property code

Returns:

  • (Fixnum)


12194
12195
12196
# File 'lib/google/apis/dlp_v2/classes.rb', line 12194

def code
  @code
end

#messageString

Detail message copybara:strip_begin(b/383363683) copybara: strip_end_and_replace optional string message = 3; Corresponds to the JSON property message

Returns:

  • (String)


12200
12201
12202
# File 'lib/google/apis/dlp_v2/classes.rb', line 12200

def message
  @message
end

#message_setGoogle::Apis::DlpV2::Proto2BridgeMessageSet

This is proto2's version of MessageSet. DEPRECATED: DO NOT USE FOR NEW FIELDS. If you are using editions or proto2, please make your own extendable messages for your use case. If you are using proto3, please use Any instead. MessageSet was the implementation of extensions for proto1. When proto2 was introduced, extensions were implemented as a first-class feature. This schema for MessageSet was meant to be a "bridge" solution to migrate MessageSet- bearing messages from proto1 to proto2. This schema has been open-sourced only to facilitate the migration of Google products with MessageSet-bearing messages to open-source environments. Corresponds to the JSON property messageSet



12213
12214
12215
# File 'lib/google/apis/dlp_v2/classes.rb', line 12213

def message_set
  @message_set
end

#spaceString

copybara:strip_begin(b/383363683) Space to which this status belongs copybara: strip_end_and_replace optional string space = 2; // Space to which this status belongs Corresponds to the JSON property space

Returns:

  • (String)


12220
12221
12222
# File 'lib/google/apis/dlp_v2/classes.rb', line 12220

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12227
12228
12229
12230
12231
12232
12233
# File 'lib/google/apis/dlp_v2/classes.rb', line 12227

def update!(**args)
  @canonical_code = args[:canonical_code] if args.key?(:canonical_code)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @message_set = args[:message_set] if args.key?(:message_set)
  @space = args[:space] if args.key?(:space)
end